import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.SortedMap;
import java.util.TreeMap;
import java.util.stream.Collectors;

public class BathroomStalls {

  public static void main(String[] args) throws IOException {

    InputStream in = System.in;

    BufferedReader reader =
        new BufferedReader(new InputStreamReader(in));

    int totalTestCases = Integer.valueOf(reader.readLine());

    List<Result> results = new ArrayList<>();

    for (int testcase = 1; testcase <= totalTestCases; testcase++) {

      String[] inputData = reader.readLine().split(" ");

      // adding +1 since 2 guards are always present
      Long maxIndexOfStalls = Long.parseLong(inputData[0]) + 1;
      Long noOfPeople = Long.parseLong(inputData[1]);

      SortedMap<Long, List<AvailableRange>> rangesByDiff = new TreeMap<>();
      List<AvailableRange> initialList = new ArrayList<>();
      initialList.add(new AvailableRange(0l, maxIndexOfStalls));
      rangesByDiff.put(maxIndexOfStalls - 1, initialList);

      results.add(getLastResult(noOfPeople, rangesByDiff));
    }

    for (int testcase = 1; testcase <= totalTestCases; testcase++) {
      System.out.println("Case #" + testcase + ": " + results.get(testcase - 1).max + " " + results
          .get(testcase - 1).min);
    }
  }

  private static Result getLastResult(Long noOfPeople,
                                      SortedMap<Long, List<AvailableRange>> rangesByDiff) {

    SortedMap<Long, List<AvailableRange>> children = new TreeMap<>();

    List<AvailableRange> allRanges = rangesByDiff.entrySet()
        .stream()
        .flatMap(entry -> entry.getValue().stream())
        .collect(Collectors.toList());

    Collections.reverse(allRanges);

    for (AvailableRange range : allRanges) {

      Long mid = range.lowerBound + ((range.upperBound - range.lowerBound) / 2);

      if (noOfPeople == 1) {
        long max;
        long min;

        if ((range.upperBound - mid) > (mid - range.lowerBound)) {
          max = range.upperBound - mid - 1;
          min = mid - range.lowerBound - 1;
        } else {
          max = mid - range.lowerBound - 1;
          min = range.upperBound - mid - 1;
        }

        return new Result(max, min);
      }

      if (children.containsKey((mid - range.lowerBound - 1))) {
        children.get((mid - range.lowerBound - 1)).add(new AvailableRange(range.lowerBound, mid));
      } else {
        List<AvailableRange> ranges = new ArrayList<>();
        ranges.add(new AvailableRange(range.lowerBound, mid));
        children.put((mid - range.lowerBound - 1), ranges);
      }

      if (children.containsKey(range.upperBound - mid - 1)) {
        children.get(range.upperBound - mid - 1).add(new AvailableRange(mid, range.upperBound));
      } else {
        List<AvailableRange> ranges = new ArrayList<>();
        ranges.add(new AvailableRange(mid, range.upperBound));
        children.put(range.upperBound - mid - 1, ranges);
      }

      noOfPeople--;
    }

    children.remove(0L);

    return getLastResult(noOfPeople, children);
  }

  public static class Result {

    public Result(Long max, Long min) {
      this.max = max;
      this.min = min;
    }

    public Long max = 0l;
    public Long min = 0l;
  }

  public static class AvailableRange {

    public AvailableRange(Long lowerBound, Long upperBound) {
      this.lowerBound = lowerBound;
      this.upperBound = upperBound;
    }

    public Long upperBound = 0l;
    public Long lowerBound = 0l;
  }

}
