import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;
import java.util.SortedSet;
import java.util.TreeSet;

public class BathroomStalls {

  public static void main(String[] args) throws IOException {

    InputStream in = System.in;

    BufferedReader reader =
        new BufferedReader(new InputStreamReader(in));

    int totalTestCases = Integer.valueOf(reader.readLine());

    List<Distance> results = new ArrayList<>();

    for (int testcase = 1; testcase <= totalTestCases; testcase++) {

      final String[] inputData = reader.readLine().split(" ");

      // adding +1 since 2 guards are always present
      Long maxIndexOfStalls = Long.parseLong(inputData[0]) + 1;
      Long noOfPeople = Long.parseLong(inputData[1]);

      SortedSet<Long> occupiedIndexes = new TreeSet<>();
      occupiedIndexes.add(0l);
      occupiedIndexes.add(maxIndexOfStalls);

      Long preferredStallIndex = 0l;
      for (Long person = 1l; person <= noOfPeople; person++) {
        preferredStallIndex = getPreferredStallIndex(occupiedIndexes);
        occupiedIndexes.add(preferredStallIndex);
      }

      results.add(getDistance(preferredStallIndex, occupiedIndexes));
    }

    for (int testcase = 1; testcase <= totalTestCases; testcase++) {
      System.out.println("Case #" + testcase + ": " + results.get(testcase - 1).max + " " + results
          .get(testcase - 1).min);
    }
  }

  private static Distance getDistance(Long preferredStallIndex, SortedSet<Long> occupiedIndexes) {
    Distance distance = new Distance();

    Long previous = 0l;
    Long next = 0l;

    boolean terminateNext = false;

    for (Long occupiedIndex : occupiedIndexes) {

      if (terminateNext) {
        next = occupiedIndex;
        break;
      }

      if (preferredStallIndex.equals(occupiedIndex)) {
        terminateNext = true;
      } else {
        previous = occupiedIndex;
      }
    }

    distance.min = preferredStallIndex - previous - 1;
    distance.max = next - preferredStallIndex - 1;
    return distance;
  }

  private static Long getPreferredStallIndex(SortedSet<Long> occupiedIndexes) {
    Long maxQuotient = -1l;
    Long preferredStallIndex = -1l;
    Long previousRemainder = 0l;

    boolean isFirstElement = true;

    Long previousIndex = 0l;

    for (Long occupiedIndex : occupiedIndexes) {

      if (isFirstElement) {
        previousIndex = occupiedIndex;
        isFirstElement = false;
      } else {
        final long difference = occupiedIndex - previousIndex;
        Long quotient = difference / 2;
        Long remainder = difference % 2;

        if (quotient > 0 && quotient > maxQuotient ||
            quotient > 0 && quotient.equals(maxQuotient) && remainder > previousRemainder) {
          maxQuotient = quotient;
          preferredStallIndex = previousIndex + quotient;
          previousRemainder = remainder;
        }
        previousIndex = occupiedIndex;
      }
    }

    return preferredStallIndex;
  }

  public static class Distance {

    public Long max = 0l;
    public Long min = 0l;
  }

}
