package cj1a;

import static java.lang.Double.parseDouble;
import static java.lang.Integer.parseInt;
import static java.lang.Long.parseLong;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.util.StringTokenizer;

public class Ratatouille {

  private static StringTokenizer stringTokenizer;
  private static BufferedReader inputBufferReader;
  private static PrintWriter printWriter;
  private static int currentTest;

  public static void main(String[] args) {
    try {
      printWriter = new PrintWriter(new OutputStreamWriter(System.out));
      inputBufferReader = new BufferedReader(new InputStreamReader(System.in));
      int tests = nextInt();
      for (currentTest = 1; currentTest <= tests; currentTest++) {
        solve();
      }
      inputBufferReader.close();
      printWriter.close();
    } catch (Throwable e) {
      e.printStackTrace();
    }
  }

  private static void solve() throws IOException {

    int numberOfIngredients = nextInt();
    int numberOfPackages = nextInt();

    int[] quantityOfIngredientsNeeded = new int[numberOfIngredients];

    int[][] ingredientsToPackageWeight = new int[numberOfIngredients][numberOfPackages];

    // Read quantity needed
    for (int ingredient = 0; ingredient < numberOfIngredients; ingredient++) {
      quantityOfIngredientsNeeded[ingredient] = nextInt();
    }

    // Read available packages
    for (int ingredient = 0; ingredient < numberOfIngredients; ingredient++) {
      for (int pkg = 0; pkg < numberOfPackages; pkg++) {
        ingredientsToPackageWeight[ingredient][pkg] = nextInt();
      }
    }

    // Update max count
    for (int ingredient = 0; ingredient < numberOfIngredients; ingredient++) {
      for (int pkg = 0; pkg < numberOfPackages; pkg++) {

        if (ingredientsToPackageWeight[ingredient][pkg] % quantityOfIngredientsNeeded[ingredient]
            != 0) {

          int temp =
              ingredientsToPackageWeight[ingredient][pkg] / quantityOfIngredientsNeeded[ingredient];

          if (((
              ingredientsToPackageWeight[ingredient][pkg] - (quantityOfIngredientsNeeded[ingredient]
                  * (temp + 1) * 0.9)) >= 0) && ((
              ingredientsToPackageWeight[ingredient][pkg] - (quantityOfIngredientsNeeded[ingredient]
                  * (temp + 1) * 1.1)) <= 0)) {
            ingredientsToPackageWeight[ingredient][pkg] = temp + 1;
          } else if (((
              ingredientsToPackageWeight[ingredient][pkg] - (quantityOfIngredientsNeeded[ingredient]
                  * (temp) * 0.9)) >= 0) && ((
              ingredientsToPackageWeight[ingredient][pkg] - (quantityOfIngredientsNeeded[ingredient]
                  * (temp) * 1.1)) <= 0)) {
            ingredientsToPackageWeight[ingredient][pkg] = temp;
          } else {
            ingredientsToPackageWeight[ingredient][pkg] = -2;
          }
        } else {
          ingredientsToPackageWeight[ingredient][pkg] =
              ingredientsToPackageWeight[ingredient][pkg] / quantityOfIngredientsNeeded[ingredient];
        }
      }
    }

    printCase();

    int total = 0;
    for (int pkg = 0; pkg < numberOfPackages; pkg++) {
      if (ingredientsToPackageWeight[0][pkg] !=-2 &&
          ifAllPresent(numberOfIngredients, numberOfPackages, ingredientsToPackageWeight[0][pkg],
          ingredientsToPackageWeight)) {
        total++;

        resetAll(numberOfIngredients, numberOfPackages, ingredientsToPackageWeight[0][pkg],
            ingredientsToPackageWeight);
        ingredientsToPackageWeight[0][pkg] = -1;
      }
    }
    printWriter.println(total);

  }

  private static boolean resetAll(int rows, int columns, int value, int[][] content) {
    for (int r = 1; r < rows; r++) {
      int res = isPresent(r, columns, value, content);

      content[r][res] = -1;
    }

    return true;
  }

  private static boolean ifAllPresent(int rows, int columns, int value, int[][] content) {
    for (int r = 1; r < rows; r++) {
      int res = isPresent(r, columns, value, content);

      if (res == -3) {
        return false;
      }
    }

    return true;
  }


  private static int isPresent(int row, int columns, int value, int[][] content) {
    for (int col = 0; col < columns; col++) {
      if (content[row][col] == value) {
        return col;
      }
    }

    return -3;
  }


  private static void printCase() {
    printWriter.print("Case #" + currentTest + ": ");
  }

  private static int nextInt() throws IOException {
    return parseInt(next());
  }

  static long nextLong() throws IOException {
    return parseLong(next());
  }

  static double nextDouble() throws IOException {
    return parseDouble(next());
  }

  private static String next() throws IOException {
    while (stringTokenizer == null || !stringTokenizer.hasMoreTokens()) {
      stringTokenizer = new StringTokenizer(inputBufferReader.readLine());
    }
    return stringTokenizer.nextToken();
  }

}