import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.PrintWriter;
import java.io.StreamTokenizer;
import java.text.DecimalFormat;
import java.util.Random;


public class Aerobics {

	public static void main(String[] args) throws Exception {
		Aerobics object = new Aerobics();
			object.solve(object.getClass().getSimpleName().toLowerCase());
		}
	
	private static double distance(double x1, double y1, double x2, double y2)
	{
		double xd = (x2-x1);
		double yd = (y2-y1);
		
		return Math.sqrt((xd*xd) + (yd*yd));
	}
	
	private static boolean intersects(double x1, double y1, double x2, double y2, double r1, double r2)
	{
		if (distance(x1, y1, x2, y2) < r1 + r2 + 1e-6)
			return true;
		
		return false;
	}
	
	public static Random random = new Random();
		
		private void solve(String filePrefix) throws Exception {
			
			StreamTokenizer st = new StreamTokenizer(new BufferedReader(new FileReader(filePrefix + ".in")));
			PrintWriter pw = new PrintWriter(new FileWriter(filePrefix + ".out"));
			
			st.nextToken();
			int testsCount = (int) st.nval;
			
			for (int tc=0; tc<testsCount; tc++)
			{
				st.nextToken();
				int n = (int) st.nval;
				
				st.nextToken();
				int w = (int) st.nval;
				
				st.nextToken();
				int l = (int) st.nval;
				
				int r[] = new int[n];
				for (int i=0; i<n; i++)
				{
					st.nextToken();
					r[i] = (int) st.nval;
				}
				
				String solution = null;
				
				int indexes[] = new int[n];
				for (int i=0; i<n; i++)
					indexes[i] = i;
				
				while (solution == null)
				{
					//random shuffle
					for (int z=0; z<2*n; z++)
					{
						int ind1 = random.nextInt(n);
						int ind2 = random.nextInt(n);
						
						int temp = r[ind1];
						r[ind1] = r[ind2];
						r[ind2] = temp;
						
						temp = indexes[ind1];
						indexes[ind1] = indexes[ind2];
						indexes[ind2] = temp;
					}
					
					solution = solve(n, w, l, r, indexes);
				}
				
				pw.write("Case #" + (tc+1) + ": " + solution + "\n");
			}
			
			pw.flush();
			pw.close();
			
		}

		private String solve(int N, int W, int L, int[] r, int[] indexes) {
			
			double x[] = new double[N];
			double y[] = new double[N];
			
			for (int i=0; i<N; i++)
			{
				//set i, as left and as down as possible
				boolean done = false;
				
				for (int mm=0; mm<2000; mm++)
				{
					double yi = random.nextDouble()*L;
					double xi = random.nextDouble()*W;
					
					boolean problem = false;
					
					for (int j=0; j<i; j++)
						if (intersects(xi, yi, x[j], y[j], r[i], r[j]))
						{
							problem = true;
							break;
						}
					
					if (!problem)
					{
						if (done == false || distance(xi, yi, 0, 0) < distance(x[i], y[i], 0, 0))
						{
							x[i] = xi;
							y[i] = yi;
						}
						
						done = true;
					}					
				}
				
				if (!done)
					return null;				
			}
			
			for (int i=0; i<N; i++)
				for (int j=i+1; j<N; j++)
					if (intersects(x[i], y[i], x[j], y[j], r[i], r[j]))
					{
						return null;
					}
			
			String[] output = new String[N];
						
			StringBuilder res = new StringBuilder();
			DecimalFormat formatter = new DecimalFormat("0.000000000");
			
			for (int i=0; i<N; i++)
			{
				output[indexes[i]] = formatter.format(x[i]) + " " + formatter.format(y[i]);
			}
			
			res.append(output[0]);
			
			for (int i=1; i<N; i++)
				res.append(" " + output[i]);
			
			return res.toString();			
		}
}
