import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.StreamTokenizer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Factory {

	public static void main(String[] args) throws Exception {
		Factory object = new Factory();
		String className = object.getClass().getSimpleName();

		FileReader fileReader = new FileReader(new File(className.toLowerCase() + ".in"));
		StreamTokenizer st = new StreamTokenizer(new BufferedReader(fileReader));

		FileWriter wr = new FileWriter(className.toLowerCase() + ".out");

		st.nextToken();
		int testCases = (int) st.nval;

		st.resetSyntax();
		st.wordChars(0, 256);
		st.whitespaceChars(0, 32);

		List<Map<String, Object>> tests = new ArrayList<>();

		for (int tc = 1; tc <= testCases; tc++) {

			System.out.println("At test " + tc + "/" + testCases);

			st.nextToken();
			int N = Integer.parseInt(st.sval);

			boolean[][] knows = new boolean[N][N];

			for (int i = 0; i < N; i++) {
				st.nextToken();
				String line = st.sval;

				for (int j = 0; j < N; j++)
					if (line.charAt(j) == '1') {
						knows[i][j] = true;
					}
			}

			Map<String, Object> problem = new HashMap<>();
			problem.put("test", tc);
			problem.put("N", N);
			problem.put("knows", knows);

			tests.add(problem);
		}

		tests.parallelStream().forEach(problem -> {

			int tc = (Integer) problem.get("test");
			int N = (Integer) problem.get("N");
			boolean[][] knows = (boolean[][]) problem.get("knows");

			problem.put("result", object.solve(tc - 1, N, knows));
		});

		for (int tc = 1; tc <= testCases; tc++) {
			Map<String, Object> current = tests.get(tc - 1);
			int result = (int) current.get("result");

			wr.write("Case #" + tc + ": " + result + "\r\n");
		}

		wr.close();
	}

	public int solve(int tc, int N, boolean[][] knows) {

		int minSpend = 1000000000;

		for (int z = 0; z < (1 << (N * N)); z++)
			if (Integer.bitCount(z) < minSpend) {

				boolean[][] next = new boolean[N][N];

				for (int i = 0; i < N; i++)
					next[i] = Arrays.copyOf(knows[i], N);

				int spend = 0;

				for (int i = 0; i < N; i++)
					for (int j = 0; j < N; j++) {
						int k = (i * N + j);

						if (((1 << k) & z) > 0) {

							if (!next[i][j]) {
								spend++;
								next[i][j] = true;
							}

						}
					}

				if (spend < minSpend) {
					if (allGood(next)) {
						minSpend = spend;
					}
				}
			}

		return minSpend;

	}

	private boolean allGood(boolean[][] knows) {

		boolean[] takenWorkers = new boolean[knows.length];
		boolean[] takenMachines = new boolean[knows.length];

		return iterate(knows, takenWorkers, takenMachines);

	}

	private boolean iterate(boolean[][] knows, boolean[] takenWorkers, boolean[] takenMachines) {

		int freeWorkers = 0;
		for (int i = 0; i < takenWorkers.length; i++) {
			if (!takenWorkers[i]) {
				freeWorkers++;
			}
		}

		if (freeWorkers == 0) {
			return true; // all good
		}

		boolean allFine = true;

		// we have free workers
		for (int i = 0; i < takenWorkers.length && allFine; i++)
			if (!takenWorkers[i]) {

				// find a machine for this guy
				boolean foundMachine = false;
				for (int j = 0; j < takenMachines.length && allFine; j++)
					if (knows[i][j] && !takenMachines[j]) {
						foundMachine = true;

						takenWorkers[i] = true;
						takenMachines[j] = true;

						allFine = allFine && iterate(knows, takenWorkers, takenMachines);

						takenWorkers[i] = false;
						takenMachines[j] = false;
					}

				allFine = allFine && foundMachine;
			}

		return allFine;

	}

}
