import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.text.DecimalFormat;
import java.util.Scanner;

public class KiddiePool {

	public static void main(String[] args) throws Exception {
		KiddiePool object = new KiddiePool();
		String className = object.getClass().getSimpleName();

		FileReader fileReader = new FileReader(new File(className.toLowerCase() + ".in"));
		Scanner scanner = new Scanner(new BufferedReader(fileReader));

		FileWriter wr = new FileWriter(className.toLowerCase() + ".out");

		int testCases = scanner.nextInt();

		for (int tc = 1; tc <= testCases; tc++) {

			int n = scanner.nextInt();

			double v = scanner.nextDouble();
			double x = scanner.nextDouble();

			double[] ri = new double[n];
			double[] ci = new double[n];

			for (int i = 0; i < n; i++) {
				ri[i] = scanner.nextDouble();
				ci[i] = scanner.nextDouble();
			}

			System.out.println("============");
			wr.write("Case #" + tc + ": " + solve(v, x, ri, ci) + "\r\n");

		}

		scanner.close();
		wr.close();
	}

	private static String solve(double v, double x, double[] ri, double[] ci) {

		double result = 1e100;

		double rateEqual = 0;
		
		for (int i=0; i<ci.length; i++) {
			if (equal(x, ci[i])) {
				rateEqual += ri[i];
			}
		}
		
		
		double rateSmaller = -1, temperatureSmaller = -1;
		
		int takenSmaller = -1;
		
		for (int i=0; i<ri.length; i++)
			if (ci[i] < x) {
				takenSmaller = i;
				rateSmaller = ri[i];
				temperatureSmaller = ci[i];
				break;
			}
		
		
		
		double rateLarger = -1, temperatureLarger = -1;
		
		int takenLarger = -1;
		
		for (int i=0; i<ri.length; i++)
			if (ci[i] > x) {
				takenLarger = i;
				rateLarger = ri[i];
				temperatureLarger = ci[i];
				break;
			}
		
		if (takenSmaller == -1 || takenLarger == -1) {
			
			if (rateEqual > 0)				
				return format(timeToFill(rateEqual,v));
			
			return "IMPOSSIBLE";
		}
		
		for (int i=takenSmaller+1; i<ri.length; i++) 
			if (ci[i] < x) {
				
				double currentRate = rateSmaller / (x - temperatureSmaller);
				
				double newTemperature = (rateSmaller*temperatureSmaller + ri[i]*ci[i]) / (ri[i] + rateSmaller);
				
				double newRate = (rateSmaller + ri[i]) / (x - newTemperature);
				
				if (newRate > currentRate) {
					rateSmaller = rateSmaller + ri[i];
					temperatureSmaller = newTemperature;
				}
				
			}

		
		for (int i=takenLarger+1; i<ri.length; i++) 
			if (ci[i] > x) {
				
				double currentRate = rateLarger / (temperatureLarger - x);
				
				double newTemperature = (rateLarger*temperatureLarger + ri[i]*ci[i]) / (ri[i] + rateLarger);
				
				double newRate = (rateLarger + ri[i]) / (newTemperature - x);
				
				if (newRate > currentRate) {
					rateLarger = rateLarger + ri[i];
					temperatureLarger = newTemperature;
				}
				
			}
		
		
		System.out.println(rateLarger + " " + temperatureLarger);
		System.out.println(rateSmaller + " " + temperatureSmaller);

		
		
		double v0v1 = (temperatureSmaller - x) / (x - temperatureLarger);

		if (v0v1 < 1e-12) {
			return "IMPOSSIBLE";
		}

		double totalToFill = v;
		double fill1 = v / (v0v1 + 1);
		double fill0 = totalToFill - fill1;

		// take v0 from 0, and v1 from 1
		result = Math.min(result, Math.max(timeToFill(rateLarger, fill0), timeToFill(rateSmaller, fill1)));
		return format(result);

	}

	private static String format(double result) {
		DecimalFormat df = new DecimalFormat("0.0000000000");
		return df.format(result);
	}

	private static double timeToFill(double r, double v) {
		return v / r;
	}

	private static boolean equal(double a, double b) {
		return Math.abs(a - b) < 1e-9;
	}

}
