import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.StreamTokenizer;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;

public class TicketSwapping {

	public static long MOD = 1000002013L;
	
	public static void main(String[] args) throws Exception {
		TicketSwapping object = new TicketSwapping();
		String className = object.getClass().getSimpleName();

		FileReader fileReader = new FileReader(new File(className.toLowerCase()
				+ ".in"));
		StreamTokenizer st = new StreamTokenizer(new BufferedReader(fileReader));

		FileWriter wr = new FileWriter(className.toLowerCase() + ".out");

		st.nextToken();
		int testCases = (int) st.nval;
		
		for (int tc = 1; tc <= testCases; tc++) {
			st.nextToken();
			int n = (int) st.nval;
			
			st.nextToken();
			int m = (int) st.nval;
			
			int start[] = new int[m];
			int end[] = new int[m];
			int p[] = new int[m];

			for (int j=0; j<m; j++) {
				st.nextToken();
				start[j] = (int) st.nval;
				
				st.nextToken();
				end[j] = (int) st.nval;
				
				st.nextToken();
				p[j] = (int) st.nval;				
			}

			long output = object.solve(n, start, end, p);
			wr.write("Case #" + tc + ": " + output + "\r\n");		
		}

		wr.close();
	}

	private long solve(int N, int[] entry, int[] end, int[] p) {

		ArrayList<int[]> pairs = new ArrayList<int[]>();
		
		long loss = 0;
		
		for (int i=0; i<entry.length; i++) {
			int[] next = new int[]{entry[i], end[i], p[i]};
			pairs.add(next);
		}
		
		long nextLoss = -1;
		while (nextLoss != 0) {
			
			nextLoss = 0;
			
			Collections.sort(pairs, new Comparator<int[]>() {
				
				public int compare(int[] i1, int[] i2) {
					return Integer.compare(i2[2], i1[2]);
				}
			});

			//try to match 2 groups
			for (int i=0; i<pairs.size() && nextLoss==0; i++)
				for (int j=i+1; j<pairs.size() && nextLoss==0; j++) {
					
					int[] p1 = pairs.get(i);
					int[] p2 = pairs.get(j);
					
					long l1 = getLoss(p1, p2, N);
					l1 = Math.max(l1, getLoss(p2, p1, N));

					if (l1 > 0) {						
						int people = Math.min(p1[2], p2[2]);
						nextLoss = l1 * people;						

						p2[2] -= people;
						pairs.set(j, p2);
						if (p2[2] == 0) {
							pairs.remove(j);
						}
						
						p1[2] -= people;
						pairs.set(i, p1);
						if (p1[2] == 0) {
							pairs.remove(i);
						}

						int g1[] = new int[3];
						g1[2] = people;
						g1[0] = p2[0];
						g1[1] = p1[1];
						pairs.add(g1);
						
						int g2[] = new int[3];
						g2[2] = people;
						g2[0] = p1[0];
						g2[1] = p2[1];
						pairs.add(g2);													
					}
				}
			
			loss += nextLoss;
			loss %= MOD;
		}
		
		return loss;
	}

	private long getLoss(int[] arr1, int[] arr2, long N) {
		int entry1 = arr1[0];
		int exit1 = arr1[1];
		
		int entry2 = arr2[0];
		int exit2 = arr2[1];

		if (entry2 <= exit1 && entry2 >= entry1) {
			long actualPay1 = (exit1-entry1)*N - calc(exit1-entry1-1);
			long actualPay2 = (exit2-entry2)*N - calc(exit2-entry2-1);
			
			long newPay1 = (exit1-entry2)*N - calc(exit1-entry2-1);
			long newPay2 = (exit2-entry1)*N - calc(exit2-entry1-1);

			if (newPay1 + newPay2 < actualPay1 + actualPay2)
				return (actualPay1 + actualPay2 - newPay1 - newPay2);
		}
		
		return 0;
	}

	private long calc(long z) {
		return (((z)*(z+1)) / 2L);
	}
}
