import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.StreamTokenizer;

public class Showdown {

	public static void main(String[] args) throws Exception {
		Showdown object = new Showdown();
		String className = object.getClass().getSimpleName();

		FileReader fileReader = new FileReader(new File(className.toLowerCase() + ".in"));
		StreamTokenizer st = new StreamTokenizer(new BufferedReader(fileReader));

		FileWriter wr = new FileWriter(className.toLowerCase() + ".out");

		st.nextToken();
		int testCases = (int) st.nval;

		for (int tc = 1; tc <= testCases; tc++) {
			System.out.println("At test " + tc + "/" + testCases);

			st.nextToken();
			int N = (int) st.nval;

			st.nextToken();
			int R = (int) st.nval;

			st.nextToken();
			int P = (int) st.nval;

			st.nextToken();
			int S = (int) st.nval;

			String result = object.solve(N, P, R, S);

			wr.write("Case #" + tc + ": " + result.trim() + "\r\n");
		}

		wr.close();
	}

	String output = null;
	char[][] order;
	int N;

	public String solve(int N, int P, int R, int S) {

		this.N = N;
		output = "IMPOSSIBLE";

		order = new char[N + 1][P + R + S];
		setup(0, 0, N, P, R, S, 'P');
		saveResultIfValid(P, R, S);

		order = new char[N + 1][P + R + S];
		setup(0, 0, N, P, R, S, 'R');
		saveResultIfValid(P, R, S);

		order = new char[N + 1][P + R + S];
		setup(0, 0, N, P, R, S, 'S');
		saveResultIfValid(P, R, S);

		return output;
	}

	private void saveResultIfValid(int P, int R, int S) {

		int countP = 0, countR = 0, countS = 0;

		for (int i = 0; i < order[0].length; i++) {
			if (order[N][i] == 0) {

				// invalid
				return;
			}

			if (order[N][i] == 'P')
				countP++;
			if (order[N][i] == 'R')
				countR++;
			if (order[N][i] == 'S')
				countS++;

		}

		if (countP != P || countS != S || countR != R) {
			return;
		}

		String s = new String(order[N]);
		String smartest = reorder(s);
		if (output.equals("IMPOSSIBLE") || smartest.compareTo(output) < 0) {
			output = smartest;
		}
	}

	private String reorder(String str) {

		int sLen = str.length();
		char[] ch = str.toCharArray();

		for (int len = 1; len <= sLen / 2; len += len) {

			for (int pos = 0; pos + 2 * len <= sLen; pos += (2 * len)) {

				int from1 = pos;
				int to1 = pos + len;

				int from2 = pos + len;
				int to2 = from2 + len;

				String str1 = new String(ch, from1, to1 - from1 - 1);
				String str2 = new String(ch, from2, to2 - from2 - 1);

				if (str2.compareTo(str1) < 0) {

					for (int z = 0; z < len; z++) {

						char temp = ch[from1 + z];
						ch[from1 + z] = ch[from2 + z];
						ch[from2 + z] = temp;
					}

				}

			}

		}

		return new String(ch);
	}

	private void setup(int row, int col, int N, int P, int R, int S, char set) {

		if (row > N) {
			return;
		}

		order[row][col] = set;

		// this needs to win
		if (set == 'P') {
			// paper can win against 'R', and comes before it
			setup(row + 1, 2 * col, N, P, R, S, 'P');
			setup(row + 1, 2 * col + 1, N, P, R, S, 'R');
		}

		if (set == 'R') {
			// rock can win against 'S', and comes before it
			setup(row + 1, 2 * col, N, P, R, S, 'R');
			setup(row + 1, 2 * col + 1, N, P, R, S, 'S');
		}

		if (set == 'S') {
			// scissors can win against 'P', and comes after it
			setup(row + 1, 2 * col, N, P, R, S, 'P');
			setup(row + 1, 2 * col + 1, N, P, R, S, 'S');
		}
	}

}
