import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Queue;
import java.util.Scanner;
import java.util.Set;
import java.util.Stack;

public class Fairland {

	public static void main(String[] args) throws Exception {
		Fairland object = new Fairland();
		String className = object.getClass().getSimpleName();

		FileReader fileReader = new FileReader(new File(className.toLowerCase() + ".in"));
		Scanner scanner = new Scanner(new BufferedReader(fileReader));

		FileWriter wr = new FileWriter(className.toLowerCase() + ".out");

		int testCases = scanner.nextInt();

		for (int tc = 1; tc <= testCases; tc++) {

			int N = scanner.nextInt();
			int D = scanner.nextInt();

			long S0 = scanner.nextLong();
			long As = scanner.nextLong();
			long Cs = scanner.nextLong();
			long Rs = scanner.nextLong();

			long M0 = scanner.nextLong();
			long Am = scanner.nextLong();
			long Cm = scanner.nextLong();
			long Rm = scanner.nextLong();

			long Sprev = S0;
			long Mprev = M0;

			int[] salary = new int[N];
			salary[0] = (int) S0;

			for (int i = 1; i < N; i++) {
				long Scurrent = Sprev * As + Cs;
				Scurrent %= Rs;

				salary[i] = (int) Scurrent;
				Sprev = Scurrent;
			}

			int[] parent = new int[N];
			parent[0] = -1;

			for (int i = 1; i < N; i++) {
				long Mcurrent = Mprev * Am + Cm;
				Mcurrent %= Rm;

				parent[i] = (int) (Mcurrent % i);
				Mprev = Mcurrent;
			}

			System.out.println("At test " + tc);

			int result = object.solve(N, D, salary, parent);

			wr.write("Case #" + tc + ": " + result + "\r\n");

		}

		scanner.close();
		wr.close();
	}

	Map<Integer, Set<Integer>> connections;
	int[] salary;

	private int solve(int n, int D, int[] salary, int[] parent) {
		this.salary = salary;

		connections = new HashMap<>();

		for (int i = 1; i < n; i++) {
			addConnection(parent[i], i);
		}

		List<Employee> employees = new ArrayList<>();

		for (int i = 0; i < n; i++) {
			Employee employee = new Employee(i, salary[i]);
			employees.add(employee);
		}

		Collections.sort(employees);

		int left = employees.get(0).salary;
		int right = left + D;

		int startPos = 0;
		int lastPos = 0;

		Set<Integer> inside = new HashSet<>();

		while (lastPos < n) {
			if (employees.get(lastPos).salary >= left && employees.get(lastPos).salary <= right) {
				inside.add(employees.get(lastPos).id);
				lastPos++;
				continue;
			}

			break;
		}

		while (!inside.contains(0)) {
			right = employees.get(lastPos).salary;
			left = right - D;
			inside.add(employees.get(lastPos).id);
			lastPos++;
		}

		while (employees.get(startPos).salary < left) {
			destroyTree(parent, connections, employees.get(startPos).id);
			inside.remove(employees.get(startPos).id);
			startPos++;
		}

		Set<Integer> valuesInside = new HashSet<>();
		addAll(valuesInside, 0, left, right);
		int output = valuesInside.size();

		while (startPos < n) {

			output = Math.max(output, valuesInside.size());

			startPos++;

			if (startPos < n) {
				int prevLeft = left;
				left = employees.get(startPos).salary;
				right = left + D;

				if (left > salary[0]) {
					break;
				}

				for (int i = startPos - 1; i >= 0 && employees.get(i).salary >= prevLeft && employees.get(i).salary < left; i--) {
					if (parent[employees.get(i).id] != -2) {
						Set<Integer> removed = destroyTree(parent, connections, employees.get(i).id);
						inside.remove(employees.get(i).id);

						for (Integer rem : removed) {
							valuesInside.remove(rem);
						}
					}
				}

				for (int current = Math.max(startPos, lastPos); current < n && employees.get(current).salary <= right; current++) {

					lastPos = Math.max(lastPos, current);
					
					if (parent[employees.get(current).id] == -2) {
						continue;
					}

					if (valuesInside.contains(parent[employees.get(current).id])) {
						addAll(valuesInside, employees.get(current).id, left, right);
						inside.add(employees.get(current).id);
						
						
					}
				}
			}
		}

		return output;
	}

	private void addAll(Set<Integer> valuesInside, int id, int left, int right) {

		Queue<Integer> q = new LinkedList<>();
		q.add(id);

		while (!q.isEmpty()) {
			id = q.poll();

			if (salary[id] < left || salary[id] > right)
				continue;

			valuesInside.add(id);

			Set<Integer> next = connections.get(id);

			if (next != null)
				for (Integer n : next)
					if (salary[n] >= left && salary[n] <= right) {
						q.add(n);
					}
		}

	}

	private Set<Integer> destroyTree(int[] parent, Map<Integer, Set<Integer>> connections, int id) {

		Stack<Integer> stack = new Stack<>();
		stack.add(id);

		Set<Integer> removed = new HashSet<>();

		while (!stack.empty()) {
			id = stack.pop();

			Set<Integer> next = connections.get(id);

			if (next != null) {

				stack.add(id);

				for (Integer n : next) {
					stack.add(n);
				}

			} else {

				if (parent[id] >= 0) {
					connections.get(parent[id]).remove(id);
					if (connections.get(parent[id]).size() == 0) {
						connections.remove(parent[id]);
					}
				}

				parent[id] = -2;
				connections.remove(id);
				removed.add(id);
			}
		}
		return removed;
	}

	private void addConnection(int from, int to) {
		if (!connections.containsKey(from)) {
			connections.put(from, new HashSet<>());
		}

		connections.get(from).add(to);
	}

}

class Employee implements Comparable<Employee> {

	public int id;
	public int salary;

	public Employee(int id, int salary) {
		this.id = id;
		this.salary = salary;
	}

	public int compareTo(Employee other) {
		// TODO Auto-generated method stub
		return Integer.compare(salary, other.salary);
	}
}
