package world2014.round2;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.PriorityQueue;

public class DontBreakTheNile {

	private static final int INF = 1000000000;
	
	public int solve(int W, int H, int B, int[][] buildings) {
		PriorityQueue<Building> que = new PriorityQueue<Building>();
		for (int i=0; i<B; i++)
			que.add(new Building(buildings[i]));
		List<Connection> connectionList = new ArrayList<Connection>();
		int s = 0, id = 1;
		Point[] pary = new Point[W];
		for (int i=0; i<W; i++) {
			pary[i] = new Point(i, 0);
			connectionList.add(new Connection(s, pary[i].getId(id)));
			id++;
		}
		while (que.size()>0) {
			Building building = que.poll();
			int x0 = building.bound[0], y0 = building.bound[1];
			int x1 = building.bound[2], y1 = building.bound[3];
			int lx = Math.max(0, x0-1);
			int rx = Math.min(W-1, x1+1);
			Point[] line = new Point[rx-lx+1];
			for (int x=lx; x<=rx; x++)
				line[x-lx] = pary[x];
			boolean overlap = false;
			for (int x=x0; x<=x1; x++) {
				if (pary[x].y>=y0)
					overlap = true;
				else {
					line[x-lx] = new Point(x, y0-1);
					if (pary[x].y<y0-1) {
						if (pary[x].getId(id)==id)
							id++;
						connectionList.add(new Connection(pary[x].id, line[x-lx].getId(id)));
						id++;
					}
				}
				pary[x] = new Point(x, y1+1);
			}
			if (!overlap) {
				Point lp = line[0];
				if (lp.equals(pary[lp.x]) && lp.y<y0-1) {
					if (lp.getId(id)==id)
						id++;
					pary[lp.x] = new Point(lp.x, y0-1);
					connectionList.add(new Connection(lp.id, pary[lp.x].getId(id)));
					lp = pary[lp.x];
					id++;
				}
				Point rp = line[rx-lx];
				if (rp.equals(pary[rp.x]) && rp.y<y0-1) {
					if (rp.getId(id)==id)
						id++;
					pary[rp.x] = new Point(rp.x, y0-1);
					connectionList.add(new Connection(rp.id, pary[rp.x].getId(id)));
					rp = pary[rp.x];
					id++;
				}
				if (line[0].getId(id)==id)
					id++;
				for (int x=lp.x; x<rp.x; x++) {
					if (line[x-lx+1].getId(id)==id)
						id++;
					connectionList.add(new Connection(line[x-lx].id, line[x-lx+1].id));
					connectionList.add(new Connection(line[x-lx+1].id, line[x-lx].id));
				}
			}
		}
		int t = id++;
		for (int i=0; i<W; i++) {
			if (pary[i].getId(id)==id)
				id++;
			connectionList.add(new Connection(pary[i].id, t));
		}
		int[][] cap = new int[id][id];
		for (Connection connection : connectionList)
			cap[connection.from][connection.to] = 1;
		return maxflow(cap, s, t);
	}
	
	public int maxflow(int[][] cap, int s, int t) {
		int n = cap.length;
		int[][] capcopy = new int[n][n];
		for (int i=0; i<n; i++)
			for (int j=0; j<n; j++)
				capcopy[i][j] = cap[i][j];
		int[][] connection = new int[n][];
		for (int i=0; i<n; i++) {
			int cnt = 0;
			for (int j=0; j<n; j++)
				if (cap[i][j]>0 || cap[j][i]>0)
					cnt++;
			connection[i] = new int[cnt];
			cnt = 0;
			for (int j=0; j<n; j++)
				if (cap[i][j]>0 || cap[j][i]>0)
					connection[i][cnt++] = j;
		}
		int flow = 0;
		int[] iter = new int[n];
		for (;;) {
			int[] dist = this.bfs(capcopy, connection, s);
			if (dist[t]<0)
				return flow;
			Arrays.fill(iter, 0);
			int f;
			while ((f=this.dfs(capcopy, connection, dist, iter, INF, s, t))>0)
				flow += f;
		}
	}

	private int[] bfs(int[][] cap, int[][] connection, int s) {
		int[] dist = new int[cap.length];
		Arrays.fill(dist, -1);;
		PriorityQueue<Integer> que = new PriorityQueue<Integer>();
		dist[s] = 0;
		que.add(s);
		while (que.size()>0) {
			int v = que.poll();
			for (int i=0; i<connection[v].length; i++) {
				int vv = connection[v][i];
				if (cap[v][vv]>0 && dist[vv]<0) {
					dist[vv] = dist[v]+1;
					que.add(vv);
				}
			}
		}
		return dist;
	}

	private int dfs(int[][] cap, int[][] connection, int[] dist, int[] iter, int max, int v, int t) {
		if (v==t)
			return max;
		for (; iter[v]<connection[v].length; iter[v]++) {
			int vv = connection[v][iter[v]];
			if (cap[v][vv]>0 && dist[v]<dist[vv]) {
				int f = this.dfs(cap, connection, dist, iter, Math.min(max, cap[v][vv]), vv, t);
				if (f>0) {
					cap[v][vv] -= f;
					cap[vv][v] += f;
					return f;
				}
			}
		}
		return 0;
	}
	
	private class Building implements Comparable<Building> {
		private int[] bound;
		private Building(int[] bound) {
			this.bound = bound;
		}
		public int compareTo(Building building) {
			if (bound[1]<building.bound[1])
				return -1;
			else if (bound[1]>building.bound[1])
				return 1;
			else if (bound[0]<building.bound[0])
				return -1;
			else if (bound[0]>building.bound[0])
				return 1;
			return 0;
		}
	}
	
	private class Point {
		private int x, y;
		private int id = -1;
		private Point(int x, int y) {
			this.x = x;
			this.y = y;
		}
		private int getId(int id) {
			if (this.id==-1)
				return this.id = id;
			else
				return this.id;
		}
	}
	
	private class Connection {
		private int from, to;
		private Connection(int from, int to) {
			this.from = from;
			this.to = to;
		}
	}
	
	public static void main(String args[]) throws IOException {
		String inputPath = "file/world2014/round2/C-small-attempt3.in";
		String outputPath = inputPath.substring(0, inputPath.lastIndexOf('.')) + ".out";
		BufferedReader br = new BufferedReader(new FileReader(inputPath));
		PrintWriter pw = new PrintWriter(outputPath);
		String line = br.readLine();
		int problemNum = Integer.parseInt(line);
		for (int i=0; i<problemNum; i++) {
			line = br.readLine().trim();
			String[] split = line.split(" ");
			int W = Integer.parseInt(split[0]);
			int H = Integer.parseInt(split[1]);
			int B = Integer.parseInt(split[2]);
			int[][] buildings = new int[B][4];
			for (int j=0; j<B; j++) {
				split = br.readLine().trim().split(" ");
				for (int k=0; k<4; k++)
					buildings[j][k] = Integer.parseInt(split[k]);
			}
			int res = new DontBreakTheNile().solve(W, H, B, buildings);
			StringBuilder sb = new StringBuilder();
			sb.append("Case #" + (i+1) + ": " + res);
			System.out.println(sb);
			pw.println(sb);
		}
		br.close();
		pw.close();
	}
}
