package my.codejam;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @author "Dzianis Siarheyeu" <denser.by@gmail.com>
 * 
 */
public class TaskC {

	private final static boolean DEBUG_OUTPUT = true;

	static class Pair {
		final int first;
		final int second;

		private Pair(int first, int second) {
			super();
			this.first = first;
			this.second = second;
		}

		public int getFirst() {
			return first;
		}

		public int getSecond() {
			return second;
		}

		@Override
		public String toString() {
			return "Pair [first=" + first + ", second=" + second + "]";
		}

		@Override
		public int hashCode() {
			final int prime = 31;
			int result = 1;
			result = prime * result + first;
			result = prime * result + second;
			return result;
		}

		@Override
		public boolean equals(Object obj) {
			if (this == obj)
				return true;
			if (obj == null)
				return false;
			if (getClass() != obj.getClass())
				return false;
			Pair other = (Pair) obj;
			if (first != other.first)
				return false;
			if (second != other.second)
				return false;
			return true;
		}

	}

	static Set<Pair> allPairs = new HashSet<Pair>();

	static class Range {
		final int start;
		final int stop;

		public Range(int start, int stop) {
			super();
			this.start = start;
			this.stop = stop;
		}

		public int getStart() {
			return start;
		}

		public int getStop() {
			return stop;
		}

	}

	static void reportError(String text) {
		System.out.println("ERR " + text);
	}

	private static String getOutFileName(String inFileName) {
		String outFileName = inFileName.replace(".in", ".out");
		return outFileName;
	}

	/**
	 * @param args
	 * @throws IOException
	 */
	public static void main(String[] args) throws IOException {
		// TODO Auto-generated method stub
		System.out.println("Hello World!");

		String filePath = "/home/dsa/Downloads/C-small-attempt1.in";
		String filePathOut = getOutFileName(filePath);

		search2digits();
		search3digits();
		search3digits2();

		File file = new File(filePath);
		File fileOut = new File(filePathOut);

		FileInputStream fis = new FileInputStream(file);
		FileOutputStream fos = new FileOutputStream(fileOut);

		if (DEBUG_OUTPUT) {
			System.out.println("----------------------------------------");
		}

		MyReader myReader = new MyReader();
		int item;
		while ((item = fis.read()) > 0) {
			char ch = (char) item;

			if (DEBUG_OUTPUT) {
				System.out.print(ch);
			}

			myReader.feedItem(ch);
		}
		myReader.endOfInputReached();

		fis.close();

		if (DEBUG_OUTPUT) {
			System.out.println("----------------------------------------");
		}

		List<Integer> output = myReader.getOutput();
		long testCaseCount = 0;

		for (Integer testCase : output) {
			testCaseCount++;

			String s1 = "Case #" + testCaseCount + ": " + testCase + "\n";
			if (DEBUG_OUTPUT) {
				System.out.print(s1);
			}
			fos.write(s1.getBytes());
		}

		fos.flush();
		fos.close();

	}

	private static void search3digits2() {
		Set<Integer> abcSet = new HashSet<Integer>();

		for (int a = 1; a <= 9; a++) {
			// System.out.println(" b = " +b );
			for (int b = 1; b <= 9; b++) {
				// System.out.println(" a = " +a );
				for (int c = a; c <= 9; c++) {

					for (int d = 1; d <= 9; d++) {
						for (int e = 1; e <= 9; e++) {

							if (a == b && b == c && c == d && d == e) {
								continue;
							}

							int abc = 100 * a + 10 * b + c;

							// if (ab < 10) continue;

							if (abcSet.contains(abc))
								continue;

							int cde = 100 * c + 10 * d + e;
							// if(bc > 40) continue;
							if (abc >= cde)
								continue;
							if (abcSet.contains(cde))
								continue;

							allPairs.add(new Pair(abc, cde));

							// System.out.println(" (ab, bc) = (" + abc + ", " +
							// bcd
							// + ")");
							abcSet.add(abc);
							abcSet.add(cde);
						}
					}
				}
			}
		}
	}

	private static void search3digits() {
		Set<Integer> abcSet = new HashSet<Integer>();

		for (int a = 1; a <= 9; a++) {
			// System.out.println(" b = " +b );
			for (int b = a; b <= 9; b++) {
				// System.out.println(" a = " +a );
				for (int c = 1; c <= 9; c++) {

					for (int d = 1; d <= 9; d++) {

						if (a == b && b == c && c == d) {
							continue;
						}

						int abc = 100 * a + 10 * b + c;

						// if (ab < 10) continue;

						if (abcSet.contains(abc))
							continue;

						int bcd = 100 * b + 10 * c + d;
						// if(bc > 40) continue;
						if (abc >= bcd)
							continue;
						if (abcSet.contains(bcd))
							continue;

						allPairs.add(new Pair(abc, bcd));

						// System.out.println(" (ab, bc) = (" + abc + ", " + bcd
						// + ")");
						abcSet.add(abc);
						abcSet.add(bcd);
					}
				}
			}
		}
	}

	private static void search2digits() {
		Set<Integer> abSet = new HashSet<Integer>();

		for (int a = 1; a <= 9; a++) {
			// System.out.println(" b = " +b );
			for (int b = a; b <= 9; b++) {
				// System.out.println(" a = " +a );
				for (int c = 1; c <= 9; c++) {
					if (a == b && b == c) {
						continue;
					}

					int ab = 10 * a + b;

					if (abSet.contains(ab))
						continue;

					int bc = 10 * b + c;
					if (ab >= bc)
						continue;
					if (abSet.contains(bc))
						continue;

					allPairs.add(new Pair(ab, bc));

					// System.out.println(" (ab, bc) = (" + ab + ", " + bc +
					// ")");
					abSet.add(ab);
					abSet.add(bc);
//					bcSet.add(bc);
				}
			}
		}
	}

	static class MyReader {

		enum MyReaderState {
			NOT_USED, FIRST_LINE, DATA_LINE, FINISHED;
		};

		MyReaderState curState = MyReaderState.NOT_USED;
		StringBuffer curWordContent = new StringBuffer();
		int casesNumber = -1;
		List<Integer> output = new ArrayList<Integer>();
		List<String> curLine = new ArrayList<String>();

		void endOfInputReached() {
			// if (curLineReverse.size() > 0 || curWordContent.length() > 0) {
			// processLine();
			// }
		}

		List<Integer> getOutput() {
			return output;
		}

		void feedItem(char ch) {

			// if (DEBUG_OUTPUT) {
			// System.out.println("feedItem()  ch=\"" + ch + "\""
			// + "   curWordContent=" + curWordContent.toString());
			// }

			if (ch == '\r')
				return;

			switch (curState) {
			case NOT_USED:
				if (ch == '\n') {
					throw new IllegalStateException(
							"Input file can't start with empty first line.");
				}
				curState = MyReaderState.FIRST_LINE;
				curWordContent.append(ch);
				break;

			case FIRST_LINE:
				if (ch == '\n') {
					curState = MyReaderState.DATA_LINE;
					casesNumber = Integer.parseInt(curWordContent.toString());
					System.out.println("First line parsed: casesNumber="
							+ casesNumber);
					curWordContent.setLength(0);
				} else {
					curWordContent.append(ch);
				}
				break;

			case DATA_LINE:
				switch (ch) {

				case '\n':
					processDataLine();
					break;

				default:
					curWordContent.append(ch);
					break;
				}
				break;

			default:
				break;
			}
		}

		private void processDataLine() {

			String curLine = curWordContent.toString();
			String[] curLineParts = curLine.split(" ");
			int[] intParts = new int[curLineParts.length];

			for (int i = 0; i < curLineParts.length; i++) {
				intParts[i] = Integer.parseInt(curLineParts[i]);
			}

			int A = intParts[0];
			int B = intParts[1];

			System.out.println("processDataLine()   curLine=" + curLine + " A="
					+ A + " B=" + B);

			curWordContent.setLength(0);

			int count = 0;
			for (Pair p : allPairs) {
				if (p.getFirst() >= A && p.getSecond() <= B) {
					count++;
					System.out.println("processDataLine()   p=" + p);
				}
			}
			System.out.println("processDataLine()   count=" + count);

			output.add(count);
		}
	}

}
