package my.codejam;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author "Dzianis Siarheyeu" <denser.by@gmail.com>
 * 
 */
public class TaskA {

	private final static boolean DEBUG_OUTPUT = true;

	static void reportError(String text) {
		System.out.println("ERR " + text);
	}

	static class MapItem {
		final char engCh;
		final char googleCh;

		public MapItem(char engCh, char googleCh) {
			super();
			this.engCh = engCh;
			this.googleCh = googleCh;
		}

		public char getEngCh() {
			return engCh;
		}

		public char getGoogleCh() {
			return googleCh;
		}

		@Override
		public String toString() {
			return "MapItem [engCh=" + engCh + ", googleCh=" + googleCh + "]";
		}

	}

	static class Vocabulary {

		Map<Character, MapItem> engEntries = new HashMap<Character, MapItem>();
		Map<Character, MapItem> googleEntries = new HashMap<Character, MapItem>();

		String engToGoogle(String eng) {
			StringBuffer buf = new StringBuffer();

			eng = eng.toLowerCase();

			for (int i = 0; i < eng.length(); i++) {
				char ch = eng.charAt(i);
				MapItem mapItem = engEntries.get(ch);
				if (mapItem != null) {
					buf.append(mapItem.getGoogleCh());
				} else {
					System.out.println("Undefined mapping for engCh=" + ch);
					buf.append("_");
				}
			}

			return buf.toString();
		}

		String googleToEng(String googlerese) {
			StringBuffer buf = new StringBuffer();

			googlerese = googlerese.toLowerCase();

			for (int i = 0; i < googlerese.length(); i++) {
				char ch = googlerese.charAt(i);
				MapItem mapItem = googleEntries.get(ch);
				if (mapItem != null) {
					buf.append(mapItem.getEngCh());
				} else {
					System.out.println("Undefined mapping for googlereseCh="
							+ ch);
					buf.append("_");
				}
			}

			return buf.toString();
		}

		void learnLetter(char engCh, char googleCh) {
			Character engChar = engCh;
			Character googleChar = googleCh;

			MapItem item = new MapItem(engCh, googleCh);

			boolean containsKeyEng = engEntries.containsKey(engChar);
			boolean containsKeyGoogle = googleEntries.containsKey(googleChar);

			if (containsKeyEng == false) {
				engEntries.put(engChar, item);
			} else {
				MapItem x = engEntries.get(engChar);
				if (x.getEngCh() != engCh || x.getGoogleCh() != googleCh) {
					reportError("Wrong learning pattern!  x=" + x + "  engCh="
							+ engCh + "   googleCh=" + googleCh);
				}
			}

			if (containsKeyGoogle == false) {
				googleEntries.put(googleChar, item);
			} else {
				MapItem x = googleEntries.get(googleChar);
				if (x.getEngCh() != engCh || x.getGoogleCh() != googleCh) {
					reportError("Wrong learning pattern!  x=" + x + "  engCh="
							+ engCh + "   googleCh=" + googleCh);
				}
			}

		}

		void learnWord(String engWord, String googleWord) {
			System.out.println("learnWord()   engWord=" + engWord
					+ "   googleWord=" + googleWord);
			if (engWord == null || googleWord == null
					|| engWord.length() != googleWord.length()) {
				reportError("Wrong pattern!  engWord=" + engWord
						+ "   googleWord=" + googleWord);
			}
			for (int i = 0; i < engWord.length(); i++) {
				char engCh = engWord.charAt(i);
				char googleCh = googleWord.charAt(i);
				learnLetter(engCh, googleCh);
			}
		}

		void learnPhrase(String engPh, String googlePh) {
			if (engPh == null || googlePh == null
					|| engPh.length() != googlePh.length()) {
				reportError("Wrong pattern!  engPh=" + engPh + "   googlePh="
						+ googlePh);
			}

			String[] engWords = engPh.split(" ");
			String[] googleWords = googlePh.split(" ");

			if (engWords.length != googleWords.length) {
				reportError("Wrong pattern!  engWords.length="
						+ engWords.length + "   googleWords.length="
						+ googleWords.length);
			}

			for (int i = 0; i < engWords.length; i++) {
				learnWord(engWords[i], googleWords[i]);
			}
		}

	}

	private static String getOutFileName(String inFileName) {
		String outFileName = inFileName.replace(".in", ".out");
		return outFileName;
	}

	/**
	 * @param args
	 * @throws IOException
	 */
	public static void main(String[] args) throws IOException {
		// TODO Auto-generated method stub
		System.out.println("Hello World!");

		Vocabulary vocabulary = new Vocabulary();

		vocabulary.learnLetter('a', 'y');
		vocabulary.learnLetter('o', 'e');
		vocabulary.learnLetter('z', 'q');

		// !!!!
		vocabulary.learnLetter('q', 'z');
		// !!!!

		vocabulary.learnPhrase("a zoo", "y qee");

		vocabulary.learnPhrase("our language is impossible to understand",
				"ejp mysljylc kd kxveddknmc re jsicpdrysi");
		vocabulary.learnPhrase("there are twenty six factorial possibilities",
				"rbcpc ypc rtcsra dkh wyfrepkym veddknkmkrkcd");
		vocabulary.learnPhrase("so it is okay if you want to just give up",
				"de kr kd eoya kw aej tysr re ujdr lkgc jv");

		String engAlpha = "abcdefghijklmnopqrstuvwxyz";

		System.out
				.println("----------ENG alpha test  -- engToGoogle() --------------------");
		String engToGoogle = vocabulary.engToGoogle(engAlpha);
		System.out
				.println("   input=" + engAlpha + "\n  output=" + engToGoogle);

		System.out
				.println("----------Googlerese alpha test  -- googleToEng() --------------------");
		String googleToEng = vocabulary.googleToEng(engAlpha);
		System.out
				.println("   input=" + engAlpha + "\n  output=" + googleToEng);
		System.out
				.println("--------------------------------------------------");

		String filePath = "/home/dsa/Downloads/A-small-attempt0.in";
		String filePathOut = getOutFileName(filePath);

		File file = new File(filePath);
		File fileOut = new File(filePathOut);

		FileInputStream fis = new FileInputStream(file);
		FileOutputStream fos = new FileOutputStream(fileOut);

		if (DEBUG_OUTPUT) {
			System.out.println("----------------------------------------");
		}

		MyReader myReader = new MyReader(vocabulary);
		int item;
		while ((item = fis.read()) > 0) {
			char ch = (char) item;

			if (DEBUG_OUTPUT) {
				System.out.print(ch);
			}

			myReader.feedItem(ch);
		}
		myReader.endOfInputReached();

		fis.close();

		if (DEBUG_OUTPUT) {
			System.out.println("----------------------------------------");
		}

		List<List<String>> output = myReader.getOutput();
		long testCaseCount = 0;

		for (List<String> testCase : output) {
			testCaseCount++;

			StringBuffer b = new StringBuffer();
			for (String s : testCase) {
				b.append(" " + s);
			}

			String s1 = "Case #" + testCaseCount + ":" + b.toString() + "\n";
			if (DEBUG_OUTPUT) {
				System.out.print(s1);
			}
			fos.write(s1.getBytes());
		}

		fos.flush();
		fos.close();

	}

	static class MyReader {

		final Vocabulary vocabulary;

		public MyReader(Vocabulary vocabulary) {
			super();
			this.vocabulary = vocabulary;
		}

		enum MyReaderState {
			NOT_USED, FIRST_LINE, DATA_LINE, FINISHED;
		};

		MyReaderState curState = MyReaderState.NOT_USED;
		StringBuffer curWordContent = new StringBuffer();
		int casesNumber = -1;
		List<List<String>> output = new ArrayList<List<String>>();
		List<String> curLine = new ArrayList<String>();

		void endOfInputReached() {
			// if (curLineReverse.size() > 0 || curWordContent.length() > 0) {
			// processLine();
			// }
		}

		List<List<String>> getOutput() {
			return output;
		}

		void feedItem(char ch) {

			// if (DEBUG_OUTPUT) {
			// System.out.println("feedItem()  ch=\"" + ch + "\""
			// + "   curWordContent=" + curWordContent.toString());
			// }

			if (ch == '\r')
				return;

			switch (curState) {
			case NOT_USED:
				if (ch == '\n') {
					throw new IllegalStateException(
							"Input file can't start with empty first line.");
				}
				curState = MyReaderState.FIRST_LINE;
				curWordContent.append(ch);
				break;

			case FIRST_LINE:
				if (ch == '\n') {
					curState = MyReaderState.DATA_LINE;
					casesNumber = Integer.parseInt(curWordContent.toString());
					System.out.println("First line parsed: casesNumber="
							+ casesNumber);
					curWordContent.setLength(0);
				} else {
					curWordContent.append(ch);
				}
				break;

			case DATA_LINE:
				switch (ch) {

				case ' ':
					processWord();
					break;

				case '\n':
					processDataLine();
					break;

				default:
					curWordContent.append(ch);
					break;
				}
				break;

			default:
				break;
			}
		}

		private void processDataLine() {

			// new Exception("HiHH").printStackTrace();

			if (curWordContent.length() > 0)
				processWord();

			// if (DEBUG_OUTPUT)
			// System.out.println("processDataLine()   curLine="
			// + Arrays.toString(curLine.toArray(new String[0])));

			output.add(curLine);

			curLine = new ArrayList<String>();
		}

		private void processWord() {

			// new Exception("Hi").printStackTrace();

			String googlereseWord = curWordContent.toString();
			curWordContent.setLength(0);

			String engWord = vocabulary.googleToEng(googlereseWord);

			// if (DEBUG_OUTPUT)
			// System.out.println("processWord()   googlereseWord="
			// + googlereseWord + "   engWord=" + engWord);

			curLine.add(engWord);

		}

	}

}
