package my.codejam;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @author "Dzianis Siarheyeu" <denser.by@gmail.com>
 * 
 */
public class TaskD {

	public final static char CH_EMPTY = '.';
	public final static char CH_OBSERVER = 'X';
	public final static char CH_MIRROR = '#';

	public final static int K2 = 5;
	public final static int K = K2 * 2;

	private final static boolean DEBUG_OUTPUT = true;

	static void reportError(String text) {
		System.out.println("ERR " + text);
	}

	private static String getOutFileName(String inFileName) {
		String outFileName = inFileName.replace(".in", ".out");
		return outFileName;
	}

	/**
	 * @param args
	 * @throws IOException
	 */
	public static void main(String[] args) throws IOException {
		// TODO Auto-generated method stub
		System.out.println("Hello World!");

		String filePath = "/home/dsa/Downloads/D-small-attempt0.in";
		String filePathOut = getOutFileName(filePath);

		// Solver solver = new Solver();
		// solver.solve();

		File file = new File(filePath);
		File fileOut = new File(filePathOut);

		FileInputStream fis = new FileInputStream(file);
		FileOutputStream fos = new FileOutputStream(fileOut);

		if (DEBUG_OUTPUT) {
			System.out.println("----------------------------------------");
		}

		MyReader myReader = new MyReader();
		int item;
		while ((item = fis.read()) > 0) {
			char ch = (char) item;

			if (DEBUG_OUTPUT) {
				System.out.print(ch);
			}

			myReader.feedItem(ch);
		}
		myReader.endOfInputReached();

		fis.close();

		if (DEBUG_OUTPUT) {
			System.out.println("----------------------------------------");
		}

		List<Integer> output = myReader.getOutput();
		long testCaseCount = 0;

		for (Integer testCase : output) {
			testCaseCount++;

			String s1 = "Case #" + testCaseCount + ": " + testCase + "\n";
			if (DEBUG_OUTPUT) {
				System.out.print(s1);
			}
			fos.write(s1.getBytes());
		}

		fos.flush();
		fos.close();

	}

	static class HallMap {
		final int H, W, D;
		final byte[][] hallMap;
		int observerLine, observerRow;

		public HallMap(int h, int w, int d) {
			super();
			H = h;
			W = w;
			D = d;
			hallMap = new byte[H][W];
		}

		/**
		 * @param line
		 *            [1..H]
		 * @param pos
		 *            [1..W]
		 * @param marker
		 */
		public void fillMap(int line, int pos, int b) {

			hallMap[line - 1][pos - 1] = (byte) b;

			if (b == 2) {
				observerLine = line;
				observerRow = pos;
			}

		}

		public int getObserverLine() {
			return observerLine;
		}

		public void setObserverLine(int observerLine) {
			this.observerLine = observerLine;
		}

		public int getObserverRow() {
			return observerRow;
		}

		public void setObserverRow(int observerRow) {
			this.observerRow = observerRow;
		}

		public int getH() {
			return H;
		}

		public int getW() {
			return W;
		}

		public int getD() {
			return D;
		}

		public byte[][] getHallMap() {
			return hallMap;
		}

		@Override
		public String toString() {
			StringBuffer buf = new StringBuffer();
			for (byte[] line : hallMap) {
				// buf.append('{');
				for (byte m : line) {
					buf.append(m);
				}
				buf.append("\n");
			}
			String hallView = buf.toString();

			return "HallMap [\nH=" + H + ", W=" + W + ", D=" + D + ", MAP=\n"
					+ hallView + "]\n";
		}

	}

	static class MyReader {

		enum MyReaderState {
			NOT_USED, FIRST_LINE, HALL_HEADER, HALL_MAP, FINISHED;
		};

		MyReaderState curState = MyReaderState.NOT_USED;
		StringBuffer curWordContent = new StringBuffer();
		int casesNumber = -1;
		List<Integer> output = new ArrayList<Integer>();
		List<String> curLine = new ArrayList<String>();

		HallMap hallMap;
		int curHallLine;

		void endOfInputReached() {
			// if (curLineReverse.size() > 0 || curWordContent.length() > 0) {
			// processLine();
			// }
		}

		List<Integer> getOutput() {
			return output;
		}

		void feedItem(char ch) {

			// if (DEBUG_OUTPUT) {
			// System.out.println("feedItem()  ch=\"" + ch + "\""
			// + "   curWordContent=" + curWordContent.toString());
			// }

			if (ch == '\r')
				return;

			switch (curState) {
			case NOT_USED:
				if (ch == '\n') {
					throw new IllegalStateException(
							"Input file can't start with empty first line.");
				}
				curState = MyReaderState.FIRST_LINE;
				curWordContent.append(ch);
				break;

			case FIRST_LINE:
				if (ch == '\n') {
					curState = MyReaderState.HALL_HEADER;
					casesNumber = Integer.parseInt(curWordContent.toString());
					System.out.println("First line parsed: casesNumber="
							+ casesNumber);
					curWordContent.setLength(0);
				} else {
					curWordContent.append(ch);
				}
				break;

			case HALL_HEADER:
				switch (ch) {

				case '\n':
					processHallHeader();
					break;

				default:
					curWordContent.append(ch);
					break;
				}
				break;

			case HALL_MAP:
				switch (ch) {

				case '\n':
					processHallMap();
					break;

				default:
					curWordContent.append(ch);
					break;
				}
				break;

			default:
				break;
			}
		}

		private void processHallMap() {

			curHallLine++;

			String curLine = curWordContent.toString();
			curWordContent.setLength(0);

			// if (DEBUG_OUTPUT) {
			// System.out.println("processHallMap()  curLine=" + curLine);
			// }

			for (int i = 0; i < curLine.length(); i++) {
				char ch = curLine.charAt(i);

				final int curHalRow = i + 1;

				switch (ch) {
				case CH_EMPTY:
					hallMap.fillMap(curHallLine, curHalRow, 0);
					break;

				case CH_OBSERVER:
					hallMap.fillMap(curHallLine, curHalRow, 2);
					break;

				case CH_MIRROR:
					hallMap.fillMap(curHallLine, curHalRow, 1);
					break;

				default:
					break;
				}

			}

			if (curHallLine == hallMap.getH()) {
				// then the last line, so mode needs to be changed
				curState = MyReaderState.HALL_HEADER;

				calculateReflections();

			}

			// TODO Auto-generated method stub

		}

		private void calculateReflections() {
			// TODO Auto-generated method stub
			if (DEBUG_OUTPUT) {
				System.out
						.println("calculateReflections()  hallMap=" + hallMap);
			}

			Solver solver = new Solver();

			byte[][] map = hallMap.getHallMap();

			int sL = hallMap.getObserverLine();
			int sR = hallMap.getObserverRow();
			double d = hallMap.getD();
			solver.solve(map, sL, sR, d);

			output.add(solver.getReflectionsCount());

		}

		private void processHallHeader() {

			// if (DEBUG_OUTPUT) {
			// System.out.println("\nprocessHallHeader()  curWordContent="
			// + curWordContent.toString());
			// }

			String curLine = curWordContent.toString();
			curWordContent.setLength(0);

			String[] values = curLine.split(" ");

			if (values.length != 3) {
				throw new IllegalArgumentException(
						"Wrong length for HWD line   length=" + values.length);
			}

			int H = Integer.parseInt(values[0]);
			int W = Integer.parseInt(values[1]);
			int D = Integer.parseInt(values[2]);
			hallMap = new HallMap(H, W, D);
			curHallLine = 0;

			// if (DEBUG_OUTPUT) {
			// System.out.println("processHallHeader()  H=" + H + " W=" + W
			// + " D=" + D);
			// }

			curState = MyReaderState.HALL_MAP;
		}
	}

	static class Cell {
		int l;
		int r;

		Cell(int l, int r) {
			super();
			this.l = l;
			this.r = r;
		}

		Cell getNeighbour(ReflectionType rType, Angle outAngle) {
			switch (outAngle) {
			case A1:
				if (rType == ReflectionType.RIGHT) {
					return getEast();
				} else if (rType == ReflectionType.LEFT) {
					return getNorth();
				}
				break;
			case A3:
				if (rType == ReflectionType.RIGHT) {
					return getSouth();
				} else if (rType == ReflectionType.LEFT) {
					return getEast();
				}
				break;
			case A5:
				if (rType == ReflectionType.RIGHT) {
					return getWest();
				} else if (rType == ReflectionType.LEFT) {
					return getSouth();
				}
				break;
			case A7:
				if (rType == ReflectionType.RIGHT) {
					return getNorth();
				} else if (rType == ReflectionType.LEFT) {
					return getWest();
				}

				break;

			default:
				break;
			}
			return null;
		}

		byte getType(byte[][] map) {
			return map[l - 1][r - 1];
		}

		Cell getNorth() {
			return new Cell(l - 1, r);
		}

		Cell getNorthEast() {
			return new Cell(l - 1, r + 1);
		}

		Cell getNorthWest() {
			return new Cell(l - 1, r - 1);
		}

		Cell getSouthEast() {
			return new Cell(l + 1, r + 1);
		}

		Cell getSouthWest() {
			return new Cell(l + 1, r - 1);
		}

		Cell getSouth() {
			return new Cell(l + 1, r);
		}

		Cell getEast() {
			return new Cell(l, r + 1);
		}

		Cell getWest() {
			return new Cell(l, r - 1);
		}

		@Override
		public String toString() {
			return "Cell [l=" + l + ", r=" + r + "]";
		}

	}

	static enum ReflectionType {
		REVERSE, LEFT, RIGHT, BLACK_HOLE;

		boolean isNotMirror(byte b) {
			return b != 1;
		}

		public static ReflectionType detect(Cell next, Cell prev,
				Angle inAngle, byte[][] map) {

			switch (inAngle) {
			case A1: {
				byte northType = prev.getNorth().getType(map);
				byte eastType = prev.getEast().getType(map);

				if (northType != 1 && eastType != 1) {
					return BLACK_HOLE;
				} else if (northType == 1 && eastType != 1) {
					return RIGHT;
				} else if (northType != 1 && eastType == 1) {
					return LEFT;
				} else if (northType == 1 && eastType == 1) {
					return REVERSE;
				}
			}

				break;
			case A3: {
				byte southType = prev.getSouth().getType(map);
				byte eastType = prev.getEast().getType(map);

				if (southType != 1 && eastType != 1) {
					return BLACK_HOLE;
				} else if (southType == 1 && eastType != 1) {
					return LEFT;
				} else if (southType != 1 && eastType == 1) {
					return RIGHT;
				} else if (southType == 1 && eastType == 1) {
					return REVERSE;
				}

			}

				break;
			case A5: {

				byte southType = prev.getSouth().getType(map);
				byte westType = prev.getWest().getType(map);

				if (southType != 1 && westType != 1) {
					return BLACK_HOLE;
				} else if (southType == 1 && westType != 1) {
					return RIGHT;
				} else if (southType != 1 && westType == 1) {
					return LEFT;
				} else if (southType == 1 && westType == 1) {
					return REVERSE;
				}

			}

				break;
			case A7: {

				byte northType = prev.getNorth().getType(map);
				byte westType = prev.getWest().getType(map);

				if (northType != 1 && westType != 1) {
					return BLACK_HOLE;
				} else if (northType == 1 && westType != 1) {
					return LEFT;
				} else if (northType != 1 && westType == 1) {
					return RIGHT;
				} else if (northType == 1 && westType == 1) {
					return REVERSE;
				}

			}

				break;

			default:
				break;
			}

			return null;
		}
	}

	static enum Angle {
		A1, A2, A3, A4, A5, A6, A7, A8;

		public static Angle turnLeft(Angle a) {
			switch (a) {
			case A1:
				return Angle.A7;

			case A3:
				return Angle.A1;

			case A5:
				return Angle.A3;

			case A7:
				return Angle.A5;

			default:
				break;
			}

			return null;
		}

		public static Angle turnRight(Angle a) {
			switch (a) {
			case A1:
				return Angle.A3;

			case A3:
				return Angle.A5;

			case A5:
				return Angle.A7;

			case A7:
				return Angle.A1;

			default:
				break;
			}

			return null;
		}

		public static Angle reverseAngle(Angle angle) {
			switch (angle) {
			case A1:
				return A5;
			case A2:
				return A6;
			case A3:
				return A7;
			case A4:
				return A8;
			case A5:
				return A1;
			case A6:
				return A2;
			case A7:
				return A3;
			case A8:
				return A4;

			default:
				break;
			}
			return null;
		}

		public static Cell getNextCellCandidateWithoutReflections(Cell curCell,
				Angle outAngle) {

			if (outAngle.isOdd()) {

				switch (outAngle) {
				case A2:
					return curCell.getEast();
				case A4:
					return curCell.getSouth();
				case A6:
					return curCell.getWest();
				case A8:
					return curCell.getNorth();

				default:
					break;
				}

			} else {

				switch (outAngle) {
				case A1:
					return curCell.getNorthEast();
				case A3:
					return curCell.getSouthEast();
				case A5:
					return curCell.getSouthWest();
				case A7:
					return curCell.getNorthWest();

				default:
					break;
				}

			}

			return null;
		}

		boolean isOdd() {
			switch (this) {
			case A2:
			case A4:
			case A6:
			case A8:
				return true;

			default:
				break;
			}
			return false;
		}

	}

	static class Solver {

		double L1 = (double) 1 / (double) 2;
		double L2 = (double) Math.sqrt(2) / (double) 2;

		// int H = 5;
		// int W = 6;
		// int D = 10;

		int reflectionsCount = 0;

		// byte[][] map = new byte[][] { { 1, 1, 1, 1, 1, 1 },
		// { 1, 0, 0, 2, 0, 1 }, { 1, 0, 1, 0, 0, 1 },
		// { 1, 0, 0, 0, 1, 1 }, { 1, 1, 1, 1, 1, 1 } };

		public int getReflectionsCount() {
			return reflectionsCount;
		}

		public void solve(byte[][] map, int sL, int sR, double d) {
			// int sL = 2;
			// int sR = 4;
			// double d = 10;

			System.out.println("L1=" + L1 + "   L2=" + L2);

			Cell curCell = new Cell(sL, sR);

			{
				Angle outAngle = Angle.A1;
				Cell next = Angle.getNextCellCandidateWithoutReflections(
						curCell, outAngle);
				visit(next, outAngle, d - L2, curCell, map);
			}
			System.out.println("");

			{
				Angle outAngle = Angle.A2;
				Cell next = Angle.getNextCellCandidateWithoutReflections(
						curCell, outAngle);
				visit(next, outAngle, d - L1, curCell, map);
			}
			System.out.println("");

			{
				Angle outAngle = Angle.A3;
				Cell next = Angle.getNextCellCandidateWithoutReflections(
						curCell, outAngle);
				visit(next, outAngle, d - L2, curCell, map);
			}
			System.out.println("");

			{
				Angle outAngle = Angle.A4;
				Cell next = Angle.getNextCellCandidateWithoutReflections(
						curCell, outAngle);
				visit(next, outAngle, d - L1, curCell, map);
			}
			System.out.println("");

			{
				Angle outAngle = Angle.A5;
				Cell next = Angle.getNextCellCandidateWithoutReflections(
						curCell, outAngle);
				visit(next, outAngle, d - L2, curCell, map);
			}
			System.out.println("");

			{
				Angle outAngle = Angle.A6;
				Cell next = Angle.getNextCellCandidateWithoutReflections(
						curCell, outAngle);
				visit(next, outAngle, d - L1, curCell, map);
			}
			System.out.println("");

			{
				Angle outAngle = Angle.A7;
				Cell next = Angle.getNextCellCandidateWithoutReflections(
						curCell, outAngle);
				visit(next, outAngle, d - L2, curCell, map);
			}
			System.out.println("");

			{
				Angle outAngle = Angle.A8;
				Cell next = Angle.getNextCellCandidateWithoutReflections(
						curCell, outAngle);
				visit(next, outAngle, d - L1, curCell, map);
			}

			System.out.println("   reflectionsCount=" + reflectionsCount);
		}

		/**
		 * @param curCell
		 * @param inAngle
		 * @param d
		 *            - it should decrease D just for value which is spent
		 *            inside curCell, in case of reflection - 0
		 * @param prevCell
		 * @param outAngle
		 */
		void visit(Cell curCell, Angle inAngle, double d, Cell prevCell,
				byte[][] map) {

//			System.out.println("visit()  curCell=" + curCell + " inAngle="
//					+ inAngle + " d=" + d + " prevCell=" + prevCell);

			if (d <= 0) {
				// new Exception("D < 0").printStackTrace();
				System.out
						.println("D <= 0, this path won't show any reflection.");
				return;
			}

			byte curCellType = map[curCell.l - 1][curCell.r - 1];

			if (curCellType == 1) {

				if (inAngle.isOdd()) {
					// send it back
					visit(prevCell, Angle.reverseAngle(inAngle), d, curCell,
							map);
					return;
				} else {

					ReflectionType reflectionType = ReflectionType.detect(
							curCell, prevCell, inAngle, map);

//					System.out.println("visit()   reflectionType="
//							+ reflectionType + "  inAngle=" + inAngle
//							+ "  curCell=" + curCell);

					switch (reflectionType) {
					case BLACK_HOLE:
						// this ray was consumed by such reflection type
						System.out
								.println("this ray was consumed by such reflection type, this path won't show any reflection.");
						return;

					case LEFT: {
						Cell next = prevCell.getNeighbour(reflectionType,
								inAngle);
						visit(next, Angle.turnLeft(inAngle), d, prevCell, map);
						return;
					}

					case RIGHT: {
						Cell next = prevCell.getNeighbour(reflectionType,
								inAngle);
						visit(next, Angle.turnRight(inAngle), d, prevCell, map);
						return;
					}

					case REVERSE: {
						visit(prevCell, Angle.reverseAngle(inAngle), d,
								curCell, map);
						return;
					}

					default:
						break;
					}
				}

			} else if (curCellType == 2) {

				if (inAngle.isOdd() && d >= L1 || inAngle.isOdd() == false
						&& d >= L2) {
					// Observer is reached!!!
					reflectionsCount++;
					System.out
							.println("Observer is reached!!!.   reflectionsCount="
									+ reflectionsCount + "  d=" + d);
				} else {
					System.out
							.println("Observer's sector is reached, but the observer isn't reached because of not enough d...    reflectionsCount="
									+ reflectionsCount + "  d=" + d);

				}
				return;

			} else if (curCellType == 0) {
				// current new cell is EMPTY one, so no reflections

				Cell nextCellCandidate = Angle
						.getNextCellCandidateWithoutReflections(curCell,
								inAngle);

				double newD = inAngle.isOdd() ? d - (double) 1 : d - (double) 2
						* L2;

				visit(nextCellCandidate, inAngle, newD, curCell, map);
				return;

			}
		}

	}

}
