import java.io.*;
import java.util.*;

public class B {

	BufferedReader br;
	PrintWriter out;
	StringTokenizer st;
	boolean eof;

	enum InputType {
		EXAMPLE, SMALL, LARGE
	}

	static final InputType INPUT_TYPE = InputType.SMALL;
	static final int ATTEMPT_NUMBER = 2;

	void solve() throws IOException {
		int n = nextInt();
		int m = nextInt();
		int[][] id = new int[n][n];
		for (int i = 0; i < n; i++) {
			Arrays.fill(id[i], -1);
		}
		
		int[] vs = new int[m];
		int[] us = new int[m];

		for (int i = 0; i < m; i++) {
			int v = nextInt() - 1;
			int u = nextInt() - 1;
			id[v][u] = i;
			vs[i] = v;
			us[i] = u;
		}
		
		int[] ans = go(n, m, vs, us, id);
		if (ans == null) {
			out.println("IMPOSSIBLE");
		} else {
			for (int x : ans) {
				out.print(x + " ");
			}
			out.println();
		}
	}
	
	int n, m;
	int[][] id;
	
	int[] par;
	int[] up;
	int[] depth;
	
	boolean isEdge(int v, int u) {
		return id[v][u] != -1 || id[u][v] != -1;
	}
	
	boolean dfs(int v, int p) {
		par[v] = p;
		up[v] = depth[v];
		for (int u = 0; u < n; u++) {
			if (!isEdge(v, u)) {
				continue;
			}
			if (u == p) {
				continue;
			}
			if (depth[u] == -1) {
				depth[u] = depth[v] + 1;
				if (dfs(u, v)) {
					return true;
				}
				up[v] = Math.min(up[v], up[u]);
			} else {
				up[v] = Math.min(up[v], depth[u]);
			}
		}
		if (up[v] == depth[v] && p != -1) {
			if (id[v][p] == -1 || id[p][v] == -1) {
				return true;
			}
		}
		
		return false;
	}
	
	int[] go(int argN, int argM, int[] argVs, int[] argUs, int[][] argId) {
		
//		System.err.println(Arrays.toString(argVs));
//		System.err.println(Arrays.toString(argUs));
		
		n = argN;
		m = argM;
		id = argId;
		par = new int[n];
		up = new int[n];
		depth = new int[n];
		Arrays.fill(depth, -1);
		for (int i = 0; i < n; i++) {
			if (depth[i] == -1) {
				depth[i] = 0;
				if (dfs(i, -1)) {
					return null;
				}
			}
		}
		
		outer: while (true) {
			int[] ret = new int[m];
			for (int i = 0; i < m; i++) {
				int v = argVs[i];
				int u = argUs[i];
				
				if (par[v] == u || par[u] == v) {
					continue;
				}
				
				int x = genRand();
				ret[id[v][u]] += x;
				for (int vv = u; par[vv] != -1; vv = par[vv]) {
					int uu = par[vv];
					int nowId = id[vv][uu];
					if (nowId == -1) {
						nowId = id[uu][vv];
						if (nowId == -1) {
							throw new AssertionError();
						}
						ret[nowId] -= x;
					} else {
						ret[nowId] += x;
					}
				}
				
				for (int vv = v; par[vv] != -1; vv = par[vv]) {
					int uu = par[vv];
					int nowId = id[vv][uu];
					if (nowId == -1) {
						nowId = id[uu][vv];
						if (nowId == -1) {
							throw new AssertionError();
						}
						ret[nowId] += x;
					} else {
						ret[nowId] -= x;
					}
				}
			}
			
			for (int i = 0; i < m; i++) {
				if (ret[i] < -n * n || ret[i] > n * n) {
					continue outer;
				}
				if (ret[i] == 0) {
					int v = argVs[i];
					int u = argUs[i];
					int inv = id[u][v];
					if (inv == -1) {
						continue outer;
					}
					
					if (ret[inv] != -1 && ret[inv] != n * n) {
						ret[i]++;
						ret[inv]++;
					} else {
						ret[i]--;
						ret[inv]--;
					}
					
				}
			}
			
			int[] balance = new int[n];
			for (int i = 0; i < m; i++) {
				int v = argVs[i];
				int u = argUs[i];
				balance[v] += ret[i];
				balance[u] -= ret[i];
			}
			
//			System.err.println(Arrays.toString(balance));
			
			return ret;
		}
	}
	
	static final Random rng = new Random();
	
	int genRand() {
		int ret = 0;
		while (ret == 0) {
			ret = rng.nextInt(5) - 2;
		}
		return ret;
	}

	B() throws IOException {
		switch (INPUT_TYPE) {
		case EXAMPLE: {
			br = new BufferedReader(new InputStreamReader(System.in));
			out = new PrintWriter(System.out);
			break;
		}
		case SMALL: {
			br = new BufferedReader(new FileReader("B-small-attempt"
					+ ATTEMPT_NUMBER + ".in"));
			out = new PrintWriter("B-small-attempt" + ATTEMPT_NUMBER + ".out");
			break;
		}
		case LARGE: {
			br = new BufferedReader(new FileReader("B-large.in"));
			out = new PrintWriter("B-large.out");
			break;
		}
		}
		int t = nextInt();
		for (int i = 1; i <= t; i++) {
			System.err.println("Test " + i);
			out.print("Case #" + i + ": ");
			solve();
		}
		out.close();
	}

	public static void main(String[] args) throws IOException {
		new B();
	}

	String nextToken() {
		while (st == null || !st.hasMoreTokens()) {
			try {
				st = new StringTokenizer(br.readLine());
			} catch (Exception e) {
				eof = true;
				return null;
			}
		}
		return st.nextToken();
	}

	String nextString() {
		try {
			return br.readLine();
		} catch (IOException e) {
			eof = true;
			return null;
		}
	}

	int nextInt() throws IOException {
		return Integer.parseInt(nextToken());
	}

	long nextLong() throws IOException {
		return Long.parseLong(nextToken());
	}

	double nextDouble() throws IOException {
		return Double.parseDouble(nextToken());
	}
}