import java.io.*;
import java.util.*;

public class B {

	BufferedReader br;
	PrintWriter out;
	StringTokenizer st;
	boolean eof;

	enum InputType {
		SAMPLE, SMALL, LARGE;
	}

	static final InputType currentInputType = InputType.SMALL;
	static final int attemptNumber = 0; // for small inputs only

	static final int[] dx = { 1, 0, -1, -1, 0, 1 };
	static final int[] dy = { 1, 1, 0, -1, -1, 0 };

	ArrayList<Integer>[] g;
	int n;
	int m;
	int N;

	int[][] vNum;
	Pair[] coord;
	
	static final int INF = Integer.MAX_VALUE / 2;

	class Pair {
		int x, y;

		public Pair(int x, int y) {
			this.x = x;
			this.y = y;
		}
	}

	boolean onBoard(int x, int y) {
		return x >= 0 && y >= 0 && x <= 2 * n - 2 && y <= 2 * n - 2
				&& x - y <= n - 1 && y - x <= n - 1;
	}
	
	boolean[] hasStone;
	int[] moves;
	int[] whichSide;
	
	class ReachedArea {
		
		int totReached;
		
		int reachMask;
		
		boolean[] active;
		
		void dfs(int v) {
			if (hasStone[v])
				totReached++;
			active[v] = true;
			if (!hasStone[v])
				return;
			if (whichSide[v] != -1)
				reachMask |= 1 << whichSide[v];
			for (int to : g[v])
				if (!active[to])
					dfs(to);
		}
		
		void add(int v) {
			// haveStone update before!
			if (active[v])
				dfs(v);
		}
		
		boolean contains(int v) {
			return hasStone[v] && active[v];
		}
		
		public ReachedArea(int[] init) {
			active = new boolean[N];
			for (int v : init)
				active[v] = true;
		}
		
		public ReachedArea(int init) {
			active = new boolean[N];
			active[init] = true;
		}
	}

	int getBridge() {
		Arrays.fill(hasStone, false);
		int[] init = { vNum[0][0], vNum[0][n - 1], vNum[n - 1][2 * n - 2],
				vNum[2 * n - 2][2 * n - 2], vNum[2 * n - 2][n - 1],
				vNum[n - 1][0] };
		
		ReachedArea[] reach = new ReachedArea[6];
		for (int i = 0; i < 6; i++)
			reach[i] = new ReachedArea(init[i]);
		
		for (int i = 0; i < m; i++) {
			int v = moves[i];
			hasStone[v] = true;
			for (int j = 0; j < 6; j++) {
				reach[j].add(v);
				for (int k = 0; k < 6; k++)
					if (j != k && reach[j].contains(init[k]))
						return i;
			}
		}
		
		return INF;
	}
	
	int getFork() {
		
		whichSide = new int[N];
		Arrays.fill(whichSide, -1);
		
		Arrays.fill(hasStone, false);
		int[][] init = new int[6][n - 2];
		
		for (int i = 0; i < n - 2; i++)
			init[0][i] = vNum[0][i + 1];
		
		for (int i = 0; i < n - 2; i++)
			init[1][i] = vNum[i + 1][i + n];
		
		for (int i = 0; i < n - 2; i++)
			init[2][i] = vNum[i + n][2 * n - 2];
		
		for (int i = 0; i < n - 2; i++)
			init[3][i] = vNum[2 * n - 2][i + n];
		
		for (int i = 0; i < n - 2; i++)
			init[4][i] = vNum[i + n][i + 1];
		
		for (int i = 0; i < n - 2; i++)
			init[5][i] = vNum[i + 1][0];
		
		ReachedArea[] reach = new ReachedArea[6];
		for (int i = 0; i < 6; i++) {
			reach[i] = new ReachedArea(init[i]);
			for (int v : init[i])
				whichSide[v] = i;
		}
		
		for (int i = 0; i < m; i++) {
			int v = moves[i];
			hasStone[v] = true;
			for (int j = 0; j < 6; j++) {
				reach[j].add(v);
				if (Integer.bitCount(reach[j].reachMask) >= 3)
					return i;
			}
		}
		
		return INF;	
	}
	
	boolean[] getRing() {
		boolean[] res = new boolean[m + 1];
		
		int[] border = new int[6 * (n - 1)];
		int ptr = 0;
		for (int i = 0; i < n - 1; i++)
			border[ptr++] = vNum[0][i];
		for (int i = 0; i < n - 1; i++)
			border[ptr++] = vNum[i][n - 1 + i];
		for (int i = 0; i < n - 1; i++)
			border[ptr++] = vNum[n - 1 + i][2 * n - 2];
		for (int i = 0; i < n - 1; i++)
			border[ptr++] = vNum[2 * n - 2][2 * n - 2 - i];
		for (int i = 0; i < n - 1; i++)
			border[ptr++] = vNum[2 * n - 2 - i][n - 1 - i];
		for (int i = 0; i < n - 1; i++)
			border[ptr++] = vNum[n - 1 - i][0];
		
		ReachedArea all = new ReachedArea(border);
		
		Arrays.fill(hasStone, true);
		for (int i = 0; i < m; i++)
			hasStone[moves[i]] = false;
		
		ArrayList<Integer> addQueue = new ArrayList<Integer>();
		
		for (int i = 0; i < N; i++)
			if (hasStone[i])
				addQueue.add(i);
		
		Arrays.fill(hasStone, false);
		
		for (int v : addQueue) {
			hasStone[v] = true;
			all.add(v);
		}
		
		if (all.totReached != N - m)
			res[m] = true;
		
		for (int i = m - 1; i >= 0; i--) {
			hasStone[moves[i]] = true;
			all.add(moves[i]);
			if (all.totReached != N - i)
				res[i] = true;
		}
		
		return res;
	}

	void solve() throws IOException {
		n = nextInt();
		m = nextInt();

		vNum = new int[2 * n - 1][2 * n - 1];

		N = 3 * n * (n - 1) + 1;
		coord = new Pair[N];

		int ptr = 0;
		for (int i = 0; i < 2 * n - 1; i++)
			for (int j = 0; j < 2 * n - 1; j++)
				if (onBoard(i, j)) {
					vNum[i][j] = ptr;
					coord[ptr++] = new Pair(i, j);
				}

		g = new ArrayList[N];
		for (int i = 0; i < N; i++)
			g[i] = new ArrayList<Integer>();

		for (int i = 0; i < N; i++) {
			int nx = coord[i].x;
			int ny = coord[i].y;
			for (int dir = 0; dir < 6; dir++) {
				int cx = nx + dx[dir];
				int cy = ny + dy[dir];
				if (onBoard(cx, cy))
					g[i].add(vNum[cx][cy]);
			}
		}

		moves = new int[m];
		for (int i = 0; i < m; i++) {
			int cx = nextInt() - 1;
			int cy = nextInt() - 1;
			moves[i] = vNum[cx][cy];
		}
		
		
		hasStone = new boolean[N];
		int fork = getFork();
		int bridge = getBridge(); // 0-based, -1 if it doesn't exist
		
		//out.println(bridge + " " + fork);
		
		boolean[] hasRing = getRing();
		
		for (int i = 0; i < m; i++) {
			if (fork <= i || bridge <= i || hasRing[i + 1]) {
				String s = "";
				if (bridge <= i)
					s += "bridge-";
				if (fork <= i)
					s += "fork-";
				if (hasRing[i + 1])
					s += "ring-";
				
				s = s.substring(0, s.length() - 1);
				out.println(s + " in move " + (i + 1));
				return;
			}
		}
		
		out.println("none");
	}

	void inp() throws IOException {
		switch (currentInputType) {
		case SAMPLE:
			br = new BufferedReader(new InputStreamReader(System.in));
			out = new PrintWriter(System.out);
			break;
		case SMALL:
			String fileName = "B-small-attempt" + attemptNumber;
			br = new BufferedReader(new FileReader(fileName + ".in"));
			out = new PrintWriter(fileName + ".out");
			break;
		case LARGE:
			fileName = "B-large";
			br = new BufferedReader(new FileReader(fileName + ".in"));
			out = new PrintWriter(fileName + ".out");
			break;
		}
		int test = nextInt();
		for (int i = 1; i <= test; i++) {
			System.err.println("Running test " + i);
			out.print("Case #" + i + ": ");
			solve();
		}
		out.close();
	}

	public static void main(String[] args) throws IOException {
		new B().inp();
	}

	String nextToken() {
		while (st == null || !st.hasMoreTokens()) {
			try {
				st = new StringTokenizer(br.readLine());
			} catch (Exception e) {
				eof = true;
				return null;
			}
		}
		return st.nextToken();
	}

	String nextString() {
		try {
			return br.readLine();
		} catch (Exception e) {
			eof = true;
			return null;
		}
	}

	int nextInt() throws IOException {
		return Integer.parseInt(nextToken());
	}

	long nextLong() throws IOException {
		return Long.parseLong(nextToken());
	}

	double nextDouble() throws IOException {
		return Double.parseDouble(nextToken());
	}
}
