package vraniak.igor.codejam2015.qualification.B;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Scanner;

public class InfiniteHouseOfPancakes {
	public static final String INPUT_FILE = "B-small-attempt3.in";
	public static final String OUTPUT_FILE = "B-small-attempt3.out";
	
	private int nonEmptyPlates;
	private ArrayList<Integer> dinners;
	private int minutesTaken;
	private String output;
	
	public InfiniteHouseOfPancakes() {
		this.dinners = new ArrayList<Integer>();
	}
	
	public static void main(String[] args) {
		ArrayList<InfiniteHouseOfPancakes> ihps = LoadInputFile(INPUT_FILE);

		// Iterate through all cases
		for (int i = 0; i < ihps.size(); i++) {
			InfiniteHouseOfPancakes ihp = ihps.get(i);
			
			boolean done = false;
			
			do {
				// Get max number of pancakes
				int maxPancakes = ihp.getMaxPancakes(ihp);
				
				int minutesTaken = ihp.minutesTaken + maxPancakes;
				int minutesTakenWithSpecial = ihp.minutesTaken + ihp.getMinutesTakenWithSpecialMinutes(ihp, maxPancakes);
				
				if (minutesTaken < minutesTakenWithSpecial) {
					ihp.minutesTaken = minutesTaken;
					done = true;
				} else {
					ihp.issueSpecialMinutes(ihp, maxPancakes);
				}
			} while (!done);
			
			ihp.output = "Case #" + (i + 1) + ": " + ihp.minutesTaken;
		}
		
		// Log
		for (int i = 0; i < ihps.size(); i++) {
			InfiniteHouseOfPancakes ihp = ihps.get(i);
			
			System.out.println(ihp.nonEmptyPlates);
			for (int j = 0; j < ihp.dinners.size(); j++) {
				System.out.print(ihp.dinners.get(j) + " ");
			}
			System.out.println("= " + ihp.minutesTaken);
		}
		
		SaveOutputFile(ihps, OUTPUT_FILE);
	}
	
	// Get max number of pancakes
	private int getMaxPancakes(InfiniteHouseOfPancakes ihp) {
		int maxPancakes = 0;
		for (int i = 0; i < ihp.dinners.size(); i++) {
			if (ihp.dinners.get(i) > maxPancakes) {
				maxPancakes = ihp.dinners.get(i);
			}
		}
		return maxPancakes;
	}
	
	// Issue special minutes for occurrences of max pancakes
	private void issueSpecialMinutes(InfiniteHouseOfPancakes ihp, int maxPancakes) {
		// Split all dinners with max pancakes
		for (int i = 0; i < ihp.dinners.size(); i++) {
			if (ihp.dinners.get(i) == maxPancakes && maxPancakes != 9) {
				int pancakesToMove = ihp.dinners.get(i) / 2;
				// Decrease pancakes from existing dinner
				int remainingPancakes = ihp.dinners.get(i) - pancakesToMove;
				ihp.dinners.set(i, remainingPancakes);
				// Move pancakes to new dinner
				ihp.dinners.add(pancakesToMove);
				
				// Increase minutes taken
				ihp.minutesTaken++;
			}
			
			if (ihp.dinners.get(i) == maxPancakes && maxPancakes == 9) {
				int pancakesToMove = ihp.dinners.get(i) - 6;
				// Decrease pancakes from existing dinner
				int remainingPancakes = ihp.dinners.get(i) - pancakesToMove;
				ihp.dinners.set(i, remainingPancakes);
				// Move pancakes to new dinner
				ihp.dinners.add(pancakesToMove);
				
				// Increase minutes taken
				ihp.minutesTaken++;
			}
		}
	}
	
	// Get minutes taken with special minutes for all dinners with max pancakes
	private int getMinutesTakenWithSpecialMinutes(InfiniteHouseOfPancakes ihp, int maxPancakes) {
		int specialMinutes = 0;
		int newMaxPancakes = 0;
		
		// Divide all dinners with max pancakes
		for (int i = 0; i < ihp.dinners.size(); i++) {
			// Skip iteration if we find - to be max dinner which we might split
			if (ihp.dinners.get(i) == maxPancakes) {
				specialMinutes++;
				
				// Check if max dinner split will be new max dinner
				if (newMaxPancakes < maxPancakes / 2 + maxPancakes % 2 && maxPancakes != 9) {
					newMaxPancakes = maxPancakes / 2 + maxPancakes % 2;
				} 
				// 9
				if (newMaxPancakes < maxPancakes - 3) {
					newMaxPancakes = maxPancakes - 3;
				}
				
				continue;
			}
			
			// Check for new max dinner
			if (ihp.dinners.get(i) > newMaxPancakes) {
				newMaxPancakes = ihp.dinners.get(i);
			}
		}
		
		return newMaxPancakes + specialMinutes;
	}
	
	private static ArrayList<InfiniteHouseOfPancakes> LoadInputFile(String path) {
		ArrayList<InfiniteHouseOfPancakes> ihps = new ArrayList<InfiniteHouseOfPancakes>();
		File file = new File(path);
		
		try {
			FileReader fr = new FileReader(file);
			BufferedReader br = new BufferedReader(fr);
			// Read number of test cases
			int cases = Integer.parseInt(br.readLine());
			
			// Loop through all lines
			for (int index = 0; index < cases; index++) {
				InfiniteHouseOfPancakes ihp = new InfiniteHouseOfPancakes();
				
				// Number of dinners with non empty plates
				ihp.nonEmptyPlates = Integer.parseInt(br.readLine());
				
				String line = br.readLine();
				Scanner sc = new Scanner(line);
				
				while (sc.hasNextInt()) {
					ihp.dinners.add(sc.nextInt());
				}
				
				sc.close();
				
				ihps.add(ihp);
			}
			br.close();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return ihps;
	}
	
	private static void SaveOutputFile(ArrayList<InfiniteHouseOfPancakes> ihps, String path) {
		File file = new File(path);
		
		try {
			FileWriter fw = new FileWriter(file);
			BufferedWriter bw = new BufferedWriter(fw);
			
			for (int i = 0; i < ihps.size(); i++) {
				bw.write(ihps.get(i).output);
				bw.newLine();
			}
			
			bw.flush();
			bw.close();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
