package com.zingler.googlecodejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

import lombok.AllArgsConstructor;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import com.google.common.collect.HashBasedTable;
import com.google.common.collect.Lists;
import com.google.common.collect.Table;

public class Dijkstra {
    public static void main( String[] args ) throws FileNotFoundException {
        File input = new File( "C-small-attempt0.in" );
        Scanner scan = new Scanner( input );
        File output = new File( "output.txt" );
        PrintWriter out = new PrintWriter( new FileOutputStream( output ) );

        int testcases = scan.nextInt();
        for ( int testCaseId = 1; testCaseId <= testcases; testCaseId++ ) {
            System.out.println( "Starting test " + testCaseId );
            int charLength = scan.nextInt();
            int repeats = scan.nextInt();
            String string = scan.next();

            boolean doAble = solve( repeats, string );
            out.println( String.format( "Case #%d: %s", testCaseId, doAble ? "YES" : "NO" ) );
        }

        scan.close();
        out.close();
        System.out.println( "DONE" );
    }

    public static final Quaternion I = new Quaternion( Q.I, false );
    public static final Quaternion J = new Quaternion( Q.J, false );
    public static final Quaternion K = new Quaternion( Q.K, false );
    public static final Quaternion J_TIMES_K = J.multipleBy( K );

    private static boolean solve( int repeats, String string ) {
        if ( string.length() * repeats < 3 ) {
            return false;
        }
        ArrayList<Quaternion> quaternions = new ArrayList<>();
        for ( int i = 0; i < repeats; i++ ) {
            string.chars().mapToObj( c -> new Quaternion( Q.fromChar( c ), false ) ).forEach( quaternions::add );
        }

        List<Quaternion> backwardsProduct = new ArrayList<>( quaternions.size() );

        Quaternion product = new Quaternion( Q.ONE, false );
        for ( int i = quaternions.size() - 1; i >= 0; i-- ) {
            product = quaternions.get( i ).multipleBy( product );
            backwardsProduct.add( product );
        }

        backwardsProduct = Lists.reverse( backwardsProduct );

        product = new Quaternion( Q.ONE, false );
        for ( int i = 0; i < quaternions.size() - 2; i++ ) {
            product = product.multipleBy( quaternions.get( i ) );
            if ( product.equals( I ) && backwardsProduct.get( i + 1 ).equals( J_TIMES_K ) ) {
                boolean foundJKSplit = huntJK( quaternions, i + 1 );
                if ( foundJKSplit ) {
                    return true;
                }
            }
        }

        return false;
    }

    private static boolean huntJK( List<Quaternion> quaternions, int start ) {
        List<Quaternion> forwardsProduct = new ArrayList<>();

        Quaternion product = new Quaternion( Q.ONE, false );
        for ( int i = start; i < quaternions.size() - 1; i++ ) {
            product = product.multipleBy( quaternions.get( i ) );
            forwardsProduct.add( product );
        }

        product = new Quaternion( Q.ONE, false );
        for ( int i = quaternions.size() - 1; i > start; i-- ) {
            product = quaternions.get( i ).multipleBy( product );
            if ( product.equals( K ) && forwardsProduct.get( i - 1 - start ).equals( J ) ) {
                return true;
            }
        }
        return false;
    }

    @AllArgsConstructor
    @EqualsAndHashCode
    @ToString
    private static class Quaternion {
        Q q;
        boolean negative;

        private static final Table<Q, Q, Quaternion> multiplicationTable;
        static {
            multiplicationTable = HashBasedTable.create();
            multiplicationTable.put( Q.ONE, Q.ONE, new Quaternion( Q.ONE, false ) );
            multiplicationTable.put( Q.ONE, Q.I, new Quaternion( Q.I, false ) );
            multiplicationTable.put( Q.ONE, Q.J, new Quaternion( Q.J, false ) );
            multiplicationTable.put( Q.ONE, Q.K, new Quaternion( Q.K, false ) );
            multiplicationTable.put( Q.I, Q.ONE, new Quaternion( Q.I, false ) );
            multiplicationTable.put( Q.I, Q.I, new Quaternion( Q.ONE, true ) );
            multiplicationTable.put( Q.I, Q.J, new Quaternion( Q.K, false ) );
            multiplicationTable.put( Q.I, Q.K, new Quaternion( Q.J, true ) );
            multiplicationTable.put( Q.J, Q.ONE, new Quaternion( Q.J, false ) );
            multiplicationTable.put( Q.J, Q.I, new Quaternion( Q.K, true ) );
            multiplicationTable.put( Q.J, Q.J, new Quaternion( Q.ONE, true ) );
            multiplicationTable.put( Q.J, Q.K, new Quaternion( Q.I, false ) );
            multiplicationTable.put( Q.K, Q.ONE, new Quaternion( Q.K, false ) );
            multiplicationTable.put( Q.K, Q.I, new Quaternion( Q.J, false ) );
            multiplicationTable.put( Q.K, Q.J, new Quaternion( Q.I, true ) );
            multiplicationTable.put( Q.K, Q.K, new Quaternion( Q.ONE, true ) );

        }

        public Quaternion multipleBy( Quaternion q ) {
            Quaternion result = multiplicationTable.get( this.q, q.q ).clone();
            if ( this.negative != q.negative ) {
                result.negative = !result.negative;
            }
            return result;
        }

        @Override
        public Quaternion clone() {
            return new Quaternion( this.q, this.negative );
        }
    }

    enum Q {
        ONE,
        I, J, K;

        public static Q fromChar( int c ) {
            switch ( c ) {
            case 'i':
                return I;
            case 'j':
                return J;
            case 'k':
                return K;
            default:
                return ONE;
            }
        }
    }
}
