package com.zingler.googlecodejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collection;
import java.util.PriorityQueue;
import java.util.Scanner;
import java.util.SortedMap;
import java.util.TreeMap;

import lombok.ToString;

public class Pancakes {

    public static void main( String[] args ) throws FileNotFoundException {
        File input = new File( "B-small-attempt2.in" );
        Scanner scan = new Scanner( input );
        File output = new File( "output.txt" );
        PrintWriter out = new PrintWriter( new FileOutputStream( output ) );

        int testcases = scan.nextInt();
        for ( int testCaseId = 1; testCaseId <= testcases; testCaseId++ ) {
            int diners = scan.nextInt();
            PancakeCounts counts = new PancakeCounts();
            for ( int i = 0; i < diners; i++ ) {
                counts.addStack( scan.nextInt() );
            }

            int secondsNeeded = solve( counts );
            out.println( String.format( "Case #%d: %d", testCaseId, secondsNeeded ) );
        }

        scan.close();
        out.close();
        System.out.println( "DONE" );

    }

    private static int solve( PancakeCounts pancakeCounts ) {
        int maxSolution = justEatSolution( pancakeCounts );
        int bestSolution = Integer.MAX_VALUE;
        PriorityQueue<PancakeCounts> states = new PriorityQueue<>();
        states.add( pancakeCounts );

        while ( !states.isEmpty() ) {
            PancakeCounts current = states.poll();
            states.addAll( splitMax( current ) );
            int currentSolution = current.steps + justEatSolution( current );
            PancakeCounts nextHueristicState = states.peek();
            if ( currentSolution < bestSolution ) {
                bestSolution = currentSolution;
            }

            if ( nextHueristicState == null ) {
                return bestSolution;
            }
            int nextHeuristicSolution = nextHueristicState.admissibleDistanceFromSolution();
            if ( bestSolution <= nextHeuristicSolution ) {
                return bestSolution;
            }
        }
        // Shouln't happen
        System.out.println( "STAAAHPPP!" );
        return maxSolution;
    }

    public static Collection<PancakeCounts> splitMax( PancakeCounts pancakeCount ) {
        Collection<PancakeCounts> newStates = new ArrayList<>( pancakeCount.getMaxStack() );
        int maxStacks = pancakeCount.getMaxStack();
        for ( int i = 1; i < maxStacks; i++ ) {
            PancakeCounts newState = pancakeCount.copy();
            newState.steps++;
            newState.removeStack( maxStacks );
            newState.addStack( i );
            newState.addStack( maxStacks - i );
            newStates.add( newState );
        }
        return newStates;
    }

    private static int justEatSolution( PancakeCounts pancakeCounts ) {
        return pancakeCounts.getMaxStack();
    }

    @ToString
    private static class PancakeCounts implements Comparable<PancakeCounts> {
        int steps = 0;
        SortedMap<Integer, Integer> pancakeCountsMap;

        public PancakeCounts() {
            this.pancakeCountsMap = new TreeMap<>();
        }

        public int getMaxStack() {
            return this.pancakeCountsMap.lastKey();
        }

        public void addStack( int height ) {
            this.pancakeCountsMap.merge( height, 1, ( x, y ) -> x + y );
        }

        public void removeStack( int height ) {
            int newCountOfHeight = this.pancakeCountsMap.get( height ) - 1;
            if ( newCountOfHeight == 0 ) {
                this.pancakeCountsMap.remove( height );
            } else {
                this.pancakeCountsMap.put( height, newCountOfHeight );
            }
        }

        public PancakeCounts copy() {
            PancakeCounts p = new PancakeCounts();
            p.pancakeCountsMap.putAll( this.pancakeCountsMap );
            p.steps = this.steps;
            return p;
        }

        @Override
        public int compareTo( PancakeCounts o ) {
            return -o.admissibleDistanceFromSolution() + admissibleDistanceFromSolution();
        }

        public int admissibleDistanceFromSolution() {
            return this.steps + (int) Math.floor( Math.log( getMaxStack() ) / Math.log( 2 ) );
        }
    }
}
