import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.*;

public class KingdomRush {
    public static class Level {
        private int index;
        private int oneStar;
        private int twoStars;
        private boolean completeOne;

        public Level(int index, int oneStar, int twoStars) {
            this.index = index;
            this.oneStar = oneStar;
            this.twoStars = twoStars;
            this.completeOne = false;
        }

        public int getIndex() {
            return index;
        }

        public int getOneStar() {
            return oneStar;
        }

        public int getTwoStars() {
            return twoStars;
        }

        public boolean isCompleteOne() {
            return completeOne;
        }

        public void completeOne() {
            completeOne = true;
        }

    }

    public static void main(String[] args) {
        try {
            Scanner in = new Scanner(new File("B-small-attempt0.in"));
            PrintWriter out = new PrintWriter(new FileWriter("B.out"));

            int cases = in.nextInt();
            in.nextLine();
            for (int i = 0; i < cases; i++) {
                String answer = solve(in);
                out.println(String.format("Case #%d: %s", i+1, answer));
            }

            in.close();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static String solve(Scanner in) {
        int numLevels = in.nextInt();
        in.nextLine();

        List<Level> twoStarQueue = new ArrayList<Level>();
        List<Level> oneStarQueue = new ArrayList<Level>();

        for (int i = 0; i < numLevels; i++) {
            Level level = new Level(i, in.nextInt(), in.nextInt());
            twoStarQueue.add(level);
            oneStarQueue.add(level);
            in.nextLine();
        }

        Collections.sort(twoStarQueue, new Comparator<Level>() {
            public int compare(Level o1, Level o2) {
                return o1.twoStars - o2.twoStars;
            }
        });

        Collections.sort(oneStarQueue, new Comparator<Level>() {
            public int compare(Level o1, Level o2) {
                if (o1.oneStar == o2.oneStar) {
                    return o2.twoStars - o1.twoStars;
                }
                return o1.oneStar - o2.oneStar;
            }
        });

        int stars = 0;
        int levelsPlayed = 0;

        BigInteger allComplete = new BigInteger("2").pow(numLevels).add(BigInteger.ONE.negate());
        BigInteger completed = BigInteger.ZERO;

        while (!(completed.equals(allComplete))) {
            if (!twoStarQueue.isEmpty()) {
                Level level = twoStarQueue.get(0);
                if (level.getTwoStars() <= stars) {
                    levelsPlayed++;
                    stars += level.isCompleteOne() ? 1 : 2;
                    twoStarQueue.remove(0);
                    oneStarQueue.remove(level);
                    completed = completed.setBit(level.getIndex());
                    continue;
                }
            }

            if (!oneStarQueue.isEmpty()) {
                Level level = oneStarQueue.get(0);
                if (level.getOneStar() <= stars) {
                    levelsPlayed++;
                    stars += level.isCompleteOne() ? 0 : 1;
                    level.completeOne();
                    oneStarQueue.remove(0);
                } else {
                    break;
                }
            } else {
                break;
            }
        }

        return completed.equals(allComplete) ? String.valueOf(levelsPlayed) : "Too Bad";
    }
}
