import java.io.*;
import java.util.Scanner;

public class Tomek {

    static class Board {
        private char[] data = new char[16];

        public Board(Scanner scanner) throws IOException {
            for (int i = 0; i < 4; i++) {
                String line = scanner.nextLine();
                for (int j = 0; j < line.length(); j++) {
                    data[i*4+j] = line.charAt(j);
                }
            }
            scanner.nextLine();
        }

        public boolean isDraw() {
            for (int i = 0; i < data.length; i++) {
                if (data[i] == '.') {
                    return false;
                }
            }
            return true;
        }

        public boolean xWins() {
            return winsByRow('X') || winsByColumn('X') || winsByLeftDiagonal('X') || winsByRightDiagonal('X');
        }

        public boolean oWins() {
            return winsByRow('O') || winsByColumn('O') || winsByLeftDiagonal('O') || winsByRightDiagonal('O');
        }

        private boolean winsByRow(char player) {
            for (int r = 0; r < 4; r++) {
                boolean won = true;
                for (int c = 0; c < 4; c++) {
                    if (data[r*4+c] != player && data[r*4+c] != 'T') {
                        won = false;
                        break;
                    }
                }
                if (won) return true;
            }
            return false;
        }

        private boolean winsByColumn(char player) {
            for (int c = 0; c < 4; c++) {
                boolean won = true;
                for (int r = 0; r < 4; r++) {
                    if (data[r*4+c] != player && data[r*4+c] != 'T') {
                        won = false;
                        break;
                    }
                }
                if (won) return true;
            }
            return false;
        }

        private boolean winsByLeftDiagonal(char player) {
            for (int i = 0; i < 4; i++) {
                if (data[i*4+i] != player && data[i*4+i] != 'T') {
                    return false;
                }
            }
            return true;
        }

        private boolean winsByRightDiagonal(char player) {
            for (int i = 0; i < 4; i++) {
                if (data[i*4+(3-i)] != player && data[i*4+(3-i)] != 'T') {
                    return false;
                }
            }
            return true;
        }
    }

    public static void main(String[] args) {
        String fileName = args[0];
        try (PrintWriter out = new PrintWriter(new FileWriter("A.out"))) {
            try (Reader in = new FileReader(fileName)) {
                Scanner scanner = new Scanner(in);
                int cases = scanner.nextInt();
                scanner.nextLine();
                for (int i = 0; i < cases; i++) {
                    out.print(String.format("Case #%d: ", i+1));
                    Board board = new Board(scanner);
                    if (board.xWins()) {
                        out.println("X won");
                    } else if (board.oWins()) {
                        out.println("O won");
                    } else if (board.isDraw()) {
                        out.println("Draw");
                    } else {
                        out.println("Game has not completed");
                    }
                }
            } catch (IOException e) {
                System.err.println(e);
            }
        } catch (IOException e) {
            System.err.println(e);
        }
    }
}
