import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;


public class Solution {

	public static void main(String[] args) {
		new Solution();
	}
	
	public Solution() {
		// Built-in scanner to read input file
		Scanner s = null;
		try {
			s = new Scanner(new File("input.txt"));
		} catch (FileNotFoundException e) {
			System.err.println("Input file not found");
			e.printStackTrace();
			System.exit(1);
		}
		s.useDelimiter(" |\\n");
		
		// Built-in writer to save the results
		PrintWriter out = null;
		try {
			out = new PrintWriter("output.txt");
		} catch (FileNotFoundException e) {
			System.err.println("Output file not writable");
			e.printStackTrace();
			System.exit(1);
		}
		
		// Number of test grids to read
		final int T = s.nextInt();
		
		String result;
		// For each test grid
		for(int test=1;test<=T;test++) {
			final int N = s.nextInt();
			final int M = s.nextInt();
			// Fill the corresponding array
			int[][] grid = new int[N][M];
			for(int i=0;i<N;i++) {
				for(int j=0;j<M;j++) {
					grid[i][j] = s.nextInt();
				}
			}
			// Find the result and display it
			result = this.compute(grid,N,M);
			out.println("Case #"+test+": "+result);
		}
		
		s.close();
		out.flush();
		out.close();
	}
	
	/*
	 * Algorithm, complexity O(4*N*M), using :
	 * 
	 *  Theroem (not proved) : 
	 *  A pattern is possible if for each 1x1 point in the grid,
	 *  it is possible to reach (the top and the bottom) or (the
	 *  left and the right) bounds of the grid, without passing
	 *  by points with heights strictly higher than the original
	 *  point.
	 */
	public final String compute(final int[][] grid,final int N,final int M) {
		
		boolean[][] horizontalScan = new boolean[N][M];
		boolean[][] verticalScan = new boolean[N][M];
		
		// Horizontal scan
		for(int i=0;i<N;i++) {
			int maxVal = Integer.MIN_VALUE;
			for(int j=0;j<M;j++) { // Can (i,j) reach the left bound ?
				horizontalScan[i][j] = (grid[i][j]>=maxVal);
				maxVal = Math.max(maxVal,grid[i][j]);
			}
			maxVal = Integer.MIN_VALUE;
			for(int j=M-1;j>=0;j--) { // Can (i,j) reach the left and right bounds ?
				horizontalScan[i][j] = (horizontalScan[i][j] && grid[i][j]>=maxVal);
				maxVal = Math.max(maxVal,grid[i][j]);
			}
		}
		// Vertical scan
		for(int j=0;j<M;j++) {
			int maxVal = Integer.MIN_VALUE;
			for(int i=0;i<N;i++) { // Can (i,j) reach the top bound ?
				verticalScan[i][j] = (grid[i][j]>=maxVal);
				maxVal = Math.max(maxVal,grid[i][j]);
			}
			maxVal = Integer.MIN_VALUE;
			for(int i=N-1;i>=0;i--) { // Can (i,j) reach the bottom and top bounds ?
				verticalScan[i][j] = (verticalScan[i][j] && grid[i][j]>=maxVal);
				maxVal = Math.max(maxVal,grid[i][j]);
			}
		}
		
		// Check if all points can reach top and left, or top and bottom.
		for(int i=0;i<N;i++) {
			for(int j=0;j<M;j++) {
				if(!horizontalScan[i][j] && !verticalScan[i][j])
					return "NO";
			}
		}
		
		return "YES";
	}

}
