import java.io.*;
import java.util.Scanner;
import java.math.BigInteger;

/**
 * @author Iskander Akishev
 */
public class Cards {
	private static final String FILE_NAME = "C-large";

	private static class BigRational {
		final BigInteger a, b;
		public static final BigRational ZERO = new BigRational(BigInteger.ZERO);
		public static final BigRational ONE = new BigRational(BigInteger.ONE);

		private BigRational(BigInteger a, BigInteger b) {
			BigInteger gcd = a.gcd(b);
			a = a.divide(gcd);
			b = b.divide(gcd);
			if (b.compareTo(BigInteger.ZERO) < 0) {
				a = a.negate();
				b = b.negate();
			}
			this.a = a;
			this.b = b;
		}

		private BigRational(BigInteger a) {
			this.a = a;
			this.b = BigInteger.ONE;
		}

		public double doubleValue() {
			return a.doubleValue() / b.doubleValue();
		}

		public BigRational multiply(BigRational x) {
			return new BigRational(a.multiply(x.a), b.multiply(x.b));
		}

		public BigRational divide(BigRational x) {
			if (a.equals(BigInteger.ZERO)) {
				return this;
			}
			return new BigRational(a.multiply(x.b), b.multiply(x.a));
		}

		public BigRational add(BigRational x) {
			return new BigRational(a.multiply(x.b).add(b.multiply(x.a)), b.multiply(x.b));
		}

		public BigRational substract(BigRational x) {
			return new BigRational(a.multiply(x.b).subtract(b.multiply(x.a)), b.multiply(x.b));
		}

		@Override
		public String toString() {
			return Double.toString(doubleValue());
		}
	}

	public static void main(String[] args) throws IOException {
		BufferedReader in = new BufferedReader(new FileReader(FILE_NAME + ".in"));
		PrintWriter out = new PrintWriter(new BufferedWriter(new FileWriter(FILE_NAME + ".out")));

		final int N = 50;
		BigInteger[][] c = new BigInteger[N + 1][];
		for (int i = 0; i <= N; i++) {
			c[i] = new BigInteger[i + 1];
			c[i][0] = c[i][i] = BigInteger.ONE;
			for (int j = 1; j < i; j++) {
				c[i][j] = c[i - 1][j].add(c[i - 1][j - 1]);
			}
		}

		int numberOfCases = Integer.parseInt(in.readLine().trim());
		for (int caseNumber = 1; caseNumber <= numberOfCases; caseNumber++) {
			Scanner s = new Scanner(in.readLine());
			int m = s.nextInt();
			int n = s.nextInt();
			BigRational[] f = new BigRational[m + 1];

			f[m] = BigRational.ZERO;
			for (int k = m - 1; k >= 0; k--) {
				BigRational v = BigRational.ZERO;
				BigRational t = null;
				for (int x = 0, lim = Math.min(n, k); x <= lim; x++) {
					if (n - x > m - k) continue;
					BigRational p = new BigRational(c[k][x].multiply(c[m - k][n - x]), c[m][n]);
					if (x == n) {
						t = BigRational.ONE.substract(p);
					} else {
						v = v.add(p.multiply(f[k + n - x]));
					}
				}
				v = v.add(BigRational.ONE);
				if (t != null) {
					v = v.divide(t);
				}
				f[k] = v;
			}

			System.out.println(caseNumber + " " + f[0]);
			out.println("Case #" + caseNumber + ": " + f[0].doubleValue());
		}

		in.close();
		out.close();
	}


}