import java.io.*;
import java.util.*;

/**
 * @author Iskander Akishev
 */
public class Watersheds {

    private final static String FILE_NAME = "B-large";

    private final static Random rnd = new Random(123); 
    private final static int[] di = {-1, 0, 0, 1};
    private final static int[] dj = {0, -1, 1, 0};
    private static long[][] p;

    public static void main(String[] args) throws IOException {
        BufferedReader in = new BufferedReader(new FileReader(FILE_NAME + ".in"));
        PrintWriter out = new PrintWriter(new File(FILE_NAME + ".out"));
        int t = Integer.parseInt(in.readLine());

        for (int caseNum = 1; caseNum <= t; caseNum++) {
            StringTokenizer st = new StringTokenizer(in.readLine());
            int h = Integer.parseInt(st.nextToken());
            int w = Integer.parseInt(st.nextToken());
            if (st.hasMoreTokens()) throw new AssertionError();
            long[][] v = new long[h + 2][w + 2];
            Arrays.fill(v[0], Long.MAX_VALUE);
            Arrays.fill(v[h + 1], Long.MAX_VALUE);
            for (int i = 1; i <= h; i++) {
                st = new StringTokenizer(in.readLine());
                v[i][0] = v[i][w + 1] = Long.MAX_VALUE;
                for (int j = 1; j <= w; j++) {
                    v[i][j] = Long.parseLong(st.nextToken());
                }
                if (st.hasMoreTokens()) throw new AssertionError();
            }

            p = new long[h + 2][w + 2];
            for (int i = 1; i <= h; i++) {
                for (int j = 1; j <= w; j++) {
                    p[i][j] = pack(i, j);
                }
            }

            for (int i = 1; i <= h; i++) {
                for (int j = 1; j <= w; j++) {
                    int minDir = -1;
                    long minVal = v[i][j];
                    for (int dir = 0; dir < 4; dir++) {
                        long val = v[i + di[dir]][j + dj[dir]];
                        if (val < minVal) {
                            minDir = dir;
                            minVal = val;
                        }
                    }
                    if (minDir > -1) {
                        merge(i, j, i + di[minDir], j + dj[minDir]);
                    }
                }
            }

            Map<Long, Character> matching = new HashMap<Long, Character>();
            char cc = 'a';
            out.println("Case #" + caseNum + ":");
            for (int i = 1; i <= h; i++) {
                for (int j = 1; j <= w; j++) {
                    long val = get(i, j);
                    Character c = matching.get(val);
                    if (c == null) {
                        c = cc++;
                        matching.put(val, c);
                    }
                    out.print(c + " ");
                }
                out.println();
            }
            System.out.println(caseNum);
        }

        in.close();
        out.close();
    }

    private static long pack(int i, int j) {
        return ((i & 0xFFFFFFFFL) << 32) | (j & 0xFFFFFFFFL);
    }

    private static int unpackI(long l) {
        return (int) (l >> 32);
    }

    private static int unpackJ(long l) {
        return (int) (l & 0xFFFFFFFFL);
    }

    private static void merge(int i1, int j1, int i2, int j2) {
        if (rnd.nextBoolean()) {
            int tt;
            tt = i1;
            i1 = i2;
            i2 = tt;

            tt = j1;
            j1 = j2;
            j2 = tt;
        }
        long g1 = get(i1, j1);
        long g2 = get(i2, j2);
        if (rnd.nextBoolean()) {
            long tmp = g1;
            g1 = g2;
            g2 = tmp;
        }
        int i = unpackI(g1);
        int j = unpackJ(g1);
        p[i][j] = g2;
    }


    private static long get(int i, int j) {
        return get(pack(i, j));
    }

    private static long get(long v) {
        int i = unpackI(v);
        int j = unpackJ(v);
        if (p[i][j] != v) {
            p[i][j] = get(p[i][j]);
        }
        return p[i][j];
    }
}
