import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Scanner;

/**
 * @author Iskander Akishev
 */
public class Blade {

	public static void main(String[] args) throws IOException {
		Scanner in = new Scanner(new FileReader("input.txt"));
		PrintWriter out = new PrintWriter(new FileWriter("output.txt"));

		int numberOfTests = in.nextInt();
		for (int i = 1; i <= numberOfTests; i++) {
			new Blade().solve(in, out, i);
		}

		in.close();
		out.close();
	}

	private void solve(Scanner in, PrintWriter out, int testNumber) {
		int r = in.nextInt();
		int c = in.nextInt();
		in.nextInt();

		int[][] wa = new int[r][c];
		int[][] wb = new int[c][r];

		boolean[][] za = new boolean[r][c];
		boolean[][] zb = new boolean[c][r];

		for (int i = 0; i < r; i++) {
			char[] chars = in.next().trim().toCharArray();
			for (int j = 0; j < c; j++) {
				wa[i][j] = wb[j][i] = chars[j] - '0';
			}
		}

		int[][] sa = sums(r, c, wa);
		int[][] sb = sums(c, r, wb);

		int[] xa = new int[c];
		int[] xb = new int[r];

		int best = -1;

		LOOP: for (int k = Math.min(r, c); k >= 3; k--) {
			check(k, r, c, wa, sa, xa, za);
			check(k, c, r, wb, sb, xb, zb);
			for (int i = 0; i <= r - k; i++) {
				for (int j = 0; j <= c - k; j++) {
					if (za[i][j] && zb[j][i]) {
						best = k;
						System.out.println(i + " " + j);
						break LOOP;
					}
				}
			}
		}

		String msg = "Case #" + testNumber + ": " + (best == -1 ? "IMPOSSIBLE" : best);
		out.println(msg);
		System.out.println(msg);
	}

	private int[][] sums(int r, int c, int[][] w) {
		int[][] s = new int[r + 1][c];
		for (int i = 0; i < r; i++) {
			for (int j = 0; j < c; j++) {
				s[i + 1][j] = s[i][j] + w[i][j];
			}
		}
		return s;
	}

	private void check(int k, int r, int c, int[][] w, int[][] s, int[] x, boolean[][] z) {
		boolean odd = (k & 1) == 1;

		int k2 = k / 2;

		for (int i1 = 0; ; i1++) {
			int i2 = i1 + k;
			if (i2 > r) {
				break;
			}

			for (int j = 0; j < c; j++) {
				x[j] = s[i2][j] - s[i1][j];
			}

			int j1 = 0;
			int j2 = j1 + k2;
			int j4 = j1 + k;
			int j3 = j4 - k2;

			int sx1 = 0;
			int sy1 = 0;
			int sx2 = 0;
			int sy2 = 0;
			for (int j = 0; j < k2; j++) {
				int jj;

				jj = j2 - 1 - j;
				sx1 += x[jj];
				sy1 += (j + 1) * x[jj];

				jj = j3 + j;
				sx2 += x[jj];
				sy2 += (j + 1) * x[jj];
			}

			while (true) {
				int dw1 = w[i1][j1    ] + w[i2 - 1][j1    ];
				int dw2 = w[i1][j4 - 1] + w[i2 - 1][j4 - 1];

				int qx1 = sx1 - dw1;
				int qx2 = sx2 - dw2;
				int qy1 = sy1 - k2 * dw1;
				int qy2 = sy2 - k2 * dw2;

				if (odd) {
					z[i1][j1] = (qy1 == qy2);
				} else {
					z[i1][j1] = (2 * qy1 - qx1 == 2 * qy2 - qx2);
				}

				if (j4 + 1 > c) {
					break;
				}

				sx1 += x[j2] - x[j1];
				sy1 += sx1 - k2 * x[j1];

				j1++;
				j2++;

				sy2 += k2 * x[j4] - sx2;
				sx2 += x[j4] - x[j3];

				j3++;
				j4++;
			}
		}
	}

}
