import java.util.*;
import java.io.*;
import java.nio.charset.*;
import java.nio.file.*;

public class Main {

	// Class

	// Main Method
	public static void main(String[] args) throws FileNotFoundException  {
		InputReader in = new InputReader("input.in");
		
		int T = in.readInt();
		final Solver solver = new Solver();
		String[] ans = new String[T];
		for(int i = 0; i < T; i++) {
			int J = in.readInt();
			int P = in.readInt();
			int S = in.readInt();
			int K = in.readInt();

			ans[i] = "Case #" + (i+1) + ": " + solver.solve(J, P, S, K);
		}

		IOUtils.write("output.out", ans);
	}
}

class Solver {
     public String solve(int J, int P, int S, int K) {
        // J <= P <= S
        List<String> outfits = new ArrayList<>();
        HashMap<String, Integer> combination = new HashMap<>();


        for(int j = 0; j < J; j++) {
        	for(int p = 0; p < P; p++) {
        		for(int s = 0; s < S; s++) {
        			String JP = genJP(j, p);
        			String JS = genJS(j, s);
        			String PS = genPS(p, s);

        			Integer cJP = combination.get(JP);
        			Integer cJS = combination.get(JS);
        			Integer cPS = combination.get(PS);

        			if(cJP == null) cJP = 0;
        			if(cJS == null) cJS = 0;
        			if(cPS == null) cPS = 0;

        			if(cJP >= K) continue;
        			if(cJS >= K) continue;
        			if(cPS >= K) continue;

        			String outfit = generateOutfit(j, p, s);
        			combination.put(JP, cJP + 1);
        			combination.put(JS, cJS + 1);
        			combination.put(PS, cPS + 1);

        			outfits.add(outfit);
        		}
        	}
        }
        
        String result = outfits.size() + "";
        for(int i = 0; i < outfits.size(); i++) {
            result += "\n" + outfits.get(i);
        }
        
        return result;
    }
    

    private String generateOutfit(int j, int p, int s) {
        return (j+1) + " " + (p+1) + " " + (s+1);
    }

    private String genJP(int j, int p) {
    	return "J" + (j+1) + "P" + (p+1);
    }

    private String genJS(int j, int s) {
    	return "J" + (j+1) + "S" + (s+1);
    }

    private String genPS(int p, int s) {
    	return "P" + (p+1) + "S" + (s+1);
    }

}

class InputReader {
 
	private InputStream stream;
	private byte[] buf = new byte[1024];
	private int curChar;
	private int numChars;
	private SpaceCharFilter filter;

	public InputReader(InputStream stream) {
		this.stream = stream;
	}

	public InputReader(String fileName) throws FileNotFoundException {
		InputStream is = new FileInputStream(fileName);
		this.stream = is;
	}

	public int read() {
		if (numChars == -1)
			throw new InputMismatchException();
		if (curChar >= numChars) {
			curChar = 0;
			try {
				numChars = stream.read(buf);
			} catch (IOException e) {
				throw new InputMismatchException();
			}
			if (numChars <= 0)
				return -1;
		}
		return buf[curChar++];
	}

	public int readInt() {
		int c = read();
		while (isSpaceChar(c))
			c = read();
		int sgn = 1;
		if (c == '-') {
			sgn = -1;
			c = read();
		}
		int res = 0;
		do {
			if (c < '0' || c > '9')
				throw new InputMismatchException();
			res *= 10;
			res += c - '0';
			c = read();
		} while (!isSpaceChar(c));
		return res * sgn;
	}

	public String readString() {
		int c = read();
		while (isSpaceChar(c))
			c = read();
		StringBuilder res = new StringBuilder();
		do {
			res.appendCodePoint(c);
			c = read();
		} while (!isSpaceChar(c));
		return res.toString();
	}

	public boolean isSpaceChar(int c) {
		if (filter != null)
			return filter.isSpaceChar(c);
		return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
	}

	public String next() {
		return readString();
	}

	public interface SpaceCharFilter {
		public boolean isSpaceChar(int ch);
	}
}
 
class IOUtils {

	public static String[] readStringArray(InputReader in, int size) {
		String[] array = new String[size];
		for(int i = 0; i < size; i++) {
			array[i] = in.readString();
		}

		return array;
	}

	public static int[] readIntArray(InputReader in, int size) {
		int[] array = new int[size];
		for (int i = 0; i < size; i++)
			array[i] = in.readInt();
		return array;
	}

	public static void print(Object message) {		
		System.out.println(message);
	}

	public static void write(String fileName, String[] contents) {
		List<String> lines = Arrays.asList(contents);
		Path file = Paths.get(fileName);
		try {
			Files.write(file, lines, Charset.forName("UTF-8"));
		} catch (IOException e) {
			print("ERROR: " + e.getMessage());
			e.printStackTrace();
		}
	}
}


