
import java.io.InputStream;
import java.io.PrintStream;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Scanner;
import java.util.Stack;

/**
 * @author Abhimanyu Singh
 *
 */
class Card {

    int station;
    int type;
    int pCount;
    static final int ORG = 0;
    static final int EXIT = 1;

    public Card(int station, int p, int type) {
        this.station = station;
        this.pCount = p;
        this.type = type;
    }
}

class CardComparator implements Comparator<Card> {

    public CardComparator() {
    }

    @Override
    public int compare(Card c1, Card c2) {
        if (c1.station > c2.station) {
            return 1;
        } else if (c1.station < c2.station) {
            return -1;
        } else {
            if (c1.type > c2.type) {
                return 1;
            } else if (c1.type < c2.type) {
                return -1;
            } else {
                return 0;
            }
        }
    }
}

public class TicketSwapping {

    private InputStream input;
    private PrintStream output;
    private Scanner inputSc;
    static final int MOD = 1000002013;

    public TicketSwapping(InputStream input, PrintStream output) {
        this.input = input;
        this.output = output;
        init();
    }

    private void init() {
        inputSc = new Scanner(input);
    }

    static int lineToInt(String line) {
        return Integer.parseInt(line);
    }

    public void solve() {
        int testCaseCount = inputSc.nextInt();
        for (int testN = 1; testN <= testCaseCount; testN++) {
            solveTestCase(testN);
        }
    }

    static int mod(long a) {
        return (int) (a % MOD);
    }

    static int mul(long a, long b) {
        a = mod(a);
        b = mod(b);
        return (int) ((a * b) % MOD);
    }

    static int add(long a, long b) {
        a = mod(a);
        b = mod(b);
        return (int) ((a + b) % MOD);
    }

    static int sub(long a, long b) {
        long a1 = mod(a);
        long b1 = mod(b);
        return mod(a1 + MOD - b1);
    }

    long getPay(long o, long e, long N) {
        long d = e - o;
        /*
         * d*N  - d(d-1)/2
         */

        long pay = d * N - ((d * (d - 1)) / 2); // OK 10^18
        if (pay < 0) {
            System.err.println("Error pay:" + pay);
        }
        return pay;
    }

    private void solveTestCase(int testN) {
        int N = inputSc.nextInt();
        int M = inputSc.nextInt();

        long actualPay = 0;

        Card c[] = new Card[2 * M];
        for (int i = 0; i < M; i++) {
            int o = inputSc.nextInt();
            int e = inputSc.nextInt();
            int p = inputSc.nextInt();
            actualPay = add(actualPay, mul(p, getPay(o, e, N)));
            c[2 * i] = new Card(o, p, Card.ORG);
            c[2 * i + 1] = new Card(e, p, Card.EXIT);
        }

        CardComparator cc = new CardComparator();
        Arrays.sort(c, cc);
        Stack<Card> st = new Stack<Card>();

        long paid = 0;
        for (int i = 0; i < 2 * M; i++) {
            if (c[i].type == Card.ORG) {
                st.push(c[i]);
            } else {
                Card exitCard = c[i];
                int pCount = exitCard.pCount;
                while (pCount > 0) {
                    Card tempC = st.pop();
                    int o = tempC.station;
                    int e = c[i].station;
                    if (tempC.pCount > pCount) {
                        // push back;
                        tempC.pCount -= pCount;
                        st.push(tempC);
                        paid = add(paid, mul(pCount, getPay(o, e, N)));
                        pCount = 0;
                    } else {
                        paid = add(paid, mul(tempC.pCount, getPay(o, e, N)));
                        pCount -= tempC.pCount;
                    }
                }
            }
        }

        System.err.println(actualPay);
        System.err.println(paid);
        long loss = sub(actualPay, paid);
        System.err.println(loss);
        output.println("Case #" + testN + ": " + loss);
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        TicketSwapping ts = new TicketSwapping(System.in, System.out);
        ts.solve();
    }
}
