import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.Arrays;

public class CoinJam1 {

	private static String infileName, outFileName;
	private static BufferedReader reader;
	private static BufferedWriter writer;
	private static double[][] powerMatrix = new double[9][32];
	private static long[] tempDivisorBuffer = new long[9];
	static {
		preparePowerMatrix();
	}

	public static void main(String[] args) throws IOException {

		infileName = args[0];
		outFileName = infileName.substring(0, infileName.indexOf('.')).concat(
				".out");
		openFileForReading();
		openFileForWriting();
		int numTests = readIntFromFile();

		for (int i = 0; i < numTests; i++) {
			StringBuilder sb = new StringBuilder();
			int[] data = readIntArrayFromFile();
			int count = 0;
			for (int p = 0; p < Math.pow(2, data[0]); p++) {
				String s = "1" + getPthString(p, data[0] - 2) + "1";
				for (int j = 2; j <= 10; j++) {
					double valueInBase = valueInBase(s, j);
					if (isPrime(valueInBase, j - 2))
						break;
					if (j == 10) {
						sb.append(s);
						sb.append(" ");
						for (int k = 0; k < 9; k++) {
							sb.append(tempDivisorBuffer[k]);
							sb.append(" ");
						}
						Arrays.fill(tempDivisorBuffer, 0);
						sb.trimToSize();
						sb.deleteCharAt(sb.length() - 1);
						sb.append("\n");
						count++;
					}
				}
				if (count == data[1])
					break;
			}
			writeAnswer(i + 1, sb);
		}
		closeFiles();
		// System.out.println(Arrays.toString(bitBuffer[bitBuffer.length - 1]));
	}

	private static String getPthString(int p, int len) {
		char[] charArr = new char[len];
		for(int i = 0; i < len; i++)
		{
			charArr[i] = ((long)((double)p / powerMatrix[0][len - i - 1])) % 2.0 == 1.0 ? '1' : '0';
		}
		return new String(charArr);
	}

	private static void preparePowerMatrix() {
		for (int i = 2; i <= 10; i++) {
			for (int j = 0; j < 32; j++)
				powerMatrix[i - 2][j] = Math.pow(i, j);
		}
	}

	private static int[] readIntArrayFromFile() throws IOException {

		String line = reader.readLine();
		String[] arr = line.split("\\s");
		int items[] = new int[2];
		for (int i = 0; i < 2; i++) {
			items[i] = Integer.parseInt(arr[i]);
		}
		return items;
	}

	private static double valueInBase(String s, int base) {
		double val = 0;

		for (int i = s.length() - 1; i >= 0; i--)
			if (s.charAt(i) == '1')
				val += powerMatrix[base - 2][s.length() - 1 - i];
		return val;
	}

	private static void closeFiles() throws IOException {
		reader.close();
		writer.close();
	}

	private static boolean isPrime(double l, int itr) {
		double last = l % 10;
		if (last == 2.0 || last == 4.0 || last == 6.0 || last == 8.0) {
			tempDivisorBuffer[itr] = 2;
			return false;
		}
		if (last == 5) {
			tempDivisorBuffer[itr] = 5;
			return false;
		}
		long sqrt = (long) Math.sqrt(l);
		for (long i = 3; i <= sqrt; i++)
			if (l % i == 0) {
				tempDivisorBuffer[itr] = i;
				return false;
			}
		return true;
	}

	private static void writeAnswer(int i, StringBuilder sb) throws IOException {
		writer.write("Case #" + i + ": \n" + (sb));
		writer.newLine();
	}

	private static void openFileForWriting() throws IOException {
		writer = Files.newBufferedWriter(Paths.get(outFileName));
	}

	private static int readIntFromFile() throws IOException {
		return Integer.parseInt(reader.readLine());
	}

	private static void openFileForReading() throws IOException {
		reader = Files.newBufferedReader(Paths.get(infileName));
	}

}
