import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.Arrays;

public class CoinJam {

	private static String infileName, outFileName;
	private static BufferedReader reader;
	private static BufferedWriter writer;
	private static String[][] bitBuffer;
	private static long[][] powerMatrix = new long[9][32];
	private static long[] tempDivisorBuffer = new long[9];
	static {
		preparePowerMatrix();
	}

	public static void main(String[] args) throws IOException {

		infileName = args[0];
		outFileName = infileName.substring(0, infileName.indexOf('.')).concat(
				".out");
		openFileForReading();
		openFileForWriting();
		int numTests = readIntFromFile();

		for (int i = 0; i < numTests; i++) {
			StringBuilder sb = new StringBuilder();
			int[] data = readIntArrayFromFile();
			generateBits(data[0] - 2);
			int count = 0;
			for (String s : bitBuffer[data[0] - 3]) {
				s = "1" + s + "1";
				for (int j = 2; j <= 10; j++) {
					long valueInBase = valueInBase(s, j);
					if (isPrime(valueInBase, j - 2))
						break;
					if (j == 10) {
						sb.append(s);
						sb.append(" ");
						for (int k = 0; k < 9; k++) {
							sb.append(tempDivisorBuffer[k]);
							sb.append(" ");
						}
						Arrays.fill(tempDivisorBuffer, 0);
						sb.trimToSize();
						sb.deleteCharAt(sb.length() - 1);
						sb.append("\n");
						count++;
					}
				}
				if (count == data[1])
					break;
			}
			writeAnswer(i + 1, sb);
		}
		closeFiles();
		// System.out.println(Arrays.toString(bitBuffer[bitBuffer.length - 1]));
	}

	private static void preparePowerMatrix() {
		for (int i = 2; i <= 10; i++) {
			for (int j = 0; j < 32; j++)
				powerMatrix[i - 2][j] = (long) Math.pow(i, j);
		}
	}

	private static int[] readIntArrayFromFile() throws IOException {

		String line = reader.readLine();
		String[] arr = line.split("\\s");
		int items[] = new int[2];
		for (int i = 0; i < 2; i++) {
			items[i] = Integer.parseInt(arr[i]);
		}
		return items;
	}

	private static void generateBits(int len) {
		bitBuffer = new String[len][];
		for (int i = 0; i < len; i++) {
			generateBits0(i);
		}
	}

	private static void generateBits0(int i) {
		bitBuffer[i] = new String[(int) Math.pow(2, i + 1)];
		if (i == 0) {
			bitBuffer[i][0] = "0";
			bitBuffer[i][1] = "1";
		} else {
			int index = 0;
			for (String s : bitBuffer[i - 1]) {
				bitBuffer[i][index] = "0" + s;
				bitBuffer[i][bitBuffer[i].length / 2 + index] = "1" + s;
				index++;
			}
			bitBuffer[i - 1] = null;
		}
	}

	private static long valueInBase(String s, int base) {
		long val = 0;

		for (int i = s.length() - 1; i >= 0; i--)
			if (s.charAt(i) == '1')
				val += powerMatrix[base - 2][s.length() - 1 - i];
		return val;
	}

	private static void closeFiles() throws IOException {
		reader.close();
		writer.close();
	}

	private static boolean isPrime(long l, int itr) {
		long last = l % 10;
		if (last == 2 || last == 4 || last == 6 || last == 8) {
			tempDivisorBuffer[itr] = 2;
			return false;
		}
		if (last == 5) {
			tempDivisorBuffer[itr] = 5;
			return false;
		}
		long sqrt = (long) Math.sqrt(l);
		for (long i = 3; i <= sqrt; i++)
			if (l % i == 0) {
				tempDivisorBuffer[itr] = i;
				return false;
			}
		return true;
	}

	private static void writeAnswer(int i, StringBuilder sb) throws IOException {
		writer.write("Case #" + i + ": \n" + (sb));
		writer.newLine();
	}

	private static void openFileForWriting() throws IOException {
		writer = Files.newBufferedWriter(Paths.get(outFileName));
	}

	private static int readIntFromFile() throws IOException {
		return Integer.parseInt(reader.readLine());
	}

	private static void openFileForReading() throws IOException {
		reader = Files.newBufferedReader(Paths.get(infileName));
	}

}
