import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Scanner;
import java.util.Set;


public class TrainTimeTable {

	static DateFormat format = new SimpleDateFormat("HH:mm");
	
	public static void main(String[] args) throws ParseException, IOException {
		
		Scanner scanner = new Scanner(new File(args[0]));
		BufferedWriter writer = new BufferedWriter(new FileWriter(args[1]));
		
		int cases = scanner.nextInt();
		
		for (int i = 0; i < cases; i++) {
			int latency = scanner.nextInt();
			
			Station stationA = new Station();
			Station stationB = new Station();
			
			int fromA = scanner.nextInt();
			int fromB = scanner.nextInt();
			
			List<Trip> trips = new ArrayList<Trip>();
			
			for (int j = 0; j < fromA; j++) {
				String depart = scanner.next();
				String arrival = scanner.next();
				
				Date departDate = format.parse(depart);
				Date arrivalDate = format.parse(arrival);
				
				trips.add(new Trip(stationA, stationB, departDate, arrivalDate));
			}
			
			for (int j = 0; j < fromB; j++) {
				String depart = scanner.next();
				String arrival = scanner.next();
				
				Date departDate = format.parse(depart);
				Date arrivalDate = format.parse(arrival);
				
				trips.add(new Trip(stationB, stationA, departDate, arrivalDate));
			}
			
			Collections.sort(trips);
			
			for (Trip trip : trips) {
				trip.trip(latency);
			}
			
			writer.write("Case #" + (i+1) + ": " + stationA.neededBuses + " " + stationB.neededBuses);
			writer.newLine();
			writer.flush();
		}
		
		writer.close();
	}
	
}

class Trip implements Comparable<Trip>{
	
	Station from;
	Station to;
	Date departure;
	Date arrival;
	
	public Trip(Station from, Station to, Date departure, Date arrival) {
		this.from = from;
		this.to = to;
		this.departure = departure;
		this.arrival = arrival;
	}
	
	void trip(int latency) {
		from.leave(to, departure, arrival, latency);
	}

	@Override
	public int compareTo(Trip o) {
		return this.departure.compareTo(o.departure);
	}
	
}

class Station {
	
	Set<Bus> buses;
	int neededBuses = 0;
	
	public Station() {
		buses = new HashSet<Bus>();
	}
	
	void leave(Station station, Date leavingdate, Date arrivingDate, int latency) {
		Bus busToLeave = null;
		
		for (Bus bus : buses) {
			if (bus.isReady(leavingdate)) {
				busToLeave = bus;
				break;
			}
		}
		
		if (busToLeave == null) {
			busToLeave = new Bus(latency);
			neededBuses++;
		} else {
			buses.remove(busToLeave);
		}
		
		station.arrive(busToLeave, arrivingDate);
	}
	
	void arrive(Bus bus, Date date) {
		bus.setLastArrival(date);
		buses.add(bus);
	}
	
}

class Bus {
	
	Date lastArrival;
	int latency;
	
	public Bus(int latency) {
		this.latency = latency;
	}
	
	boolean isReady(Date date) {
		return (lastArrival.getTime() + latency * 60 * 1000) <= date.getTime();
	}
	
	public void setLastArrival(Date lastArrival) {
		this.lastArrival = lastArrival;
	}
}