import java.util.ArrayList;
import java.util.List;
import java.math.BigInteger;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.Writer;
import java.io.FileReader;
import java.io.IOException;
import java.io.FileInputStream;
import java.util.HashSet;
import java.io.StringWriter;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Random;
import java.io.BufferedReader;
import java.io.FilenameFilter;
import java.util.Collection;
import java.io.FileNotFoundException;
import java.util.Locale;
import java.io.FileOutputStream;
import java.io.File;
import java.util.Set;
import java.util.StringTokenizer;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class Main {
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		InputStream inputStream;
		try {
			final String regex = "C-(small|large).*[.]in";
			File directory = new File(".");
			File[] candidates = directory.listFiles(new FilenameFilter() {
				public boolean accept(File dir, String name) {
					return name.matches(regex);
				}
			});
			File toRun = null;
			for (File candidate : candidates) {
				if (toRun == null || candidate.lastModified() > toRun.lastModified())
					toRun = candidate;
			}
			inputStream = new FileInputStream(toRun);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("c.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		TaskC solver = new TaskC();
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i, in, out);
		out.close();
	}
}

class TaskC extends SimpleSolution {

    List<Integer> check(String s) {
        List<Integer> divisors = new ArrayList<>();

        for (int radix = 2; radix <= 10; radix++) {
            BigInteger x = new BigInteger(s, radix);

            boolean foundDivisor = false;
            for (BigInteger i : primesBigIntegers) {
                if (x.mod(i).equals(BigInteger.ZERO)) {
                    foundDivisor = true;
                    divisors.add(i.intValue());
                    break;
                }
            }

            if (!foundDivisor) {
                return null;
            }
        }
        return divisors;
    }

    int N = 1000;
    List<Integer> primes;
    List<BigInteger> primesBigIntegers;
    Set<Integer> primesSet;

    public void init() {
        primes = new ArrayList<>();
        boolean[] sieve = new boolean[N];
        for (int i = 2; i < N; i++) {
            if (sieve[i]) {
                continue;
            }
            primes.add(i);
            for (int j = i + i; j < N; j += i) {
                sieve[j] = true;
            }
        }

        primesSet = new HashSet<>();
        primesSet.addAll(primes);

        primesBigIntegers = new ArrayList<>();
        for (int i : primes) {
            primesBigIntegers.add(BigInteger.valueOf(i));
        }
    }

    public void solve(int testNumber) {
        int n = in.nextInt();
        int J = in.nextInt();
        
        out.println(String.format("Case #%d:", testNumber));

        Random random = new Random();

Set<String> found = new HashSet<>();
        Set<String> bad = new HashSet<>();

        while (found.size() < J) {
            StringBuilder sb = new StringBuilder();
            sb.append('1');
            for (int i = 0; i < n - 2; i++) {
                sb.append(random.nextBoolean() ? '1' : '0');
            }
            sb.append('1');

            String res = sb.toString();

            if (found.contains(res) || bad.contains(res)) {
                continue;
            }

            List<Integer> ch = check(res);

            if (ch == null) {
                bad.add(res);
            } else {
                log.println(res);
                log.flush();
                found.add(res);

                out.print(res + " ");
                out.prints(ch);
                out.println();
            }
        }
    }
}

abstract class SimpleSolution extends AbstractSolution {
    public String postProcessTestOutput(String output, int testNumber) {
        return output;
    }
}

class InputReader {

	BufferedReader br;
	StringTokenizer in;

    public InputReader(InputStream inputStream) {
		br = new BufferedReader(new InputStreamReader(inputStream));
	}

	boolean hasMoreTokens() {
		while (in == null || !in.hasMoreTokens()) {
			String s = nextLine();
			if (s == null) {
				return false;
			}
			in = new StringTokenizer(s);
		}
		return true;
	}

	public String nextString() {
		return hasMoreTokens() ? in.nextToken() : null;
	}

	public String nextLine() {
		try {
			in = null;
			return br.readLine();
		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	public int nextInt() {
		return Integer.parseInt(nextString());
	}

    public String next() {
		return nextString();
	}
}

class OutputWriter extends PrintWriter {

    public static final String DEFAULT_SEPARATOR = " ";

    private String separator = DEFAULT_SEPARATOR;

    public OutputWriter(String fileName) throws FileNotFoundException {
        super(fileName);
    }

    public OutputWriter(OutputStream outputStream) {
        super(outputStream);
    }

    public OutputWriter(Writer writer) {
        super(writer);
    }

    public void prints(Collection collection) {
        boolean first = true;
        for (Object i : collection) {
            if (!first) {
                print(separator);
            } else {
                first = false;
            }
            print(i);
        }
    }
}

abstract class AbstractSolution {

    protected InputReader in;
    protected OutputWriter out;

    protected OutputWriter log;

    private OutputWriter fileOut;

    public AbstractSolution() {
        try {
            fileOut = new OutputWriter("last_output.txt");
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }

        log = new OutputWriter(System.out);
    }

    private boolean initialized = false;

    public void init() {
    }

    public void solve(int testNumber, InputReader in, OutputWriter out) {
        if (!initialized) {
            init();
            initialized = true;
        }

        StringWriter sw = new StringWriter();

        this.in = in;
        this.out = new OutputWriter(sw);

        solve(testNumber);

        String testOutput = postProcessTestOutput(sw.toString(), testNumber);

        out.print(testOutput);
        out.flush();

        fileOut.print(testOutput);
        fileOut.flush();
    }

    abstract public void solve(int testNumber);

    abstract public String postProcessTestOutput(String output, int testNumber);
}

