import java.io.*;
import java.util.*;
import java.math.*;

// 5/26/12 6:30 PM
// by Abrackadabra

public class Aerobics {
    public static void main(String[] args) throws IOException {
        if (args.length > 0 && args[0].equals("Abra")) debugMode = true;
        new Aerobics().run();
        /*new Thread(null, new Runnable() {
            public void run() {
                try {
                    new Aerobics().run();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }, "1", 1 << 24).start();*/
    }

    int IOMode = 0; //0 - consoleIO, 1 - <taskName>.in/out, 2 - input.txt/output.txt, 3 - test case generator
    String taskName = "";
    boolean testBasedProblem = true;

    double eps = 1e-6;

    double pif(double x1, double y1, double x2, double y2) {
        return Math.sqrt((x2 - x1) * (x2 - x1) + (y2 - y1) * (y2 - y1));
    }

    boolean ok(double x, double y, int i) {
        boolean ok = x >= 0 && x <= w && y >= 0 && y <= h;
        for (int j = 0; j < i && ok; j++) {
            ok &= pif(x, y, xs[j], ys[j]) > r[i] + r[j];
        }
        return ok;
    }

    class Circle implements Comparable<Circle> {
        double x, y, r;
        int index;

        @Override
        public int compareTo(Circle o) {
            if (r != o.r) return r - o.r > 0 ? 1 : -1;
            if (x != o.x) return x - o.x > 0 ? 1 : -1;
            if (r != o.r) return r - o.r > 0 ? 1 : -1;
            return 0;
        }
    }

    int n, w, h;
    int[] r;
    double[] xs = new double[n];
    double[] ys = new double[n];

    void solve() throws IOException {
        out.print("Case #" + testIndex + ": ");
        n = nextInt();
        w = nextInt();
        h = nextInt();
        r = new int[n];
        xs = new double[n];
        ys = new double[n];
        for (int i = 0; i < n; i++)
            r[i] = nextInt();
        for (int i = 0; i < n; i++) {
            double x = 0, y = 0;
            double step = 1e8;
            while (step > eps) {
                if (ok(x + step, y, i)) {
                    x += step;
                    continue;
                }
                if (ok(x, y + step, i)) {
                    y += step;
                    continue;
                }
                step /= 2;
            }
            xs[i] = x;
            ys[i] = y;
        }
        for (int i = 0; i < n; i++)
            out.print(xs[i] + " " + ys[i] + " ");
        out.println();
    }

    long startTime = System.nanoTime(), tempTime = startTime, finishTime = startTime;
    long startMem = Runtime.getRuntime().totalMemory(), finishMem = startMem;
    int testIndex;

    void run() throws IOException {
        init();
        if (debugMode) {
            con.println("Start");
            con.println("Console:");
        }

        int tests = testBasedProblem ? nextInt() : 1;
        for (testIndex = 1; testIndex <= tests; testIndex++)
            solve();

        finishTime = System.nanoTime();
        finishMem = Runtime.getRuntime().totalMemory();
        out.flush();
        if (debugMode) {
            int maxSymbols = 1000;
            BufferedReader tbr = new BufferedReader(new FileReader("input.txt"));
            char[] a = new char[maxSymbols];
            tbr.read(a);
            if (a[0] != 0) {
                con.println("File input:");
                con.println(a);
                if (a[maxSymbols - 1] != 0) con.println("...");
            }
            tbr = new BufferedReader(new FileReader("output.txt"));
            a = new char[maxSymbols];
            tbr.read(a);
            if (a[0] != 0) {
                con.println("File output:");
                con.println(a);
                if (a[maxSymbols - 1] != 0) con.println("...");
            }
            con.println("Execution time: " + (finishTime - startTime) / 1000000000.0 + " sec");
            con.println("Used memory:    " + (finishMem - startMem) + " bytes");
            con.println("Total memory:   " + Runtime.getRuntime().totalMemory() + " bytes");
        }
    }

    boolean tick(double x) {
        if (System.nanoTime() - tempTime > x * 1e9) {
            tempTime = System.nanoTime();
            con.println("Tick at " + (tempTime - startTime) / 1000000000 + " sec");
            con.print("   ");
            return true;
        }
        return false;
    }

    static boolean debugMode = false;
    PrintStream con = System.out;

    void init() throws IOException {
        if (debugMode && IOMode != 3) {
            br = new BufferedReader(new FileReader("input.txt"));
            out = new PrintWriter(new FileWriter("output.txt"));
        } else
            switch (IOMode) {
                case 0:
                    br = new BufferedReader(new InputStreamReader(System.in));
                    out = new PrintWriter(System.out);
                    break;
                case 1:
                    br = new BufferedReader(new FileReader(taskName + ".in"));
                    out = new PrintWriter(new FileWriter(taskName + ".out"));
                    break;
                case 2:
                    br = new BufferedReader(new FileReader("input.txt"));
                    out = new PrintWriter(new FileWriter("output.txt"));
                    break;
                case 3:
                    out = new PrintWriter(new FileWriter("input.txt"));
                    break;
            }
        if (!debugMode)
            con = new PrintStream(new OutputStream() {
                public void write(int b) throws IOException {
                } // to /dev/null
            });
        if ((IOMode == 1 && taskName.length() == 0) || (IOMode != 1 && taskName.length() != 0)) {
            System.err.println("Leha, check IO settings");
            System.err.flush();
            System.exit(0);
        }
    }

    BufferedReader br;
    PrintWriter out;
    StringTokenizer in;

    boolean hasMoreTokens() throws IOException {
        while (in == null || !in.hasMoreTokens()) {
            String line = br.readLine();
            if (line == null) return false;
            in = new StringTokenizer(line);
        }
        return true;
    }

    String nextString() throws IOException {
        return hasMoreTokens() ? in.nextToken() : null;
    }

    int nextInt() throws IOException {
        return Integer.parseInt(nextString());
    }

    long nextLong() throws IOException {
        return Long.parseLong(nextString());
    }

    double nextDouble() throws IOException {
        return Double.parseDouble(nextString());
    }
}