import java.io.FileNotFoundException;
import java.util.Locale;
import java.io.BufferedReader;
import java.util.Comparator;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.File;
import java.io.Writer;
import java.io.FilenameFilter;
import java.util.List;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.FileReader;
import java.util.ArrayList;
import java.io.FileOutputStream;
import java.io.FileInputStream;
import java.util.StringTokenizer;
import java.io.ByteArrayOutputStream;
import java.util.Collections;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 * @author abra
 */
public class Main {
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		InputStream inputStream;
		try {
			final String regex = "B-(small|large).*[.]in";
			File directory = new File(".");
			File[] candidates = directory.listFiles(new FilenameFilter() {
				public boolean accept(File dir, String name) {
					return name.matches(regex);
				}
			});
			File toRun = null;
			for (File candidate : candidates) {
				if (toRun == null || candidate.lastModified() > toRun.lastModified())
					toRun = candidate;
			}
			inputStream = new FileInputStream(toRun);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("b.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		TaskB solver = new TaskB();
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i, in, out);
		out.close();
	}
}

class TaskB extends GCJSolution {

  List<Couple<Double>> pos;
  List<Couple<Double>> neg;

  public void solve(int testNumber) {
    int n = in.nextInt();
    double V = in.nextDouble();
    double T = in.nextDouble();

    pos = new ArrayList<>();
    neg = new ArrayList<>();

    for (int i = 0; i < n; i++) {
      double v = in.nextDouble();
      double t = in.nextDouble() - T;
      if (t > 0) {
        pos.add(new Couple<>(v, t));
      } else {
        neg.add(new Couple<>(v, Math.abs(t)));
      }
    }

    Comparator<Couple<Double>> comp = (o1, o2) -> Double
        .compare(Math.abs(o1.second), Math.abs(o2.second));

    Collections.sort(pos, comp);
    Collections.sort(neg, comp);

//    out.println("POS");
//    for (Couple<Double> x : pos) {
//      out.println(x.first + " " + x.second);
//    }
//    out.println("NEG");
//    for (Couple<Double> x : neg) {
//      out.println(x.first + " " + x.second);
//    }
    double l = 1e-9;
    double r = 1e+9;
    while (r - l > 1e-9) {
      double m = (l + r) / 2;
      if (getWater(m) >= V) {
        r = m;
      } else {
        l = m;
      }
    }
    if (l == 1e+9) {
      out.println("IMPOSSIBLE");
    } else {
      out.println(l);
    }
  }

  private double getWater(double time) {
    double Xpos = 0;
    double Xneg = 0;
    for (Couple<Double> x : pos) {
      Xpos += x.first * x.second * time;
    }
    for (Couple<Double> x : neg) {
      Xneg += x.first * x.second * time;
    }
    double X = Math.min(Xpos, Xneg);
    return getWater(time, X, pos) + getWater(time, X, neg);
  }

  private double getWater(double time, double X, List<Couple<Double>> a) {
    double got = 0;
    double ans = 0;
    for (Couple<Double> x : a) {
      double could = x.first * x.second * time;
      double ratio = 1;
      if (could + got > X) {
        if (could > 0) {
          ratio = Math.min(1, (X - got) / could);
        }
      }
      ans += ratio * x.first * time;
      got += could * ratio;
    }
    return ans;
  }


}

abstract class GCJSolution extends SavingChelperSolution {

	public String processOutputPreCheck(int testNumber, String output) {
		return "Case #" + testNumber + ": " + output;
	}

	public String processOutputPostCheck(int testNumber, String output) {
		return output;
	}
}

class Couple<A> extends Pair<A, A> {

	public Couple(A first, A second) {
		super(first, second);
	}
}

class InputReader {

	BufferedReader br;
	StringTokenizer in;

  public InputReader(InputStream inputStream) {
		br = new BufferedReader(new InputStreamReader(inputStream));
	}

	boolean hasMoreTokens() {
		while (in == null || !in.hasMoreTokens()) {
			String s = nextLine();
			if (s == null) {
				return false;
			}
			in = new StringTokenizer(s);
		}
		return true;
	}

	public String nextString() {
		return hasMoreTokens() ? in.nextToken() : null;
	}

	public String nextLine() {
		try {
			in = null; // riad legacy
			return br.readLine();
		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	public int nextInt() {
		return Integer.parseInt(nextString());
	}

  public double nextDouble() {
		return Double.parseDouble(nextString());
	}

  public String next() {
		return nextString();
	}
}

abstract class SavingChelperSolution {

	protected int testNumber;

	public InputReader in;
	public OutputWriter out;

	private OutputWriter toFile;

	private boolean local = new File("chelper.properties").exists();

	public OutputWriter debug = local
			? new OutputWriter(System.out)
			: new OutputWriter(new OutputStream() {
				public void write(int b) {
				}
			});

	public SavingChelperSolution() {
		try {
			toFile = new OutputWriter("last_test_output.txt");
		} catch (FileNotFoundException e) {
			throw new RuntimeException(e);
		}
	}

	public abstract void solve(int testNumber);

	public abstract String processOutputPreCheck(int testNumber, String output);

	public abstract String processOutputPostCheck(int testNumber, String output);

	public void solve(int testNumber, InputReader in, OutputWriter out) {
		this.testNumber = testNumber;

		ByteArrayOutputStream substituteOutContents = new ByteArrayOutputStream();
		OutputWriter substituteOut = new OutputWriter(substituteOutContents);

		this.in = in;
		this.out = substituteOut;

		solve(testNumber);
		substituteOut.flush();

		String result = substituteOutContents.toString();

		result = processOutputPreCheck(testNumber, result);
		out.print(result);
		out.flush();

		if (local) {
			debug.flush();

			result = processOutputPostCheck(testNumber, result);
			toFile.print(result);
			toFile.flush();
		}
	}

}

class Pair<A, B> {

	public final A first;
	public final B second;

	public Pair(A first, B second) {
		if (first == null || second == null) {
			throw new IllegalArgumentException();
		}

		this.first = first;
		this.second = second;
	}

	public boolean equals(Object o) {
		if (this == o) {
			return true;
		}
		if (!(o instanceof Pair)) {
			return false;
		}

		Pair pair = (Pair) o;

		if (!first.equals(pair.first)) {
			return false;
		}
		if (!second.equals(pair.second)) {
			return false;
		}

		return true;
	}

	public int hashCode() {
		int result = first.hashCode();
		result = 31 * result + second.hashCode();
		return result;
	}

	public String toString() {
		return "{" + first + ", " + second + "}";
	}
}

class OutputWriter extends PrintWriter {

  public OutputWriter(String fileName) throws FileNotFoundException {
		super(fileName);
	}

	public OutputWriter(OutputStream outputStream) {
		super(outputStream);
	}

}

