import java.util.LinkedList;
import java.util.ArrayList;
import java.util.List;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.ByteArrayOutputStream;
import java.io.Writer;
import java.io.FileReader;
import java.io.IOException;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.io.BufferedReader;
import java.io.FilenameFilter;
import java.util.Map;
import java.io.FileNotFoundException;
import java.util.Locale;
import java.util.AbstractCollection;
import java.io.FileOutputStream;
import java.io.File;
import java.util.StringTokenizer;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 * @author abra
 */
public class Main {
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		InputStream inputStream;
		try {
			final String regex = "A-(small|large).*[.]in";
			File directory = new File(".");
			File[] candidates = directory.listFiles(new FilenameFilter() {
				public boolean accept(File dir, String name) {
					return name.matches(regex);
				}
			});
			File toRun = null;
			for (File candidate : candidates) {
				if (toRun == null || candidate.lastModified() > toRun.lastModified())
					toRun = candidate;
			}
			inputStream = new FileInputStream(toRun);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("a.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		TaskA solver = new TaskA();
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i, in, out);
		out.close();
	}
}

class TaskA extends GCJSolution {

  public void solve(int testNumber) {
    n = in.nextInt();
    d = in.nextInt();

    int S0 = in.nextInt();
    int As = in.nextInt();
    int Cs = in.nextInt();
    int Rs = in.nextInt();

    int M0 = in.nextInt();
    int Am = in.nextInt();
    int Cm = in.nextInt();
    int Rm = in.nextInt();

    s = new int[n];
    m = new int[n];

    s[0] = S0;
    m[0] = M0;

    for (int i = 1; i < n; i++) {
      s[i] = (int)(((long)s[i - 1] * As + Cs) % Rs);
      m[i] = (int)(((long)m[i - 1] * Am + Cm) % Rm);
    }

    for (int i = 1; i < n; i++) {
      m[i] %= i;
    }

    colored = new boolean[n];
    coloredCounter = 0;
    children = new ArrayList<>();

    Map<Integer, List<Integer>> bySalary = new HashMap<>();

    for (int i = 0; i < n; i++) {
      children.add(new ArrayList<>());

      if (!bySalary.containsKey(s[i])) {
        bySalary.put(s[i], new ArrayList<>());
      }
      bySalary.get(s[i]).add(i);
    }

    for (int i = 1; i < n; i++) {
      children.get(m[i]).add(i);
    }

    int l = s[0];
    int r = s[0] + d;

    color(0, l, r);

    int ans = coloredCounter;

    for (int i = 0; i < d; i++) {
      if (bySalary.containsKey(r)) {
        for (int j : bySalary.get(r)) {
          blank(j);
        }
      }
      l--;
      r--;
      if (bySalary.containsKey(l)) {
        for (int j : bySalary.get(l)) {
          if (colored[m[j]]) {
            color(j, l, r);
          }
        }
      }
      ans = Math.max(ans, coloredCounter);
    }

    out.println(ans);

  }

  boolean[] colored;
  int coloredCounter;
  int n, d;
  int[] s, m;

  List<List<Integer>> children;

  void color(int i, int l, int r) {
    LinkedList<Integer> buf = new LinkedList<>();
    buf.add(i);

    while (!buf.isEmpty()) {
      i = buf.pop();

      if (l <= s[i] && s[i] <= r && !colored[i]) {
        colored[i] = true;
        coloredCounter++;
      } else {
        continue;
      }
      for (int j : children.get(i)) {
        if (l <= s[j] && s[j] <= r && !colored[j]) {
          buf.add(j);
        }
      }
    }
  }

  void blank(int i) {
    LinkedList<Integer> buf = new LinkedList<>();
    buf.add(i);

    while (!buf.isEmpty()) {
      i = buf.pop();

      if (colored[i]) {
        colored[i] = false;
        coloredCounter--;
      } else {
        continue;
      }
      for (int j : children.get(i)) {
        if (colored[j]) {
          buf.add(j);
        }
      }
    }
  }
}

abstract class GCJSolution extends SavingChelperSolution {

	public String processOutputPreCheck(int testNumber, String output) {
		return "Case #" + testNumber + ": " + output;
	}

	public String processOutputPostCheck(int testNumber, String output) {
		return output;
	}
}

class InputReader {

	BufferedReader br;
	StringTokenizer in;

	public InputReader(InputStream inputStream) {
		br = new BufferedReader(new InputStreamReader(inputStream));
	}

	boolean hasMoreTokens() {
		while (in == null || !in.hasMoreTokens()) {
			String s = nextLine();
			if (s == null) {
				return false;
			}
			in = new StringTokenizer(s);
		}
		return true;
	}

	public String nextString() {
		return hasMoreTokens() ? in.nextToken() : null;
	}

	public String nextLine() {
		try {
			in = null;
			return br.readLine();
		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	public int nextInt() {
		return Integer.parseInt(nextString());
	}

	public String next() {
		return nextString();
	}
}

abstract class SavingChelperSolution {

	protected int testNumber;

	public InputReader in;
	public OutputWriter out;

	private OutputWriter toFile;

	private boolean local = new File("chelper.properties").exists();

	public OutputWriter debug = local
			? new OutputWriter(System.out)
			: new OutputWriter(new OutputStream() {
				public void write(int b) {
				}
			});

	public SavingChelperSolution() {
		try {
			toFile = new OutputWriter("last_test_output.txt");
		} catch (FileNotFoundException e) {
			throw new RuntimeException(e);
		}
	}

	public abstract void solve(int testNumber);

	public abstract String processOutputPreCheck(int testNumber, String output);

	public abstract String processOutputPostCheck(int testNumber, String output);

	public void solve(int testNumber, InputReader in, OutputWriter out) {
		this.testNumber = testNumber;

		ByteArrayOutputStream substituteOutContents = new ByteArrayOutputStream();
		OutputWriter substituteOut = new OutputWriter(substituteOutContents);

		this.in = in;
		this.out = substituteOut;

		solve(testNumber);
		substituteOut.flush();

		String result = substituteOutContents.toString();

		result = processOutputPreCheck(testNumber, result);
		out.print(result);
		out.flush();

		if (local) {
			debug.flush();

			result = processOutputPostCheck(testNumber, result);
			toFile.print(result);
			toFile.flush();
		}
	}

}

class OutputWriter extends PrintWriter {

	public OutputWriter(String fileName) throws FileNotFoundException {
		super(fileName);
	}

	public OutputWriter(OutputStream outputStream) {
		super(outputStream);
	}

}

