import java.util.Scanner;

final class Grid
{
  boolean[][] grid;
  int count = 0;
  public Grid()
  {
    grid = new boolean[1][1];
    grid[0][0] = false;
  }
  public Grid(Grid old)
  {
    grid = new boolean[old.sizeX()][old.sizeY()];
    for (int i = 0; i < grid.length; i++)
    {
      for (int j = 0; j < grid[i].length; j++)
      {
        grid[i][j] = old.grid[i][j];
      }
    }
    count = old.count;
  }

  private void ensureSize(int x, int y)
  {
    if (grid.length < x || grid[0].length < y)
    {
      int newX = Math.max(x,grid.length);
      int newY = Math.max(y,grid[0].length);
      boolean[][] newGrid = new boolean[newX][newY];
      for (int i = 0; i < newX; i++)
      {
        for (int j = 0; j < newY; j++)
        {
          if (i < grid.length && j < grid[0].length)
          {
            newGrid[i][j] = grid[i][j];
          }
          else
          {
            newGrid[i][j] = false;
          }
        }
      }
      grid = newGrid;
    }
  }

  void set(int x, int y, boolean b)
  {
    ensureSize(x + 1, y + 1);
    if (get(x,y) && !b)
    {
      count--;
    }
    if (!get(x,y) && b)
    {
      count++;
    }
    grid[x][y] = b;
  }

  void set(int x1, int y1, int x2, int y2)
  {
    ensureSize(x2 + 1, y2 + 1);
    for (int i = x1; i <= x2; i++)
    {
      for (int j = y1; j <= y2; j++)
      {
        set(i,j,true);
      }
    }
  }

  boolean get(int x, int y)
  {
    if (x >= grid.length || y >= grid[0].length)
    {
      return false;
    }
    return grid[x][y];
  }

  int sizeX()
  {
    return grid.length;
  }

  int sizeY()
  {
    return grid[0].length;
  }

  int count()
  {
    return count;
  }

  public String toString()
  {
    StringBuffer buf = new StringBuffer();
    buf.append("size: " + grid.length + "," + grid[0].length + "\n");
    for (int i = 0; i < grid.length; i++)
    {
      for (int j = 0; j < grid[i].length; j++)
      {
        buf.append(get(i,j) ? "1" : "0");
      }
      buf.append("\n");
    }
    return buf.toString();
  }
}

public class Bacteria
{
  public static void main(String[] args)
  {
    Scanner s = new Scanner(System.in);

    int tests = s.nextInt();
    for (int test = 1; test <= tests; test++)
    {
      int r = s.nextInt();

      Grid grid = new Grid();
      for (int rect = 0; rect < r; rect++)
      {
        grid.set(s.nextInt(), s.nextInt(), s.nextInt(), s.nextInt());
      }
      int steps = simulate(grid);
      System.out.println("Case #" + test + ": " + steps);
    }
  }

  public static int simulate(Grid grid)
  {
    int steps = 0;
    while (grid.count() > 0)
    {
      Grid newGrid = new Grid(grid);

      for (int i = 0; i < grid.sizeX(); i++)
      {
        for (int j = 0; j < grid.sizeY(); j++)
        {
          if (grid.get(i,j))
          {
            // check whether to unset
            if (i == 0 && (j == 0 || !grid.get(0,j-1)) ||
                j == 0 && (i == 0 || !grid.get(i-1,0)) ||
                i > 0 && j > 0 && !grid.get(i-1,j) && !grid.get(i,j-1))
            {
              newGrid.set(i,j,false);
            }
          }
          else
          {
            if (i > 0 && j > 0 && grid.get(i-1,j) && grid.get(i,j-1))
            {
              newGrid.set(i,j,true);
            }
          }
        }
      }
      grid = newGrid;
      steps++;
    }
    return steps;
  }
}





