import java.util.Scanner;
import java.util.List;
import java.util.LinkedList;

public class Chessboard
{
  
  public static void main(String[] args)
  {
    Scanner s = new Scanner(System.in);
    int numTests = s.nextInt();

    for (int test = 1; test <= numTests; test++)
    {
      int m = s.nextInt();
      int n = s.nextInt();
      s.nextLine();

      Cell[][] board = new Cell[m][];
      for (int r = 0; r < m; r++)
      {
        String line = s.nextLine();
        Cell[] row = new Cell[n];
        for (int c = 0; c < n / 4; c++)
        {
          char hex = line.charAt(c);
          int value = Character.digit(hex, 16);
          row[c*4]   = ((value & 0x08) > 0 ? Cell.WHITE : Cell.BLACK);
          row[c*4+1] = ((value & 0x04) > 0 ? Cell.WHITE : Cell.BLACK);
          row[c*4+2] = ((value & 0x02) > 0 ? Cell.WHITE : Cell.BLACK);
          row[c*4+3] = ((value & 0x01) > 0 ? Cell.WHITE : Cell.BLACK);
        }
        board[r] = row;
      }


      List<Pair<Integer, Integer>> counts = findSquares(board);
      System.out.println("Case #" + test + ": " + counts.size());
      for (Pair<Integer, Integer> p : counts)
      {
        System.out.println(p.first() + " " + p.second());
      }
    }
  }

  private static List<Pair<Integer,Integer>> findSquares(Cell[][] board)
  {
    List<Pair<Integer,Integer>> results = new LinkedList<Pair<Integer,Integer>>();
    int maxSize = Math.min(board.length, board[0].length);
    for (int size = maxSize; size > 0; size--)
    {
      int squares = 0;
      for (int i = 0; i < board.length; i++)
      {
        for (int j = 0; j < board[i].length; j++)
        {
          if (board[i][j] == Cell.USED)
          {
            continue;
          }
          if (isSquare(board, i, j, size))
          {
            markSquare(board, i, j, size);
            squares++;
          }
        }
      }
      if (squares > 0)
      {
        results.add(new Pair<Integer,Integer>(size, squares));
      }
    }
    return results;
  }

  private static boolean isSquare(Cell[][] board, int x, int y, int size)
  {
    if (x + size > board.length || y + size > board[0].length)
    {
      return false;
    }
    Cell topLeft = board[x][y];
    for (int i = x; i < x + size; i++)
    {
      for (int j = y; j < y + size; j++)
      {
        Cell expected;
        if (((i - x) + (j - y)) % 2 == 0)
        {
          expected = topLeft;
        }
        else
        {
          expected = (topLeft == Cell.BLACK ? Cell.WHITE : Cell.BLACK);
        }
        if (board[i][j] != expected)
        {
          return false;
        }
      }
    }
    return true;
  }

  private static void markSquare(Cell[][] board, int x, int y, int size)
  {
    for (int i = x; i < x + size; i++)
    {
      for (int j = y; j < y + size; j++)
      {
        board[i][j] = Cell.USED;
      }
    }
  }


  private static enum Cell
  {
    BLACK, WHITE, USED;
  }
}

class Pair<A,B>
{
  private A a;
  private B b;
  public Pair(A a, B b)
  {
    this.a = a;
    this.b = b;
  }

  public A first()
  {
    return a;
  }

  public B second()
  {
    return b;
  }
}
