package com.agustin.y2017;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.*;

/**
 * @author Agustin on 4/8/2017.
 * @since x.x
 */
public class Pancakes {

    private static final String folder = "y2017/pancakes/";
    private static final String NO_SOLUTION = "IMPOSSIBLE";
    private final PancakeNode pancakes;
    private final Set<PancakeNode> solutions;

    private Pancakes(PancakeNode node) {
        this.pancakes = node;
        this.solutions = new HashSet<>();
    }

    public static Pancakes of(boolean[] pan, int flipSize) {
        if (flipSize < 0) throw new IllegalArgumentException("flip size must be greater than 0");
        if (flipSize > pan.length) throw new IllegalArgumentException("flip size must be smaller than pancake size");
        return new Pancakes(PancakeNode.of(pan, flipSize));
    }

    public static void main(String... args) {
//        String filename = "test01.txt";
        String filename = "A-small-attempt0.in";
        InputStream resourceAsStream = ClassLoader.getSystemClassLoader().getResourceAsStream(Pancakes.folder + filename);
        try (BufferedReader bf = new BufferedReader(new InputStreamReader(resourceAsStream))) {
            int numCases = HelperClass.asInt(bf.readLine());
            for (int i = 0; i < numCases; i++) {
                String caseLine = bf.readLine();
                int indexSpace = caseLine.indexOf(' ');
                Pancakes pancakeSolver = Pancakes.of(HelperClass.toBoolArray(caseLine.substring(0, indexSpace)), HelperClass.asInt(caseLine.substring(indexSpace + 1)));
                int result = pancakeSolver.solve();
                System.out.println(String.format("Case #%d: %s", i + 1, result < 0 ? NO_SOLUTION : result));
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private int solve() {
        final LinkedList<PancakeNode> queue = new LinkedList<>();
        queue.offer(this.pancakes);
        while (!queue.isEmpty()) {
            PancakeNode peek = queue.remove();
            if (peek.allPancakesHappyFaced()) {
                return peek.flips;
            }
            solutions.add(peek);
            List<PancakeNode> children = peek.children(solutions);
            for(PancakeNode child: children) {
                if (child.allPancakesHappyFaced()) {
                    return child.flips;
                }
                solutions.add(child);
                queue.offer(child);
            }
        }
        return -1;
    }

    public static class PancakeNode {

        private final boolean[] s;
        private final int k;
        private final int flips;

        private PancakeNode(boolean[] s, int k, int flips) {
            this.s = s;
            this.k = k;
            this.flips = flips;
        }

        public static PancakeNode of(boolean[] s, int k, int flips) {
            return new PancakeNode(s, k, flips);
        }

        public static PancakeNode of(boolean[] s, int k) {
            return new PancakeNode(s, k, 0);
        }

        private PancakeNode flip(int startIdx){
            if(startIdx < 0 || startIdx + k > s.length){
                throw new IllegalArgumentException("unable to perform flip form given starting index" + startIdx + " k:" + k);
            }
            boolean[] copyS = Arrays.copyOf(s, s.length);
            for (int i = 0; i < k; i++) {
                int currIdx = i + startIdx;
                copyS[currIdx] = !s[currIdx];
            }
            return of(copyS, k, flips+1);
        }

        /**
         * Adds only the children that have been unseen by the seen set.
         * @param seen the control set
         * @return a list of unseen control set children
         */
        public List<PancakeNode> children(Set<PancakeNode> seen) {
            List<PancakeNode> children = new ArrayList<>();
            for (int i = 0; i <= s.length - k; i++) {
                PancakeNode potentiallyUnseenChild = flip(i);
                if (!seen.contains(potentiallyUnseenChild)) {
                    children.add(potentiallyUnseenChild);
                }
            }
            return children;
        }

        public boolean allPancakesHappyFaced() {
            for (int i = 0; i < s.length; i++) {
                if (!s[i]) {
                    return false;
                }
            }
            return true;
        }

        @Override
        public String toString() {
            return "PancakeNode{" + Arrays.toString(s) + "}";
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (!(o instanceof PancakeNode)) return false;

            PancakeNode that = (PancakeNode) o;

            return k == that.k && Arrays.equals(s, that.s);

        }

        @Override
        public int hashCode() {
            return Arrays.hashCode(s);
        }
    }

    public static class HelperClass {

        public static int asInt(String str) {
            return Integer.parseInt(str);
        }

        public static boolean[] toBoolArray(String pancakes) {
            boolean[] onThePan = new boolean[pancakes.length()];
            int index = 0;
            for(char p: pancakes.toCharArray()) {
                onThePan[index++] = p == '+';
            }
            return onThePan;
        }
    }
}
