package com.agustin.y2017;

import java.io.*;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author Agustin on 4/8/2017.
 * @since x.x
 */
public class BathroomStall {

    private static final String folder = "y2017/bathroomstall/";
    private static final String prefix_output = "bathroomstall_";
    private final int n;
    private final int k;
    private final List<StallNode> stalls;

    public BathroomStall(int n, int k) {
        this.n = n;
        this.k = k;
        this.stalls = BathroomStallHelper.buildStalls(n);
    }

    public static void main(String... args) {
//        String filename = "test01.txt";
//        String filename = "mytest01.txt";
        String filename = "C-small-1-attempt0.in";
//        String filename = "B-large.in";
        InputStream resourceAsStream = ClassLoader.getSystemClassLoader().getResourceAsStream(BathroomStall.folder + filename);
        try (BufferedReader bf = new BufferedReader(new InputStreamReader(resourceAsStream))) {
            PrintWriter bw = new PrintWriter(prefix_output + filename + ".out", "UTF-8");
            int numCases = BathroomStallHelper.asInt(bf.readLine());
            for (int i = 0; i < numCases; i++) {
                String[] str = bf.readLine().split(" ");
                int n = BathroomStallHelper.asInt(str[0]);
                int k = BathroomStallHelper.asInt(str[1]);
                BathroomStall bs = new BathroomStall(n, k);
                String res = String.format(i == 0 ? "Case #%d: %s" : "\nCase #%d: %s", i + 1, bs.solve());
                System.out.print(res);
                bw.write(res);
            }
            bw.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private String solve() {
        for (int i = 0; i < k - 1; i++) {
            occupy();
        }
        StallNode lastStall = occupyLast();
        lastStall.setLs(calculateLs(lastStall.idx));
        lastStall.setRs(calculateRs(lastStall.idx));
        return String.format("%d %d", lastStall.calculateMaxLsRs(), lastStall.calculateMinLsRs());
    }

    private StallNode occupyLast() {
        initializeLsRsForEmptyStalls();

        List<StallNode> minLsRsMaximal = findMinLsRsMaximal();
        StallNode stallNode;
        if (minLsRsMaximal.size() == 1) {
            stallNode = minLsRsMaximal.get(0).occupy();
            stalls.set(stallNode.idx, stallNode);
        } else {
            List<StallNode> maxLsRsMaximal = findMaxLsRsMaximal(minLsRsMaximal);
            if (maxLsRsMaximal.size() == 1) {
                 stallNode = maxLsRsMaximal.get(0).occupy();
                stalls.set(stallNode.idx, stallNode);
            } else {
                int minIndex = maxLsRsMaximal.stream()
                        .mapToInt(x -> x.idx)
                        .min()
                        .orElse(-1);
                stallNode = stalls.get(minIndex).occupy();
                stalls.set(minIndex, stallNode);
            }
        }
        return stallNode;
    }

    private void occupy() {
        initializeLsRsForEmptyStalls();

        List<StallNode> minLsRsMaximal = findMinLsRsMaximal();
        if (minLsRsMaximal.size() == 1) {
            StallNode stallNode = minLsRsMaximal.get(0).occupy();
            stalls.set(stallNode.idx, stallNode);
        } else {
            List<StallNode> maxLsRsMaximal = findMaxLsRsMaximal(minLsRsMaximal);
            if (maxLsRsMaximal.size() == 1) {
                StallNode stallNode = maxLsRsMaximal.get(0).occupy();
                stalls.set(stallNode.idx, stallNode);
            } else {
                int minIndex = maxLsRsMaximal.stream()
                        .mapToInt(x -> x.idx)
                        .min()
                        .orElse(-1);
                stalls.set(minIndex, stalls.get(minIndex).occupy());
            }
        }
    }

    private void initializeLsRsForEmptyStalls() {
        for (int i = 1; i < stalls.size() - 1; i++) {
            if (stalls.get(i).isEmpty()) {
                StallNode s = stalls.get(i);
                s.setLs(calculateLs(i));
                s.setRs(calculateRs(i));
                s.calculateMinLsRs();
                s.calculateMaxLsRs();
            }
        }
    }

    private List<StallNode> findMaxLsRsMaximal(List<StallNode> minLsRsMaximal) {
        final int max = minLsRsMaximal.stream()
                .filter(StallNode::isEmpty)
                .mapToInt(StallNode::calculateMaxLsRs)
                .max().orElse(-1);
        return minLsRsMaximal.stream()
                .filter(x -> x.isEmpty() && x.calculateMaxLsRs() == max)
                .collect(Collectors.toList());
    }

    private List<StallNode> findMinLsRsMaximal() {
        final int max = stalls.stream()
                .filter(StallNode::isEmpty)
                .mapToInt(StallNode::calculateMinLsRs)
                .max().orElse(-1);
        return stalls.stream()
                .filter(x -> x.isEmpty() && x.calculateMinLsRs() == max)
                .collect(Collectors.toList());
    }

    private int calculateLs(int stallIdx) {
        int empty = 0;
        for (int j = stallIdx - 1; j >= 0; j--,empty++) {
            if(!stalls.get(j).isEmpty()) {
                return empty;
            }
        }
        return empty;
    }

    private int calculateRs(int stallIdx) {
        int empty = 0;
        for (int j = stallIdx + 1; j < stalls.size(); j++, empty++) {
            if(!stalls.get(j).isEmpty()) {
                return empty;
            }
        }
        return empty;
    }

    public static class BathroomStallHelper {

        static int asInt(String str) {
            return Integer.parseInt(str);
        }

        public static List<StallNode> buildStalls(int n) {
            List<StallNode> stalls = new ArrayList<>(n+2);
            stalls.add(StallNode.ofOccupied(0));
            for (int i = 1; i < n + 1; i++) {
                stalls.add(StallNode.ofEmpty(i));
            }
            stalls.add(StallNode.ofOccupied(n+1));
            return stalls;
        }
    }

    private static class StallNode {
        public final int idx;
        private boolean empty;
        private int ls;
        private int rs;

        public StallNode(int idx, boolean empty, int ls, int rs) {
            this.idx = idx;
            this.empty = empty;
            this.ls = ls;
            this.rs = rs;
        }

        public static StallNode ofOccupied(int idx) {
            return new StallNode(idx, false, -1, -1);
        }

        public static StallNode ofEmpty(int idx) {
            return new StallNode(idx, true, -1, -1);
        }

        public boolean isEmpty() {
            return empty;
        }

        public int getLs() {
            return ls;
        }

        public void setLs(int ls) {
            this.ls = ls;
        }

        public int getRs() {
            return rs;
        }

        public void setRs(int rs) {
            this.rs = rs;
        }

        public int calculateMinLsRs(){
            return Math.min(ls, rs);
        }

        public int calculateMaxLsRs(){
            return Math.max(ls, rs);
        }

        public StallNode occupy() {
            return new StallNode(idx, false, -1, -1);
        }

        @Override
        public String toString() {
            return isEmpty() ? "." : "o";
        }
    }
}
