import java.io.BufferedReader;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintStream;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.Comparator;
import java.util.Date;
import java.util.List;

public class Problem2TrainTimetableSimulation {

  public class TrainEventsByDateComparator implements Comparator<TrainEvent> {

    public int compare(final TrainEvent o1, final TrainEvent o2) {
      if (o1.time.equals(o2.time)) {
        if (o1.type == o2.type) {
          if (o1.station == o2.station) {
            return 0;
          }
          return o1.station == Station.A ? -1 : 1;
        }
        return o1.type == TrainEventType.Available ? -1 : 1;
      }
      return o1.time.compareTo(o2.time);
    }
  }

  public enum TrainEventType {
    Departure, Available

  }

  public enum Station {
    A, B

  }

  public class TrainEvent {
    Station station;
    TrainEventType type;
    Date time;

    public TrainEvent(final Station station, final TrainEventType type, final Date time) {
      super();
      this.type = type;
      this.station = station;
      this.time = time;
    }
  }

  public class Trip {

    private final Date departure;
    private final Date arrival;

    public Trip(final Date departure, final Date arrival) {
      this.departure = departure;
      this.arrival = arrival;
    }

    public Date getArrivalTime() {
      return arrival;
    }

    public Date getDepartureTime() {
      return departure;
    }

  }

  private final DateFormat df = new SimpleDateFormat("HH:mm");
  private final int turnarround;
  private int trainsNeededAtA;
  private int trainsNeededAtB;
  private final List<TrainEvent> trainEvents = new ArrayList<TrainEvent>();

  public Problem2TrainTimetableSimulation(final int turnarround) {
    this.turnarround = turnarround;
  }

  public static void main(final String[] args) throws NumberFormatException, IOException, ParseException {
    final BufferedReader r = new BufferedReader(new FileReader(args[0]));
    final PrintStream out = new PrintStream(new FileOutputStream("p2.out"));
    // final PrintStream out = System.out;
    final int cases = Integer.parseInt(r.readLine());
    for (int i = 0; i < cases; i++) {
      final int turnarround = Integer.parseInt(r.readLine());
      final String[] nanb = r.readLine().trim().split(" ");
      final int na = Integer.parseInt(nanb[0]);
      final int nb = Integer.parseInt(nanb[1]);
      final Problem2TrainTimetableSimulation problem2TrainTimetable = new Problem2TrainTimetableSimulation(turnarround);

      for (int j = 0; j < na; j++) {
        problem2TrainTimetable.addATrip(r.readLine());
      }

      for (int j = 0; j < nb; j++) {
        problem2TrainTimetable.addBTrip(r.readLine());
      }
      problem2TrainTimetable.solve();
      problem2TrainTimetable.write(i + 1, out);
    }
  }

  private void solve() {
    trainsNeededAtA = 0;
    trainsNeededAtB = 0;
    int trainsAvailableAtA = 0;
    int trainsAvailableAtB = 0;
    Collections.sort(trainEvents, new TrainEventsByDateComparator());
    for (final TrainEvent trainEvent : trainEvents) {
      if (trainEvent.type == TrainEventType.Available) {
        if (trainEvent.station == Station.A) {
          trainsAvailableAtA++;
        } else {
          trainsAvailableAtB++;
        }
      } else {
        if (trainEvent.station == Station.A) {
          if (trainsAvailableAtA > 0) {
            trainsAvailableAtA--;
          } else {
            trainsNeededAtA++;
          }
        } else {
          if (trainsAvailableAtB > 0) {
            trainsAvailableAtB--;
          } else {
            trainsNeededAtB++;
          }
        }
      }
    }
  }

  private void addATrip(final String line) throws ParseException {
    final String[] tripTimes = line.trim().split(" ");
    addEvent(new TrainEvent(Station.A, TrainEventType.Departure, df.parse(tripTimes[0])));
    final Calendar cal = Calendar.getInstance();
    cal.setTime(df.parse(tripTimes[1]));
    cal.add(Calendar.MINUTE, turnarround);
    addEvent(new TrainEvent(Station.B, TrainEventType.Available, cal.getTime()));
  }

  /**
   * @param trainEvent
   */
  private void addEvent(final TrainEvent trainEvent) {
    this.trainEvents.add(trainEvent);

  }

  private void addBTrip(final String line) throws ParseException {
    final String[] tripTimes = line.trim().split(" ");
    addEvent(new TrainEvent(Station.B, TrainEventType.Departure, df.parse(tripTimes[0])));
    final Calendar cal = Calendar.getInstance();
    cal.setTime(df.parse(tripTimes[1]));
    cal.add(Calendar.MINUTE, turnarround);
    addEvent(new TrainEvent(Station.A, TrainEventType.Available, cal.getTime()));
  }

  /**
   * @param i
   *          case number
   * @param out
   *          output stream to write
   */
  private void write(final int i, final PrintStream out) {
    out.println("Case #" + i + ": " + trainsNeededAtA + " " + trainsNeededAtB);
  }
}
