package ominiyi.codejam.d;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.List;

/**
 * 
 * @author Adedayo Ominiyi
 */
public class ProgD {

	public static void main(String[] args) {
		String inputFilename = "D-small-attempt2.in";
		String outputFilename = "D-small-attempt2.out";

		try {
			List<String> inputs = BoilerPlate.readLines(inputFilename);

			List<String> testCases = extractTestCases(inputs);

			List<String> solutions = solveTestCases(testCases);

			writeOutput(solutions, outputFilename);
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}

	private static void writeOutput(List<String> solutions,
			String outputFilename) throws Exception {
		FileOutputStream outputStream = new FileOutputStream(outputFilename);

		int numberOfSolutions = solutions.size();
		for (int solution = 0; solution < numberOfSolutions; solution++) {
			BoilerPlate.writeLine(
					formatOutput((solution + 1), solutions.get(solution)),
					outputStream);
		}
		BoilerPlate.closeQuietly(outputStream);
	}

	private static String formatOutput(int testCaseNumber, String output) {
		return String.format("Case #%d: %s", testCaseNumber, output);
	}

	private static List<String> extractTestCases(List<String> inputs) {
		List<String> testCases = new ArrayList<String>();

		int numberOfLines = inputs.size();

		String line1 = inputs.get(0); // read line 1
		int N = Integer.parseInt(line1); // number of test cases

		int numberOfLinesPerTestCase = (numberOfLines - 1) / N;

		for (int testCase = 1; testCase <= (numberOfLines - 1); testCase = (testCase + numberOfLinesPerTestCase)) {

			for (int j = 0; j < numberOfLinesPerTestCase; j++) {
				String dataAtLine = inputs.get(testCase + j);
				int testCaseLine = (numberOfLinesPerTestCase - 1);
				if (j == testCaseLine) {
					testCases.add(dataAtLine);
				}
			}
		}
		return testCases;
	}

	private static List<String> solveTestCases(List<String> testCases) {
		List<String> solutions = new ArrayList<String>();

		int numberOfTestCases = testCases.size();
		for (int testCaseIndex = 0; testCaseIndex < numberOfTestCases; testCaseIndex++) {
			String[] testCase = testCases.get(testCaseIndex).split(" ");

			Integer[] testCaseAsInt = convertStringArrayToIntArray(testCase);
			Integer totalNumberOfSwaps = goroSort(testCaseAsInt);
			solutions.add(String.valueOf(totalNumberOfSwaps * 2) + ".000000");
		}

		return solutions;
	}

	private static Integer[] convertStringArrayToIntArray(
			String[] arrayToConvert) {
		int arrayToConvertLength = arrayToConvert.length;

		Integer[] integerArray = new Integer[arrayToConvertLength];
		for (int i = 0; i < arrayToConvertLength; i++) {
			integerArray[i] = Integer.parseInt(arrayToConvert[i]);
		}

		return integerArray;
	}

	private static Integer goroSort(Integer[] numbers) {
		int sizeOfNumbers = numbers.length;

		int totalNumberOfSwaps = 0;
		for (int i = 0; i < sizeOfNumbers; i++) {
			int smallest = i;

			for (int j = (i + 1); j < sizeOfNumbers; j++) {
				int a = numbers[smallest];
				int b = numbers[j];
				if (a > b) {
					smallest = j;
				}
			}
			
			int temp = numbers[smallest];
			numbers[smallest] = numbers[i];
			numbers[i] = temp;
			if (smallest != i) {
				totalNumberOfSwaps++;
			} 
		}

		return totalNumberOfSwaps;
	}
}

class BoilerPlate {

	public static List<String> readLines(String filename) throws IOException {
		InputStream input = null;
		try {
			input = new FileInputStream(filename);
			return readLines(input);
		} finally {
			closeQuietly(input);
		}
	}

	private static List<String> readLines(InputStream input) throws IOException {
		InputStreamReader inputStreamReader = new InputStreamReader(input,
				"ASCII");

		BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
		List<String> list = new ArrayList<String>();
		String line = bufferedReader.readLine();
		while (line != null) {
			list.add(line);
			line = bufferedReader.readLine();
		}
		return list;
	}

	public static void closeQuietly(InputStream input) {
		try {
			if (input != null) {
				input.close();
			}
		} catch (IOException ioe) {
			// ignore
		}
	}

	public static void closeQuietly(OutputStream output) {
		try {
			if (output != null) {
				output.close();
			}
		} catch (IOException ioe) {
			// ignore
		}
	}

	public static void writeLine(String line, OutputStream output)
			throws IOException {
		String encoding = "ASCII";
		String LINE_SEPARATOR = null;
		try {
			LINE_SEPARATOR = System.getProperty("line.separator");
		} catch (Exception ex) {
			// avoid security issues
			StringWriter buf = new StringWriter(4);
			PrintWriter out = new PrintWriter(buf);
			out.println();
			LINE_SEPARATOR = buf.toString();
		}
		output.write(line.getBytes(encoding));
		output.write(LINE_SEPARATOR.getBytes(encoding));
	}
}
