import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * 
 * @author Adedayo Ominiyi
 */
public class ProgA {

	public static void main(String[] args) {
		String inputFilename = "A-small-attempt0.in";
		String outputFilename = "A-small-attempt0.out";

		try {
			List<String> inputs = BoilerPlate.readLines(inputFilename);
			List<String> testCases = extractTestCases(inputs);

			List<String> solutions = solveTestCases(testCases);
			writeOutput(solutions, outputFilename);
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}

	private static void writeOutput(List<String> solutions,
			String outputFilename) throws Exception {
		FileOutputStream outputStream = new FileOutputStream(outputFilename);

		int numberOfSolutions = solutions.size();
		for (int solution = 0; solution < numberOfSolutions; solution++) {
			BoilerPlate.writeLine(
					formatOutput((solution + 1), solutions.get(solution)),
					outputStream);
		}
		BoilerPlate.closeQuietly(outputStream);
	}

	private static String formatOutput(int testCaseNumber, String output) {
		return String.format("Case #%d: %s", testCaseNumber, output);
	}

	private static List<String> extractTestCases(List<String> inputs) {
		List<String> testCases = new ArrayList<String>();

		int numberOfLines = inputs.size();

		String line1 = inputs.get(0); // read line 1
		int N = Integer.parseInt(line1); // number of test cases

		int numberOfLinesPerTestCase = (numberOfLines - 1) / N;

		for (int testCase = 1; testCase <= (numberOfLines - 1); testCase = (testCase + numberOfLinesPerTestCase)) {

			for (int j = 0; j < numberOfLinesPerTestCase; j++) {
				String dataAtLine = inputs.get(testCase + j);
				int testCaseLine = (numberOfLinesPerTestCase - 1);
				if (j == testCaseLine) {
					testCases.add(dataAtLine);
				}
			}
		}
		return testCases;
	}

	private static List<String> solveTestCases(List<String> testCases) {
		List<String> solutions = new ArrayList<String>();
		int numberOfTestCases = testCases.size();

		for (int testCaseIndex = 0; testCaseIndex < numberOfTestCases; testCaseIndex++) {
			String[] testCase = testCases.get(testCaseIndex).split(" ");
		
			// build button to push events
			List<ButtonToPushEvent> buttonToPushEvents = new ArrayList<ButtonToPushEvent>();
			for (int i = 1; i < testCase.length; i = i + 2) {
				String robotColor = testCase[i];
				int buttonToPush = Integer.parseInt(testCase[i + 1]);
				
				ButtonToPushEvent buttonToPushEvent = new ButtonToPushEvent((robotColor.equals("O")? RobotColor.ORANGE : RobotColor.BLUE), buttonToPush);
				buttonToPushEvents.add(buttonToPushEvent);
			}
			
			Robot orangeRobot = new Robot(RobotColor.ORANGE);
			Robot blueRobot = new Robot(RobotColor.BLUE);
			
			// let robots know the locations they need to be at
			for (ButtonToPushEvent event : buttonToPushEvents) {
				if (event.robotToPushButton.equals(RobotColor.ORANGE)) {
					orangeRobot.addLocationToBeAt(event.buttonToPush);
				} else if (event.robotToPushButton.equals(RobotColor.BLUE)) {
					blueRobot.addLocationToBeAt(event.buttonToPush);
				}
			}
			
			// process events
			int numberOfSteps = 0;
			while (buttonToPushEvents.size() > 0) {
				numberOfSteps++;
				ButtonToPushEvent eventToPerform = buttonToPushEvents.get(0);
				boolean orangeHasPushedButton = orangeRobot.makeNextMove(eventToPerform);
				boolean blueHasPushedButton = blueRobot.makeNextMove(eventToPerform);
				if (orangeHasPushedButton == true || blueHasPushedButton == true) {
					buttonToPushEvents.remove(0);
				}
				
			}
			solutions.add(String.valueOf(numberOfSteps));
		}
		return solutions;
	}
}

enum RobotColor {
	ORANGE, BLUE
}

class ButtonToPushEvent {
	
	public final RobotColor robotToPushButton;
	public final int buttonToPush;

	public ButtonToPushEvent(RobotColor robotToPushButton, int buttonToPush) {
		this.robotToPushButton = robotToPushButton;
		this.buttonToPush = buttonToPush;
	}
}

class Robot {

	private final RobotColor robotColor;
	private int currentlyAtButton = 1;
	private List<Integer> locationsToBeAt = new ArrayList<Integer>();
	

	public Robot(RobotColor robotColor) {
		this.robotColor = robotColor;
	}

	public boolean makeNextMove(ButtonToPushEvent buttonToPushEvent) {
		boolean buttonHasBeenPush = false;
		
		// decide if robot needs to push button
		if (buttonToPushEvent.robotToPushButton.equals(robotColor)) {
			if (buttonToPushEvent.buttonToPush == currentlyAtButton) {
				buttonHasBeenPush = true;
			}
		}
		
		// decide if robot needs to move
		if (locationsToBeAt.size() > 0) {
			Integer buttonLocationToBeAt = locationsToBeAt.get(0);
			if (currentlyAtButton != buttonLocationToBeAt) {
				if (currentlyAtButton > buttonLocationToBeAt) {
					currentlyAtButton--;
				} else if (currentlyAtButton < buttonLocationToBeAt) {
					currentlyAtButton++;
				}
			}
		}
		
		if (buttonHasBeenPush == true) {
			locationsToBeAt.remove(0);
		}
				
		return buttonHasBeenPush;
	}
	
	public void addLocationToBeAt(Integer locationToBeAt) {
		locationsToBeAt.add(locationToBeAt);
	}
	
	public void showLocationsToBeAt() {
		System.out.println(robotColor + " : " + Arrays.toString(locationsToBeAt.toArray()));
	}
}

class BoilerPlate {

	public static List<String> readLines(String filename) throws IOException {
		InputStream input = null;
		try {
			input = new FileInputStream(filename);
			return readLines(input);
		} finally {
			closeQuietly(input);
		}
	}

	private static List<String> readLines(InputStream input) throws IOException {
		InputStreamReader inputStreamReader = new InputStreamReader(input,
				"ASCII");

		BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
		List<String> list = new ArrayList<String>();
		String line = bufferedReader.readLine();
		while (line != null) {
			list.add(line);
			line = bufferedReader.readLine();
		}
		return list;
	}

	public static void closeQuietly(InputStream input) {
		try {
			if (input != null) {
				input.close();
			}
		} catch (IOException ioe) {
			// ignore
		}
	}

	public static void closeQuietly(OutputStream output) {
		try {
			if (output != null) {
				output.close();
			}
		} catch (IOException ioe) {
			// ignore
		}
	}

	public static void writeLine(String line, OutputStream output)
			throws IOException {
		String encoding = "ASCII";
		String LINE_SEPARATOR = null;
		try {
			LINE_SEPARATOR = System.getProperty("line.separator");
		} catch (Exception ex) {
			// avoid security issues
			StringWriter buf = new StringWriter(4);
			PrintWriter out = new PrintWriter(buf);
			out.println();
			LINE_SEPARATOR = buf.toString();
		}
		output.write(line.getBytes(encoding));
		output.write(LINE_SEPARATOR.getBytes(encoding));
	}
}
