package ominiyi.codejam.b;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * 
 * @author Adedayo Ominiyi
 */
public class ProgB {

	public static void main(String[] args) {
		String inputFilename = "B-large.in";
		String outputFilename = "B-large.out";

		try {
			List<String> inputs = BoilerPlate.readLines(inputFilename);
			
			List<String> testCases = extractTestCases(inputs);
			
			List<String> solutions = solveTestCases(testCases);
			
			writeOutput(solutions, outputFilename);
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}

	private static void writeOutput(List<String> solutions,
			String outputFilename) throws Exception {
		FileOutputStream outputStream = new FileOutputStream(outputFilename);

		int numberOfSolutions = solutions.size();
		for (int solution = 0; solution < numberOfSolutions; solution++) {
			BoilerPlate.writeLine(
					formatOutput((solution + 1), solutions.get(solution)),
					outputStream);
		}
		BoilerPlate.closeQuietly(outputStream);
	}

	private static String formatOutput(int testCaseNumber, String output) {
		return String.format("Case #%d: %s", testCaseNumber, output);
	}

	private static List<String> extractTestCases(List<String> inputs) {
		List<String> testCases = new ArrayList<String>();

		int numberOfLines = inputs.size();

		String line1 = inputs.get(0); // read line 1
		int N = Integer.parseInt(line1); // number of test cases

		int numberOfLinesPerTestCase = (numberOfLines - 1) / N;

		for (int testCase = 1; testCase <= (numberOfLines - 1); testCase = (testCase + numberOfLinesPerTestCase)) {

			for (int j = 0; j < numberOfLinesPerTestCase; j++) {
				String dataAtLine = inputs.get(testCase + j);
				int testCaseLine = (numberOfLinesPerTestCase - 1);
				if (j == testCaseLine) {
					testCases.add(dataAtLine);
				}
			}
		}
		return testCases;
	}

	private static List<String> solveTestCases(List<String> testCases) {
		List<String> solutions = new ArrayList<String>();
		
		int numberOfTestCases = testCases.size();
		for (int testCaseIndex = 0; testCaseIndex < numberOfTestCases; testCaseIndex++) {
			String[] testCase = testCases.get(testCaseIndex).split(" ");
			
			List<Character> invokedCharacters = new ArrayList<Character>();
			List<String> baseElements = new ArrayList<String>();
			List<String> opposingElements = new ArrayList<String>();
			
			int numberOfBaseElements = Integer.parseInt(testCase[0]);
			
			for (int i = 0; i < numberOfBaseElements; i++) {
				baseElements.add(testCase[i + 1]);
			}
			
			int numberOfOpposingElements = Integer.parseInt(testCase[1 + numberOfBaseElements]);
			for (int i = 0; i < numberOfOpposingElements; i++) {
				opposingElements.add(testCase[i + 2 + numberOfBaseElements]);
			}
			
			// read characters to be invoked
			String stringToInvoke = testCase[testCase.length - 1];
			for (int i = 0; i < stringToInvoke.length(); i++) {
				char invokedChar = stringToInvoke.charAt(i);
				if (invokedCharacters.size() <= 0) {
					invokedCharacters.add(invokedChar);
				} else if (invokedCharacters.size() > 0) {
					// check for base elements
					boolean foundBaseElement = false;
					for (String baseElement : baseElements) {
						int indexOfInvokedChar = baseElement.indexOf(invokedChar);
						
						if ((indexOfInvokedChar != 2) && (indexOfInvokedChar != -1)) {
							char nextBaseElement = '\u0000';
							if (indexOfInvokedChar == 0) {
								nextBaseElement = baseElement.charAt(1);
							} else if (indexOfInvokedChar == 1) {
								nextBaseElement = baseElement.charAt(0);
							}
					
							char previousInvokedChar = invokedCharacters.get(invokedCharacters.size() - 1);
							if (nextBaseElement == previousInvokedChar) {
								if (foundBaseElement == false) {
									foundBaseElement = true;
								}
								invokedCharacters.remove(invokedCharacters.size() - 1);
								invokedCharacters.add(baseElement.charAt(2));
							}
						}
					}
					
					if ((foundBaseElement == false)) {
						// check for opposing characters
						boolean foundOpposingElement = false;
						for (String opposingElement : opposingElements) {
							int indexOfInvokedChar = opposingElement.indexOf(invokedChar);
							
							if ((indexOfInvokedChar != -1)) {
								char nextOpposingElement = '\u0000';
								if (indexOfInvokedChar == 0) {
									nextOpposingElement = opposingElement.charAt(1);
								} else if (indexOfInvokedChar == 1) {
									nextOpposingElement = opposingElement.charAt(0);
								}
								for (Character c : invokedCharacters) {
									if (c == nextOpposingElement) {
										if (foundOpposingElement == false) {
											foundOpposingElement = true;
										}									
										invokedCharacters.clear();
										break;
									}
								}
							}
						}
						if ((foundOpposingElement == false)) {
							invokedCharacters.add(invokedChar);
						}
					}
				}
			}
			solutions.add(Arrays.toString(invokedCharacters.toArray()));
		}
		return solutions;
	}
}

class BoilerPlate {

	public static List<String> readLines(String filename) throws IOException {
		InputStream input = null;
		try {
			input = new FileInputStream(filename);
			return readLines(input);
		} finally {
			closeQuietly(input);
		}
	}

	private static List<String> readLines(InputStream input) throws IOException {
		InputStreamReader inputStreamReader = new InputStreamReader(input,
				"ASCII");

		BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
		List<String> list = new ArrayList<String>();
		String line = bufferedReader.readLine();
		while (line != null) {
			list.add(line);
			line = bufferedReader.readLine();
		}
		return list;
	}

	public static void closeQuietly(InputStream input) {
		try {
			if (input != null) {
				input.close();
			}
		} catch (IOException ioe) {
			// ignore
		}
	}

	public static void closeQuietly(OutputStream output) {
		try {
			if (output != null) {
				output.close();
			}
		} catch (IOException ioe) {
			// ignore
		}
	}

	public static void writeLine(String line, OutputStream output)
			throws IOException {
		String encoding = "ASCII";
		String LINE_SEPARATOR = null;
		try {
			LINE_SEPARATOR = System.getProperty("line.separator");
		} catch (Exception ex) {
			// avoid security issues
			StringWriter buf = new StringWriter(4);
			PrintWriter out = new PrintWriter(buf);
			out.println();
			LINE_SEPARATOR = buf.toString();
		}
		output.write(line.getBytes(encoding));
		output.write(LINE_SEPARATOR.getBytes(encoding));
	}
}
