package fashion_show;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;

import java.util.List;
import java.util.Map;
import java.util.Scanner;

/**
 * Created by Adi on 09/04/2016.
 * Guava Library is available online by Google :) - https://github.com/google/guava
 */
public class D_small {

    private List<String> lstOutput = Lists.newArrayList();

    public static final char EMPTY_CELL = '.';
    public static final char PLUS_CELL = '+';
    public static final char X_CELL = 'x';
    public static final char O_CELL = 'o';

    public static Map<Character, Integer> mpStylePoints;
    static
    {
        mpStylePoints = Maps.newHashMap();
        mpStylePoints.put(EMPTY_CELL, 0);
        mpStylePoints.put(PLUS_CELL, 1);
        mpStylePoints.put(X_CELL, 1);
        mpStylePoints.put(O_CELL, 2);
    }

    public static final int TYPE = 0;
    public static final int ROW = 1;
    public static final int COL  = 2;

    public D_small()
    {
        Scanner in = new Scanner(System.in);

        int T = in.nextInt();

        for(int i=0; i < T; i++)
        {
            int N = in.nextInt();
            char[][] grid = initGrid(N);

            int M = in.nextInt();
            for(int j=0; j < M;j++)
            {
                String type = in.next();
                int iRow = in.nextInt() - 1;
                int iCol = in.nextInt() - 1;

                grid[iRow][iCol] = type.toCharArray()[0];
            }

            List<Map<Integer, String>> lstAddedModels = addModels(grid, N);

            lstOutput.add("Case #" + (i+1) + ": " + String.valueOf(sumStyle(grid, N)) + " " + lstAddedModels.size());
            for(int j=0; j < lstAddedModels.size(); j++)
            {
                Map<Integer, String> mpAddedModel = lstAddedModels.get(j);
                lstOutput.add(mpAddedModel.get(TYPE) + " " + mpAddedModel.get(ROW) + " " + mpAddedModel.get(COL));
            }
        }

        in.close();
    }

    private List<Map<Integer, String>> addModels(char[][] grid, int N)
    {
        List<Map<Integer, String>> lstAddedModels = Lists.newArrayList();
        for(int i=0; i < N; i++)
        {
            for(int j=0; j < N; j++)
            {
                if(grid[i][j] != EMPTY_CELL)
                {
                    if(grid[i][j] != O_CELL)
                    {
                        char cOldChar = grid[i][j];
                        grid[i][j] = O_CELL;
                        if(isGridValid(grid, N))
                        {
                            Map<Integer, String> mpAddedModel = Maps.newHashMap();
                            mpAddedModel.put(TYPE, String.valueOf(O_CELL));
                            mpAddedModel.put(ROW, String.valueOf(i+1));
                            mpAddedModel.put(COL, String.valueOf(j+1));
                            lstAddedModels.add(mpAddedModel);
                            continue;
                        }
                        grid[i][j] = cOldChar;
                    }
                    continue;
                }

                grid[i][j] = O_CELL;
                if(isGridValid(grid, N))
                {
                    Map<Integer, String> mpAddedModel = Maps.newHashMap();
                    mpAddedModel.put(TYPE, String.valueOf(O_CELL));
                    mpAddedModel.put(ROW, String.valueOf(i+1));
                    mpAddedModel.put(COL, String.valueOf(j+1));
                    lstAddedModels.add(mpAddedModel);
                    continue;
                }
                grid[i][j] = X_CELL;
                if(isGridValid(grid, N))
                {
                    Map<Integer, String> mpAddedModel = Maps.newHashMap();
                    mpAddedModel.put(TYPE, String.valueOf(X_CELL));
                    mpAddedModel.put(ROW, String.valueOf(i+1));
                    mpAddedModel.put(COL, String.valueOf(j+1));
                    lstAddedModels.add(mpAddedModel);
                    continue;
                }
                grid[i][j] = PLUS_CELL;
                if(isGridValid(grid, N))
                {
                    Map<Integer, String> mpAddedModel = Maps.newHashMap();
                    mpAddedModel.put(TYPE, String.valueOf(PLUS_CELL));
                    mpAddedModel.put(ROW, String.valueOf(i+1));
                    mpAddedModel.put(COL, String.valueOf(j+1));
                    lstAddedModels.add(mpAddedModel);
                    continue;
                }
                grid[i][j] = EMPTY_CELL;
            }
        }

        return lstAddedModels;
    }

    private boolean isGridValid(char[][] grid, int N)
    {
        for(int i=0; i < N; i++)
        {
            int rowModels = 0;
            int rowPlusModels = 0;

            int colModels = 0;
            int colPlusModels = 0;

            for(int j=0; j < N; j++)
            {
                if(grid[i][j] != EMPTY_CELL)
                {
                    rowModels++;
                    if(grid[i][j] == PLUS_CELL)
                    {
                        rowPlusModels++;
                    }
                }

                if(grid[j][i] != EMPTY_CELL)
                {
                    colModels++;
                    if(grid[j][i] == PLUS_CELL)
                    {
                        colPlusModels++;
                    }
                }
            }

            if(rowModels - rowPlusModels > 1)
            {
                return false;
            }
            if(colModels - colPlusModels > 1)
            {
                return false;
            }
        }

        return checkDiag(grid, N);
    }

    private boolean checkDiag(char[][] grid, int N)
    {
        for(int j=0; j < N; j++)
        {
            int diagModels = 0;
            int diagXModels = 0;

            int diagModelsLower = 0;
            int diagXModelsLower = 0;

            int invertedDiagModels = 0;
            int invertedDiagXModels = 0;

            int invertedDiagModelsLower = 0;
            int invertedDiagXModelsLower = 0;

            for(int i=0; i < N; i++)
            {
                if((i+j<N) && (grid[i+j][i] != EMPTY_CELL))
                {
                    diagModelsLower++;
                    if(grid[i+j][i] == X_CELL)
                    {
                        diagXModelsLower++;
                    }
                }

                if((i+j<N) && (grid[i][i+j] != EMPTY_CELL))
                {
                    diagModels++;
                    if(grid[i][i+j] == X_CELL)
                    {
                        diagXModels++;
                    }
                }

                if((N-1-i-j >= 0) && (i+j < N) && (grid[N-1-i-j][i] != EMPTY_CELL))
                {
                    invertedDiagModels++;
                    if(grid[N-1-i-j][i] == X_CELL)
                    {
                        invertedDiagXModels++;
                    }
                }

                if((N-1-i-j >= 0) && (i+j < N) && (grid[N-1-i][i+j] != EMPTY_CELL))
                {
                    invertedDiagModelsLower++;
                    if(grid[N-1-i][i+j] == X_CELL)
                    {
                        invertedDiagXModelsLower++;
                    }
                }
            }

            if(diagModels - diagXModels > 1)
            {
                return false;
            }
            if(diagModelsLower - diagXModelsLower > 1)
            {
                return false;
            }
            if(invertedDiagModels - invertedDiagXModels > 1)
            {
                return false;
            }
            if(invertedDiagModelsLower - invertedDiagXModelsLower > 1)
            {
                return false;
            }
        }

        return true;
    }

    private int sumStyle(char[][] grid, int N)
    {
        int iStyle = 0;
        for(int i=0; i < N; i++)
        {
            for(int j=0; j < N; j++)
            {
                iStyle += mpStylePoints.get(grid[i][j]);
            }
        }

        return iStyle;
    }

    private char[][] initGrid(int N)
    {
        char[][] grid = new char[N][N];

        for(int i=0; i < N; i++)
        {
            for (int j=0; j<N; j++)
            {
                grid[i][j] = EMPTY_CELL;
            }
        }

        return grid;
    }

    public void printOutput()
    {
        for(String string : lstOutput)
        {
            System.out.println(string);
        }
    }

    public static void main(String[] args)
    {
        D_small main = new D_small();
        main.printOutput();
    }
}
