import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

abstract class BackTrack<T> {
	public final List<T> l;
	protected final int n;
	public final List<List<T>> sol = new ArrayList<List<T>>();
	
	public BackTrack(final int n) {
		l = new ArrayList<T>(Collections.<T>nCopies(n, null));
		this.n = n;
	}
	
	public BackTrack(final List<T> l) {
		this.l = l;
		n = l.size();
	}
	
	protected abstract boolean check(int pos);
	
	protected boolean checkComplete() {
		return true;
	}
	
	protected abstract T nextVal(T x);
	
	protected void remove(int pos) {}
	
	protected void add(int pos) {}
	
	protected void init() {}
	
	public boolean run() {
		init();
		int pos = 0;
		T x;
		while (true) {
			if (pos == n) {
				if (checkComplete()) {
					sol.add(new ArrayList<T>(l));
				}
				--pos;
				remove(pos);
			}
			else // !?
			if (l.get(pos) != null && check(pos)) {
				add(pos);
				++pos;
				continue;
			}
			while (true) {
				x = nextVal(l.get(pos));
				if (pos < n - 1) {
					l.set(pos + 1, null);
				}
				if (x == null) {
					--pos;
					if (pos < 0) {
						return false;
					}
					remove(pos);
				} else {
					l.set(pos, x);
					break;
				}
			}
		}
	}
}


public class D_1_drum {
	public void solve(final Scanner sc, final PrintWriter pw) {
		final int r = sc.nextInt();
		final int c = sc.nextInt();
		BackTrack<Integer> b = new BackTrack<Integer>(r * c) {
			private List<Integer> getn(int t) {
				List<Integer> l = new ArrayList<Integer>();
				int x = t % c;
				int y = t / c;
				l.add(x == 0 ? t + c - 1 : t - 1);
				l.add(x == c - 1 ? t - c + 1 : t + 1);
				if (y > 0) l.add(t - c);
				if (y < r - 1) l.add(t + c);
				return l;
			}
			
			private boolean checkn(int t) {
				if (l.get(t) == null) return true;
				int v = l.get(t);
				int n = 0;
				int k = 0;
				for (int x : getn(t)) {
					Integer vx = l.get(x);
					if (vx == null) {
						k++;
					}
					else if (vx == v) {
						n++;
					}
				}
				return n <= v && n + k >= v;
			}

			@Override
			protected boolean check(int pos) {
				if (!checkn(pos)) {
					return false;
				}
				for (int x : getn(pos)) {
					if (!checkn(x)) {
						return false;
					}
				}
				return true;
			}

			@Override
			protected Integer nextVal(final Integer x) {
				if (x == null) return 1;
				if (x == 4) return null;
				return x + 1;
			}
		};
		b.run();
		
		for (int i = b.sol.size() - 1; i >= 0; --i) {
			for (int j = 0; j < i; ++j) {
				if (eq(b.sol.get(j), b.sol.get(i), r, c)) {
					b.sol.remove(i);
					break;
				}
			}
		}
		pw.println(b.sol.size());
//		for (List<Integer> l : b.sol) System.out.println(l);
	}
	
	private boolean eq(List<Integer> a, List<Integer> b, int r, int c) {
		for (int i = 1; i < c; ++i) {
			if (eq(a, b, r, c, i)) {
				return true;
			}
		}
		return false;
	}
	
	private boolean eq(List<Integer> a, List<Integer> b, int r, int c, int d) {
		for (int i = 0; i < a.size(); ++i) {
			int x = i % c;
			int y = i / c;
			int x1 = x >= d ? x - d : x + c - d;
			int i1 = y * c + x1;
			if (a.get(i) != b.get(i1)) {
				return false;
			}
		}
		return true;
	}
	
	public static void main(final String... args) throws IOException {
		final String fname = "D-small-attempt1";
		final Scanner sc = new Scanner(new File(fname + ".in"));
		final PrintWriter pw = new PrintWriter(fname + ".out");
		final int t = sc.nextInt();
		
		for (int i = 1; i <= t; ++i) {
			System.out.println(i);
			pw.print("Case #" + i + ": ");
			new D_1_drum().solve(sc, pw);
		}
		pw.close();
	}
}
