package aditsu.gcj.portal;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;

public class Heap<T> {
	private final List<T> l = new ArrayList<T>();
	private final Comparator<T> comp;
	private HeapListener<T> listener;

	public Heap(final Comparator<T> comp) {
		this.comp = comp;
	}

	public Heap() {
		this(null);
	}

	public HeapListener<T> getListener() {
		return listener;
	}

	public void setListener(final HeapListener<T> listener) {
		this.listener = listener;
	}

	@SuppressWarnings("unchecked")
	private int compare(final T x, final T y) {
		return comp == null ? ((Comparable<T>) x).compareTo(y) : comp.compare(x, y);
	}

	private int compare(final int x, final int y) {
		return compare(l.get(x), l.get(y));
	}

	private int add(final T x) {
		final int pos = l.size();
		l.add(x);
		if (listener != null) {
			listener.added(x, pos);
		}
		return pos;
	}

	private T removeLast() {
		final int pos = l.size() - 1;
		final T x = l.get(pos);
		l.remove(x);
		if (listener != null) {
			listener.removed(x, pos);
		}
		return x;
	}

	private void swap(final int x, final int y) {
		if (x == y) {
			return;
		}
		final T tx = l.get(x);
		final T ty = l.get(y);
		l.set(x, ty);
		l.set(y, tx);
		if (listener != null) {
			listener.moved(tx, x, y);
			listener.moved(ty, y, x);
		}
	}

	private int promote(final int pos) {
		int p = pos;
		while (p > 0) {
			final int p2 = (p - 1) / 2;
			if (compare(p2, p) <= 0) {
				return p;
			}
			swap(p2, p);
			p = p2;
		}
		return p;
	}

	private int demote(final int pos) {
		int p = pos;
		final int n = l.size();
		while (true) {
			int p0 = p * 2 + 1;
			if (p0 >= n) {
				return p;
			}
			final int p1 = p0 + 1;
			if (p1 < n && compare(p0, p1) > 0) {
				p0 = p1;
			}
			if (compare(p, p0) <= 0) {
				return p;
			}
			swap(p, p0);
			p = p0;
		}
	}

	public int insert(final T x) {
		return promote(add(x));
	}

	public T get(final int x) {
		return l.get(x);
	}

	public int getSize() {
		return l.size();
	}

	public T remove(final int x) {
		final int p = l.size() - 1;
		swap(x, p);
		final T t = removeLast();
		demote(x);
		return t;
	}

	public List<T> getList() {
		return l;
	}

	public boolean isEmpty() {
		return l.isEmpty();
	}

	public static void main(final String... args) {
		final Heap<Integer> h = new Heap<Integer>();
		h.insert(5);
		h.insert(2);
		h.insert(3);
		h.insert(7);
		System.out.println(h.getList());
		while (h.getSize() > 0) {
			System.out.println(h.remove(0));
			System.out.println(h.getList());
		}
	}
}
