import java.awt.Point;
import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayDeque;
import java.util.Arrays;
import java.util.Deque;
import java.util.HashMap;
import java.util.Map;
import java.util.Scanner;

public class Watershed {
	private static final int[][] DIR = {{0, -1}, {-1, 0}, {1, 0}, {0, 1}};
	
	private static void set(final Point[][] b, final Point p, final Point p1) {
		b[p.y][p.x] = p1;
	}
	
	private static Point get(final Point[][] b, final Point p) {
		return b[p.y][p.x];
	}
	
	private static int get(final int[][] m, final Point p) {
		return m[p.y][p.x];
	}
	
	private static Point flow(final int[][] m, final Point p) {
		int a = get(m, p);
		Point r = p;
		for (int[] d : DIR) {
			Point p1 = new Point(p.x + d[0], p.y + d[1]);
			int t = get(m, p1);
			if (t < a) {
				a = t;
				r = p1;
			}
		}
		return r;
	}
	
	private static void expand(final Deque<Point> q, final Point p, final int w, final int h) {
		for (int[] d : DIR) {
			Point p1 = new Point(p.x + d[0], p.y + d[1]);
			if (p1.x > 0 && p1.x <= w && p1.y > 0 && p1.y <= h) {
				q.addLast(p1);
			}
		}
	}
	
	public static void main(final String... args) throws IOException {
		final String fname = "B-small-attempt0";
		final Scanner sc = new Scanner(new File(fname + ".in"));
		final PrintWriter pw = new PrintWriter(fname + ".out");
		final int t = sc.nextInt();
		for (int i = 0; i < t; ++i) {
			final int h = sc.nextInt();
			final int w = sc.nextInt();
			final int[][] m = new int[h + 2][w + 2];
			for (int j = 0; j < h + 2; ++j) {
				Arrays.fill(m[j], 1234567890);
			}
			for (int j = 0; j < h; ++j) {
				for (int k = 0; k < w; ++k) {
					m[j + 1][k + 1] = sc.nextInt();
				}
			}
			final Point[][] b = new Point[h + 2][w + 2];
			final Deque<Point> q = new ArrayDeque<Point>();
			for (int j = 1; j <= h; ++j) {
				for (int k = 1; k <= w; ++k) {
					final Point p = new Point(k, j);
					if (flow(m, p) == p) {
						q.push(p);
					}
				}
			}
			while (!q.isEmpty()) {
				Point p = q.removeFirst();
				if (get(b, p) != null) {
					continue;
				}
				Point p1 = flow(m, p);
				if (p1 == p) {
					set(b, p, p);
					expand(q, p, w, h);
				} else if (get(b, p1) != null) {
					set(b, p, get(b, p1));
					expand(q, p, w, h);
				} else {
//					expand(q, p, w, h);
//					q.addLast(p);
				}
			}
			final Map<Point, Character> bm = new HashMap<Point, Character>();
			char c = 'a';
			pw.println("Case #" + (i + 1) + ":");
			for (int j = 1; j <= h; ++j) {
				for (int k = 1; k <= w; ++k) {
					final Point p = new Point(k, j);
					final Point p1 = get(b, p);
					Character ch = bm.get(p1);
					if (ch == null) {
						ch = c++;
						bm.put(p1, ch);
					}
					if (k > 1) {
						pw.print(' ');
					}
					pw.print(ch);
				}
				pw.println();
			}
		}
		pw.close();
	}
}
