import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

abstract class BackTrack<T> {
	public final List<T> l;
	protected final int n;
	
	public BackTrack(final int n) {
		l = new ArrayList<T>(Collections.<T>nCopies(n, null));
		this.n = n;
	}
	
	public BackTrack(final List<T> l) {
		this.l = l;
		n = l.size();
	}
	
	protected abstract boolean check(int pos);
	
	protected boolean checkComplete() {
		return true;
	}
	
	protected abstract T nextVal(T x);
	
	protected void remove(int pos) {}
	
	protected void add(int pos) {}
	
	protected void init() {}
	
	public boolean run() {
		init();
		int pos = 0;
		T x;
		while (true) {
			if (pos == n) {
				if (checkComplete()) {
					return true;
				}
				--pos;
				remove(pos);
			}
			else 
			if (l.get(pos) != null && check(pos)) {
				add(pos);
				++pos;
				continue;
			}
			while (true) {
				x = nextVal(l.get(pos));
				if (pos < n - 1) {
					l.set(pos + 1, null);
				}
				if (x == null) {
					--pos;
					if (pos < 0) {
						return false;
					}
					remove(pos);
				} else {
					l.set(pos, x);
					break;
				}
			}
		}
	}
}

public class C_Erdos_Szekeres extends BackTrack<Integer> {
	private final int[] v;
	private final int[] a;
	private final int[] b;
	
	@Override
	protected boolean checkComplete() {
		for (int i = n - 1; i >= 0; --i) {
			final int x = l.get(i);
			int m = 1;
			for (int j = i + 1; j < n; ++j) {
				if (l.get(j) < x && m <= b[j]) {
					m = b[j] + 1;
					if (m > b[i]) {
						return false;
					}
				}
			}
			if (m != b[i]) return false;
		}
		return true;
	}

	@Override
	protected boolean check(int pos) {
		final int x = l.get(pos);
		if (v[x] != 0) return false;
		int m = 1;
		for (int i = 0; i < pos; ++i) {
			if (l.get(i) < x && m <= a[i]) {
				m = a[i] + 1;
				if (m > a[pos]) {
					return false;
				}
			}
		}
		return m == a[pos];
	}
	
	@Override
	protected void remove(int pos) {
		v[l.get(pos)] = 0;
	}

	@Override
	protected void add(int pos) {
		v[l.get(pos)] = 1;
	}

	@Override
	protected Integer nextVal(final Integer x) {
		if (x == null) return 1;
		if (x == n) return null;
		return x + 1;
	}
	
	public C_Erdos_Szekeres(int n, int[] a, int[] b) {
		super(n);
		this.a = a;
		this.b = b;
		v = new int[n + 1];
	}

	public static void main(final String... args) throws IOException {
		final String fname = "C-small-attempt0";
		final Scanner sc = new Scanner(new File(fname + ".in"));
		final PrintWriter pw = new PrintWriter(fname + ".out");
		final int t = sc.nextInt();
		
		for (int i = 1; i <= t; ++i) {
			System.out.println(i);
			final int n = sc.nextInt();
			final int[] a = new int[n];
			for (int j = 0; j < n; ++j) {
				a[j] = sc.nextInt();
			}
			final int[] b = new int[n];
			for (int j = 0; j < n; ++j) {
				b[j] = sc.nextInt();
			}
			final C_Erdos_Szekeres x = new C_Erdos_Szekeres(n, a, b);
			x.run();
			pw.print("Case #" + i + ":");
			for (int j = 0; j < n; ++j) {
				pw.print(" " + x.l.get(j));
			}
			pw.println();
		}
		pw.close();
	}
}
