import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Scanner;
import java.util.Set;
import java.util.TreeSet;

public class PerfectHarmony {
	private static final List<Integer> primes = new ArrayList<Integer>();
	
	public static long gcd(long x, long y) {
		long r;
		while (true) {
			r = x % y;
			if (r == 0) {
				return y;
			}
			x = y;
			y = r;
		}
	}
	
	public static Map<Long, Integer> getFactors(final long x) {
		final Map<Long, Integer> m = new LinkedHashMap<Long, Integer>();
		long t = x;
		for (long p : primes) {
			if (p * p > t) {
				break;
			}
			int n = 0;
			while (t % p == 0) {
				t /= p;
				++n;
			}
			if (n > 0) {
				m.put(p, n);
			}
		}
		if (t > 1) {
			m.put(t, 1);
		}
		return m;
	}
	
	public static long getDiv(final long x, final long y, final long l, final long h) {
		if (x >= l && x <= h && x < l * 2) {
			return x;
		}
		final Map<Long, Integer> m = getFactors(x);
		final Map<Long, Integer> m2 = getFactors(y);
		final int n = m.size();
		final long[] f = new long[n];
		final int[] pow = new int[n];
		final int[] mp = new int[n];
		int i = 0;
		for (Entry<Long, Integer> e : m.entrySet()) {
			f[i] = e.getKey();
			pow[i] = e.getValue();
			mp[i++] = m2.containsKey(e.getKey()) ? m2.get(e.getKey()) : 0;
		}
		final int[] a = Arrays.copyOf(mp, n);
		final long[] b = new long[n];
		long p = 1;
		for (i = 0; i < n; ++i) {
			for (int j = 0; j < a[i]; ++j) {
				p *= f[i];
			}
			b[i] = p;
		}
		int pos = n;
		long min = h + 1;
		do {
			if (pos == n) {
				if (p >= l && p < min) {
					min = p;
				}
			}
			else {
				++pos;
				if (pos < n) {
					a[pos] = mp[pos];
					for (int e = 0; e < mp[pos]; ++e) {
						p *= f[pos];
					}
					b[pos] = p;
				}
				continue;
			}
			while (true) {
				--pos;
				if (pos < 0) {
					break;
				}
				if (a[pos] < pow[pos]) {
					a[pos]++;
					b[pos] = p = b[pos] * f[pos];
					if (p < min) {
						break;
					}
				}
			}
		} while (pos >= 0);
		return min;
	}
	
	public static void main(final String... args) throws IOException {
		for (int i = 2; i < 1000000; ++i) {
			if (i % 1000000 == 0) {
				System.out.println(i);
			}
			boolean ok = true;
			for (int j : primes) {
				if (j * j > i) {
					break;
				}
				if (i % j == 0) {
					ok = false;
					break;
				}
			}
			if (ok) {
				primes.add(i);
			}
		}
		
		final String fname = "C-small-attempt1";
		final Scanner sc = new Scanner(new File(fname + ".in"));
		final PrintWriter pw = new PrintWriter(fname + ".out");
		final int t = sc.nextInt();
		final Set<Long> set = new TreeSet<Long>();
		
		for (int i = 0; i < t; ++i) {
			pw.print("Case #" + (i + 1) + ": ");
			set.clear();
			final int n = sc.nextInt();
			final long l = sc.nextLong();
			final BigInteger bl = BigInteger.valueOf(l);
			final long h = sc.nextLong();
			System.out.print(l + ", " + h + " -- ");
			final BigInteger bh = BigInteger.valueOf(h);
			for (int j = 0; j < n; ++j) {
				final long q = sc.nextLong();
				System.out.print(q + " ");
				set.add(q);
			}
			System.out.println();
			int ss = set.size();
			final Long[] a = set.toArray(new Long[ss]);
			final long[] gcd = new long[ss];
			final BigInteger[] lcm = new BigInteger[ss];
			long g = gcd[ss - 1] = a[ss - 1];
			for (int j = 1; j < ss; ++j) {
				g = gcd[ss - 1 - j] = gcd(g, a[ss - 1 - j]);
			}
			BigInteger b = lcm[0] = BigInteger.valueOf(a[0]);
			for (int j = 1; j < ss; ++j) {
				final BigInteger aj = BigInteger.valueOf(a[j]);
				b = lcm[j] = b.multiply(aj).divide(b.gcd(aj));
			}
			long best = Long.MAX_VALUE;
			if (g >= l) {
				final long x = getDiv(g, 1, l, h);
				if (x <= h) {
					best = x;
				}
			}
			if (b.compareTo(bh) <= 0) {
				long x = b.longValue();
				if (x >= l) {
					if (x < best) {
						best = x;
					}
				}
				else {
					x *= (l + x - 1) / x;
					if (x <= h) {
						if (x < best) {
							best = x;
						}
					}
				}
			}
			for (int j = 0; j < ss - 1; ++j) {
				if (BigInteger.valueOf(gcd[j + 1]).mod(lcm[j]).equals(BigInteger.ZERO)) {
					long x = lcm[j].longValue();
					x = getDiv(gcd[j + 1], x, l, h);
					if (x <= h) {
						if (x < best) {
							best = x;
						}
					}
				}
			}
			if (best <= h) {
				pw.println(best);
				System.out.println(best);
			}
			else {
				pw.println("NO");
				System.out.println("NO");
			}
		}
		pw.close();
	}
}
