import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Objects;
import java.util.Scanner;
import java.util.Set;

public class C_BeamingWithJoy {
	private static final P UP = new P(-1, 0);
	private static final P DOWN = new P(1, 0);
	private static final P LEFT = new P(0, -1);
	private static final P RIGHT = new P(0, 1);
	
	private int r;
	private int c;
	private char[][] a;
	
	private static class P {
		int row;
		int col;
		
		public P(int row, int col) {
			this.row = row;
			this.col = col;
		}

		@Override
		public int hashCode() {
			return Objects.hash(row, col);
		}

		@Override
		public boolean equals(Object o) {
			P p = (P) o;
			return row == p.row && col == p.col;
		}
		
		void move(final P d) {
			row += d.row;
			col += d.col;
		}
	}
	
	P slash(P d) {
		if (d.equals(UP)) return RIGHT;
		if (d.equals(DOWN)) return LEFT;
		if (d.equals(LEFT)) return DOWN;
		return UP;
	}
	
	P bslash(P d) {
		if (d.equals(UP)) return LEFT;
		if (d.equals(DOWN)) return RIGHT;
		if (d.equals(LEFT)) return UP;
		return DOWN;
	}
	
	private Set<P> shoot(final P p, final P dir) {
		P x = new P(p.row, p.col);
		P d = dir;
		Set<P> s = new HashSet<>();
		while (true) {
			x.move(d);
			if (x.row < 0 || x.row >= r || x.col < 0 || x.col >= c) {
				return s;
			}
			switch (a[x.row][x.col]) {
			case '.':
				s.add(new P(x.row, x.col));
				break;
			case '#':
				return s;
			case '/':
				d = slash(d);
				break;
			case '\\':
				d = bslash(d);
				break;
			case '-':
			case '|':
				return null;
			}
		}
	}
	
	public void solve(final Scanner sc, final PrintWriter pw) {
		r = sc.nextInt();
		c = sc.nextInt();
		sc.nextLine();
		
		a = new char[r][];
		for (int i = 0; i < r; ++i) {
			a[i] = sc.nextLine().toCharArray();
		}
		
		final List<P> cell = new ArrayList<>();
		final List<P> shoot = new ArrayList<>();
		final Map<P, Set<Integer>> cellShoot = new HashMap<>();
		for (int i = 0; i < r; ++i) {
			for (int j = 0; j < c; ++j) {
				final P p = new P(i, j);
				switch (a[i][j]) {
				case '.':
					cell.add(p);
					cellShoot.put(p, new HashSet<>());
					break;
				case '-':
				case '|':
					shoot.add(p);
					break;
				}
			}
		}
		
		final List<Set<P>> h = new ArrayList<>();
		final List<Set<P>> v = new ArrayList<>();
		
		for (P x : shoot) {
			Set<P> l1 = shoot(x, RIGHT);
			Set<P> l2 = shoot(x, LEFT);
			if (l1 == null || l2 == null) {
				h.add(null);
			}
			else {
				l1.addAll(l2);
				h.add(l1);
			}
			l1 = shoot(x, UP);
			l2 = shoot(x, DOWN);
			if (l1 == null || l2 == null) {
				v.add(null);
			}
			else {
				l1.addAll(l2);
				v.add(l1);
			}
		}
		boolean ok = true;
		for (int i = 0; i < shoot.size(); ++i) {
			final Set<P> hi = h.get(i);
			final Set<P> vi = v.get(i);
			if (hi == null && vi == null) {
				ok = false;
				break;
			}
			if (hi == null || vi == null) {
				final P p = shoot.get(i);
				a[p.row][p.col] = hi == null ? '|' : '-';
				final Set<P> s = hi == null ? vi : hi;
				for (P x : s) {
					cellShoot.remove(x);
				}
			}
			else {
				for (P x : hi) {
					final Set<Integer> s = cellShoot.get(x);
					if (s != null) {
						s.add(i);
					}
				}
				for (P x : vi) {
					final Set<Integer> s = cellShoot.get(x);
					if (s != null) {
						s.add(-i - 1);
					}
				}
			}
		}
		while (ok && !cellShoot.isEmpty()) {
			boolean b = false;
			for (Entry<P, Set<Integer>> e : cellShoot.entrySet()) {
				final List<Integer> l = new ArrayList<>(e.getValue());
				if (l.isEmpty()) {
					ok = false;
					break;
				}
				if (l.size() == 1) {
					b = true;
					int t = l.get(0);
					int s = t < 0 ? -1 : 1;
					if (t < 0) {
						t = -t - 1;
					}
					P x = shoot.get(t);
					a[x.row][x.col] = s < 0 ? '|' : '-';
					Set<P> set = s < 0 ? v.get(t) : h.get(t);
					for (P y : set) {
						cellShoot.remove(y);
					}
					for (Entry<P, Set<Integer>> f : cellShoot.entrySet()) {
						f.getValue().remove(t);
						f.getValue().remove(-t - 1);
					}
					break;
				}
			}
			if (!ok) {
				break;
			}
			if (b) {
				continue;
			}
			Entry<P, Set<Integer>> f = null;
			for (Entry<P, Set<Integer>> e : cellShoot.entrySet()) {
				if (f == null || f.getValue().size() > e.getValue().size()) {
					f = e;
				}
			}
			Set<Integer> s1 = f.getValue();
			int x = -1;
			Set<P> pp = null;
			for (int y : s1) {
				int t = y;
				int s = t < 0 ? -1 : 1;
				if (t < 0) {
					t = -t - 1;
				}
				Set<P> set = s < 0 ? v.get(t) : h.get(t);
				Set<P> set2 = s < 0 ? h.get(t) : v.get(t);
				boolean o = true;
				for (P a : set2) {
					final Set<Integer> cs = cellShoot.get(a);
					if (cs == null) {
						continue;
					}
					if (cs.size() == 1) {
						o = false;
						break;
					}
				}
				if (o && (x < 0 || pp.size() > set.size())) {
					x = y;
					pp = set;
				}
			}
			if (x < 0) {
				ok = false;
				break;
			}
			int t = x;
			int s = t < 0 ? -1 : 1;
			if (t < 0) {
				t = -t - 1;
			}
			P z = shoot.get(t);
			a[z.row][z.col] = s < 0 ? '|' : '-';
			Set<P> set = s < 0 ? v.get(t) : h.get(t);
			for (P y : set) {
				cellShoot.remove(y);
			}
			for (Entry<P, Set<Integer>> g : cellShoot.entrySet()) {
				g.getValue().remove(t);
				g.getValue().remove(-t - 1);
			}
		}
		pw.println(ok ? "POSSIBLE" : "IMPOSSIBLE");
		if (ok) {
			for (int i = 0; i < r; ++i) {
				pw.println(new String(a[i]));
			}
		}
	}
	
	@SuppressWarnings("resource")
	public static void main(final String... args) throws IOException {
		final String fname = "C-small-attempt0";
		final Scanner sc = new Scanner(new File(fname + ".in"));
		final PrintWriter pw = new PrintWriter(fname + ".out");
		final int t = sc.nextInt();
		sc.nextLine();
		
		for (int i = 1; i <= t; ++i) {
			System.out.println(i);
			pw.print("Case #" + i + ": ");
			new C_BeamingWithJoy().solve(sc, pw);
		}
		pw.close();
		
		final File f = new File(fname + ".out.good");
		if (!f.exists()) {
			return;
		}
		System.out.println("Comparing");
		final BufferedReader r1 = new BufferedReader(new FileReader(fname + ".out"));
		final BufferedReader r2 = new BufferedReader(new FileReader(f));
		int n = 0;
		while (true) {
			n++;
			final String s1 = r1.readLine();
			final String s2 = r2.readLine();
			if (!Objects.equals(s1, s2)) {
				System.out.println("Line " + n);
				System.out.println("Expected: " + s2);
				System.out.println("Got:      " + s1);
				break;
			}
			if (s1 == null) {
				System.out.println("OK");
				break;
			}
		}
		r1.close();
		r2.close();
	}
}
