package sms.gcjam;

import java.io.File;
import java.io.IOException;
import java.net.URISyntaxException;
import java.nio.file.Path;
import java.util.HashSet;
import java.util.Set;
import java.util.function.BiFunction;

/**
 * Created on Apr 9, 2016.
 */
public class CountingSheep implements BiFunction<Integer, Integer, String>
{
    private static final int RADIX = 10;
    private final Set<Integer> digits;

    public CountingSheep()
    {
        digits = new HashSet<>();
    }

    private void initDigits()
    {
        digits.clear();
        for (int i = 0; i < RADIX; ++i)
        {
            digits.add(i);
        }
    }

    @Override
    public String apply(Integer caseIndex, Integer N)
    {
        if (N <= 0)
            return output(caseIndex, -1L);
        initDigits();
        // find limit
        int limit = RADIX;
        while (limit <= N)
        {
            limit *= RADIX;
        }
        limit *= (RADIX - 1);
        limit /= N;
        ++limit;
        for (int i = 1; i <= limit; ++i)
        {
            long n = i * N;
            markDigits(n);
            if (digits.isEmpty())
                return output(caseIndex, n);
        }
        return output(caseIndex, -1L);
    }

    private void markDigits(long n)
    {
        while (n > 0)
        {
            int remainder = (int)(n % RADIX);
            digits.remove(remainder);
            n /= RADIX;
        }
    }

    private String output(int caseIndex, long result)
    {
        String strResult;
        if (result < 0)
            strResult = "INSOMNIA";
        else
            strResult = Long.toString(result, 10);
        return "Case #" + (caseIndex + 1) + ": " + strResult;
    }
    
    public static void main(String[] args) throws IOException, URISyntaxException
    {
        File dir = new File("C:\\Users\\Steve\\Documents\\src\\GoogleCodeJam\\src\\main\\resources");
        File fIn = new File(dir, "A-large.in");
        Path inputPath = fIn.toPath();
        File fOut = new File(dir, "countingsheep.output.txt");
        Path outputPath = fOut.toPath();
        CountingSheep function = new CountingSheep();
        Driver.driveTextFileOfIntegers(inputPath, function, outputPath);
    }
}
