package sms.gcjam;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.Closeable;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Scanner;

/**
 * Created on Apr 9, 2016.
 */
public class Driver
{
    public static class ScannerWriter implements AutoCloseable
    {
        public final Scanner scanner;
        public final BufferedWriter writer;

        public ScannerWriter(Scanner scanner, BufferedWriter writer)
        {
            this.scanner = scanner;
            this.writer = writer;
        }

        @Override
        public void close()
        {
            closeQuietly(writer);
            closeQuietly(scanner);
        }
    }

    public static void closeQuietly(final Closeable closeable)
    {
        try
        {
            if (closeable != null)
            {
                closeable.close();
            }
        }
        catch (final IOException ioe)
        {
            // ignore
        }
    }

    public static ScannerWriter newScannerWriter(String[] args) throws IOException
    {
        if (args.length > 2)
        {
            System.err.println("Usage: Main [<input filename> <output filename>]");
            return null;
        }
        if ((args.length >= 1) && !args[0].endsWith(".in"))
            throw new IllegalArgumentException();
        if ((args.length >= 2) && !args[1].endsWith(".out"))
            throw new IllegalArgumentException();
        ScannerWriter scannerWriter = null;
        Scanner scanner = null;
        Reader inputReader = null;
        BufferedWriter outputWriter = null;
        try
        {
            if (args.length >= 1)
            {
                Path inputPath = Paths.get(args[0]);
                inputReader = Files.newBufferedReader(inputPath);
            }
            else
                inputReader = new BufferedReader(new InputStreamReader(System.in));
            scanner = new Scanner(inputReader);
            if (args.length >= 2)
            {
                Path outputPath = Paths.get(args[1]);
                outputWriter = Files.newBufferedWriter(outputPath);
            }
            else
                outputWriter = new BufferedWriter(new OutputStreamWriter(System.out));
            scannerWriter = new ScannerWriter(scanner, outputWriter);
        }
        finally
        {
            if (scannerWriter == null)
            {
                closeQuietly(outputWriter);
                closeQuietly(scanner);
                closeQuietly(inputReader);
            }
        }
        return scannerWriter;
    }
}
