import java.util.Comparator;
import java.util.PriorityQueue;
import java.util.Vector;

public class Timetable {
	public enum EventType {
		ARRIVAL_A, ARRIVAL_B, TRAIN_AVAILABLE_A, TRAIN_AVAILABLE_B, DEPARTURE_A, DEPARTURE_B
	};

	private static class Event {

		private Event() {
		}

		public Event(Time tm, EventType tp) {
			time = new Time(tm);
			type = tp;
		}

		public Time getTime() {
			return time;
		}

		public EventType getEventType() {
			return type;
		}

		EventType type;
		Time time;
	}

	public static void main(String[] args) {
		FileUtils.Fout fout = new FileUtils.Fout();
		FileUtils.Fin fin = new FileUtils.Fin();

		fin.open("src/input.txt");
		fout.open("src/output.txt");

		int N = Integer.parseInt(fin.readLine());
		for (int i = 0; i < N; i++) {

			int turnaround = Integer.parseInt(fin.readLine());

			String[] arr = fin.readLineTokenized(" ");
			int NA = Integer.parseInt(arr[0]);
			int NB = Integer.parseInt(arr[1]);

			PriorityQueue<Event> queue = new PriorityQueue<Event>(NA + NB,
					new Comparator<Event>() {
						public int compare(Event i, Event j) {
							if (i.getTime().before(j.getTime()))
								return -1;
							else if (i.getTime().after(j.getTime()))
								return 1;
							else
								return i.getEventType().compareTo(j.getEventType());
						}
					});

			for (int j = 0; j < NA; j++) {
				String[] tmp = fin.readLineTokenized(" ");

				Time departure = new Time(tmp[0]);
				queue.add(new Event(departure, EventType.DEPARTURE_A));
				
				Time arrival = new Time(tmp[1]);
				arrival.addMins(turnaround);
				queue.add(new Event(arrival, EventType.TRAIN_AVAILABLE_B));
			}

			for (int j = 0; j < NB; j++) {
				String[] tmp = fin.readLineTokenized(" ");

				Time departure = new Time(tmp[0]);
				queue.add(new Event(departure,EventType.DEPARTURE_B));

				Time arrival = new Time(tmp[1]);
				arrival.addMins(turnaround);
				queue.add(new Event(arrival, EventType.TRAIN_AVAILABLE_A));
			}

			int trainsRequiredForA=0,trainsRequiredForB=0;
			int trainsAvailableAtA=0,trainsAvailableAtB=0;
			
			//System.out.println("Case #"+(i+1)+":");
			while(!queue.isEmpty()){
				Event ev=queue.poll();
				//System.out.println(ev.getEventType()+" "+ev.getTime());
				switch(ev.getEventType()){
				case DEPARTURE_A:
					if(trainsAvailableAtA==0){
						trainsRequiredForA++;
						trainsAvailableAtA++;
					}
					trainsAvailableAtA--;
					break;
				case DEPARTURE_B:
					if(trainsAvailableAtB==0){
						trainsRequiredForB++;
						trainsAvailableAtB++;
					}
					trainsAvailableAtB--;
					break;
				case TRAIN_AVAILABLE_A:
					trainsAvailableAtA++;
					break;
				case TRAIN_AVAILABLE_B:
					trainsAvailableAtB++;
					break;
				}
			}
			fout.println("Case #"+(i+1)+": " + trainsRequiredForA + " " + trainsRequiredForB);
		}
	}

}
