import java.awt.Point;
import java.awt.geom.Line2D;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;

class FileUtils {
	public static String getCwd() {
		try {
			return new File(".").getCanonicalPath();
		} catch (IOException ie) {
			return null;
		}
	}

	public static class Fout {
		public void finalize() {
			if (fout != null)
				fout.close();
		}

		public boolean open(String fileName) {
			try {
				fout = new PrintWriter(new FileWriter(fileName), true);
				return true;
			} catch (FileNotFoundException fe) {
				return false;
			} catch (IOException ie) {
				return false;
			}
		}

		public boolean close() {
			if (fout != null) {
				fout.close();
				return true;
			} else
				return true;
		}

		public void println(String line) {
			fout.println(line);
		}

		private PrintWriter fout;
	}

	public static class Fin {
		public void finalize() throws IOException {
			if (fin != null)
				fin.close();
		}

		public boolean open(String fileName) {
			try {
				fin = new BufferedReader(new FileReader(fileName));
				return true;
			} catch (FileNotFoundException fe) {
				return false;
			}
		}

		public boolean close() {
			if (fin != null) {
				try {
					fin.close();
					return true;
				} catch (IOException ie) {
					return false;
				}
			} else
				return true;
		}

		public String[] readLineTokenized(String token) {
			try {
				String line = fin.readLine();
				if (line == null)
					return null;
				return line.split(token);
			} catch (IOException ie) {
				return null;
			}
		}

		public String readLine() {
			try {
				return fin.readLine();
			} catch (IOException ie) {
				return null;
			}
		}

		private BufferedReader fin;
	}
}

class GeomUtils {
	public static class Triangle {
		private Triangle() {
		}

		public Triangle(Point point1, Point point2, Point point3) {
			setTriangle(point1, point2, point3);
		}

		public void setTriangle(Point point1, Point point2, Point point3) {
			p1 = (Point) point1.clone();
			p2 = (Point) point2.clone();
			p3 = (Point) point3.clone();
			a = p1.distance(p2);// Math.sqrt(Math.pow(p1.x-p2.x, 2) +
			// Math.pow(p1.y-p2.y, 2));
			b = p2.distance(p3);// Math.sqrt(Math.pow(p2.x-p3.x, 2) +
			// Math.pow(p2.y-p3.y, 2));
			c = p3.distance(p1);// Math.sqrt(Math.pow(p3.x-p1.x, 2) +
			// Math.pow(p3.y-p1.y, 2));
			A = angle_between(p1, p3, p2);
			B = angle_between(p3, p1, p2);
			C = angle_between(p1, p2, p3);
		}

		public boolean isValid() {
			if (p1 == p2 || p1 == p3 || p2 == p3)
				return false;
			else if (p1.x == p2.x && p2.x == p3.x)
				return false;
			else if (p1.y == p2.y && p2.y == p3.y)
				return false;
			else
			/*
			 * Point tp1 = p1.x<p2.x? p1 : p2; tp1 = tp1.x<p3.x ? tp1 : p3;
			 * Point tp2 = p1.x>p2.x? p1 : p2; tp2 = tp2.x>p3.x ? tp2 : p3;
			 */
			if ((p1.x * (p2.y - p3.y) + p2.x * (p3.y - p1.y) + p3.x
					* (p1.y - p2.y)) == 0)
				return false;
			else
				return true;
		}

		public boolean isRight() {
			if (A == 90.0 || B == 90.0 || C == 90.0)
				return true;

			/*
			 * if(Math.pow(a, 2)+Math.pow(b, 2)==Math.pow(c, 2) || Math.pow(a,
			 * 2)+Math.pow(c, 2)==Math.pow(b, 2) || Math.pow(c, 2)+Math.pow(b,
			 * 2)==Math.pow(a, 2)) return true;
			 */

			return false;
		}

		public boolean isObtuse() {
			// if (A > 90.0 || B > 90.0 || C > 90.0)
			// return true;
			if (!isRight() && !isAcute())
				return true;
			return false;
		}

		public boolean isAcute() {
			if(isRight())
				return false;
			if (Math.pow(a, 2) + Math.pow(b, 2) > Math.pow(c, 2)
					&& Math.pow(a, 2) + Math.pow(c, 2) > Math.pow(b, 2)
					&& Math.pow(c, 2) + Math.pow(b, 2) > Math.pow(a, 2))
				return true;
			return false;
		}

		public boolean isScalene() {
			if (a != b && a != c && b != c)
				return true;
			return false;
		}

		public boolean isEquilateral() {
			if (a == b && b == c)
				return true;
			return false;
		}

		public boolean isIsosceles() {
			if (!isScalene() && !isEquilateral())
				return true;
			return false;
		}

		public double side_a() {
			return a;
		}

		public double side_b() {
			return b;
		}

		public double side_c() {
			return c;
		}

		public double angle_A() {
			return A;
		}

		public double angle_B() {
			return B;
		}

		public double angle_C() {
			return C;
		}

		// code from http://www.allegro.cc/forums/thread/591460 is used in this
		// function
		public static double angle_between(Point point1, Point point2,
				Point point3) {
			Point p1, p2, p3;
			p1 = (Point) point1.clone();
			p2 = (Point) point2.clone();
			p3 = (Point) point3.clone();

			double result, theta1, theta2;
			p1.translate(-p2.x, -p2.y);
			p3.translate(-p2.x, -p2.y);
			theta1 = Math.toDegrees(Math.atan2(p1.y, p1.x));
			theta2 = Math.toDegrees(Math.atan2(p3.y, p3.x));
			if (theta1 < 0)
				theta1 += 360;
			if (theta2 < 0)
				theta2 += 360;

			result = Math.abs(theta1 - theta2);
			if (result > 180.0)
				result = 360 - result;
			return result;
		}

		public boolean testvalid() {
			double s = (a + b + c) / 2.0;
			return Math.sqrt((s * (s - a) * (s - b) * (s - c))) > 0;
		}

		private Point p1, p2, p3;
		private double a, b, c;
		private double A, B, C;
	}
}

class Time{
	public Time(String tim){
		String[] arr=tim.split(":");
		hr=Integer.parseInt(arr[0]);
		min=Integer.parseInt(arr[1]);
	}
	
	public Time(Time tm){
		hr=tm.getHr();
		min=tm.getMin();
	}
	public Time(int h, int m){
		hr=h;
		min=m;
	}
	
	public boolean before(Time tm){
		if(this.hr<tm.getHr())
			return true;
		else 
			if(this.hr==tm.getHr()&& this.min<tm.getMin())
				return true;
		return false;
	}
	
	public boolean after(Time tm){
		if(this.hr>tm.getHr())
			return true;
		else 
			if(this.hr==tm.getHr()&& this.min>tm.getMin())
				return true;
		return false;
	}
	
	public void addMins(int mins){
		int hrs=mins/60;
		mins=mins%60;
		this.hr+=hrs;
		this.min+=mins;
	}
	
	public String toString(){
		return ""+hr+":"+min;
	}
	
	public int getHr(){return hr;}
	public int getMin(){return min;}
	
	private int hr, min;
}