package A;

import java.io.File;
import java.io.PrintWriter;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

public class A {

    private class TestCase {

        final int destination;
        final List<Horse> horses;
        double speed;

        TestCase() {
            int[] params = nextIntLine();
            destination = params[0];
            int numHorses = params[1];
            horses = new ArrayList<>(numHorses);
            for (int i=0; i<numHorses; i++) {
                horses.add(new Horse(nextIntLine()));
            }
        }

        private void calc() {
            double maxTimeToDestination = horses.stream()
                    .mapToDouble(h -> (destination - h.initialPosition)/h.speed)
                    .max()
                    .orElse(Double.NaN);
            speed = destination / maxTimeToDestination;
        }

        String getResult() {
            return String.format("%.6f", speed);
        }
    }

    private static class Horse {
        final int initialPosition;
        final double speed;

        Horse(int[] params) {
            this.initialPosition = params[0];
            this.speed = params[1];
        }
    }

    public static void main(String[] args) throws Exception {
        new A().run();
    }

    private List<String> lines;

    private String[] nextLine() {
        return lines.remove(0).split(" ");
    }

    private int[] nextIntLine() {
        String[] line = nextLine();
        int[] result = new int[line.length];
        for (int i=0; i<line.length; i++) {
            result[i] = Integer.parseInt(line[i]);
        }
        return result;
    }

    private void run() throws Exception {
        Path inputFile = findInputFile();
        Path outputFile = Paths.get("src", this.getClass().getSimpleName(), inputFile.getFileName().toString().replace(".in", ".out"));
        lines = Files.readAllLines(inputFile);
        try (PrintWriter out = new PrintWriter(Files.newBufferedWriter(outputFile))) {
            int count = Integer.parseInt(lines.remove(0));
            for (int i = 1; i <= count; i++) {
                TestCase tc = new TestCase();
                tc.calc();
                printResults(out, i, tc);
            }
        }
    }

    private void printResults(PrintWriter out, int caseNum, TestCase tc) {
        String resultString = String.format("Case #%d: %s", caseNum, tc.getResult());
        System.out.println(resultString);
        out.println(resultString);
    }

    private Path findInputFile() {
        final String base = this.getClass().getSimpleName();
        try {
            List<File> files = Files.list(Paths.get("input"))
                    .filter(Files::isRegularFile)
                    .map(Path::toFile)
                    .filter(f -> f.getName().startsWith(base))
                    .filter(f -> f.getName().endsWith(".in"))
                    .collect(Collectors.toList());

            if (files.isEmpty()) {
                throw new RuntimeException("No input files found");
            }

            files.sort((f1, f2) -> (int)(f2.lastModified() - f1.lastModified()));

            return files.get(0).toPath();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}
