package round1a;

import java.io.PrintWriter;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.*;
import java.util.stream.Collectors;

public class Ratatouille {
    public static void main(String[] args) throws Exception {
        List<String> lines = Files.readAllLines(Paths.get("files/two/B-small-attempt0.in"));
        try (PrintWriter out = new PrintWriter(Files.newBufferedWriter(Paths.get("files/two/B-small-attempt0.out")))) {
            int count = Integer.parseInt(lines.remove(0));
            for (int i = 1; i <= count; i++) {
                Holder p = new Holder(lines);
                int numKits = calcResult(p);
                out.println(String.format("Case #%d: %d", i, numKits));
            }
        }
    }



    private static int calcResult(Holder h) {
        int kitSize = 1;
        int numKits = 0;
        while (true) {
            boolean nextKitSize = false;
            double min = 0.9*kitSize;
            double max = 1.1*kitSize;
            for (int i=0; i<h.numIngredients; i++) {
                List<Packet> packets = h.packets.get(i);
                while (!packets.isEmpty() && packets.get(0).recipePercentage < min) {
                    packets.remove(0);
                }
                if (packets.isEmpty()) {
                    return numKits;
                }
                if (packets.get(0).recipePercentage > max) {
                    nextKitSize = true;
                    break;
                }
            }
            if (nextKitSize) {
                kitSize++;
            } else {
                numKits++;
                h.packets.forEach(l -> l.remove(0));
            }
        }
    }

    private static class Holder {

        public final int[] recipe;
        public final int numIngredients;
        public final int numPackets;
        public final List<List<Packet>> packets;

        public Holder(List<String> lines) {
            String[] s = lines.remove(0).split(" ");
            numIngredients = Integer.parseInt(s[0]);
            numPackets = Integer.parseInt(s[1]);
            recipe = Arrays.stream(lines.remove(0).split(" "))
                    .mapToInt(Integer::parseInt)
                    .toArray();
            packets = new ArrayList<>(numIngredients);
            for (int i=0; i<numIngredients; i++) {
                int r = recipe[i];
                List<Packet> p = Arrays.stream(lines.remove(0).split(" "))
                        .mapToInt(Integer::parseInt)
                        .mapToObj(size -> new Packet(size, ((double) size) / r))
                        .collect(Collectors.toList());
                Collections.sort(p);
                packets.add(p);
            }
        }
    }

    private static class Packet implements Comparable<Packet> {
        public final int weight;
        public final double recipePercentage;

        public Packet(int weight, double recipePercentage) {
            this.weight = weight;
            this.recipePercentage = recipePercentage;
        }

        @Override
        public int compareTo(Packet o) {
            return weight - o.weight;
        }
    }
}
