package ap.playground.algo;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.StringTokenizer;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class C implements Runnable {

    static final String TASK_ID = "C";

    BufferedReader reader;
    StringTokenizer tokenizer = null;
    PrintWriter writer;

    class Solver implements Runnable {
        int testId;
        boolean noSolution = false;
        
        private int[] candies;
        private int sum;

        Solver(int testId) {
            this.testId = testId;
        }

        private void readInput() {
            Integer count = nextInt();
            candies = new int[count];
            for (int i = 0; i < count; i++) {
                candies[i] = nextInt();
            }
            Arrays.sort(candies);
        }

        public void run() {
            int xor = 0;
            sum = 0;
            for (Integer candy : candies) {
                xor ^= candy;
                sum += candy;
            }
            if (xor != 0) {
                noSolution = true;
            } else {
                sum -= candies[0];
            }
            
        }

        private void printOutput() {
            String r = String.format("Case #%d: ", testId + 1);
            if (noSolution) {
                r += "NO\n";
            } else {
                r += String.format("%d\n", sum);
            }
            writer.printf(r);
            System.out.print(r);
            
        }
    }

    private void solveSequential() {
        int numTests = nextInt();
        for (int testId = 0; testId < numTests; ++testId) {
            Solver solver = new Solver(testId);
            solver.readInput();
            solver.run();
            solver.printOutput();
        }
    }

    private void solveParallel() {
        int numTests = nextInt();
        ExecutorService executor = Executors.newFixedThreadPool(4);
        Solver[] solver = new Solver[numTests];
        for (int testId = 0; testId < numTests; ++testId) {
            solver[testId] = new Solver(testId);
            solver[testId].readInput();
        }
        @SuppressWarnings("rawtypes")
        Future[] res = new Future[numTests];
        for (int testId = 0; testId < numTests; ++testId) {
            res[testId] = executor.submit(new Thread(solver[testId]));
        }
        for (int testId = 0; testId < numTests; ++testId) {
            try {
                res[testId].get();
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            } catch (ExecutionException e) {
                throw new RuntimeException(e);
            }
        }
        for (int testId = 0; testId < numTests; ++testId) {
            solver[testId].printOutput();
        }
        executor.shutdown();
    }

    public static void main(String[] args) {
        new C().run();
    }

    public void run() {
        try {
            long now = System.nanoTime();
            reader = new BufferedReader(new FileReader(TASK_ID + ".in"));
            writer = new PrintWriter(TASK_ID + ".out");
            solveSequential();
            reader.close();
            writer.close();
            System.out.println((System.nanoTime() - now) / 1000 + " us");
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    int nextInt() {
        return Integer.parseInt(nextToken());
    }

    double nextDouble() {
        return Double.parseDouble(nextToken());
    }

    long nextLong() {
        return Long.parseLong(nextToken());
    }

    String nextToken() {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            try {
                tokenizer = new StringTokenizer(reader.readLine());
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        return tokenizer.nextToken();
    }
}