package ap.playground.algo;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class B implements Runnable {

    static final String TASK_ID = "B";

    BufferedReader reader;
    StringTokenizer tokenizer = null;
    PrintWriter writer;

    class Solver implements Runnable {
        int testId;
        private List<Character> elementsList = new ArrayList<Character>();
        private List<Set<Character>> oppositions = new ArrayList<Set<Character>>();
        private Map<Set<Character>, Character> combinations = new HashMap<Set<Character>, Character>();

        Solver(int testId) {
            this.testId = testId;
        }

        private void readInput() {
            Integer combine = nextInt();
            for (int i = 0; i < combine; i++) {
                String combination = nextToken();
                Set<Character> key = new HashSet<Character>();
                key.add(combination.charAt(0));
                key.add(combination.charAt(1));
                Character value = combination.charAt(2);
                combinations.put(key, value);
            }
            Integer opposite = nextInt();
            for (int i = 0; i < opposite; i++) {
                String opposition = nextToken();
                Set<Character> op = new HashSet<Character>();
                op.add(opposition.charAt(0));
                op.add(opposition.charAt(1));
                oppositions.add(op);
            }
            Integer elements = nextInt();
            char[] els = nextToken().toCharArray();
            for (int i = 0; i < els.length; i++) {
                elementsList.add(new Character(els[i]));
            }
        }

        public void run() {
            int index = 0;
            
            while (index < elementsList.size()) {
                Character element = elementsList.get(index);
                
                boolean changed = false;
                for (int i = index - 1; i >= 0; i--) {
                    Character prevoiusElement = elementsList.get(i);
                    Set<Character> els = new HashSet<Character>();
                    els.add(element);
                    els.add(prevoiusElement);
                    if (i + 1 == index) {
                        if (combinations.containsKey(els)) {
                            elementsList.set(i, combinations.get(els));
                            elementsList.remove(index);
                            index--;
                            changed = true;
                            break;
                        }
                    }
                    if (oppositions.contains(els)) {
                        for (int k = index; k >= 0; k--) {
                            elementsList.remove(k);
                            index--;
                        }
                        index++;
                        changed = true;
                        break;
                    }
                }
                if (!changed) {
                    index++;
                }
                
            }
            
            
        }

        private void printOutput() {            
            String r = String.format("Case #%d: ", testId + 1);
            r += elementsList + "\n";
            writer.printf(r);
            System.out.print(r);
        }
    }

    private void solveSequential() {
        int numTests = nextInt();
        for (int testId = 0; testId < numTests; ++testId) {
            Solver solver = new Solver(testId);
            solver.readInput();
            solver.run();
            solver.printOutput();
        }
    }

    private void solveParallel() {
        int numTests = nextInt();
        ExecutorService executor = Executors.newFixedThreadPool(4);
        Solver[] solver = new Solver[numTests];
        for (int testId = 0; testId < numTests; ++testId) {
            solver[testId] = new Solver(testId);
            solver[testId].readInput();
        }
        @SuppressWarnings("rawtypes")
        Future[] res = new Future[numTests];
        for (int testId = 0; testId < numTests; ++testId) {
            res[testId] = executor.submit(new Thread(solver[testId]));
        }
        for (int testId = 0; testId < numTests; ++testId) {
            try {
                res[testId].get();
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            } catch (ExecutionException e) {
                throw new RuntimeException(e);
            }
        }
        for (int testId = 0; testId < numTests; ++testId) {
            solver[testId].printOutput();
        }
        executor.shutdown();
    }

    public static void main(String[] args) {
        new B().run();
    }

    public void run() {
        try {
            long now = System.nanoTime();
            reader = new BufferedReader(new FileReader(TASK_ID + ".in"));
            writer = new PrintWriter(TASK_ID + ".out");
            solveSequential();
            reader.close();
            writer.close();
            System.out.println((System.nanoTime() - now) / 1000 + " us");
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    int nextInt() {
        return Integer.parseInt(nextToken());
    }

    double nextDouble() {
        return Double.parseDouble(nextToken());
    }

    long nextLong() {
        return Long.parseLong(nextToken());
    }

    String nextToken() {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            try {
                tokenizer = new StringTokenizer(reader.readLine());
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        return tokenizer.nextToken();
    }
}