package ap.playground.algo;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.StringTokenizer;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

import javax.management.RuntimeErrorException;

public class A implements Runnable {

    static final String TASK_ID = "A";

    BufferedReader reader;
    StringTokenizer tokenizer = null;
    PrintWriter writer;

    class Solver implements Runnable {
        int testId;
        private long turns = 0;

        private List<String> targets = new ArrayList<String>();
        private List<Integer> orange = new ArrayList<Integer>();
        private List<Integer> blue = new ArrayList<Integer>();

        Solver(int testId) {
            this.testId = testId;
        }

        private void readInput() {
            int buttons = nextInt();

            for (int i = 0; i < buttons; i++) {
                String robot = nextToken();
                int number = nextInt();
                if (robot.equals("O")) {
                    orange.add(number);
                } else if (robot.equals("B")) {
                    blue.add(number);
                } else {
                    throw new RuntimeException("Wrong data");
                }
                targets.add(robot);
            }
        }

        public void run() {
            int pOrange = 1;
            int pBlue = 1;

            while (!targets.isEmpty()) {
                String tgtRobot = targets.get(0);
                if (!orange.isEmpty()) {
                    Integer targetField = orange.get(0);
                    if (pOrange == targetField) {
                        if (tgtRobot.equals("O")) {
                            orange.remove(0);
                            targets.remove(0);
                        } else {
                            // wait for blue
                        }
                    } else if (pOrange < targetField) {
                        pOrange++;
                    } else {
                        pOrange--;
                    }
                }
                if (!blue.isEmpty()) {
                    Integer targetField = blue.get(0);
                    if (pBlue == targetField) {
                        if (tgtRobot.equals("B")) {
                            blue.remove(0);
                            targets.remove(0);
                        } else {
                            // wait for orange
                        }
                    } else if (pBlue < targetField) {
                        pBlue++;
                    } else {
                        pBlue--;
                    }
                }
                turns++;

            }

        }

        private void printOutput() {
            String r = String.format("Case #%d: %d\n", testId + 1, turns);
            writer.printf(r);
            System.out.print(r);
        }
    }

    private void solveSequential() {
        int numTests = nextInt();
        for (int testId = 0; testId < numTests; ++testId) {
            Solver solver = new Solver(testId);
            solver.readInput();
            solver.run();
            solver.printOutput();
        }
    }

    private void solveParallel() {
        int numTests = nextInt();
        ExecutorService executor = Executors.newFixedThreadPool(4);
        Solver[] solver = new Solver[numTests];
        for (int testId = 0; testId < numTests; ++testId) {
            solver[testId] = new Solver(testId);
            solver[testId].readInput();
        }
        @SuppressWarnings("rawtypes")
        Future[] res = new Future[numTests];
        for (int testId = 0; testId < numTests; ++testId) {
            res[testId] = executor.submit(new Thread(solver[testId]));
        }
        for (int testId = 0; testId < numTests; ++testId) {
            try {
                res[testId].get();
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            } catch (ExecutionException e) {
                throw new RuntimeException(e);
            }
        }
        for (int testId = 0; testId < numTests; ++testId) {
            solver[testId].printOutput();
        }
        executor.shutdown();
    }

    public static void main(String[] args) {
        new A().run();
    }

    public void run() {
        try {
            long now = System.nanoTime();
            reader = new BufferedReader(new FileReader(TASK_ID + ".in"));
            writer = new PrintWriter(TASK_ID + ".out");
            solveSequential();
            reader.close();
            writer.close();
            System.out.println((System.nanoTime() - now) / 1000 + " us");
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    int nextInt() {
        return Integer.parseInt(nextToken());
    }

    double nextDouble() {
        return Double.parseDouble(nextToken());
    }

    long nextLong() {
        return Long.parseLong(nextToken());
    }

    String nextToken() {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            try {
                tokenizer = new StringTokenizer(reader.readLine());
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        return tokenizer.nextToken();
    }
}