package ap.playground.algo;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Locale;
import java.util.StringTokenizer;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class D implements Runnable {

    static final String TASK_ID = "D";

    BufferedReader reader;
    StringTokenizer tokenizer = null;
    PrintWriter writer;

    class Solver implements Runnable {
        int testId;
        
        int[] numbers;
        
        int steps = 0;
        int steps2 = 0;

        Solver(int testId) {
            this.testId = testId;
        }

        private void readInput() {
            Integer n = nextInt();
            numbers = new int[n];
            for (int i = 0; i < n; i++) {
                numbers[i] = nextInt();
            }
        }

        public void run() {
            System.out.println(Arrays.toString(numbers));
            int[] n2 = Arrays.copyOf(numbers, numbers.length);
            for (int i = 0; i < numbers.length - 1; i++) {
                if (i == numbers[i]) {
                    continue;
                }
                for (int j = i + 1; j < numbers.length; j++) {
                    if (i + 1 == numbers[j]) {
                        int temp = numbers[i];
                        numbers[i] = numbers[j];
                        numbers[j] = temp;
                        steps+=2;
                    }
                }
            }
            
            for (int i = 0; i < n2.length; i++) {
                if (n2[i] != 0) {
                    steps2 += go(n2, i);
                }
            }
            
            System.out.println(Arrays.toString(numbers));
        }

        private int go(int[] n2, int i) {
            int ret = 0;
            if (n2[i] == 0 || n2[i] == i + 1) {
                n2[i] = 0;
                return 0;
            } else {
                n2[i] = 0;
                ret++;
                ret += go(n2, n2[i]);
            }
            return ret;
        }

        private void printOutput() {
            Locale.setDefault(new Locale("en"));
            String r = String.format("Case #%d: %f\n", testId + 1, (float) steps2);
            writer.printf(r);
            System.out.print(r);
        }
    }

    private void solveSequential() {
        int numTests = nextInt();
        for (int testId = 0; testId < numTests; ++testId) {
            Solver solver = new Solver(testId);
            solver.readInput();
            solver.run();
            solver.printOutput();
        }
    }

    private void solveParallel() {
        int numTests = nextInt();
        ExecutorService executor = Executors.newFixedThreadPool(4);
        Solver[] solver = new Solver[numTests];
        for (int testId = 0; testId < numTests; ++testId) {
            solver[testId] = new Solver(testId);
            solver[testId].readInput();
        }
        @SuppressWarnings("rawtypes")
        Future[] res = new Future[numTests];
        for (int testId = 0; testId < numTests; ++testId) {
            res[testId] = executor.submit(new Thread(solver[testId]));
        }
        for (int testId = 0; testId < numTests; ++testId) {
            try {
                res[testId].get();
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            } catch (ExecutionException e) {
                throw new RuntimeException(e);
            }
        }
        for (int testId = 0; testId < numTests; ++testId) {
            solver[testId].printOutput();
        }
        executor.shutdown();
    }

    public static void main(String[] args) {
        new D().run();
    }

    public void run() {
        try {
            long now = System.nanoTime();
            reader = new BufferedReader(new FileReader(TASK_ID + ".in"));
            writer = new PrintWriter(TASK_ID + ".out");
            solveSequential();
            reader.close();
            writer.close();
            System.out.println((System.nanoTime() - now) / 1000 + " us");
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    int nextInt() {
        return Integer.parseInt(nextToken());
    }

    double nextDouble() {
        return Double.parseDouble(nextToken());
    }

    long nextLong() {
        return Long.parseLong(nextToken());
    }

    String nextToken() {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            try {
                tokenizer = new StringTokenizer(reader.readLine());
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        return tokenizer.nextToken();
    }
}