package codejam2013.round1C.C;

import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.PriorityQueue;

import com.google.common.io.Files;

public class ProblemC {

	private final static String prefix = "src/codejam2013/round1C/C/";
	private final static String problem = "C";
	private final static String dataset = "small-attempt3";

	private static class Tribe {

		int d;
		int n;
		int w;
		int e;
		int s;
		int delta_d;
		int delta_p;
		int delta_s;

		public Tribe(String st) {
			String[] comps = st.split(" ");
			d = Integer.parseInt(comps[0]);
			n = Integer.parseInt(comps[1]);
			w = Integer.parseInt(comps[2]);
			e = Integer.parseInt(comps[3]);
			s = Integer.parseInt(comps[4]);
			delta_d = Integer.parseInt(comps[5]);
			delta_p = Integer.parseInt(comps[6]);
			delta_s = Integer.parseInt(comps[7]);
		}

		public List<TribeAttack> generateAttacks() {
			List<TribeAttack> result = new ArrayList<ProblemC.TribeAttack>(n);
			for (int i = 0; i < n; i++) {
				result.add(new TribeAttack(d + i * delta_d, s + i * delta_s, w + i * delta_p, e + i * delta_p));
			}
			return result;
		}
	}

	private static class TribeAttack implements Comparable<TribeAttack> {

		int d;
		int s;
		int w;
		int e;

		public TribeAttack(int d, int s, int w, int e) {
			super();
			this.d = d;
			this.s = s;
			this.w = w;
			this.e = e;
		}

		@Override
		public int compareTo(TribeAttack o) {
			return ((Integer)d).compareTo(o.d);
		}

		@Override
		public String toString() {
			return "[d=" + d + ", s=" + s + ", p=[" + w + ", " + e + "]]";
		}
	}

	private static void setWall(int[] wall, int i, int w_min, int v) {
		wall[i - w_min] = v;
	}

	private static int getWall(int[] wall, int i, int w_min) {
		return wall[i - w_min];
	}

	private static int attackWall(int[] wall, TribeAttack a, int w_min) {
		for (int i = a.w; i < a.e; i++) {
			if (getWall(wall, i, w_min) < a.s) {
				System.out.println("Success : " + a + " vs " + Arrays.toString(Arrays.copyOfRange(wall, a.w - w_min, a.e - w_min)));
				return 1;
			}
		}
		System.out.println("Failure : " + a + " vs " + Arrays.toString(Arrays.copyOfRange(wall, a.w - w_min, a.e - w_min)));
		return 0;
	}

	private static void resolveWall(int[] wall, TribeAttack a, int w_min) {
		for (int i = a.w; i < a.e; i++) {
			setWall(wall, i, w_min, Math.max(getWall(wall, i, w_min), a.s));
		}
	}

	private static int result(List<Tribe> tribes, int w_min, int e_max) {
		int result = 0;

		int[] wall = new int[e_max - w_min + 1];
		PriorityQueue<TribeAttack> attacks = new PriorityQueue<>();
		for (Tribe t : tribes) {
			attacks.addAll(t.generateAttacks());
		}
		int d = 0;
		List<TribeAttack> pendingAttacks = new LinkedList<>();
		while(attacks.size() > 0) {
			TribeAttack attack = attacks.poll();
			int success = attackWall(wall, attack, w_min);
			result += success;
			if (attack.d > d) {
				for (TribeAttack tribeAttack : pendingAttacks) {
					resolveWall(wall, tribeAttack, w_min);
				}
				pendingAttacks.clear();
				d = attack.d;
			}
			if (success == 1) {				
				pendingAttacks.add(attack);
			}
		}

		return result;
	}

	public static void main(String[] args) throws IOException {
		List<String> lines = Files.readLines(new File(prefix + problem + "-" + dataset + ".in"), Charset.defaultCharset());
		Iterator<String> linesIterator = lines.iterator();
		int T = Integer.valueOf(linesIterator.next());
		File out = new File(prefix + problem + "-" + dataset + ".out");
		Files.write("", out, Charset.defaultCharset());

		for (int i = 1; i <= T; i++) {
			int N = Integer.parseInt(linesIterator.next());

			List<Tribe> tribes = new ArrayList<>(N);
			int w_min = Integer.MAX_VALUE;
			int e_max = Integer.MIN_VALUE;
			for (int j = 0; j < N; j++) {
				Tribe t = new Tribe(linesIterator.next());
				tribes.add(t);
				w_min = Math.min(w_min, t.w + (t.delta_p < 0 ? (t.n - 1) * t.delta_p : 0));
				e_max = Math.max(e_max, t.e + (t.delta_p > 0 ? (t.n - 1) * t.delta_p : 0));
			}
			System.out.println();
			Files.append("Case #" + i + ": " + result(tribes, w_min, e_max) + System.getProperty("line.separator"), out, Charset.defaultCharset());
		}
	}
}
