package codejam2016.round1C.C;

import com.google.common.io.Files;

import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class ProblemC {
    private final static String prefix  = "src/main/java/codejam2016/round1C/C/";
    private final static String problem = "C";
    private final static String dataset = "small-attempt2";

    public static void main(String[] args) throws IOException {
        List<String> lines = Files.readLines(new File(prefix + problem + "-" + dataset + ".in"), Charset.defaultCharset());
        Iterator<String> linesIterator = lines.iterator();
        int T = Integer.valueOf(linesIterator.next());
        File out = new File(prefix + problem + "-" + dataset + ".out");
        Files.write("", out, Charset.defaultCharset());
        for (int i = 1; i <= T; i++) {
            String line = linesIterator.next();

            String[] comps = line.split(" ");
            int J = Integer.valueOf(comps[0]);
            int P = Integer.valueOf(comps[1]);
            int S = Integer.valueOf(comps[2]);
            int K = Integer.valueOf(comps[3]);
            String result = solve(J, P, S, K);

            System.out.println(result);
            Files.append("Case #" + i + ": " + result + System.getProperty("line.separator"), out, Charset.defaultCharset());
        }
    }

    private static String solve(int j, int p, int s, int k) {

        List<Combination> list = new ArrayList<>();
        int[][] jp = new int[j][p], js = new int[j][s], ps = new int[p][s];

        for (int ij = 0; ij < j; ij++) {
            for (int ip = 0; ip < p; ip++) {
                for (int is = 0; is < s; is++) {
                    list.add(new Combination(ij, ip, is));
                    jp[ij][ip]++;
                    js[ij][is]++;
                    ps[ip][is]++;
                }
            }
        }

        if (isValid(list, k)) {
            return buildAnswer(list);
        }

        while (max(jp) > k || max(js) > k || max(ps) > k) {
            removeWorst(list, jp, js, ps, k);
        }

        return buildAnswer(list);
    }

    private static void removeWorst(List<Combination> list, int[][] jp, int[][] js, int[][] ps, int k) {
        List<Combination> toRemove = new ArrayList<>();
        for (Combination c : list) {
            if (jp[c.j][c.p] > k && js[c.j][c.s] > k && ps[c.p][c.s] > k) {
                toRemove.add(c);
                jp[c.j][c.p]--;
                js[c.j][c.s]--;
                ps[c.p][c.s]--;
            }
        }
        if (toRemove.size() > 0) {
            list.removeAll(toRemove);
            return;
        }

        for (Combination c : list) {
            boolean failjp = jp[c.j][c.p] > k;
            boolean failjs = js[c.j][c.s] > k;
            boolean failps = ps[c.p][c.s] > k;
            if (failjp && failjs || failjs && failps || failps && failjp) {
                toRemove.add(c);
                jp[c.j][c.p]--;
                js[c.j][c.s]--;
                ps[c.p][c.s]--;
            }
        }
        if (toRemove.size() > 0) {
            list.removeAll(toRemove);
            return;
        }

        for (Combination c : list) {
            boolean failjp = jp[c.j][c.p] > k;
            boolean failjs = js[c.j][c.s] > k;
            boolean failps = ps[c.p][c.s] > k;
            if (failjp || failjs || failps) {
                toRemove.add(c);
                jp[c.j][c.p]--;
                js[c.j][c.s]--;
                ps[c.p][c.s]--;
            }
        }
        list.removeAll(toRemove);
    }

    private static int max(int[][] tab) {
        int max = Integer.MIN_VALUE;
        for (int[] row : tab) {
            for (int cell : row) {
                max = Math.max(cell, max);
            }
        }
        return max;
    }

    private static String buildAnswer(List<Combination> bestSample) {
        StringBuilder sb = new StringBuilder();
        sb.append(bestSample.size());
        for (Combination c : bestSample) {
            sb.append("\n").append(c);
        }
        return sb.toString();
    }

    private static boolean isValid(List<Combination> sample, int k) {
        Map<String, Integer> jp = new HashMap<>(), js = new HashMap<>(), ps = new HashMap<>();
        for (Combination c : sample) {
            increment(jp, c.j, c.p);
            increment(js, c.j, c.s);
            increment(ps, c.p, c.s);
        }
        int maxjp = max(jp);
        int maxjs = max(js);
        int maxps = max(ps);
        return maxjp <= k && maxjs <= k && maxps <= k;
    }

    private static int max(Map<String, Integer> map) {
        int max = Integer.MIN_VALUE;
        for (Integer i : map.values()) {
            max = Math.max(i, max);
        }
        return max;
    }

    private static void increment(Map<String, Integer> map, int a, int b) {
        String key = a + "," + b;
        if (map.get(key) == null) {
            map.put(key, 0);
        }
        map.put(key, map.get(key) + 1);
    }

    private static class Combination {
        int j, p, s;

        public Combination(int j, int p, int s) {
            this.j = j;
            this.p = p;
            this.s = s;
        }

        public String toString() {
            return (j+1) + " " + (p+1) + " " + (s+1);
        }
    }
}
