package codejam2015.qualif.C;

import com.google.common.io.Files;

import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class ProblemC {
    private final static String prefix = "src/main/java/codejam2015/qualif/C/";
    private final static String problem = "C";
    private final static String dataset = "small-attempt3";

    private static enum QuaternionValue {
        ONE, I, J, K;

        public static Quaternion product(QuaternionValue qv1, QuaternionValue qv2) {
            if (qv1 == ONE) {
                switch (qv2) {
                    case ONE:
                        return Quaternion.ONE;
                    case I:
                        return Quaternion.I;
                    case J:
                        return Quaternion.J;
                    case K:
                        return Quaternion.K;
                }
            }
            if (qv2 == ONE) {
                switch (qv1) {
                    case I:
                        return Quaternion.I;
                    case J:
                        return Quaternion.J;
                    case K:
                        return Quaternion.K;
                }
            }
            if (qv1 == I) {
                switch (qv2) {
                    case I:
                        return Quaternion.MINUS_ONE;
                    case J:
                        return Quaternion.K;
                    case K:
                        return Quaternion.MINUS_J;
                }
            } else if (qv1 == J) {
                switch (qv2) {
                    case I:
                        return Quaternion.MINUS_K;
                    case J:
                        return Quaternion.MINUS_ONE;
                    case K:
                        return Quaternion.I;
                }
            } else {
                switch (qv2) {
                    case I:
                        return Quaternion.J;
                    case J:
                        return Quaternion.MINUS_I;
                    case K:
                        return Quaternion.MINUS_ONE;
                }
            }
            throw new RuntimeException("Invalid combination: " + qv1 + " " + qv2);
        }
    }

    private static class Quaternion {

        public static Quaternion ONE = new Quaternion(true, QuaternionValue.ONE);
        public static Quaternion MINUS_ONE = new Quaternion(false, QuaternionValue.ONE);
        public static Quaternion I = new Quaternion(true, QuaternionValue.I);
        public static Quaternion MINUS_I = new Quaternion(false, QuaternionValue.I);
        public static Quaternion J = new Quaternion(true, QuaternionValue.J);
        public static Quaternion MINUS_J = new Quaternion(false, QuaternionValue.J);
        public static Quaternion K = new Quaternion(true, QuaternionValue.K);
        public static Quaternion MINUS_K = new Quaternion(false, QuaternionValue.K);

        boolean positive;
        QuaternionValue value;

        public Quaternion(boolean positive, QuaternionValue value) {
            this.positive = positive;
            this.value = value;
        }

        public static Quaternion product(Quaternion q1, Quaternion q2) {
            Quaternion v = QuaternionValue.product(q1.value, q2.value);
            if (q1.positive == q2.positive) {
                return v;
            } else {
                return v.opposite();
            }
        }

        private Quaternion opposite() {
            switch (value) {
                case ONE:
                    return positive ? MINUS_ONE : ONE;
                case I:
                    return positive ? MINUS_I : I;
                case J:
                    return positive ? MINUS_J : J;
                case K:
                    return positive ? MINUS_K : K;
            }
            throw new RuntimeException("Invalid value: " + this);
        }

        public static Quaternion valueOf(char c) {
            switch (c) {
                case 'i':
                    return I;
                case 'j':
                    return J;
                case 'k':
                    return K;
            }
            throw new RuntimeException("Invalid char: " + c);
        }

        public String toString() {
            if (!positive) {
                return "-" + opposite().toString();
            }
            switch (value) {
                case ONE:
                    return "1";
                case I:
                    return "i";
                case J:
                    return "j";
                case K:
                    return "k";
            }
            throw new RuntimeException("Impossible: " + this);
        }

    }

    private static String result(String text, int X) {
        Quaternion[] quaternions = new Quaternion[text.length() * X];
        for (int i = 0; i < text.length(); i++) {
            Quaternion q = Quaternion.valueOf(text.charAt(i));
            for (int j = 0; j < X; j++) {
                quaternions[i + j * text.length()] = q;
            }
        }

        Quaternion first = Quaternion.ONE;
        for (int i = 0; i < quaternions.length - 1; i++) {
            first = Quaternion.product(first, quaternions[i]);
            if (first == Quaternion.I) {
                Quaternion last = Quaternion.ONE;
                for (int j = quaternions.length - 1; j > i; j--) {
                    last = Quaternion.product(quaternions[j], last);
                    if (last == Quaternion.K) {
                        Quaternion mid = quaternions[i + 1];
                        for (int k = i + 2; k < j; k++) {
                            mid = Quaternion.product(mid, quaternions[k]);
                        }
                        if (mid == Quaternion.J) {
                            return "YES";
                        }
                    }
                }
            }
        }

        return "NO";
    }

    static final Map<Integer, String> results = new HashMap<>();

    public static void main(String[] args) throws IOException {
        List<String> lines = Files.readLines(new File(prefix + problem + "-" + dataset + ".in"), Charset.defaultCharset());
        Iterator<String> linesIterator = lines.iterator();
        int T = Integer.valueOf(linesIterator.next());
        File out = new File(prefix + problem + "-" + dataset + ".out");
        Files.write("", out, Charset.defaultCharset());

        ExecutorService executor = Executors.newFixedThreadPool(4);

        for (int i = 1; i <= T; i++) {
            String[] comps = linesIterator.next().split(" ");
            int L = Integer.valueOf(comps[0]);
            final int X = Integer.valueOf(comps[1]);

            final String text = linesIterator.next();


            System.out.println(text + " * " + X);

            final int finalI = i;
            executor.execute(new Runnable() {
                @Override
                public void run() {
                    String result = result(text, X);
                    synchronized (results) {
                        results.put(finalI, result);
                    }
                }
            });
        }
        executor.shutdown();
        while (!executor.isTerminated()) {
            System.out.println("size: " + results.size());
            try {
                Thread.sleep(2000L);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }

        for (int i = 1; i <= T; i++) {
            String result = results.get(i);
            System.out.println("Case #" + i + ": " + result);
            Files.append("Case #" + i + ": " + result + System.getProperty("line.separator"), out, Charset.defaultCharset());
        }
    }

}