import java.io.PrintWriter;
import java.util.Arrays;
import java.util.PriorityQueue;
import java.util.Scanner;

public class MineSweeper {

	static class Board implements Comparable<Board> {

		private int[][] data;

		private int mineCount;

		private int score;

		private int nonMineCount;

		private int zeroI;

		private int zeroJ;

		Board(int i, int j) {
			this.data = new int[i][j];
			zeroI = i - 1;
			zeroJ = j - 1;
		}

		Board(Board b, int i, int j) {
			this.data = new int[b.data.length][];
			this.zeroI = b.zeroI;
			this.zeroJ = b.zeroJ;
			for (int j2 = 0; j2 < data.length; j2++) {
				this.data[j2] = Arrays.copyOf(b.data[j2], b.data[j2].length);
			}
			this.data[i][j] = Integer.MIN_VALUE;
			increment(i - 1, j);
			increment(i - 1, j + 1);
			increment(i - 1, j - 1);
			increment(i + 1, j + 1);
			increment(i + 1, j);
			increment(i + 1, j - 1);
			increment(i, j - 1);
			increment(i, j + 1);
			this.mineCount = b.mineCount + 1;
			int rc = data.length * data[0].length;
			boolean[][] seen = new boolean[data.length][data[0].length];
			if (hasZeroNeighbor(zeroI, zeroJ)) {
				dfs(seen, seen.length - 1, seen[0].length - 1);
			}
			if (mineCount == M && nonMineCount == rc - M) {
				score = Integer.MIN_VALUE;
			} else if (nonMineCount < rc - M) {
				score = Integer.MAX_VALUE;
			} else{
				score += rc - nonMineCount;
			}
		}

		private void dfs(boolean[][] seen, int i, int j) {
			if (i > -1 && j > -1 && i < data.length && j < data[0].length) {
				if (!seen[i][j]) {
					if (data[i][j] != Integer.MIN_VALUE) {
						seen[i][j] = true;
						if (hasZeroNeighbor(i, j))
							nonMineCount++;
						dfs(seen, i - 1, j);
						dfs(seen, i - 1, j + 1);
						dfs(seen, i - 1, j - 1);
						dfs(seen, i + 1, j + 1);
						dfs(seen, i + 1, j);
						dfs(seen, i + 1, j - 1);
						dfs(seen, i, j - 1);
						dfs(seen, i, j + 1);
					}
				}
			}
		}

		private boolean hasZeroNeighbor(int i, int j) {
			return zeroNeighbour(i - 1, j) ||
				zeroNeighbour(i - 1, j + 1) ||
				zeroNeighbour(i - 1, j - 1) ||
				zeroNeighbour(i + 1, j) ||
				zeroNeighbour(i + 1, j + 1) ||
				zeroNeighbour(i + 1, j - 1) ||
				zeroNeighbour(i, j + 1) ||
				zeroNeighbour(i, j - 1)||
				zeroNeighbour(i, j);
		}

		private boolean zeroNeighbour(int i, int j) {
			if (i > -1 && j > -1 && i < data.length && j < data[0].length) {
				return data[i][j] == 0;
			}
			return false;
		}

		private void increment(int i, int j) {
			if (i > -1 && j > -1 && i < data.length && j < data[0].length) {
				if (data[i][j] != Integer.MIN_VALUE) {
					data[i][j] = data[i][j] + 1;
				}
			}
		}

		@Override
		public int compareTo(Board o) {
			int compareTo = Integer.valueOf(score).compareTo(o.score);
			if (compareTo == 0) {
				compareTo = -Integer.valueOf(mineCount).compareTo(o.mineCount);
			}
			return compareTo;
		}

		@Override
		public String toString() {
			StringBuilder sb = new StringBuilder();
//			sb.append(score).append("\n");
			for (int i = 0; i < data.length; i++) {
				for (int j = 0; j < data[0].length; j++) {
					if (data[i][j] == Integer.MIN_VALUE) {
						sb.append('*');
					} else if (i == zeroI && j == zeroJ) {
						sb.append('c');
					} else {
						sb.append('.');
					}
				}
				sb.append('\n');
			}
			sb.delete(sb.length() -1, sb.length());
			return sb.toString();
		}

	}

	private static int M;

	public static void main(String[] args) {
		try (PrintWriter pw = new PrintWriter(System.out)) {
			Scanner s = new Scanner(System.in);
			int t = s.nextInt();
			for (int i = 0; i < t; i++) {
				solve(i + 1, s, pw);
			}
		}
	}

	private static void solve(int caseNumber, Scanner s, PrintWriter pw) {
		pw.flush();
		pw.println("Case #" + caseNumber + ": ");
		int R = s.nextInt();
		int C = s.nextInt();
		M = s.nextInt();
		Board initial = new Board(R, C);
		if (M == 0) {
			pw.println(initial);
			return;
		}
		if (R*C - M == 1) {
			for (int i = 0; i < R; i++) {
				for (int j = 0; j < C; j++) {
					if (!(i == initial.zeroI && j == initial.zeroJ)) {
						initial.data[i][j] = Integer.MIN_VALUE;
					}
				}
			}
			pw.println(initial);
			return;
		}
		PriorityQueue<Board> pq = new PriorityQueue<>();
		pq.add(new Board(initial, 0, 0));
		while (!pq.isEmpty()) {
			Board b = pq.poll();
//			System.out.println(b);
			if (b.mineCount > M) {
				pw.println("Impossible");
				return;
			} else {
				if (b.mineCount == M) {
					if (b.score == Integer.MAX_VALUE) {
						pw.println("Impossible");
						return;
					}
					if (b.score == Integer.MIN_VALUE) {
						pw.println(b);
						return;
					}
				} else {
					PriorityQueue<Board> inner = new PriorityQueue<>();
					for (int i = 0; i < b.data.length; i++) {
						for (int j = 0;  j <  b.data[0].length; j++) {
							if (b.data[i][j] != Integer.MIN_VALUE) {
								inner.add(new Board(b, i, j));
								break;
							}
						}
					}
					
					Board max = inner.poll();
					Board prevMax = null;
					while (!inner.isEmpty()) {
						prevMax = max;
						pq.add(max);
						max = inner.poll();
						if (max.compareTo(prevMax) != 0) {
							break;
						}
					}
//					boolean failure = true;
//					for (Board board : pqInner) {
//						if (board.score != Integer.MAX_VALUE) {
//							failure = false;
//							break;
//						}
//					}
//					if (failure) {
//						pw.println("Impossible");
//						return;
//					}
					
				}
			}
		}
	}
}
