import java.io.FileNotFoundException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

public class BSolution {
	public static enum Status {
		WAITING, EATING
	}

	public static class Diner implements Comparable<Diner> {
		private Status status = Status.WAITING;
		private int pancakes;
		public Diner(int pancakes) { this.pancakes = pancakes; }
		public void eat() { status = Status.EATING; }
		public void chomp() { status = Status.WAITING; pancakes--; }
		public boolean isNotEating() { return !status.equals(Status.EATING); }
		public boolean isEating() { return status.equals(Status.EATING); }
		public boolean hasPancakes() { return pancakes > 0; }
		public int half() { return pancakes / 2; }
		public Diner movePancakesToHelper() {
			if (pancakes % 2 != 0) return null;
			
			int half = half();
			
			if (half > 0) {
				Diner helper = new Diner(half);
				pancakes -= half;
				return helper;
			}
			
			return null;
		}
		@Override
		public int compareTo(Diner o) {
			return o.pancakes - pancakes;
		}
	}
	
	public boolean hasFullPlate(List<Diner> diners) {
		for (Diner diner : diners) {
			if (diner.hasPancakes()) {
				return true;
			}
		}
		return false;
	}
	
	public int fs (List<Diner> diners, int minutes) {
		int tmp = 0;
		
		while (hasFullPlate(diners)) {
			Diner greedy = Collections.max(diners);
			Diner helper = greedy.movePancakesToHelper();
			if (helper != null) {
				// special minute
				diners.add(helper);
				tmp += fs(diners, minutes);
			} else {
				// everybody needs to eat
				for (int i = 0; i < diners.size(); i++) {
					Diner diner = diners.get(i);
					diner.chomp();
				}

				tmp ++;
			}
		}
		
		return tmp;
	}
	
	public static void main(String[] args) throws FileNotFoundException {
		StdIO out = new StdIO();
		BSolution bsol = new BSolution();
		
		Scanner sc;
		String in = System.getProperty("in");
		
		if (in != null && in.length() > 0) {
			InputStream is = BSolution.class.getResourceAsStream(in);
			sc = new Scanner(is);
		} else {
			sc = new Scanner(System.in);
		}
		sc.useDelimiter("\n");
		int T = sc.nextInt();
		
		for (int x = 1; x <= T; x++) {
			// prepares datastructure
			List<Diner> diners = new ArrayList<>(sc.nextInt());
			String str = sc.next();
			Scanner pancakes = new Scanner(str);
			pancakes.useDelimiter("\\s");
			while (pancakes.hasNext()) {
				diners.add(new Diner(pancakes.nextInt()));
			}
			pancakes.close();
			
			// start execution
			int y = bsol.fs(diners, 0);
			
			// response
			out.print("Case #%d: %d\n", x, y);
		}
		
		out.close();
		sc.close();
		
	}
	
	public static class StdIO {
		PrintWriter pw;
		
		public StdIO() throws FileNotFoundException {
			String output = System.getProperty("out");
			if (output != null && output.length() > 0) {
				pw = new PrintWriter(output);
			} else {
				pw = new PrintWriter(System.out);
			}
		}
		
		public void print(String content, Object ...args) {
			pw.print(String.format(content, args));
		}
		
		public void close() {
			pw.close();
		}

	}

}
