import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

/**
 * @author aeon
 */
public class Watersheds {

	public static void main(String[] args) throws Exception {
		final int T;
		final Scanner scanner;

		if (args.length > 0) {
			scanner = new Scanner(new File(args[0]));
		} else {
			scanner = new Scanner(new File("input.txt"));
		}

		T = scanner.nextInt();
		scanner.nextLine();

		for (int t = 1; t <= T; t++) {
			final int[] altitudes;
			final Node[] nodes;
			final int H, W;
			final int cellCount;

			H = scanner.nextInt();
			W = scanner.nextInt();
			cellCount = H * W;
			altitudes = new int[cellCount];
			nodes = new Node[cellCount];

			for (int i = 0; i < cellCount; i++) {
				altitudes[i] = scanner.nextInt();
				nodes[i] = new Node();
			}

			for (int i = 0; i < cellCount; i++) {
				int idx = i;
				int lowest = altitudes[i];

				// north
				if (i - W >= 0) {
					if (altitudes[i - W] < lowest) {
						idx = i - W;
						lowest = altitudes[idx];
					}
				}

				// west
				if (i % W != 0) {
					if (altitudes[i - 1] < lowest) {
						idx = i - 1;
						lowest = altitudes[idx];
					}
				}

				// east
				if ((i + 1) % W != 0) {
					if (altitudes[i + 1] < lowest) {
						idx = i + 1;
						lowest = altitudes[idx];
					}
				}

				// south
				if (i + W < cellCount) {
					if (altitudes[i + W] < lowest) {
						idx = i + W;
						lowest = altitudes[idx];
					}
				}

				// connect graph
				if (idx != i) {
					nodes[i].mNext = nodes[idx];
					nodes[idx].mIncoming.add(nodes[i]);
				}
			}

			System.out.println(String.format("Case #%1$d:", t));
			char currentLabel = 'a';
			for (int i = 0; i < cellCount; i++) {
				if (nodes[i].mLabel == 0) {
					nodes[i].putLabel(currentLabel++);
				}
				
				if ((i + 1) % W != 0) {
					System.out.print(nodes[i].mLabel + " ");
				} else {
					System.out.println(nodes[i].mLabel);
				}
			}
		}
	}

	private static class Node {
		public List<Node> mIncoming = new ArrayList<Node>();
		public Node mNext;
		public char mLabel;

		public void putLabel(char lbl) {
			if (mNext != null) {
				mNext.putLabel(lbl);
			} else {
				putLabelUp(lbl);
			}
		}

		public void putLabelUp(char lbl) {
			mLabel = lbl;
			for (Node u : mIncoming) {
				u.putLabelUp(lbl);
			}
		}
	}

}
