/**
 * The source code in this file is compilable and runnable with the Java SE
 * JDK 1.6.0_07 downloadable from http://java.sun.com/javase/downloads/index.jsp
 */
package gcj.lorenzfischer;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Solution to the "Saving the Universe" puzzle for Google Codjam 2008.
 */
public class SavingTheUniverse {

	public static int calculateSwitches(Set<String> searchEngines, List<String> queries) {
		int switchCounter = 0;
		Set<String> availableSearchEngines = copySearchEngines(searchEngines);

		for (String query : queries) {
			// make sure the universe doesn't implode
			availableSearchEngines.remove(query);

			if (availableSearchEngines.size() == 0) {
				// no more search engines we could use at this point -> switch
				availableSearchEngines = copySearchEngines(searchEngines);
				// make sure the universe doesn't implode
				availableSearchEngines.remove(query);
				switchCounter++;
			}
		}

		return switchCounter;
	}

	private static Set<String> copySearchEngines(Set<String> searchEngines) {
		Set<String> copy = new HashSet<String>(searchEngines.size());
		copy.addAll(searchEngines);
		return copy;
	}

	/**
	 * @param args
	 *            arguments
	 * @throws IOException
	 *             if input/output files can't be read/written from/to
	 */
	public static void main(String[] args) throws IOException {
		File inputFile = new File("A-small-attempt1.in");
		BufferedReader br = new BufferedReader(new FileReader(inputFile));
		File outputFile = new File("A-small-attempt1.out");
		BufferedWriter wr = new BufferedWriter(new FileWriter(outputFile));

		int numberOfCases = Integer.valueOf(br.readLine()).intValue();

		for (int i = 0; i < numberOfCases; i++) {
			long time = System.currentTimeMillis();
			int numberOfSwitches;

			int numberOfSearchEngines = Integer.valueOf(br.readLine()).intValue();
			Set<String> searchEngines = new HashSet<String>(numberOfSearchEngines);

			int numberOfQueries;
			List<String> queries;

			System.out.print("starting case #" + (i + 1) + " ...");

			for (int j = 0; j < numberOfSearchEngines; j++) {
				searchEngines.add(br.readLine());
			}

			numberOfQueries = Integer.valueOf(br.readLine()).intValue();
			queries = new ArrayList<String>(numberOfQueries);
			for (int j = 0; j < numberOfQueries; j++) {
				queries.add(br.readLine());
			}

			numberOfSwitches = SavingTheUniverse.calculateSwitches(searchEngines, queries);

			wr.write("Case #" + (i + 1) + ": " + numberOfSwitches + "\n");

			System.out.print(" done! took " + (System.currentTimeMillis() - time) + " millis.\n");

		}

		br.close();
		wr.close();

	}

}
