import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

/**
 * Usage: java MainClassName < fileIn.txt > fileOut.txt
 */
public class GCJ2016QA {

    private static class InputData {
        int N;
        byte digitsCollected;
        boolean[] collected;

        InputData(Scanner in) {
            N = in.nextInt();
            digitsCollected = 0;
            collected = new boolean[10];
        }

        /**
         * Main method to solve the problem
         */
        void solve(PrintWriter out) {
            if (N == 0) {
                out.println("INSOMNIA");
                return;
            }
            int counter = 0;
            int value = counter * N;
            while (digitsCollected < 10 && value >= 0) {
                counter++;
                value = counter * N;
                collectDigits(value);
            }

            if (value <= 0) {
                out.println("INSOMNIA");
            } else {
                out.println(value);
            }
        }

        void collectDigits(int num) {
            char[] digits = String.valueOf(num).toCharArray();
            for (char digit : digits) {
                collectDigit(Integer.parseInt(digit + ""));
            }
        }

        void collectDigit(int digit) {
            if (!collected[digit]) {
                digitsCollected++;
                collected[digit] = true;
            }
        }
    }

    static class Solver implements Callable<String> {

        InputData data;

        Solver(InputData data) {
            this.data = data;
        }

        @Override
        public String call() {
            StringWriter out = new StringWriter();
            data.solve(new PrintWriter(out));
            return out.toString();
        }

    }

    public static void main(String[] args) {
        try {
            // Scanner in = new Scanner(new File("C:\\Dropbox\\java\\projects\\google-codejam-2014\\inputs\\qualification\\Problem C. Minesweeper Master - small.txt"));
            Scanner in = new Scanner(System.in);

            ExecutorService service = Executors.newFixedThreadPool(NUM_THREADS);

            int testCount = in.nextInt();
            @SuppressWarnings("unchecked")
            Future<String>[] ts = new Future[testCount];
            for (int test = 0; test < testCount; test++) {
                ts[test] = service.submit(new Solver(new InputData(in)));
            }
            for (int test = 0; test < testCount; ++test) {
                while (!ts[test].isDone()) {
                    Thread.sleep(500);
                }
                System.err.println("Test " + (test + 1));
                out.print("Case #" + (test + 1) + ": ");
                out.print(ts[test].get());
            }
            service.shutdown();

            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private final static PrintStream out = System.out;
    private final static int NUM_THREADS = 10;
}
