import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Arrays;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

/**
 * Usage: java MainClassName < fileIn.txt > fileOut.txt
 */
public class GCJ2016QC {

    private static class InputData {
        int N;
        int J;
        long candidate;
        long maxCandidate;

        InputData(Scanner in) {
            N = in.nextInt();
            J = in.nextInt();
            candidate = 0;
            maxCandidate = (long) (Math.pow(2, N-2)) - 1;
        }

        /**
         * Main method to solve the problem
         */
        void solve(PrintWriter out) {
            out.println();
            outer:
            for (int j = 0; j < J && hasNextCandidate(); ) {
                String coin = nextCandidate();
                long[] divisors = new long[9];
                for (int i = 0; i < 9; i++) {
                    long coinNum = Long.parseLong(coin, i+2);
                    long divisor = getSmallestDivisor(coinNum);
                    if (divisor == coinNum)
                        continue outer; // skip prime number
                    divisors[i] = divisor;
                }
                j++;
                out.print(coin);
                for (int i = 0; i < 9; i++) {
                    out.print(" " + divisors[i]);
                }
                out.println();
            }
        }

        boolean hasNextCandidate() {
            return candidate <= maxCandidate;
        }

        String nextCandidate() {
            String candidateStr = Long.toBinaryString(candidate);
            StringBuilder sb = new StringBuilder(N);
            sb.append("1");
            for (int i = 0; i < (N - 2)-candidateStr.length() && i>=0; i++) {
                sb.append("0");
            }
            sb.append(candidateStr);
            sb.append("1");
            candidate++;
            return sb.toString();
        }

        long getSmallestDivisor(long num) {
            long result = num; // consider prime number by default
            for (long i = 2; i <= Math.floor(Math.sqrt(num)); i++) {
                if (num % i == 0) {
                    result = i;
                    break;
                }
            }
            return result;
        }
    }

    static class Solver implements Callable<String> {

        InputData data;

        Solver(InputData data) {
            this.data = data;
        }

        @Override
        public String call() {
            StringWriter out = new StringWriter();
            data.solve(new PrintWriter(out));
            return out.toString();
        }

    }

    public static void main(String[] args) {
        try {
            // Scanner in = new Scanner(new File("C:\\Dropbox\\java\\projects\\google-codejam-2014\\inputs\\qualification\\Problem C. Minesweeper Master - small.txt"));
            Scanner in = new Scanner(System.in);

            ExecutorService service = Executors.newFixedThreadPool(NUM_THREADS);

            int testCount = in.nextInt();
            @SuppressWarnings("unchecked")
            Future<String>[] ts = new Future[testCount];
            for (int test = 0; test < testCount; test++) {
                ts[test] = service.submit(new Solver(new InputData(in)));
            }
            for (int test = 0; test < testCount; ++test) {
                while (!ts[test].isDone()) {
                    Thread.sleep(500);
                }
                System.err.println("Test " + (test + 1));
                out.print("Case #" + (test + 1) + ": ");
                out.print(ts[test].get());
            }
            service.shutdown();

            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private final static PrintStream out = System.out;
    private final static int NUM_THREADS = 10;
}
