import java.io.File;
import java.io.FileNotFoundException;
import java.lang.reflect.Field;
import java.util.*;

/**
 * @author aeros
 * @since 12-Apr-14
 */
public class ProblemCMinesweeperMasterMax {

    /**
     * Usage: java ProblemCMinesweeperMaster < fileIn.txt > fileOut.txt
     *
     * @param args
     */
    public static void main(String[] args) throws FileNotFoundException {
        Scanner scanner = new Scanner(System.in);
        //Scanner scanner = new Scanner(new File("C:\\Dropbox\\java\\projects\\google-codejam-2014\\inputs\\qualification\\Problem C. Minesweeper Master - small.txt"));
        int testsCount = scanner.nextInt();

        for (int i = 0; i < testsCount; i++) {
            System.out.println("Case #"+ (i+1) + ":");
            byte rows = scanner.nextByte();
            byte cols = scanner.nextByte();
            int mines = scanner.nextInt();

            // represent minefield as a graph
            Graph g = new Graph(rows * cols);
            FieldCell[][] gameField = new FieldCell[rows][cols];
            int vertexNumber = 0;
            for (byte j = 0; j < rows; j++) {
                for (byte k = 0; k < cols; k++) {
                    gameField[j][k] = new FieldCell(j, k, vertexNumber++);
                }
            }

            for (byte j = 0; j < rows; j++) {
                for (byte k = 0; k < cols; k++) {
                    if (isValidCoordinates(j - 1, k - 1, rows, cols)) {
                        g.addEdge(gameField[j][k], gameField[j - 1][k - 1]);
                    }
                    if (isValidCoordinates(j - 1, k, rows, cols)) {
                        g.addEdge(gameField[j][k], gameField[j - 1][k]);
                    }
                    if (isValidCoordinates(j - 1, k + 1, rows, cols)) {
                        g.addEdge(gameField[j][k], gameField[j - 1][k + 1]);
                    }
                    if (isValidCoordinates(j, k - 1, rows, cols)) {
                        g.addEdge(gameField[j][k], gameField[j][k - 1]);
                    }
                    if (isValidCoordinates(j, k + 1, rows, cols)) {
                        g.addEdge(gameField[j][k], gameField[j][k + 1]);
                    }
                    if (isValidCoordinates(j + 1, k - 1, rows, cols)) {
                        g.addEdge(gameField[j][k], gameField[j + 1][k - 1]);
                    }
                    if (isValidCoordinates(j + 1, k, rows, cols)) {
                        g.addEdge(gameField[j][k], gameField[j + 1][k]);
                    }
                    if (isValidCoordinates(j + 1, k + 1, rows, cols)) {
                        g.addEdge(gameField[j][k], gameField[j + 1][k + 1]);
                    }
                }
            }

            // put mines diagonally, start from left corner
            // next pick the smallest side
            int minesPlaced = 0;
            if (mines > 0) {
                placeMine(gameField[0][0], g);
                minesPlaced++;
            }

            int diagonals = rows + cols - 1;
            minesLoop:
            for (int j = 1; j < diagonals && minesPlaced < mines; j++) {
                List<Pair> pairs = Partition.getPairs(j);
                for (int k = 0; k < pairs.size(); k++) {
                    Pair p = pairs.get(k);
                    if (rows >= cols) {
                        // tall matrix
                        if ((p.value2 >= rows) || (p.value1 >= cols)) {
                            continue; // skip this
                        }
                        if (gameField[p.value2][p.value1].state != FieldCell.State.Mined) {
                            placeMine(gameField[p.value2][p.value1], g);
                            if (++minesPlaced >= mines) {
                                break minesLoop;
                            }
                        }
                    } else{
                        // wide matrix
                        if ((p.value1 >= rows) || (p.value2 >= cols)) {
                            continue; // skip this
                        }
                        if (gameField[p.value1][p.value2].state != FieldCell.State.Mined) {
                            placeMine(gameField[p.value1][p.value2], g);
                            if (++minesPlaced >= mines) {
                                break minesLoop;
                            }
                        }
                    }
                }
            }

            // draw a gamefield
/*
            for (byte j = 0; j < rows; j++) {
                for (byte k = 0; k < cols; k++) {
                    if ((j == rows - 1) && (k == cols -1)) {
                        if (gameField[j][k].state == FieldCell.State.Mined) {
                            System.out.print("*");
                        } else {
                            System.out.print("c");
                        }
                        continue;
                    }
                    switch (gameField[j][k].state) {
                        case Free:
                            System.out.print(".");
                            break;
                        case Non_Zero:
                            System.out.print("%");
                            break;
                        case Mined:
                            System.out.print("*");
                            break;
                    }
                    if (k < cols - 1) {
                        System.out.print(" ");
                    }
                }
                System.out.println();
            }
*/


            // determine connected components
            CC cc = new CC(g);
            if (cc.count() <= mines + 1) {
                // Ok
                // draw a gamefield
                for (byte j = 0; j < rows; j++) {
                    for (byte k = 0; k < cols; k++) {
                        if ((j == rows - 1) && (k == cols -1)) {
                            if (gameField[j][k].state == FieldCell.State.Mined) {
                                System.out.print("*");
                            } else {
                                System.out.print("c");
                            }
                            continue;
                        }
                        switch (gameField[j][k].state) {
                            case Free:
                                System.out.print(".");
                                break;
                            case Non_Zero:
                                System.out.print(".");
                                break;
                            case Mined:
                                System.out.print("*");
                                break;
                        }
/*
                    if (k < cols - 1) {
                        System.out.print(" ");
                    }
*/
                    }
                    System.out.println();
                }

            } else {
                System.out.println("Impossible");
            }
            // draw different connected components
 /*           for (byte j = 0; j < rows; j++) {
                for (byte k = 0; k < cols; k++) {
                    System.out.print(cc.id(gameField[j][k].vertexNumber));
                    if (k < cols - 1) {
                        System.out.print(" ");
                    }
                }
                System.out.println();
            }
 */

        }
    }

    private static int getFieldCell(int i, int j, int colsNum) {
        if (i < 0 || j < 0) {
            return -1;
        }
        return i * colsNum + j;
    }

    private static boolean isValidCoordinates(int i, int j, int rowsNum, int colsNum) {
        return (i >= 0 && i < rowsNum) && (j >= 0 && j < colsNum);
    }

    private static void placeMine(FieldCell currentCell, Graph g) {
        currentCell.state = FieldCell.State.Mined;
        for (FieldCell fieldCell : new ArrayList<FieldCell>(g.adj(currentCell.vertexNumber))) {
            if (FieldCell.State.Free.equals(fieldCell.state)) {
                fieldCell.state = FieldCell.State.Non_Zero;
                // make sure all non_zero cells are connected only to free cells
                // remove the connections with other cells except free
                for (FieldCell fieldCell2 : new ArrayList<FieldCell>(g.adj(fieldCell.vertexNumber))) {
                    if (!FieldCell.State.Free.equals(fieldCell2.state)) {
                        g.removeEdge(fieldCell, fieldCell2);
                    }
                }
            }
            g.removeEdge(currentCell, fieldCell);
        }
    }

}

class FieldCell {
    State state = State.Free;
    final byte xCoord;
    final byte yCoord;
    final int vertexNumber;

    FieldCell(byte x, byte y, int vertexNumber) {
        this.xCoord = x;
        this.yCoord = y;
        this.vertexNumber = vertexNumber;
    }

    enum State {
        Free,
        Non_Zero,
        Mined
    }
}

class Graph {
    private final int V;          // number of vertices
    private int E;                // number of edges
    private List<FieldCell>[] adj;   // adjacency lists

    @SuppressWarnings("unchecked")
    public Graph(int V) {
        this.V = V;
        this.E = 0;
        adj = (List<FieldCell>[]) new List[V];
        for (int v = 0; v < V; v++)
            adj[v] = new ArrayList<FieldCell>();
    }

    public int V() {
        return V;
    }

    public int E() {
        return E;
    }

    public void addEdge(FieldCell v, FieldCell w) {
        adj[v.vertexNumber].add(w);
        adj[w.vertexNumber].add(v);
        E++;
    }

    public void removeEdge(FieldCell v, FieldCell w) {
        adj[v.vertexNumber].remove(w);
        adj[w.vertexNumber].remove(v);
        E--;
    }

    public List<FieldCell> adj(int v) {
        return adj[v];
    }
}

class CC {
    private boolean[] marked;
    private int[] id;
    private int count;

    public CC(Graph G) {
        marked = new boolean[G.V()];
        id = new int[G.V()];
        for (int s = 0; s < G.V(); s++)
            if (!marked[s]) {
                dfs(G, s);
                count++;
            }
    }

    private void dfs(Graph G, int v) {
        marked[v] = true;
        id[v] = count;
        for (FieldCell w : G.adj(v))
            if (!marked[w.vertexNumber]) {
                dfs(G, w.vertexNumber);
            }
    }

    public boolean connected(int v, int w) {
        return id[v] == id[w];
    }

    public int id(int v) {
        return id[v];
    }

    public int count() {
        return count;
    }
}


class Partition {

    public static void partition(int n, List<Pair> list) {
        partition(n, n, n, list);
    }

    public static void partition(int n, int max, int initialValue, List<Pair> list) {
        if (n == 0) {
            return;
        }

        for (int i = Math.min(max, n); i >= 1; i--) {
            if ((i + Math.min(i, n - i)) == initialValue) {
                Pair p = new Pair(i, Math.min(i, n - i));
                list.add(p);
                if (p.value1 != p.value2) {
                    list.add(new Pair(p.value2, p.value1));
                }
            }
            partition(n - i, i, initialValue, list);
        }
    }

    public static List<Pair> getPairs(int N) {
        List<Pair> list = new ArrayList<Pair>();
        partition(N, list);
        return list;
    }
}

class Pair {
    int value1;
    int value2;

    Pair(int v1, int v2) {
        this.value1 = v1;
        this.value2 = v2;
    }

    public String toString() {
        return value1 + " " + value2;
    }
}