import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Comparator;
import java.util.PriorityQueue;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

/**
 * Usage: java MainClassName < fileIn.txt > fileOut.txt
 */
public class GCJ2017QC {

    private static class InputData {
        long N;
        long K;

        InputData(Scanner in) {
            N = in.nextLong();
            K = in.nextLong();
        }

        /**
         * Main method to solve the problem
         */
        void solve(PrintWriter out) {
            PriorityQueue<Long> queue = new PriorityQueue<>(1, new Comparator<Long>() {
                @Override
                public int compare(Long o1, Long o2) {
                    return Long.compare(o2, o1);
                }
            });
            queue.offer(N);
            long number = 1;
            for (int i = 0; i < K - 1; i++) {
                number = queue.poll();
                // do the split
                queue.offer(number / 2);
                queue.offer( (number - 1) / 2);
            }
            number = queue.poll();
            out.println( (number / 2) + " " + ( (number -1) / 2));
        }
    }

    static class Solver implements Callable<String> {

        InputData data;

        Solver(InputData data) {
            this.data = data;
        }

        @Override
        public String call() {
            StringWriter out = new StringWriter();
            data.solve(new PrintWriter(out));
            return out.toString();
        }

    }

    public static void main(String[] args) {
        try {
            // Scanner in = new Scanner(new File("C:\\Dropbox\\java\\projects\\google-codejam-2014\\inputs\\qualification\\Problem C. Minesweeper Master - small.txt"));
            Scanner in = new Scanner(System.in);

            ExecutorService service = Executors.newFixedThreadPool(NUM_THREADS);

            int testCount = in.nextInt();
            @SuppressWarnings("unchecked")
            Future<String>[] ts = new Future[testCount];
            for (int test = 0; test < testCount; test++) {
                ts[test] = service.submit(new Solver(new InputData(in)));
            }
            for (int test = 0; test < testCount; ++test) {
                while (!ts[test].isDone()) {
                    Thread.sleep(500);
                }
                System.err.println("Test " + (test + 1));
                out.print("Case #" + (test + 1) + ": ");
                out.print(ts[test].get());
            }
            service.shutdown();

            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private final static PrintStream out = System.out;
    private final static int NUM_THREADS = 10;
}
