package bottrust;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

public class BotTrust {

    private int numOfTCs = -1;
    private String input = "E:\\codejam\\input_new.txt";
    private List<String> testCases = new ArrayList<String>();
    private String output = "E:\\codejam\\output.txt";
    private List<String> intermPos = new ArrayList<String> ();
    private String movingRobot = "";
    private int otherRobotPos = -1;
    private int movingRobotPtr = 1;
    private int otherRobotPtr = 1;
    private StringBuilder codeOutput = new StringBuilder("");
    
    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        // TODO code application logic here
        BotTrust puzzle = new BotTrust();
        try {
            puzzle.validateAndParseInput();
            puzzle.solve();
        } catch (Exception e) {
            e.printStackTrace();
        }
     }
    
    private void validateAndParseInput() throws Exception{
        
        BufferedReader in = new BufferedReader(new FileReader(input));
        String inputLine;
        
        while ((inputLine = in.readLine()) != null) {        
            if(this.numOfTCs == -1) {
                try {
                    this.numOfTCs = Integer.parseInt(inputLine);
                    continue;
                } catch (NumberFormatException nfe) {
                    System.out.println("Invalid Input");
                    System.exit(0);
                }
            }
            if(this.numOfTCs == -1) {
                System.exit(0);
            }
            if (inputLine.length() > 0) {
                testCases.add(inputLine);
            }
        }
        in.close();
    }
    
    private void solve() throws Exception {
        StringBuilder outputMsg = new StringBuilder();
        for (int count=0; count<testCases.size(); count++) {
            codeOutput.append("Case #" + (count+1)).append(": ");
            String output = solveScenario(this.testCases.get(count));
            resetCounters();
            outputMsg.append(output);
        }
        
        System.out.println(outputMsg.toString());
        writeToOutput(codeOutput);
    }
    
    private void resetCounters() {
        intermPos.clear();
        movingRobot = "";
        otherRobotPos = -1;
        movingRobotPtr = 1;
        otherRobotPtr = 1;
    }

    private String solveScenario(String inputTC) {
        StringBuilder outputMsg = new StringBuilder("");
        int numOfPos = -1;
        String temp1 = null;
        String temp2 = null;
        int pos = -1;
        int swap = -1;
        int totalMoves = 0;
        boolean backward = false;
        
        StringTokenizer inputs = new StringTokenizer(inputTC, " ");
        while (inputs.hasMoreTokens()) {
            temp1 = inputs.nextToken();
            
            // First input in any test case is total number of button pushes
            if (numOfPos == -1) {
               numOfPos = Integer.parseInt(temp1);
               continue;
            }
            
            temp2 = inputs.nextToken();
            
            // Initialize moving robot
            movingRobot = (movingRobot.equalsIgnoreCase("")) ? temp1 : movingRobot;

            // Find the next position for both the robots
            if (temp1.equalsIgnoreCase(movingRobot)) {
                intermPos.add(temp2);
            } else {
                // Got the next position for both the robots. Move now.
                otherRobotPos = Integer.parseInt(temp2);

                totalMoves = move(totalMoves, outputMsg);

                // After the move, swap robots
                movingRobot = temp1;
                intermPos.clear();
                intermPos.add(""+otherRobotPos);
                swap = otherRobotPtr;
                otherRobotPtr = movingRobotPtr;
                movingRobotPtr = swap;
            }
        }
        
        // The last push doesn't count
        totalMoves = move(totalMoves, outputMsg);
        
        codeOutput.append("" + totalMoves + "\n");
        return outputMsg.toString();
    }
    
    private void writeToOutput(StringBuilder outputMsg) throws Exception{
        FileWriter writer = new FileWriter(output);
        String output = outputMsg.toString();
        System.out.println(output);
        writer.write(output);
        writer.close();
    }
    
    private int move(int prevMoves, StringBuilder msg) {
        
        // intermPos - 2, 5, 6
        // movingRobot - O
        // otherRobotPos - 3
        // otherRobPtr = 2, movingRobPtr = 2
        int pos = 0;
        
        for (int count=0; count<intermPos.size(); count++) {
            pos = Integer.parseInt(intermPos.get(count));
            if (movingRobotPtr == pos) {
                prevMoves++;
                msg.append(""+prevMoves+":");
                msg.append(movingRobot).append(" pushes button " + pos).append("\t");
                moveSecRobot(msg);
            } else {
                int ptr = movingRobotPtr;
                while(true) {
                    if (ptr<pos) {
                        movingRobotPtr++;
                        ptr++;
                    } else if (ptr > pos) {
                        movingRobotPtr--;
                        ptr--;
                    } else if (ptr == pos) {
                        break;
                    }
                    prevMoves++;
                    msg.append(""+prevMoves+":");
                    msg.append(movingRobot).append(" moves to button " + movingRobotPtr).append("\t");
                    moveSecRobot(msg);
                }
                prevMoves++;
                msg.append(""+prevMoves+":");
                msg.append(movingRobot).append(" pushes button " + pos).append("\t");
                moveSecRobot(msg);
            }
        }
        return prevMoves;
    }
    
    private void moveSecRobot(StringBuilder msg) {
        if (otherRobotPtr < otherRobotPos) {
            otherRobotPtr++;
            msg.append((movingRobot.equals("O")?"B":"O")).append(" moves to button " + otherRobotPtr).append("\n");
        } else if (otherRobotPtr > otherRobotPos) {
            otherRobotPtr--;
            msg.append((movingRobot.equals("O")?"B":"O")).append(" moves to button " + otherRobotPtr).append("\n");
        } else {
            msg.append((movingRobot.equals("O")?"B":"O")).append(" stays at button " + otherRobotPtr).append("\n");
        }
    }
}
