import java.io.*;
import java.math.BigInteger;
import java.util.*;
 
class InputReader {
    private final InputStream stream;
    private final byte buf[] = new byte[1024];
    private int curChar;
    private int numChars;
    private SpaceCharFilter filter;
 
    public InputReader(InputStream stream) {
        this.stream = stream;
    }
 
    public int read() {
        if(numChars == -1) throw new InputMismatchException();
        if(curChar >= numChars) {
            curChar = 0;
            try {
                numChars = stream.read(buf);
            } catch(IOException e) {
                throw new InputMismatchException();
            }
            if(numChars <= 0) return -1;
        }
        return buf[curChar++];
    }
 
    public int readInt() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        int res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
 
    public long readLong() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        long res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
 
    public char readChar() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        return (char) c;
    }
 
    public String readString() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            res.appendCodePoint(c);
            c = read();
        } while(!isSpaceChar(c));
        return res.toString();
    }
 
    public String readLine() {
        int c = read();
        while(isNewLineChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            if(c<0) c += 256;
            res.appendCodePoint(c);
            c = read();
        } while(!isNewLineChar(c));
        return res.toString();
    }
 
    public String next() {
        return readString();
    }
 
    public boolean isSpaceChar(int c) {
        if(filter != null) return filter.isSpaceChar(c);
        return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
    }
 
    public boolean isNewLineChar(int c) {
        if(filter != null) return filter.isNewLineChar(c);
        return c == '\n' || c == '\r' || c == -1;
    }
 
    public interface SpaceCharFilter {
        public boolean isSpaceChar(int ch);
        public boolean isNewLineChar(int ch);
    }
}
 
class OutputWriter {
    private final PrintWriter writer;
 
    public OutputWriter(OutputStream stream) {
        this.writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(stream)));
    }
 
    public OutputWriter(Writer writer) {
        this.writer = new PrintWriter(writer);
    }
 
    public void print(Object...objects) {
        for(int i=0; i<objects.length; i++) {
            if(i != 0) writer.print(' ');
            writer.print(objects[i]);
        }
    }
 
    public void println(Object...objects) {
        print(objects);
        writer.println();
    }
 
    public void flush() {
        writer.flush();
    }
 
    public void close() {
        writer.close();
    }
}
 
class Solution {
    
    private static long primeCheck(long number) {
        for(long i=2; i<number; i++) {
            if(number%i == 0) return i;
        }
        return -1;
    }
    
    private static String solve(String numbers[], int J) {
        StringBuilder sb = new StringBuilder();
        out: for(int i=0; i<numbers.length && J>0; i++) {
            long ans[] = new long[11];
            for(int base=2; base<=10; base++) {
                long number = Long.parseLong(numbers[i], base);
                if(BigInteger.valueOf(number).isProbablePrime(10)) continue out;
                long res = primeCheck(number);
                if(res == -1) continue out;
                ans[base] = res;
            }
            sb.append(numbers[i]).append(" ");
            for(int base=2; base<=10; base++) {
                sb.append(ans[base]).append(" ");
            }
            sb.deleteCharAt(sb.length()-1);
            sb.append("\n");
            J--;
        }
        return sb.toString();
    }
    
    public static void main(String[] args) throws FileNotFoundException {
//        InputReader in = new InputReader(System.in);
//        OutputWriter out = new OutputWriter(System.out);
        InputReader in = new InputReader(new FileInputStream("C-small-attempt1.in"));
        OutputWriter out = new OutputWriter(new FileOutputStream("C-small-attempt1.out"));
        int T = in.readInt();
        for(int i=1; i<=T; i++) {
            int N = in.readInt();
            int J = in.readInt();
            char num[] = new char[N];
            Arrays.fill(num, '0');
            num[0] = num[N-1] = '1';
            int start = Integer.parseInt(new String(num), 2);
            Arrays.fill(num, '1');
            int end = Integer.parseInt(new String(num), 2);
            
            String numbers[] = new String[end-start+1];
            for(int j=start, z=0; j<=end; j++) {
                numbers[z++] = Integer.toString(j, 2);
            }
            
            out.println("Case #" + i + ":");
            out.println(solve(numbers, J));
        }
        out.flush();
        out.close();
    }
    
}