import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.InputMismatchException;
import java.util.Map;
import java.util.TreeMap;

class InputReader {
    private final InputStream stream;
    private final byte buf[] = new byte[1024];
    private int curChar;
    private int numChars;
    private SpaceCharFilter filter;
    
    public InputReader(InputStream stream) {
        this.stream = stream;
    }
    
    public int read() {
        if(numChars == -1) throw new InputMismatchException();
        if(curChar >= numChars) {
            curChar = 0;
            try {
                numChars = stream.read(buf);
            } catch(IOException e) {
                throw new InputMismatchException();
            }
            if(numChars <= 0) return -1;
        }
        return buf[curChar++];
    }
    
    public int readInt() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        int res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
    
    public long readLong() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        long res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
    
    public char readChar() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        return (char) c;
    }
    
    public String readString() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            res.appendCodePoint(c);
            c = read();
        } while(!isSpaceChar(c));
        return res.toString();
    }
    
    public String readLine() {
        int c = read();
        while(isNewLineChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            if(c<0) c += 256;
            res.appendCodePoint(c);
            c = read();
        } while(!isNewLineChar(c));
        return res.toString();
    }
    
    public String next() {
        return readString();
    }
    
    public boolean isSpaceChar(int c) {
        if(filter != null) return filter.isSpaceChar(c);
        return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
    }
    
    public boolean isNewLineChar(int c) {
        if(filter != null) return filter.isNewLineChar(c);
        return c == '\n' || c == '\r' || c == -1;
    }
    
    public interface SpaceCharFilter {
        public boolean isSpaceChar(int ch);
        public boolean isNewLineChar(int ch);
    }
}
 
class OutputWriter {
    private final PrintWriter writer;
    
    public OutputWriter(OutputStream stream) {
        this.writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(stream)));
    }
    
    public OutputWriter(Writer writer) {
        this.writer = new PrintWriter(writer);
    }
    
    public void print(Object...objects) {
        for(int i=0; i<objects.length; i++) {
            if(i != 0) writer.print(' ');
            writer.print(objects[i]);
        }
    }
    
    public void printLine(Object...objects) {
        print(objects);
        writer.println();
    }
    
    public void flush() {
        writer.flush();
    }
    
    public void close() {
        writer.close();
    }
}

class CodeJam {
    private static final ArrayList<Integer> d = new ArrayList<>();
    private static final ArrayList<Integer> new_d = new ArrayList<>();
    public static void main(String args[]) throws FileNotFoundException {
        //InputReader in = new InputReader(System.in);
        //OutputWriter out = new OutputWriter(System.out);
        InputReader in = new InputReader(new FileInputStream("C-small-attempt0.in"));
        OutputWriter out = new OutputWriter(new FileOutputStream("output-small0.out"));
        byte T = (byte) in.readInt();
        for(int j=1; j<=T; j++) {
            d.clear();
            new_d.clear();
            int C = in.readInt();
            int D = in.readInt();
            int V = in.readInt();
            for(int i=0; i<D; i++) d.add(in.readInt());
            count(C, D, V);
            out.printLine("Case #" + j + ": " + new_d.size());
            out.flush();
        }
        out.close();
    }
    private static void count(int C, int D, int V) {
        for(int i=1; i<=V; i++) {
            if(d.contains(i) || new_d.contains(i)) continue;
            TreeMap<Integer, Integer> den = createHash();
            int current = i;
            for(Map.Entry<Integer, Integer> entry : den.entrySet()) {
                for(int j=C; j>=1; j--) {
                    if(entry.getKey()*j <= current) {
                        current -= entry.getKey()*j;
                        entry.setValue(j);
                    }
                }
            }
            if(current>0 && (!den.containsKey(current) || den.get(current)+1 > C)) new_d.add(i);
        }
    }
    private static TreeMap<Integer, Integer> createHash() {
        TreeMap<Integer, Integer> den = new TreeMap<>(Comparator.reverseOrder());
        int l=0, r=0;
        while(l<d.size() && r<new_d.size()) {
            if(d.get(l) < new_d.get(r)) {
                den.put(d.get(l++), 0);
            } else {
                den.put(new_d.get(r++), 0);
            }
        }
        while(l<d.size()) {
            den.put(d.get(l++), 0);
        }
        while(r<new_d.size()) {
            den.put(new_d.get(r++), 0);
        }
        return den;
    }
} 