import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.ArrayList;
import java.util.InputMismatchException;
import java.util.ListIterator;
 
class InputReader {
    private final InputStream stream;
    private final byte buf[] = new byte[1024];
    private int curChar;
    private int numChars;
    private SpaceCharFilter filter;
    
    public InputReader(InputStream stream) {
        this.stream = stream;
    }
    
    public int read() {
        if(numChars == -1) throw new InputMismatchException();
        if(curChar >= numChars) {
            curChar = 0;
            try {
                numChars = stream.read(buf);
            } catch(IOException e) {
                throw new InputMismatchException();
            }
            if(numChars <= 0) return -1;
        }
        return buf[curChar++];
    }
    
    public int readInt() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        int res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
    
    public long readLong() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        long res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
    
    public char readChar() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        return (char) c;
    }
    
    public String readString() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            res.appendCodePoint(c);
            c = read();
        } while(!isSpaceChar(c));
        return res.toString();
    }
    
    public String readLine() {
        int c = read();
        while(isNewLineChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            if(c<0) c += 256;
            res.appendCodePoint(c);
            c = read();
        } while(!isNewLineChar(c));
        return res.toString();
    }
    
    public String next() {
        return readString();
    }
    
    public boolean isSpaceChar(int c) {
        if(filter != null) return filter.isSpaceChar(c);
        return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
    }
    
    public boolean isNewLineChar(int c) {
        if(filter != null) return filter.isNewLineChar(c);
        return c == '\n' || c == '\r' || c == -1;
    }
    
    public interface SpaceCharFilter {
        public boolean isSpaceChar(int ch);
        public boolean isNewLineChar(int ch);
    }
}
 
class OutputWriter {
    private final PrintWriter writer;
    
    public OutputWriter(OutputStream stream) {
        this.writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(stream)));
    }
    
    public OutputWriter(Writer writer) {
        this.writer = new PrintWriter(writer);
    }
    
    public void print(Object...objects) {
        for(int i=0; i<objects.length; i++) {
            if(i != 0) writer.print(' ');
            writer.print(objects[i]);
        }
    }
    
    public void printLine(Object...objects) {
        print(objects);
        writer.println();
    }
    
    public void flush() {
        writer.flush();
    }
    
    public void close() {
        writer.close();
    }
}
 
class IHOP {
    private static int[] findMax(ArrayList<Integer> list) {
        int max[] = {0, 0};
        for(Integer x : list) {
            if(x>max[0]) {
                max[1] = max[0];
                max[0] = x;
            } else if(x>max[1] && x<=max[0]) {
                max[1] = x;
            }
        }
        return max;
    }
    private static int findMin(ArrayList<Integer> list) {
        int min = Integer.MAX_VALUE;
        for(Integer x : list) {
            if(min > x) min = x;
        }
        return min;
    }
    public static void main(String args[]) throws FileNotFoundException {
        InputReader in = new InputReader(new FileInputStream("B-small-attempt2.in"));
        OutputWriter out = new OutputWriter(new FileOutputStream("output-small.out"));
        byte T = (byte) in.readInt();
        for(int i=1; i<=T; i++) {
            int D = in.readInt();
            ArrayList<Integer> diners = new ArrayList<>();
            int max[] = {0, 0};
            for(int j=0; j<D; j++) {
                int x = in.readInt();
                if(x>max[0]) {
                    max[1] = max[0];
                    max[0] = x;
                } else if(x>max[1] && x<=max[0]) {
                    max[1] = x;
                }
                diners.add(x);
            }
            int count = 0;
            while(!diners.isEmpty()) {
                // Special Minute
                if(max[0] >= max[1]+2) {
                    count++;
                    diners.remove(new Integer(max[0]));
                    int x = max[0]/2;
                    diners.add(x);
                    diners.add(max[0]-x);
                    max = findMax(diners);
                    continue;
                }
                
                // Normal Minute
                int min = findMin(diners);
                ListIterator<Integer> it = diners.listIterator();
                while(it.hasNext()) {
                    int x = it.next()-min;
                    if(x==0) it.remove();
                    else it.set(x);
                }
                count += min;
            }
            out.printLine("Case #" + i + ": " + count);
            out.flush();
        }
        out.close();
    }
} 