import java.io.*;
import java.math.BigInteger;
import java.util.*;
 
class InputReader {
    private final InputStream stream;
    private final byte buf[] = new byte[1024];
    private int curChar;
    private int numChars;
    private SpaceCharFilter filter;
 
    public InputReader(InputStream stream) {
        this.stream = stream;
    }
 
    public int read() {
        if(numChars == -1) throw new InputMismatchException();
        if(curChar >= numChars) {
            curChar = 0;
            try {
                numChars = stream.read(buf);
            } catch(IOException e) {
                throw new InputMismatchException();
            }
            if(numChars <= 0) return -1;
        }
        return buf[curChar++];
    }
 
    public int readInt() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        int res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
 
    public long readLong() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        long res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
 
    public char readChar() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        return (char) c;
    }
 
    public String readString() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            res.appendCodePoint(c);
            c = read();
        } while(!isSpaceChar(c));
        return res.toString();
    }
 
    public String readLine() {
        int c = read();
        while(isNewLineChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            if(c<0) c += 256;
            res.appendCodePoint(c);
            c = read();
        } while(!isNewLineChar(c));
        return res.toString();
    }
 
    public String next() {
        return readString();
    }
 
    public boolean isSpaceChar(int c) {
        if(filter != null) return filter.isSpaceChar(c);
        return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
    }
 
    public boolean isNewLineChar(int c) {
        if(filter != null) return filter.isNewLineChar(c);
        return c == '\n' || c == '\r' || c == -1;
    }
 
    public interface SpaceCharFilter {
        public boolean isSpaceChar(int ch);
        public boolean isNewLineChar(int ch);
    }
}
 
class OutputWriter {
    private final PrintWriter writer;
 
    public OutputWriter(OutputStream stream) {
        this.writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(stream)));
    }
 
    public OutputWriter(Writer writer) {
        this.writer = new PrintWriter(writer);
    }
 
    public void print(Object...objects) {
        for(int i=0; i<objects.length; i++) {
            if(i != 0) writer.print(' ');
            writer.print(objects[i]);
        }
    }
 
    public void println(Object...objects) {
        print(objects);
        writer.println();
    }
 
    public void flush() {
        writer.flush();
    }
 
    public void close() {
        writer.close();
    }
}
 
class Solution {
    
    private static int poss(int BFF[], boolean done[], int current) {
        int max = 0;
        for(int j=1; j<BFF.length; j++) {
            int count = 0;
            if(!done[j] && BFF[j] == current) {
                done[j] = true;
                count++;
                int c = poss(BFF, done, j);
                count += c;
                done[j] = false;
            }
            if(count > max) max = count;
        }
        return max;
    }
    
    private static int solve(int BFF[]) {
        // HashMap<Integer, ArrayList<Integer>> map = new HashMap<>();
        int max = 0;
        for(int i=1; i<BFF.length; i++) {
            boolean done[] = new boolean[BFF.length];
            int count = 0;
            // ArrayList<Integer> list = new ArrayList<>();
            // list.add(i);
            count++;
            int current = i;
            int prev = -1;
            while(true) {
                int x = BFF[current];
                if(done[x]) break;
                // list.add(x);
                count++;
                done[current] = true;
                prev = current;
                current = x;
            }
            // System.out.println(i + ": " + current + ", " + BFF[current] + ", " + BFF[BFF[current]]);
            if(current == BFF[BFF[current]]) {
                int c = poss(BFF, done, current);
//                System.out.println("true: " + c);
                count += c;
            }
            
            if(prev != BFF[current] && i != BFF[current]) count = 0;
            
            // System.out.println(i + ": " + i + ", " + prev + ", " + current);
            
            if(count > max) max = count;
            
            // map.put(i, list);
        }
        
        return max;
        
//        for(Map.Entry<Integer, ArrayList<Integer>> entry : map.entrySet()) {
//            System.out.println(entry.getKey() + ": " + entry.getValue());
//        }
    }
    
    public static void main(String[] args) throws FileNotFoundException {
        
//        InputReader in = new InputReader(System.in);
//        OutputWriter out = new OutputWriter(System.out);
        InputReader in = new InputReader(new FileInputStream("C-small-attempt1.in"));
        OutputWriter out = new OutputWriter(new FileOutputStream("C-small-attempt1.out"));
        int T = in.readInt();
        for(int i=1; i<=T; i++) {
            int N = in.readInt();
            int BFF[] = new int[N+1];
            for(int j=1; j<=N; j++) BFF[j] = in.readInt();
            out.println("Case #" + i + ": " + solve(BFF));
        }
        out.flush();
        out.close();
    }
    
}