import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.InputMismatchException;
 
class InputReader {
    private final InputStream stream;
    private final byte buf[] = new byte[1024];
    private int curChar;
    private int numChars;
    private SpaceCharFilter filter;
    
    public InputReader(InputStream stream) {
        this.stream = stream;
    }
    
    public int read() {
        if(numChars == -1) throw new InputMismatchException();
        if(curChar >= numChars) {
            curChar = 0;
            try {
                numChars = stream.read(buf);
            } catch(IOException e) {
                throw new InputMismatchException();
            }
            if(numChars <= 0) return -1;
        }
        return buf[curChar++];
    }
    
    public int readInt() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        int res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
    
    public long readLong() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        int sgn = 1;
        if(c == '-') {
            sgn = -1;
            c = read();
        }
        long res = 0;
        do {
            if(c < '0' || c > '9') throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while(!isSpaceChar(c));
        return res*sgn;
    }
    
    public char readChar() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        return (char) c;
    }
    
    public String readString() {
        int c = read();
        while(isSpaceChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            res.appendCodePoint(c);
            c = read();
        } while(!isSpaceChar(c));
        return res.toString();
    }
    
    public String readLine() {
        int c = read();
        while(isNewLineChar(c)) c = read();
        StringBuilder res = new StringBuilder();
        do {
            if(c<0) c += 256;
            res.appendCodePoint(c);
            c = read();
        } while(!isNewLineChar(c));
        return res.toString();
    }
    
    public String next() {
        return readString();
    }
    
    public boolean isSpaceChar(int c) {
        if(filter != null) return filter.isSpaceChar(c);
        return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
    }
    
    public boolean isNewLineChar(int c) {
        if(filter != null) return filter.isNewLineChar(c);
        return c == '\n' || c == '\r' || c == -1;
    }
    
    public interface SpaceCharFilter {
        public boolean isSpaceChar(int ch);
        public boolean isNewLineChar(int ch);
    }
}
 
class OutputWriter {
    private final PrintWriter writer;
    
    public OutputWriter(OutputStream stream) {
        this.writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(stream)));
    }
    
    public OutputWriter(Writer writer) {
        this.writer = new PrintWriter(writer);
    }
    
    public void print(Object...objects) {
        for(int i=0; i<objects.length; i++) {
            if(i != 0) writer.print(' ');
            writer.print(objects[i]);
        }
    }
    
    public void printLine(Object...objects) {
        print(objects);
        writer.println();
    }
    
    public void flush() {
        writer.flush();
    }
    
    public void close() {
        writer.close();
    }
}
 
class CodeJam {
    private static char input[];
    private static void mult(char next, int result[]) {
        char res = (char) result[0];
        int sgn = result[1];
        if(res == '1') {
            res = next;
        } else if(res == 'i' && next == 'j') {
            res = 'k';
        } else if(res == 'j' && next == 'k') {
            res = 'i';
        } else if(res == 'k' && next == 'i') {
            res = 'j';
        } else if(res == 'i' && next == 'k') {
            res = 'j';
            sgn *= -1;
        } else if(res == 'j' && next == 'i') {
            res = 'k';
            sgn *= -1;
        } else if(res == 'k' && next == 'j') {
            res = 'i';
            sgn *= -1;
        } else {
            res = '1';
            sgn *= -1;
        }
        result[0] = res;
        result[1] = sgn;
    }
    private static boolean findK(int counter) {
        int result[] = { input[counter], 1 };
        while(counter < input.length-1) {
            mult(input[++counter], result);
        }
        return (result[0]==(int)'k' && result[1]==1);
    }
    private static boolean findJ(int counter) {
        int result[] = { input[counter], 1 };
        while(counter < input.length-1) {
            if(result[0]==(int)'j' && result[1]==1 && findK(counter+1)) return true;
            mult(input[++counter], result);
        }
        return false;
    }
    private static boolean findI() {
        int counter = 0;
        int result[] = { input[counter], 1 };
        while(counter < input.length-1) {
            if(result[0]==(int)'i' && result[1]==1 && findJ(counter+1)) return true;
            mult(input[++counter], result);
        }
        return false;
    }
    public static void main(String args[]) throws FileNotFoundException {
        InputReader in = new InputReader(new FileInputStream("C-small-attempt2.in"));
        OutputWriter out = new OutputWriter(new FileOutputStream("output-small.out"));
        byte T = (byte) in.readInt();
        for(int i=1; i<=T; i++) {
            int L = in.readInt();
            int X = in.readInt();
            String s = in.readString();
            input = new char[L*X];
            for(int j=0; j<input.length; j++) input[j] = s.charAt(j%L);
            int result[] = {input[0], 1};
            for(int j=1; j<input.length; j++) mult(input[j], result);
            if(result[1] == -1 && result[0] == (int)'1') {
                if(findI()) out.printLine("Case #" + i + ": YES");
                else out.printLine("Case #" + i + ": NO");
            } else {
                out.printLine("Case #" + i + ": NO");
            }
            out.flush();
        }
        out.close();
    }
} 