import java.util.*;

public class Main {

    private Scanner scanner = new Scanner(System.in);
    
    public static void main(String[] args) {
        new Main().execute();
    }

    private void execute() {
        int cases = scanner.nextInt();

        for(int i = 1; i <= cases; i++)
            new TestCase(scanner, i).testCase();
    }
}

class TestCase
{
    private Scanner scanner;
    private int caseNo;
    private Set existing = new HashSet();
    private Set toMake = new HashSet();

    TestCase(Scanner scanner, int caseNo) {
        this.scanner = scanner;
        this.caseNo = caseNo;
    }

    void testCase()
    {
        int dirsPresent = scanner.nextInt();
        int dirsToMake = scanner.nextInt();

        for(int i = 0; i < dirsPresent; i++)
            existing.add(scanner.next());

        for(int i = 0; i < dirsToMake; i++)
            toMake.add(scanner.next());


        toMake.removeAll(existing);

        Tree tree = makeExistingTree(existing);
        tree = makeTomakeTree(tree, toMake);
        System.out.println("Case #" + caseNo + ": " + tree.root.counter);

    }

    Tree makeExistingTree(Set<String> existing) {
        Tree tree = new Tree();

        for (String s : existing) {
            StringTokenizer tok = new StringTokenizer(s, "/", false);

            Node node = tree.root;

            while(tok.hasMoreTokens())
            {
                String string = tok.nextToken();
                node = node.addChild(string);
            }
        }

        return tree;
    }

    Tree makeTomakeTree(Tree tree, Set<String> existing) {

        for (String s : existing) {
            StringTokenizer tok = new StringTokenizer(s, "/", false);

            Node node = tree.root;

            while(tok.hasMoreTokens())
            {
                String string = tok.nextToken();
                node = node.addNewChild(string);
            } 
        }

        return tree;
    }    
}

class Tree
{
    Node root;
    
    Tree() {
        root = new Node("");
        root.counter = 0;
    }
}

class Node
{
    String text;
    boolean shouldBeMade = false;
    Map<String, Node> children = new HashMap<String, Node>();
    static int counter;

    Node(String text) {
        this.text = text;
    }

    Node addChild(String child)
    {
        Node node = new Node(child);
        if(!children.containsKey(child))
        {
            children.put(child, node);
            return node;
        }
        else
            return children.get(child);
    }

    Node addNewChild(String child)
    {

        if(!children.containsKey(child))
        {
            Node node = new Node(child);
            node.setShouldBeMade(true);
            children.put(child, node);
            return node;
        }
        else
            return children.get(child);
    }    

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Node node = (Node) o;

        if (text != null ? !text.equals(node.text) : node.text != null) return false;

        return true;
    }

    @Override
    public int hashCode() {
        return text != null ? text.hashCode() : 0;
    }

    public void setShouldBeMade(boolean shouldBeMade) {
        this.shouldBeMade = shouldBeMade;
        counter++;
    }

    @Override
    public String toString() {
        return "Node{" + text +
                (shouldBeMade ? " toMake " : "") +
                ( children.size() > 0 ? children : "" ) + 
                '}';
    }
}
