import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;

/**
 * Created by ags on 07/05/11 at 16:35
 */
public class Robots
{
    int cases;

    public static void main(String[] args) throws IOException
    {
        new Robots().solve();
    }

    private void solve() throws IOException
    {
        BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
        cases = Integer.parseInt(reader.readLine());
        for (int i = 1; i <= cases; i++)
        {
            int solution = new Case().solve(reader.readLine());
            System.out.println("Case #" + i + ": " + solution);
        }
    }
}

class Case
{
    int steps;
    private Robot blue;
    private Robot orange;
    int time = 0;
    private boolean debug = false;

    public int solve(String s)
    {
        StringTokenizer tok = new StringTokenizer(s, " ");
        steps = Integer.parseInt(tok.nextElement().toString());

        blue = new Robot("blue");
        orange = new Robot("orange");

        readOrders(tok);
        while (!(orange.isDone() && blue.isDone()))
        {
            time++;
            Order blueOrder = blue.getOrder();
            Order orangeOrder = orange.getOrder();
            if (blueOrder instanceof PushOrder && orangeOrder instanceof PushOrder)
            {
                // return orange order
                blue.insertOrder(orangeOrder);
                blueOrder = new StayOrder(blue);
            }
            if (debug)
            {
                System.out.println(time);
            }
            blueOrder.proceed();
            orangeOrder.proceed();
        }

        return time;
    }

    private void readOrders(StringTokenizer tok)
    {
        while (tok.hasMoreElements())
        {
            String colour = tok.nextElement().toString();
            Order order = new MoveOrder(Integer.parseInt(tok.nextElement().toString()));

            if ("B".equals(colour))
                blue.addOrder(order);
            else orange.addOrder(order);
        }
    }

    class MoveOrder extends Order
    {
        int target;

        MoveOrder(int button)
        {
            this.target = button;
        }

        @Override
        void proceed()
        {
            int position = owner.position;
            if (position != target)
            {
                owner.moveTo(target);
                if (debug)
                    System.out.println(owner + " moving from " + position + " to " + owner.position);
            } else
            {
                if (debug)
                    System.out.println(owner + " staying at " + position);
            }

            if (owner.position == target)
            {
                owner.insertOrder(new PushOrder());
            } else
            {
                owner.insertOrder(new MoveOrder(target));
            }
        }
    }

    class Robot
    {
        List<Order> orders = new LinkedList<Order>();
        int position = 1;
        String name;

        Robot(String name)
        {
            this.name = name;
        }

        public void addOrder(Order order)
        {
            order.owner = this;
            orders.add(order);
        }

        public boolean isDone()
        {
            return orders.isEmpty();
        }

        public Order getOrder()
        {
            if (orders.isEmpty())
                return new StayOrder(this);
            return orders.remove(0);
        }

        public void moveTo(int target)
        {
            if (target > position)
                position++;
            else
                position--;
        }

        @Override
        public String toString()
        {
            return name;
        }

        public void insertOrder(Order order)
        {
            order.owner = this;
            orders.add(0, order);
        }
    }

    class PushOrder extends Order
    {
        @Override
        void proceed()
        {
            if (debug)
                System.out.println(owner + " pushing " + owner.position);
        }
    }

    abstract class Order
    {
        Robot owner;

        protected Order() { }

        public Order(Robot robot)
        {
            this.owner = robot;
        }

        abstract void proceed();
    }

    class StayOrder extends Order
    {

        public StayOrder(Robot robot)
        {
            super(robot);
        }

        @Override
        void proceed()
        {
            if (debug)
                System.out.println(owner + " staying at" + owner.position);
        }
    }
}