import java.util.*;
import java.io.*;

public class BWater{
	public static void main(String[] args){
		if(args.length<1){
			System.out.println("Usage: <fnIn>");
		}
		String fn = args[0];
		String fnOut = toFnOut(fn);
		try{
			BufferedReader br = new BufferedReader(new FileReader(fn));
			BufferedWriter bw = new BufferedWriter(new FileWriter(fnOut));
			String line = null;
			int NCase = Integer.valueOf(br.readLine().trim());
			for(int icase=0;icase<NCase;icase++){
				
				String[] parts = br.readLine().trim().split("[\\s+]");
				int H = Integer.valueOf(parts[0]);
				int W = Integer.valueOf(parts[1]);
				int[][] map = new int[H][W];
				for(int i=0;i<H;i++){
					parts = br.readLine().trim().split("[\\s+]");
					for(int j=0;j<W;j++) map[i][j] = Integer.valueOf(parts[j]);
				}
				
				String buf = getBasin(map);
				String out = "Case #"+(icase+1)+":"+buf;
				bw.write(out,0,out.length());
				bw.newLine();
				
			}
			br.close();
			bw.close();
		}catch(IOException ex){
			System.out.println(ex);
		}
	}
	
	static String getBasin(int[][] map){
		int H = map.length;
		int W = map[0].length;
		int[] id = new int[H*W];
		for(int y=0;y<H;y++){
			for(int x=0;x<W;x++){
				int cid = y*W+x;
				id[cid] = cid;
			}
		}
		for(int y=0;y<H;y++){
			for(int x=0;x<W;x++){
				int cid = y*W+x;
				int dir = getFlowDir(map,y,x);
				//~ System.out.println("y,x,dir:"+y+","+x+","+dir);
				if(dir!=0){
					switch(dir){
						case 1:
						id[cid] = getId(id,cid,(y-1)*W+x);break;
						case 2:
						id[cid] = getId(id,cid,(y)*W+x-1);break;
						case 3:
						id[cid] = getId(id,cid,(y)*W+x+1);break;
						case 4:
						id[cid] = getId(id,cid,(y+1)*W+x);break;
					}
				}
			}
		}
		boolean change = true;
		while(change){
			change = false;
			for(int y=0;y<H;y++){
				for(int x=0;x<W;x++){
					int cid = y*W+x;
					int tmp = getId(id,cid,id[cid]);
					if(tmp != id[cid]){
						id[cid] = tmp;
						change = true;
					}
				}
			}
		}
		
		//~ for(int y=0;y<H;y++){
			//~ for(int x=0;x<W;x++){
				//~ int cid = y*W+x;
				//~ System.out.print(id[cid]+" ");
			//~ }
			//~ System.out.println();
		//~ }
		int labelCount = 0;
		char[] label = new char[W*H];
		for(int i=0;i<label.length;i++) label[i] = 0;
		String[] out = new String[H];
		for(int y=0;y<H;y++){
			out[y] = "";
			for(int x=0;x<W;x++){
				int cid = id[y*W+x];
				if(label[cid]==0){
					label[cid] = (char)('a'+labelCount);
					labelCount++;
				}
				if(x>0) out[y]+=" ";
				out[y] += label[cid];
			}
		}
		String buf = "";
		for(int i=0;i<out.length;i++) buf+="\n"+out[i];
		return buf;
	}
	
	static int getId(int[] ids, int a, int b){
		if(a==b) return a;
		//~ System.out.println("a,b:"+a+","+b);
		return getId(ids,b,ids[b]);
	}
	
	static int getFlowDir(int[][] m, int y, int x){
		int[] dx = {0,0,-1,1,0};
		int[] dy = {0,-1,0,0,1};
		int out = 0;
		int ch = m[y][x];
		for(int i=1;i<dx.length;i++){
			int cy = dy[i]+y;
			int cx = dx[i]+x;
			if(cy>=0 && cy<m.length && cx>=0 && cx<m[0].length){
				if(ch>m[cy][cx]){
					ch = m[cy][cx];
					out = i;
				}
			}
		}
		return out;
	}
	
	static String toFnOut(String fn){
		if(fn.lastIndexOf('.')!=-1){
			return fn.substring(0,fn.lastIndexOf('.'))+".out";
		}else return fn + ".out";
	}
}
