package mine_sweeper;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.LinkedList;



public class Solution {
	
	private ArrayList<MineSweeperTestCase> testCases;
	
	public Solution(){
		this.testCases = new ArrayList<MineSweeperTestCase>();
	}
	
	public void solveProblems(String filePath) throws IOException{
		loadTestCases(filePath);
		for(MineSweeperTestCase testCase : testCases){
			solveTestCase(testCase);
		}
		writeTheOutput();
	}
	
	
	public void solveTestCase(MineSweeperTestCase testCase){
		LinkedList<String> candidateCells = new LinkedList<String>();
		Hashtable<String, Boolean> candidateCellsHash = new Hashtable<String, Boolean>();
		intilaizeCandidateCells(testCase, candidateCells, candidateCellsHash);
		int currentRow=0;
		boolean special = false;
		if(testCase.m == ((testCase.c*testCase.r)-1)){
			special=true;
			for (int i = 0; i < testCase.r; i++) {
				for (int j = 0; j < testCase.c; j++) {
					testCase.map[i][j]='*';
					testCase.m-=1;
				}
			}
			testCase.map[testCase.r-1][testCase.c-1]='c';
		}
		if(special) return;
		boolean dummyFill=false;
		while(testCase.m>=testCase.c && (testCase.r-1)-currentRow>=4){
			for (int i = 0; i < testCase.c; i++) {
				testCase.map[currentRow][i]='*';
				testCase.m-=1;
			}
			dummyFill=true;
			currentRow++;
		}
		int currentCol=0;
		while(testCase.m>=testCase.r-currentRow&& (testCase.c-1)-currentCol>=4){
			for (int i = currentRow; i < testCase.r; i++) {
				testCase.map[i][currentCol]='*';
				testCase.m-=1;
			}
			dummyFill=true;
			currentCol++;
		}
		
		if(dummyFill){
			candidateCells.clear();
			candidateCells.add(0, currentRow+"_"+currentCol);
			candidateCellsHash.put(currentRow+"_"+currentCol, true);
			candidateCells.add(1, currentRow+"_"+(testCase.c-1));
			candidateCellsHash.put(currentRow+"_"+(testCase.c-1), true);
			candidateCells.add(2, (testCase.r-1)+"_"+currentCol);
			candidateCellsHash.put((testCase.r-1)+"_"+currentCol, true);
			candidateCells.add(3, (testCase.r-1)+"_"+(testCase.c-1));
			candidateCellsHash.put((testCase.r-1)+"_"+(testCase.c-1), true);
		}

		while(testCase.m>0){
			int index=0;
			boolean mineIsPlaced=false;
			for(String candidateCell : candidateCells){
				String [] rowCol = candidateCell.split("_");
				int row = Integer.parseInt(rowCol[0]);
				int col = Integer.parseInt(rowCol[1]);
				testCase.map[row][col]='*';
				//get all affected cells if we place the mine at the current candidate cell
				String [] affectedCells = getNeighbors(row, col); 
				//Do all affected cells can be revealed
				boolean canBeRevealed=true;
				for (int i = 0; i < affectedCells.length; i++) {
					String[] array = affectedCells[i].split("_");
					int iRow=Integer.parseInt(array[0]);
					int iCol=Integer.parseInt(array[1]);
					if(iRow < 0 || iRow>=testCase.map.length || iCol<0 || iCol>=testCase.map[0].length || testCase.map[iRow][iCol]!='.')continue;
					if(!isAnyNeighborIsActive(testCase.map, iRow, iCol)) canBeRevealed=false;
				}
				//if all affected cells can be revealed then place the mine here
				if(canBeRevealed){
					mineIsPlaced=true;
					testCase.map[row][col]='*';
					testCase.m -=1;
					candidateCells.remove(index);
					for (int i = 0; i < affectedCells.length; i++) {
						String[] array = affectedCells[i].split("_");
						int iRow=Integer.parseInt(array[0]);
						int iCol=Integer.parseInt(array[1]);
						if(iRow < 0 || iRow>=testCase.map.length || iCol<0 || iCol>=testCase.map[0].length || testCase.map[iRow][iCol]!='.')continue;
						if(!candidateCellsHash.containsKey(affectedCells[i])){
							candidateCells.add(affectedCells[i]);
							candidateCellsHash.put(affectedCells[i], true);
						}
					}
					break;
				}else{
					testCase.map[row][col]='.';
				}
				index++;
			}
			if (!mineIsPlaced) {
				testCase.output="Impossible";
				break;
			}
		}
		putTheClickPoisiton(testCase);
	}
	
	private void putTheClickPoisiton(MineSweeperTestCase testCase){
		boolean isSet=false;
		for (int i = testCase.r-1; i >= 0; i--) {
			for (int j = testCase.c-1; j >= 0; j--) {
				if(isActiveCell(testCase.map, i, j)){
					testCase.map[i][j]='c';
					isSet=true;
					break;
				}
			}
			if(isSet) return;
		}
		
	}
	
	private boolean isAnyNeighborIsActive(char[][] map,int row, int col){
		String [] neighbors = getNeighbors(row, col);
		for (int i = 0; i < neighbors.length; i++) {
			String [] array = neighbors[i].split("_");
			int iRow = Integer.parseInt(array[0]);
			int iCol = Integer.parseInt(array[1]);
			if(iRow < 0 || iRow>=map.length || iCol<0 || iCol>=map[0].length)continue;
			if(isActiveCell(map, iRow, iCol)) return true;
		}
		return false;
	}
	
	private String[] getNeighbors(int row, int col){
		String [] cells = new String[8];
		cells[0]=(row-1)+"_"+(col-1);
		cells[1]=(row-1)+"_"+(col);
		cells[2]=(row-1)+"_"+(col+1);
		cells[3]=(row)+"_"+(col-1);
		cells[4]=(row)+"_"+(col+1);
		cells[5]=(row+1)+"_"+(col-1);
		cells[6]=(row+1)+"_"+(col);
		cells[7]=(row+1)+"_"+(col+1);
		return cells;
	}
	
	private boolean isActiveCell(char [][] map, int i, int j){
		if(i-1>=0 && j-1>=0 && map[i-1][j-1]!='.') return false;
		if(i-1>=0 && map[i-1][j]!='.') return false;
		if(i-1>=0 && j+1<map[0].length && map[i-1][j+1]!='.') return false;
		
		if(j-1>=0 && map[i][j-1]!='.') return false;
		if(map[i][j]!='.')return false;
		if(j+1<map[0].length && map[i][j+1]!='.') return false;
		
		if(i+1<map.length && j-1>=0 && map[i+1][j-1]!='.') return false;
		if(i+1<map.length && map[i+1][j]!='.') return false;
		if(i+1<map.length && j+1<map[0].length && map[i+1][j+1]!='.') return false;
		return true;
	}
	
	private void intilaizeCandidateCells(MineSweeperTestCase testCase ,LinkedList<String> candidateCells, Hashtable<String, Boolean> candidateCellsHash){
		String corner1="0_0";
		String corner2="0_"+(testCase.c-1);
		String corner3=(testCase.r-1)+"_0";
		String corner4=(testCase.r-1)+"_"+(testCase.c-1);
		if(!candidateCellsHash.containsKey(corner1)){
			candidateCells.add(corner1);
			candidateCellsHash.put(corner1, true);
		}
		if(!candidateCellsHash.containsKey(corner2)){
			candidateCells.add(corner2);
			candidateCellsHash.put(corner2, true);
		}
		if(!candidateCellsHash.containsKey(corner3)){
			candidateCells.add(corner3);
			candidateCellsHash.put(corner3, true);
		}
		if(!candidateCellsHash.containsKey(corner4)){
			candidateCells.add(corner4);
			candidateCellsHash.put(corner4, true);
		}
	}
	
	private void writeTheOutput() throws FileNotFoundException, UnsupportedEncodingException{
		PrintWriter writer = new PrintWriter("output.txt", "UTF-8");
		for (MineSweeperTestCase testcase : testCases) {
			writer.println("Case #"+testcase.id+":");
			if(testcase.output.equalsIgnoreCase("Impossible")){
				writer.println(testcase.output);
			}else{
				for (int i = 0; i < testcase.r; i++) {
					for (int j = 0; j < testcase.c; j++) {
						writer.print(testcase.map[i][j]);
					}
					writer.println();
				}
			}
		}
		writer.close();
		
	}
	
	private void loadTestCases(String filePath) throws IOException{
		BufferedReader br = new BufferedReader(new FileReader(filePath));
	    try {
	        int numberOfTestCases = Integer.parseInt(br.readLine());
	        for (int i = 1; i <= numberOfTestCases; i++) {
	        	String [] tokens = br.readLine().split(" ");
	        	MineSweeperTestCase testCase = new MineSweeperTestCase(Integer.parseInt(tokens[0]), Integer.parseInt(tokens[1]), Integer.parseInt(tokens[2]));
	        	testCase.id = i;
	        	testCases.add(testCase);
			}
	    } finally {
	        br.close();

	    }
	}

	
	public static void main(String[] args) throws IOException {
		String filePath = "C-small-attempt1.in";
		MineSweeperTestCase testCase = new MineSweeperTestCase(5, 1,2);
		Solution solution = new Solution();

		solution.solveProblems(filePath);
	}

}
