import java.io.*;
import java.util.*;

public class Main {

    /* IO */
    InputReader in;
    BufferedWriter out;
    StringTokenizer tok;
    StringBuilder ans;

    /* FIELDS */
    private int n;
    double[] speed, max;
    double[][] g;
    int[] qFrom, qTo;
    List<Edge> next[];
    private int nQueries;

    public static void main(String[] args) throws IOException {
        Main sol = new Main();
        sol.begin();
    }

    private void begin() throws IOException {
        // io
        boolean file = true;
        if (file)
            in = new InputReader(new FileInputStream("C-large (1).in"));
        else
            in = new InputReader(System.in);
        ans = new StringBuilder();


        int nCases = in.nextInt();
        for (int cas = 1; cas <= nCases; cas++) {
            System.out.println(cas);
            n = in.nextInt();
            nQueries = in.nextInt();
            speed = new double[n];
            max = new double[n];
            g = new double[n][n];
            for (int i = 0; i < n; i++) {
                max[i] = in.nextInt();
                speed[i] = in.nextInt();
            }
            for (int i = 0; i < n; i++)
                for (int j = 0; j < n; j++)
                    g[i][j] = in.nextInt();
            qFrom = new int[nQueries];
            qTo = new int[nQueries];
            for (int i = 0; i < nQueries; i++) {
                qFrom[i] = in.nextInt() - 1;
                qTo[i] = in.nextInt() - 1;
            }
            String solution = solve();
            ans.append(String.format("Case #%d: %s\n", cas, solution));
        }
        System.out.println(ans.toString());

        // output to file
        out = new BufferedWriter(new FileWriter("output.txt"));
        out.write(ans.toString());
        out.flush();
        out.close();
    }

    private String solve() {
        formGraph();
        StringBuilder strb = new StringBuilder();
        for (int q = 0; q < nQueries; q++)
            strb.append(String.format("%.12f ", getMinDist(qFrom[q], qTo[q])));
        return strb.toString();
    }

    private double getMinDist(int source, int dest) {
        double[] dist = new double[n];
        TreeSet<Integer> pq = new TreeSet<Integer>(Comparator.comparingDouble(o -> dist[o]));
        double MAX = 10000000000000000.0;
        Arrays.fill(dist, MAX);
        dist[source] = 0;
        pq.add(source);
        while (!pq.isEmpty()) {
            int node = pq.pollFirst();
            for (Edge e : next[node])
                if (dist[e.dest] > dist[node] + e.weight) {
                    pq.remove(e.dest);
                    dist[e.dest] = dist[node] + e.weight;
                    pq.add(e.dest);
                }
        }

        return dist[dest];
    }

    private void formGraph() {
        next = new List[n];
        for (int i = 0; i < n; i++)
            next[i] = new ArrayList<>();

        for (int source = 0; source < n; source++) {
            addEdges(source);
        }
    }

    private void addEdges(int source) {
        double[] dist = new double[n];
        TreeSet<Integer> pq = new TreeSet<Integer>(Comparator.comparingDouble(o -> dist[o]));
        double MAX = 1000000000000000.0;
        Arrays.fill(dist, MAX);
        dist[source] = 0;
        pq.add(source);
        while (!pq.isEmpty()) {
            int node = pq.pollFirst();
            for (int next = 0; next < n; next++)
                if (g[node][next] != -1 &&
                        dist[next] > dist[node] + g[node][next]) {
                    pq.remove(next);
                    dist[next] = dist[node] + g[node][next];
                    pq.add(next);
                }
        }

        for (int i = 0; i < n; i++)
            if (i != source
                    && dist[i] != MAX
                    && dist[i] <= max[source])
                next[source].add(new Edge(i, dist[i] / speed[source]));


    }

    class Edge {
        int dest;
        double weight;

        public Edge(int dest, double weight) {
            this.dest = dest;
            this.weight = weight;
        }
    }
}

class InputReader {
    BufferedReader reader;
    StringTokenizer tok;

    public InputReader(InputStream stream) {
        reader = new BufferedReader(new InputStreamReader(stream), 32768);
        tok = new StringTokenizer("");
    }

    public String next() {
        while (!tok.hasMoreTokens())
            try {
                tok = new StringTokenizer(reader.readLine());
            } catch (IOException e) {
                e.printStackTrace();
            }
        return tok.nextToken();
    }

    public int nextInt() {
        return Integer.parseInt(next());
    }
}