import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.math.BigInteger;
import java.nio.charset.Charset;
import java.util.Arrays;
import java.util.HashMap;

public class CodeJam3
{
	private static final class ByteArrayWrapper
	{
		private final byte[] data;

		public ByteArrayWrapper(byte[] data)
		{
			if (data == null)
			{
				throw new NullPointerException();
			}
			this.data = data;
		}

		@Override
		public boolean equals(Object other)
		{
			if (!(other instanceof ByteArrayWrapper))
			{
				return false;
			}
			return Arrays.equals(data, ((ByteArrayWrapper) other).data);
		}

		@Override
		public int hashCode()
		{
			return Arrays.hashCode(data);
		}
	};

	private static class BI
	{
		static HashMap<ByteArrayWrapper, BigInteger> squareMap;
		static HashMap<ByteArrayWrapper, BigInteger> squareRootMap;

		static
		{
			squareMap = new HashMap<ByteArrayWrapper, BigInteger>();
			squareRootMap = new HashMap<ByteArrayWrapper, BigInteger>();
		}

		private static BigInteger computeSquareRoot(BigInteger input)
		{
			if (input.compareTo(BigInteger.ZERO) == 0)
				return BigInteger.ZERO;

			BigInteger n1 = input.shiftRight(1).add(BigInteger.ONE);
			BigInteger n2 = n1.add(input.divide(n1)).shiftRight(1);
			int guess = 0;
			while (n2.compareTo(n1) < 0)
			{
				n1 = n2;
				n2 = n1.add(input.divide(n1)).shiftRight(1);
				guess++;
			}
			// System.out.println("#guesses = " + guess);
			return n1;
		}

		private static BigInteger computeSquare(BigInteger input)
		{
			return input.pow(2);
		}

		static BigInteger squareRoot(BigInteger input)
		{
			ByteArrayWrapper inputKey = new ByteArrayWrapper(input.toByteArray());
			if (squareRootMap.containsKey(inputKey))
			{
				return squareRootMap.get(inputKey);
			}
			BigInteger root = computeSquareRoot(input);
			// squareRootMap.put(new ByteArrayWrapper(input.toByteArray()), root);
			// squareMap.put(new ByteArrayWrapper(root.toByteArray()), new BigInteger(input.toByteArray()));
			return root;
		}

		static BigInteger square(BigInteger input)
		{
			ByteArrayWrapper inputKey = new ByteArrayWrapper(input.toByteArray());
			if (squareMap.containsKey(inputKey))
			{
				return squareMap.get(inputKey);
			}
			BigInteger square = computeSquare(input);
			// squareMap.put(new ByteArrayWrapper(input.toByteArray()), square);
			// squareRootMap.put(new ByteArrayWrapper(square.toByteArray()), new BigInteger(input.toByteArray()));
			// System.out.println(count++);
			return square;
		}

		static int count = 1;

		public static boolean isPalindrome(BigInteger root)
		{
			String str = root.toString();
			int i1 = 0;
			int i2 = str.length() - 1;
			while (i2 > i1)
			{
				if (str.charAt(i1) != str.charAt(i2))
				{
					return false;
				}
				++i1;
				--i2;
			}
			return true;
		}
	};

	private static class FairSquareCheck
	{
		BigInteger lower;
		BigInteger higher;

		FairSquareCheck(String lower, String higher)
		{
			this.lower = new BigInteger(lower);
			this.higher = new BigInteger(higher);
			if (this.lower.compareTo(this.higher) > 0)
			{
				BigInteger temp = this.lower;
				this.lower = this.higher;
				this.higher = temp;
			}
		}

		public int result()
		{
			BigInteger root = BI.squareRoot(lower);
			BigInteger square = BI.computeSquare(root);
			int numMatches = 0;
			while (higher.compareTo(square) >= 0)
			{
				if (lower.compareTo(square) <= 0 && BI.isPalindrome(root) && BI.isPalindrome(square))
				{
					// System.out.println("Found a fair and square : " + square + ", root = " + root);
					numMatches++;
				}
				root = root.add(BigInteger.ONE);
				square = BI.square(root);
				// count++;
				// if (count % 10 == 0)
				// System.out.println(count++);
			}
			return numMatches;
		}

		static int count = 0;

		/*
		 * (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString()
		{
			StringBuilder builder = new StringBuilder();
			builder.append("FairSquareCheck [lower=");
			builder.append(lower);
			builder.append(", higher=");
			builder.append(higher);
			builder.append("]");
			return builder.toString();
		}
	};

	private InputStream inputStream;
	private boolean isParsed = false;
	private int numTests;
	private FairSquareCheck[] fairSquare;

	public CodeJam3(String filename) throws IOException
	{
		File file = new File(filename);
		if (!file.exists())
			throw new RuntimeException("could not open file " + filename);

		inputStream = new FileInputStream(filename);
	}

	public void parse() throws IOException
	{
		if (isParsed)
			return;

		BufferedReader br = new BufferedReader(new InputStreamReader(inputStream, Charset.forName("UTF-8")));
		String line = br.readLine();
		numTests = Integer.parseInt(line);
		fairSquare = new FairSquareCheck[numTests];

		for (int i = 0; i < numTests; i++)
		{
			line = br.readLine();
			String[] split = line.split(" ");

			fairSquare[i] = new FairSquareCheck(split[0], split[1]);
		}
		isParsed = true;
	}

	public int getNumTests()
	{
		return numTests;
	}

	public int checkTest(int i)
	{
		// System.out.println(fairSquare[i].toString());
		return fairSquare[i].result();
	}

	public static void main(String[] args)
	{
		try
		{
			CodeJam3 jam = new CodeJam3("/tmp/C-small-attempt0.in");
			OutputStream outputStream = new FileOutputStream("/tmp/result.out");
			jam.parse();
			for (int i = 0; i < jam.getNumTests(); i++)
			{
				String result = "Case #" + (i + 1) + ": " + jam.checkTest(i) + "\n";
				outputStream.write(result.getBytes());
				System.out.print(result);
			}
			outputStream.close();
		}
		catch (IOException e)
		{
			System.out.println("Exception occured" + e.getMessage());
		}
	}
}
