import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.nio.charset.Charset;
import java.util.LinkedList;

public class CodeJam2
{
	private static class Lawn
	{
		int[][] desiredSize;
		int[][] desiredSizeOther;
		int row;
		int column;

		Lawn(int row, int column)
		{
			this.row = row;
			this.column = column;
			desiredSize = new int[row][column];
			desiredSizeOther = new int[column][row];
		}

		public void addRow(int row, String line)
		{
			String[] split = line.split(" ");
			for (int col = 0; col < this.column; col++)
			{
				int val = Integer.parseInt(split[col]);
				desiredSize[row][col] = val;
				desiredSizeOther[col][row] = val;
			}
		}

		/*
		 * (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString()
		{
			StringBuilder builder = new StringBuilder();
			builder.append("Lawn [desiredSize= {\n");
			for (int r = 0; r < row; r++)
			{
				builder.append("    ");
				for (int c = 0; c < column; c++)
				{
					if (c > 0)
						builder.append(", ");
					builder.append(desiredSize[r][c]);
				}
				builder.append("\n");
			}
			builder.append("}");
			builder.append(", row=");
			builder.append(row);
			builder.append(", column=");
			builder.append(column);
			builder.append("]");
			return builder.toString();
		}

		private boolean checkRowWise(int row, int column)
		{
			int val = desiredSize[row][column];
			for (int c = 0; c < this.column; c++)
			{
				if (desiredSize[row][c] > val)
				{
					return false;
				}
				if (desiredSize[row][c] < val)
				{
					boolean check = checkColumnWise(row, c);
					if (!check)
						return false;
				}
			}
			return true;
		}

		private boolean checkColumnWise(int row, int column)
		{
			int val = desiredSize[row][column];
			for (int r = 0; r < this.row; r++)
			{
				if (desiredSize[r][column] > val)
				{
					return false;
				}
				if (desiredSize[r][column] < val)
				{
					boolean check = checkRowWise(r, column);
					if (!check)
						return false;
				}
			}
			return true;
		}

		public boolean result()
		{
			for (int r = 0; r < row; r++)
			{
				int min = 100;
				LinkedList<Integer> minColumns = new LinkedList<Integer>();
				for (int c = 0; c < column; c++)
				{
					if (min > desiredSize[r][c])
					{
						min = desiredSize[r][c];
						minColumns = new LinkedList<Integer>();
						minColumns.add(c);
					}
					else if (min == desiredSize[r][c])
					{
						minColumns.add(c);
					}
				}
				if (minColumns.size() != this.column)
				{
					for (Integer minColumn : minColumns)
					{
						if (!(checkRowWise(r, minColumn) || checkColumnWise(r, minColumn)))
							return false;
					}
				}
			}
			return true;
		}
	};

	private InputStream inputStream;
	private boolean isParsed = false;
	private int numTests;
	private Lawn[] lawns;

	public CodeJam2(String filename) throws IOException
	{
		File file = new File(filename);
		if (!file.exists())
			throw new RuntimeException("could not open file " + filename);

		inputStream = new FileInputStream(filename);
	}

	public void parse() throws IOException
	{
		if (isParsed)
			return;

		BufferedReader br = new BufferedReader(new InputStreamReader(inputStream, Charset.forName("UTF-8")));
		String line = br.readLine();
		numTests = Integer.parseInt(line);
		lawns = new Lawn[numTests];

		for (int i = 0; i < numTests; i++)
		{
			line = br.readLine();
			String[] split = line.split(" ");
			int row = Integer.parseInt(split[0]);
			int column = Integer.parseInt(split[1]);

			lawns[i] = new Lawn(row, column);
			for (int n = 0; n < row; n++)
			{
				lawns[i].addRow(n, br.readLine());
			}
			// System.out.println(lawns[i].toString());
		}
		isParsed = true;
	}

	public int getNumTests()
	{
		return numTests;
	}

	public boolean checkTest(int i)
	{
		System.out.println(lawns[i].toString());
		return lawns[i].result();
	}

	public static void main(String[] args)
	{
		try
		{
			CodeJam2 jam = new CodeJam2("/tmp/B-large.in");
			OutputStream outputStream = new FileOutputStream("/tmp/result.out");
			jam.parse();
			for (int i = 0; i < jam.getNumTests(); i++)
			{
				String result = "Case #" + (i + 1) + ": " + (jam.checkTest(i) ? "YES" : "NO") + "\n";
				outputStream.write(result.getBytes());
				System.out.print(result);
			}
			outputStream.close();
		}
		catch (IOException e)
		{
			System.out.println("Exception occured" + e.getMessage());
		}
	}
}
