import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.nio.charset.Charset;
import java.util.Arrays;

public class CodeJam1
{
	private static class Board
	{
		private static enum CellType
		{
			X, O, T, E,
		};

		private CellType[][] layout;
		private CellType[][] layoutOther;
		private CellType[] firstLine;
		private CellType[] secondLine;
		private CellType[] thirdLine;
		private CellType[] fourthLine;
		private CellType[] diagonal1;
		private CellType[] diagonal2;
		private boolean completed = true;
		private String result;

		Board()
		{
			firstLine = init();
			secondLine = init();
			thirdLine = init();
			fourthLine = init();
			diagonal1 = init();
			diagonal2 = init();

			layout = new CellType[4][];
			layout[0] = init();
			layout[1] = init();
			layout[2] = init();
			layout[3] = init();

			layoutOther = new CellType[4][];
			layoutOther[0] = init();
			layoutOther[1] = init();
			layoutOther[2] = init();
			layoutOther[3] = init();
		}

		private CellType[] init()
		{
			CellType[] ret = new CellType[4];
			ret[0] = CellType.E;
			ret[1] = CellType.E;
			ret[2] = CellType.E;
			ret[3] = CellType.E;
			return ret;
		}

		void addRow(int row, String line)
		{
			// System.out.println(row + ": " + line);
			for (int column = 0; column < 4; column++)
				addCell(row, column, line.charAt(column));
		}

		void addCell(int row, int column, char cellChar)
		{
			CellType cellType = getCellType(cellChar);
			if (row == 0)
				firstLine[column] = cellType;
			else if (row == 1)
				secondLine[column] = cellType;
			else if (row == 2)
				thirdLine[column] = cellType;
			else if (row == 3)
				fourthLine[column] = cellType;

			if (row == column)
				diagonal1[row] = cellType;
			if (3 - column == row)
				diagonal2[row] = cellType;

			layout[row][column] = cellType;
			layoutOther[column][row] = cellType;
		}

		private CellType getCellType(char cellChar)
		{
			switch (cellChar)
			{
				case 'X' :
					return CellType.X;
				case 'O' :
					return CellType.O;
				case 'T' :
					return CellType.T;
				case '.' :
					completed = false;
					return CellType.E;
			}
			throw new RuntimeException("could not convert cell type " + cellChar);
		}

		public String result()
		{
			// System.out.println(this);
			for (int i = 0; i < 4; i++)
			{
				if (result != null)
					break;
				result = check(layout[i]);
			}
			for (int i = 0; i < 4; i++)
			{
				if (result != null)
					break;
				result = check(layoutOther[i]);
			}
			if (result == null)
				result = check(diagonal1);
			if (result == null)
				result = check(diagonal2);
			if (result == null)
			{
				if (completed)
					result = "Draw";
				else
					result = "Game has not completed";
			}
			return result;
		}

		private boolean check(CellType cell, CellType cellType)
		{
			if (cell == cellType || cell == CellType.T)
				return true;
			return false;
		}

		private String check(CellType[] cellArray)
		{
			if (check(cellArray[0], CellType.O) && check(cellArray[1], CellType.O) && check(cellArray[2], CellType.O)
			        && check(cellArray[3], CellType.O))
			{
				return "O won";
			}
			if (check(cellArray[0], CellType.X) && check(cellArray[1], CellType.X) && check(cellArray[2], CellType.X)
			        && check(cellArray[3], CellType.X))
			{
				return "X won";
			}
			return null;
		}

		/*
		 * (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString()
		{
			StringBuilder builder = new StringBuilder();
			builder.append("Board [firstLine=");
			builder.append(Arrays.toString(firstLine));
			builder.append(", secondLine=");
			builder.append(Arrays.toString(secondLine));
			builder.append(", thirdLine=");
			builder.append(Arrays.toString(thirdLine));
			builder.append(", fourthLine=");
			builder.append(Arrays.toString(fourthLine));
			builder.append(", diagonal1=");
			builder.append(Arrays.toString(diagonal1));
			builder.append(", diagonal2=");
			builder.append(Arrays.toString(diagonal2));
			builder.append(", result=");
			builder.append(result);
			builder.append("]");
			return builder.toString();
		}
	};

	private InputStream inputStream;
	private boolean isParsed = false;
	private int numTests;
	private Board[] boards;

	public CodeJam1(String filename) throws IOException
	{
		File file = new File(filename);
		if (!file.exists())
			throw new RuntimeException("could not open file " + filename);

		inputStream = new FileInputStream(filename);
	}

	public void parse() throws IOException
	{
		if (isParsed)
			return;

		BufferedReader br = new BufferedReader(new InputStreamReader(inputStream, Charset.forName("UTF-8")));
		String line = br.readLine();
		numTests = Integer.parseInt(line);
		boards = new Board[numTests];
		int currentBoard = 0;

		for (int i = 0; i < numTests; i++)
		{
			boards[i] = new Board();
			boards[i].addRow(0, br.readLine());
			boards[i].addRow(1, br.readLine());
			boards[i].addRow(2, br.readLine());
			boards[i].addRow(3, br.readLine());
			br.readLine();
			// System.out.println(boards[currentBoard].toString());
		}
		isParsed = true;
	}

	public int getNumTests()
	{
		return numTests;
	}

	public String checkTest(int i)
	{
		return boards[i].result();
	}

	public static void main(String[] args)
	{
		try
		{
			CodeJam1 jam1 = new CodeJam1("/tmp/A-large.in");
			OutputStream outputStream = new FileOutputStream("/tmp/result.out");
			jam1.parse();
			for (int i = 0; i < jam1.getNumTests(); i++)
			{
				String result = "Case #" + (i + 1) + ": " + jam1.checkTest(i) + "\n";
				outputStream.write(result.getBytes());
				System.out.print(result);
			}
			outputStream.close();
		}
		catch (IOException e)
		{
			System.out.println("Exception occured" + e.getMessage());
		}
	}

}
