import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Stack;

class Cell {
	public int x, y;
	public Cell (int x, int y) {
		this.x = x;
		this.y = y;
	}
}

public class Watersheds {
	private static final String inputFile = "B-large.in";
	private static final String outputFile = "output.txt";
	
	private static int H, W;
	
	private static int[][] map;
	private static char[][] answer;
	
	private static Cell findMinNeighbor(int i, int j) {
		int minAlt = -1, minI = -1, minJ = -1;
		if (i > 0 && map[i-1][j] < map[i][j]) {
			minAlt = map[i-1][j];
			minI = i-1;
			minJ = j;
		}
		if (j > 0 && map[i][j-1] < map[i][j] && (map[i][j-1] < minAlt || minAlt == -1)) {
			minAlt = map[i][j-1];
			minI = i;
			minJ = j-1;
		}
		if (j < W-1 && map[i][j+1] < map[i][j] && (map[i][j+1] < minAlt || minAlt == -1)) {
			minAlt = map[i][j+1];
			minI = i;
			minJ = j+1;
		}
		if (i < H-1 && map[i+1][j] < map[i][j] && (map[i+1][j] < minAlt || minAlt == -1)) {
			minAlt = map[i+1][j];
			minI = i+1;
			minJ = j;
		}
		if (minAlt == -1)
			return null;
		else
			return new Cell(minI, minJ);
	}

	public static void main(String[] args) throws IOException {
		BufferedReader reader = new BufferedReader(new FileReader(inputFile));
		
		String line = reader.readLine();
		int T = Integer.parseInt(line);
		
		BufferedWriter writer = new BufferedWriter(new FileWriter(outputFile));
		for (int x=1; x<=T; x++) {
			line = reader.readLine();
			String[] lineParts = line.split(" ");
			H = Integer.parseInt(lineParts[0]);
			W = Integer.parseInt(lineParts[1]);
			map = new int[H][W];
			answer = new char[H][W];
			for (int i = 0; i < H; i++) {
				line = reader.readLine();
				lineParts = line.split(" ");
				for (int j = 0; j < W; j++)
					map[i][j] = Integer.parseInt(lineParts[j]);
			}
			
			char currentChar = 'a';
			for (int i = 0; i < H; i++) {
				for (int j = 0; j < W; j++) {
					if (answer[i][j] != 0)
						continue;
					
					Stack<Cell> stack = new Stack<Cell>();
					stack.add(new Cell(i,j));
					Cell minNeighbor = findMinNeighbor(i, j);
					
					while (minNeighbor != null && answer[minNeighbor.x][minNeighbor.y] == 0) {
						stack.add(minNeighbor);
						minNeighbor = findMinNeighbor(minNeighbor.x, minNeighbor.y);
					}
					
					char charToMark;
					if (minNeighbor == null) {
						// We came to a new sink
						charToMark = currentChar;
						currentChar++;
					}
					else {
						// We came to one of the known cells
						charToMark = answer[minNeighbor.x][minNeighbor.y];
					}
					
					while (!stack.empty()) {
						Cell cell = stack.pop();
						answer[cell.x][cell.y] = charToMark;
					}
				}
			}
			
			writer.write("Case #" + x + ":\n");
			for (int i = 0; i < H; i++) {
				for (int j = 0; j < W; j++) {
					writer.write(answer[i][j]);
					if (j < W-1)
						writer.write(" ");
				}
				if (i < H-1 || x < T)
					writer.write("\n");
			}
		}
		reader.close();
		writer.close();
	}

}

