package com.ajasuja.codejam.y2016.round0;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.ajasuja.codejam.AbstractCodeJamSolution;

public class Pancakes extends AbstractCodeJamSolution {

	private Map<String, Integer> pattern2FlipCount = new HashMap<String, Integer>();
	
	public void run(String inputFilePath, String outputFilePath) {
		List<String> positions = new ArrayList<String>();
		List<String> inputLines = this.readInput(inputFilePath);
		for (int i=1; i< inputLines.size(); i++) {
			this.pattern2FlipCount.clear();
			String pancakes = inputLines.get(i).trim();
			String minimumFlipsOutput = String.valueOf(this.minimumFlips(pancakes));
			positions.add(minimumFlipsOutput);
//			System.out.println(pancakes + " ==="+ minimumFlipsOutput);
		}
		this.write(outputFilePath, this.decorateOutput(positions));
	}

	public int minimumFlips(String pancakes) {
		return this.minimumFlips(pancakes, new HashSet<String>());
	}
	
	public int minimumFlips(String pancakes, Set<String> alreadyEncounterdPancakes) {
		if (pattern2FlipCount.containsKey(pancakes)) {
			return pattern2FlipCount.get(pancakes);
		}
		if (alreadyEncounterdPancakes.contains(pancakes)) {
			return Integer.MAX_VALUE;
		}
		if (areAllHappy(pancakes)) {
			return 0;
		} else if (allSadOnTop(pancakes)) {
			return 1;
		} else if (allHappyOnTop(pancakes)) {
			return 2;
		}
		char[] pancakesCharacters = pancakes.toCharArray();
		int minimumFlips = Integer.MAX_VALUE;
		List<Path> nextLevelPancakePaths = new ArrayList<Path>();
		for (int i=1; i<= pancakesCharacters.length; i++) {
			String prefixPancakes = pancakes.substring(0, i);
			String flippedPrefixPancakes = flip(prefixPancakes);
			String suffixPancakes = pancakes.substring(i);
			String afterFlipPancakes = flippedPrefixPancakes + suffixPancakes;
			Set<String> alreadyVisitedPaths = new HashSet<String>(alreadyEncounterdPancakes);
			alreadyVisitedPaths.add(pancakes);
			nextLevelPancakePaths.add(new Path(afterFlipPancakes, alreadyVisitedPaths));
		}
		for (Path nextLevelPath : nextLevelPancakePaths) {
			int numberOfFlips = 1 + this.minimumFlips(nextLevelPath.getPancake(), 
					nextLevelPath.getAlreadyVisitedPancakes());
			if (numberOfFlips > 0 && numberOfFlips < minimumFlips) {
				minimumFlips = numberOfFlips;
			}
		}
		pattern2FlipCount.put(pancakes, minimumFlips);
		return minimumFlips;
	}

	public boolean allHappyOnTop(String pancakes) {
		char[] pancakeCharacters = pancakes.toCharArray();
		boolean isSadEncountered = false;
		for (Character pancakeCharacter : pancakeCharacters) {
			if (pancakeCharacter == '-') {
				isSadEncountered = true;
			} else {
				if (isSadEncountered) {
					return false;
				}
			}
		}
		return true;
	}

	public boolean allSadOnTop(String pancakes) {
		char[] pancakeCharacters = pancakes.toCharArray();
		boolean isHappyEncountered = false;
		for (Character pancakeCharacter : pancakeCharacters) {
			if (pancakeCharacter == '+') {
				isHappyEncountered = true;
			} else {
				if (isHappyEncountered) {
					return false;
				}
			}
		}
		return true;
	}

	public String flip(String prefixPancakes) {
		char[] flippedPancakes = new char[prefixPancakes.length()];
		char[] pancakes = prefixPancakes.toCharArray();
		for (int i=pancakes.length -1, j=0; i>=0; i--,j++) {
			flippedPancakes[j] = flip(pancakes[i]);
		}
		return String.valueOf(flippedPancakes);
	}

	public char flip(char c) {
		if (c == '+') {
			return '-';
		} 
		return '+';
	}

	public boolean areAllHappy(String pancakes) {
		char[] pancakesCharacters = pancakes.toCharArray();
		for (Character pancakesCharacter :  pancakesCharacters) {
			if (pancakesCharacter == '-')  {
				return false;
			}
		}
		return true;
	}
}

class Path {
	private String pancake;
	private Set<String> alreadyVisitedPancakes = new HashSet<String>();
	public Path(String pancake, Set<String> alreadyVisitedPancakes) {
		this.pancake = pancake;
		this.alreadyVisitedPancakes = alreadyVisitedPancakes;
	}
	public String getPancake() {
		return pancake;
	}
	public void setPancake(String pancake) {
		this.pancake = pancake;
	}
	public Set<String> getAlreadyVisitedPancakes() {
		return alreadyVisitedPancakes;
	}
	public void setAlreadyVisitedPancakes(Set<String> alreadyVisitedPancakes) {
		this.alreadyVisitedPancakes = alreadyVisitedPancakes;
	}
	
	public void addAlreadyVisitedPancake(String alreadyVisitedPancake) {
		this.alreadyVisitedPancakes.add(alreadyVisitedPancake);
	}
	
}
