package com.ajasuja.codejam;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class AbstractCodeJamSolution {

	public InputStream readInputStreamFromClassPath(String inputFileClassPath) {
		return this.getClass().getResourceAsStream(inputFileClassPath);
	}

	public InputStream readInputStreamFromFullPath(String inputFileFullPath) {
		try {
			return new FileInputStream(inputFileFullPath);
		} catch (FileNotFoundException e) {
			throw new CodeJamRuntimeException("file not found  at :  " + inputFileFullPath, e);
		}
	}
	
	public List<String> readInput(String filePath) {
		InputStream inputStream = this.readInputStreamFromClassPath(filePath);
		if (inputStream == null) {
			inputStream = this.readInputStreamFromFullPath(filePath);
		} 
		Scanner cin = new Scanner(inputStream);
		List<String> inputLines = new ArrayList<String>();
		try {
			while(cin.hasNextLine()) {
				inputLines.add(cin.nextLine());
			}			
		} finally {
			cin.close();
		}
		return inputLines;
	}

	public String decorateOutput(List<String> outputs) {
		StringBuilder stringBuilder = new StringBuilder();
		String lineSeparator = System.getProperty("line.separator");
		for (int i=0; i < outputs.size(); i++) {
			stringBuilder.append("Case #").append(i+1).append(": ").append(outputs.get(i));
			if (i != outputs.size() -1 ) {
				stringBuilder.append(lineSeparator);
			}
		}
		return stringBuilder.toString();
	}

	public void write(String outputFilePath, String content) throws CodeJamRuntimeException {
		File file = new File(outputFilePath);
		if(!file.exists()) {
		    try {
		    	file.getParentFile().mkdirs();
				file.createNewFile();
			} catch (IOException e) {
				String message = String.format("can't create file at path [%s]", outputFilePath);
				throw new CodeJamRuntimeException(message, e);
			}
		}		
		PrintWriter writer;
		try {
			writer = new PrintWriter(file, "UTF-8");
		} catch (FileNotFoundException e) {
			String message = String.format("file not found at path [%s]", outputFilePath);
			throw new CodeJamRuntimeException(message, e);
		} catch (UnsupportedEncodingException e) {
			String message = String.format("unsupported encoding for file [%s]", outputFilePath);
			throw new CodeJamRuntimeException(message, e);
		}
		writer.println(content);
		writer.close();
	}
	
	
	protected List<Integer> toIntegerList(String[] stringArray) {
		List<Integer> integerList = new ArrayList<Integer>();
		for (String eachString : stringArray) {
			integerList.add(this.toInteger(eachString));
		}
		return integerList;
	}

	protected Integer toInteger(String eachString) {
		return Integer.parseInt(eachString.trim());
	}
	protected Long toLong(String eachString) {
		return Long.parseLong(eachString.trim());
	}

}
