import java.io.*;
import java.util.*;
import static java.lang.System.*;

public class C {
    static int w, h, b;
    public static class Edge {
        int u, v, c, flow;
        public Edge(int u, int v, int c) {
            this.u = u;
            this.v = v;
            this.c = c;
            flow = 0;
        }
        public int other(int x) {
            if (x == u) {
                return v;
            }
            return u;
        }
        public int capFrom(int x) {
            if (x == u) {
                return c-flow;
            }
            return flow;
        }
        public int capTo(int x) {
            if (x == v) {
                return c-flow;
            }
            return flow;
        }
        public void flowFrom(int x, int amt) {
            if (x == u) {
                flow += amt;
            }
            else {
                flow -= amt;
            }
        }
        public void flowTo(int x, int amt) {
            if (x == v) {
                flow += amt;
            }
            else {
                flow -= amt;
            }   
        }
    }
    public static class AdjList extends LinkedList<Edge>{}
    public static class Graph {
        AdjList[] adj;
        Edge[] pred;
        boolean[] visited;
        int n;
        public Graph(int n) {
            this.n = n;
            adj = new AdjList[n];
            for (int i = 0; i < n; i++) {
                adj[i] = new AdjList();
            }
        }
        public void createEdge(int u, int v, int c) {
            Edge e = new Edge(u, v, c);
            adj[u].add(e);
            adj[v].add(e);
        }
        public boolean bfs(int source, int sink) {
            LinkedList<Integer> q = new LinkedList<Integer>();
            q.addLast(source);
            visited[source] = true;
            while (q.size() != 0) {
                int u = q.removeFirst();
                for (Edge e : adj[u]) {
                    int v = e.other(u);
                    if (e.capTo(v) > 0 && !visited[v]) {
                        pred[v] = e;
                        visited[v] = true;
                        q.addLast(v);
                        if (v == sink) {
                            return true;
                        }
                    }
                }
            }
            return false;
        }
        public int maxflow(int source, int sink) {
            int flow = 0;
            while (true) {
                pred = new Edge[n];
                visited = new boolean[n];
                Arrays.fill(pred, null);
                if (!bfs(source, sink)) {
                    break;
                }
                // out.println("flow = "+flow);
                int t = sink;
                int mincap = 1000000;
                // out.print("path: ");
                // out.print(((t-1)/w)+","+((t-1)%w));
                while (pred[t] != null) {
                    Edge e = pred[t];
                    if (mincap > e.capTo(t)) {
                        mincap = e.capTo(t);
                    }
                    t = e.other(t);
                    // out.print(((t-1)/w)+" "+((t-1)%w)+" ");
                }
                // out.println();
                t = sink;
                while (pred[t] != null) {
                    Edge e = pred[t];
                    e.flowTo(t, mincap);
                    t = e.other(t);
                }
                flow += mincap;
            }
            return flow;
        }
    }
    public static void main(String[] args) {
        Scanner sc = new Scanner(in);
        int t = sc.nextInt();
        for (int kei = 0; kei < t; kei++) {
            w = sc.nextInt();
            h = sc.nextInt();
            b = sc.nextInt();
            Graph g = new Graph(2*(w*h+2));
            boolean[][] building = new boolean[w][h];
            for (int i = 0; i < b; i++) {
                int x0 = sc.nextInt();
                int y0 = sc.nextInt();
                int x1 = sc.nextInt();
                int y1 = sc.nextInt();
                for (int x = x0; x <= x1; x++) {
                    for (int y = y0; y <= y1; y++) {
                        building[x][y] = true;
                    }
                }
            }

            // for (int i = h-1; i >= 0; i--) {
            //     for (int j = 0; j < w; j++) {
            //         out.print(building[j][i]+" ");
            //     }
            //     out.println();
            // }

            for (int i = 0; i < w; i++) {
                for (int j = 0; j < h; j++) {
                    g.createEdge(2*(j*w+i) +2, 2*(j*w+i)+1 +2, 1);
                }
            }
            g.createEdge(0, 1, 1000000);
            g.createEdge(2*w*h+2, 2*w*h+3, 1000000);


            for (int i = 0; i < w; i++) {
                if (!building[i][0]) {
                    g.createEdge(1, 2*i +2, 1);
                }
            }
            for (int i = 0; i < w; i++) {
                if (!building[i][h-1]) {
                    g.createEdge(2*(w*(h-1)+i)+1 +2, 2*(w*h+1), 1);
                }
            }
            // map w,h -> x, y -> (i, j) -> j*w+i
            for (int i = 0; i < w; i++) {
                for (int j = 0; j < h; j++) {
                    if (building[i][j]) {
                        continue;
                    }
                    if (i != 0 && !building[i-1][j]) {
                        g.createEdge(2*(j*w+i)+1 +2, 2*(j*w+(i-1)) +2, 1);
                        // out.printf("Connect (%d,%d) to (%d,%d)\n", i, j, i-1, j);
                    }
                    if (i != w-1 && !building[i+1][j]) {
                        g.createEdge(2*(j*w+i)+1 +2, 2*(j*w+(i+1)) +2, 1);
                        // out.printf("Connect (%d,%d) to (%d,%d)\n", i, j, i+1, j);
                    }
                    if (j != 0 && !building[i][j-1]) {
                        g.createEdge(2*(j*w+i)+1 +2, 2*((j-1)*w+i) +2, 1);
                        // out.printf("Connect (%d,%d) to (%d,%d)\n", i, j, i, j-1);
                    }
                    if (j != h-1 && !building[i][j+1]) {
                        g.createEdge(2*(j*w+i)+1 +2, 2*((j+1)*w+i) +2, 1);
                        // out.printf("Connect (%d,%d) to (%d,%d)\n", i, j, i, j+1);
                    }
                }
            }
            out.printf("Case #%d: %d\n", kei+1, g.maxflow(0, 2*w*h+3));
        }
    }
}