import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Deque;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class BotTrust {
	
	public static enum BotEnum{
		O(new Bot()),
		B(new Bot());
		
		private Bot bot;
		
		private Deque<Task> tasks = new LinkedList<Task>();

		BotEnum(Bot bot){
			this.bot = bot;
		}
		
		public Boolean nextTime(boolean allowPush) {
			return bot.nextTime(allowPush);
		}

		public void setCurrentTask(Task currentTask) {
			bot.setCurrentTask(currentTask);
		}
		
		public void addTask(Task task){
			tasks.add(task);
		}
		
		public Task getLastTask(){
			Task result = tasks.peekLast();
			return result;
		}
		
		public Task getNextTask(){
			Task result = tasks.peekFirst();
			if(result != null){
				tasks.removeFirst();
			}
			return result;
		}

		public static BotEnum getOther(BotEnum bot) {
			BotEnum result = null;
			switch (bot) {
			case O:
				result = B;
				break;
			case B:
				result = O;
				break;
			}
			return result;
		}
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		
		if(args.length == 0 || args[0].isEmpty()){
			System.out.println("please enter filename");
			System.exit(0);
		}
		
		File input = new File(args[0]);
		
		Map<Integer, List<TaskDescr>> tasksMap = readInput(input);
		
		for(Integer lineNumber: tasksMap.keySet()){
			
			List<TaskDescr> tasks = tasksMap.get(lineNumber);
			BotEnum.O.bot = new Bot();
			BotEnum.O.tasks.clear();
			BotEnum.B.bot = new Bot();
			BotEnum.B.tasks.clear();
			
			for(TaskDescr td: tasks){
				BotEnum bot = BotEnum.valueOf(td.getBotName());
				Task task = new Task(bot, td.getTargetButton(), BotEnum.getOther(bot).getLastTask());
				bot.addTask(task);
			}
			
			BotEnum.O.setCurrentTask(BotEnum.O.getNextTask());
			BotEnum.B.setCurrentTask(BotEnum.B.getNextTask());
			
			BotEnum first = (BotEnum.O.bot.getCurrentTask() != null && BotEnum.O.bot.getCurrentTask().getPreviosTask() != null) ? BotEnum.O : BotEnum.B;
			BotEnum second = BotEnum.getOther(first);
			
			int times = 0;
			
			while(true){
				Boolean firstResult = first.nextTime(true);
				Boolean secondResult = second.nextTime(!first.bot.doPush());
				
				if(firstResult == null && secondResult == null){
					break;
				} 
				if (firstResult != null && firstResult){
					first.setCurrentTask(first.getNextTask());
				}
				if (secondResult != null && secondResult){
					second.setCurrentTask(second.getNextTask());
				}
				times++;
			}
			
			System.out.println(String.format("Case #%s: %s", lineNumber, times));
		}
	}

	private static Map<Integer, List<TaskDescr>> readInput(File input) {		
		BufferedReader reader = null;
		try {
			reader = new BufferedReader(new FileReader(input));			
		} catch (FileNotFoundException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
		Map<Integer, List<TaskDescr>> result = new HashMap<Integer, List<TaskDescr>>();
		try {
		String str = reader.readLine();
		//System.out.println("reading line: " + 0 + " value:" + str);
			int lineNum = 1;
			while((str = reader.readLine()) != null){
				//System.out.println("reading line: " + lineNum + " value:" + str);
				List<TaskDescr> resultList = new ArrayList<TaskDescr>();
				String[] strArr = str.split(" ");
				for (int i = 1; i < strArr.length; i++) {
					String name = strArr[i];
					i++;
					int targetButton = Integer.parseInt(strArr[i]);
					resultList.add(new TaskDescr(name, targetButton));
				}
				result.put(lineNum, resultList);
				lineNum ++;
			}
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} finally {
			try {
				reader.close();
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		
		//System.out.println(result);
		
		return result;
	}
}