package codejam;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class Milkshake {
	public static void main(String[] args) throws Exception {
	   parseFile(new File("C:/Documents and Settings/Alan/Desktop/B-small-attempt0.in"));
	}
			  
		
	public static void parseFile(File f) throws Exception {
		BufferedReader reader = new BufferedReader(new FileReader(f));
		int numTestCases = Integer.parseInt(reader.readLine());
		for (int i = 0; i < numTestCases; i++) {
			int numFlavors = Integer.parseInt(reader.readLine());
			int numCustomers = Integer.parseInt(reader.readLine());
			Customer[] customers = new Customer[numCustomers];
			for (int j = 0; j < numCustomers; j++) {
				customers[j] = new Customer(reader.readLine(), numFlavors);
			}

			
			System.out.println("Case #" + (i + 1) + ":" + computeBatches(customers, numFlavors));
		}	
	}
	
	private static String computeBatches(Customer[] customers, int totalFlavors) {
		for (boolean[] combination : computeCombinations(totalFlavors)) {
			boolean happy = true;
			for (Customer c : customers) {
				if (!c.isHappy(combination)) {
					happy = false;
				  break;	
				}
			}
			if (happy) {
				StringBuilder sb = new StringBuilder();
				for (int i = 0; i < combination.length; i++) {
					sb.append(" " + (combination[i] ? "1" : "0"));
				}
				return sb.toString();
			}
		}
		return " IMPOSSIBLE";
	}
	
	private static void printCombination(boolean[] c) {
		for(boolean b : c) {
			System.out.print(b ? "1" : "0");
		}
	}
	
	private static List<boolean[]> computeCombinations(int numFlavors) {
		List<boolean[]> combos = new ArrayList();
		for (int i = 0; i < exp(2, numFlavors); i++) {
			boolean[] computation = new boolean[numFlavors];
			for (int j = 0; j < numFlavors; j++) {
				computation[j] = ((i >> j) % 2 == 1);
			}
			combos.add(computation);
		}
		
		Collections.sort(combos, new AttemptComparator());
		return combos;
	}
	
	private static long exp(long initial, long e) {
		long result = 1;
		for (int i = 0; i < e; i++) {
			result = result * initial; 
		}
		return result;
	}
	
	private static class AttemptComparator implements Comparator {

		@Override
		public int compare(Object arg0, Object arg1) {
			boolean[] arr1 = (boolean[]) arg0;
			boolean[] arr2 = (boolean[]) arg1;
			
			int numTrue1 = countNumTrue(arr1);
			int numTrue2 = countNumTrue(arr2);
			return numTrue1 - numTrue2;
		}
		
		private int countNumTrue(boolean[] arg) {
			int result = 0;
			for (boolean b : arg) {
				if (b) {
					result++;
				}
			}
			return result;
		}
		
	}
	
	private static class Customer implements Comparable<Customer> {
		private Boolean[] _flavors;
		private Integer _maltedFlavor;
		private int _numFlavors;
		
		public Customer(String testCase, int numTotalFlavors) {
			String[] parts = testCase.split(" ");
			int numFlavors = Integer.parseInt(parts[0]);
			_flavors = new Boolean[numTotalFlavors];
			for (int i = 0; i < numFlavors; i++) {
				int flavor = Integer.parseInt(parts[(i * 2) + 1]);
				Boolean malted = Integer.parseInt(parts[((i * 2) + 2)]) == 1 ? Boolean.TRUE : Boolean.FALSE;
				_flavors[flavor - 1] = malted;
				if (Boolean.TRUE.equals(malted)) {
					_maltedFlavor = Integer.valueOf(i - i); 
				}
				_numFlavors++;
			}
			
//			System.out.println("Malted flavor " + _maltedFlavor);
//			System.out.println("Total flavors " + _numFlavors);
//			for (int i = 0; i < numTotalFlavors; i++) {
//				System.out.println("Flavor " + (i + 1) + ": " + _flavors[i]);
//			}
		}
		
		public boolean isHappy(boolean[] flavors) {
			for (int i = 0; i < flavors.length; i++) {
				if (_flavors[i] != null && _flavors[i].booleanValue() == flavors[i]) {
					return true;
				}
			}
			return false;
		}
		
		public boolean isHappy(int flavor, Boolean malted) {
			return _flavors[flavor] == malted;
		}

		@Override
		public int compareTo(Customer o) {
			if (o._maltedFlavor != null && _maltedFlavor == null) {
				return 1;
			} else if (_maltedFlavor != null && o._maltedFlavor == null) {
				return -1;
			}
			
			return _numFlavors - o._numFlavors;
		}
	}
}
