package codejam;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class TrainTimetable {

	 public static void main(String[] args) throws Exception {
	    parseFile(new File("C:/Documents and Settings/Alan/Desktop/B-large.in"));
	 }
		  
	
	public static void parseFile(File f) throws Exception {
		BufferedReader reader = new BufferedReader(new FileReader(f));
		int numTestCases = Integer.parseInt(reader.readLine());
		for (int i = 0; i < numTestCases; i++) {
			int turnaroundTime = Integer.parseInt(reader.readLine());
			String trainTimesLine = reader.readLine();
			int numAs = Integer.parseInt(trainTimesLine.substring(0, trainTimesLine.indexOf(" ")));
			int numBs = Integer.parseInt(trainTimesLine.substring(trainTimesLine.indexOf(" ") + 1));
			
			List<Train> aToBs = new ArrayList<Train>();
			for (int j = 0; j < numAs; j++) {
				String timeLine = reader.readLine();
				String[] parts = timeLine.split(" ");
				int departureTime = parseTime(parts[0]);
				int arrivalTime = parseTime(parts[1]);
				aToBs.add(new Train(departureTime, arrivalTime));			
			}
			
			List<Train> bToAs = new ArrayList<Train>();
			for (int j = 0; j < numBs; j++) {
				String timeLine = reader.readLine();
				String[] parts = timeLine.split(" ");
				int departureTime = parseTime(parts[0]);
				int arrivalTime = parseTime(parts[1]);
				bToAs.add(new Train(departureTime, arrivalTime));			
			}
			
			int[] result = calculateNumberOfTrains(turnaroundTime, aToBs, bToAs);
			System.out.println("Case #" + (i + 1) + ": " + result[0] + " " + result[1]);
		}	
	}
	
	private static int parseTime(String time) {
		String[] halves = time.split(":");
		return (Integer.parseInt(halves[0]) * 60) + Integer.parseInt(halves[1]); 
	}
	
	
	public static int[] calculateNumberOfTrains(int turnaroundTime, List<Train> aToBs, List<Train> bToAs) {
		Collections.sort(aToBs, new ArrivalTimeComparator());
		Collections.sort(bToAs, new DepartureTimeComparator());
		
		Set<Train> accountedFor = new HashSet<Train>();
		for(Train a : aToBs) {
		  for (Train b : bToAs) {
			  if (b.departureTime >= a.arrivalTime + turnaroundTime && !accountedFor.contains(b)) {
				  accountedFor.add(b);
				  break;
			  }
		  }
		}
		
		int startAtB = bToAs.size() - accountedFor.size();
		
		Collections.sort(aToBs, new DepartureTimeComparator());
		Collections.sort(bToAs, new ArrivalTimeComparator());
		accountedFor = new HashSet<Train>();
		for(Train b : bToAs) {
		  for (Train a : aToBs) {
			  if (a.departureTime >= b.arrivalTime + turnaroundTime && !accountedFor.contains(a)) {
				  accountedFor.add(a);
				  break;
			  }
		  }
		}
		int startAtA = aToBs.size() - accountedFor.size();
		
		return new int[]{startAtA, startAtB};
	}
	
	private static class Train {
		int departureTime;
		int arrivalTime;
		
		public Train(int departureTime, int arrivalTime) {
			this.departureTime = departureTime;
			this.arrivalTime = arrivalTime;
		}
	}
	
	private static class ArrivalTimeComparator implements Comparator<Train> {

		@Override
		public int compare(Train o1, Train o2) {
			return o1.arrivalTime - o2.arrivalTime;
		}
		
	}
	
	private static class DepartureTimeComparator implements Comparator<Train> {

		@Override
		public int compare(Train arg0, Train arg1) {
			return arg0.departureTime - arg1.departureTime;
		}
		
	}
}
