package codejam;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * Created by IntelliJ IDEA.
 * User: alan
 * Date: 5/7/11
 * Time: 11:16 AM
 * To change this template use File | Settings | File Templates.
 */
public class ProblemB {

  public static void main(String[] args) throws Exception {
    solveProblem(readFile("/home/alan/Downloads/B-small-attempt0.in"));
//    solveProblem(
//        "5\n" +
//        "0 0 2 EA\n" +
//        "1 QRI 0 4 RRQR\n" +
//        "1 QFT 1 QF 7 FAQFDFQ\n" +
//        "1 EEZ 1 QE 7 QEEEERA\n" +
//        "0 1 QW 2 QW");
  }

  private static String readFile(String filePath) throws Exception {
    File f = new File(filePath);
    FileInputStream fios = new FileInputStream(new File(filePath));
    byte[] buffer = new byte[(int) (f.length())];
    int numRead = fios.read(buffer);
    assert(numRead == buffer.length);
    assert(fios.read(new byte[10]) == -1);
    return new String(buffer);
  }


  public static void solveProblem(String fileContents) {
    String[] lines = fileContents.split("\n");
    int numCases = Integer.parseInt(lines[0]);
    assert lines.length == numCases + 1;
    for (int i = 1; i < lines.length; i++) {
      solveTestCase(lines[i], i);
    }
  }

  private static void solveTestCase(String line, int caseNumber) {
    String[] lineParts = line.split(" ");
    Rules rules = new Rules(lineParts);
    int numCharacters = Integer.parseInt(lineParts[lineParts.length - 2]);
    String charString = lineParts[lineParts.length - 1];
    assert numCharacters == charString.length();

    List<Character> elements = new ArrayList<Character>();
    for (int i = 0; i < numCharacters; i++) {
      char nextElement = charString.charAt(i);
      elements.add(nextElement);
      processCombinations(elements, rules);
      processOppositions(elements, rules);
    }

    StringBuilder result = new StringBuilder();
    result.append("Case #").append(caseNumber).append(": [");
    for (int i = 0; i < elements.size(); i++) {
      result.append(elements.get(i));
      if (i < elements.size() - 1) {
        result.append(", ");
      }
    }
    result.append("]");
    System.out.println(result);
  }

  private static void processCombinations(List<Character> elements, Rules rules) {
    if (elements.size() > 1) {
      Character combination = rules.getCombination(elements.get(elements.size() - 2), elements.get(elements.size() - 1));
      if (combination != null) {
        elements.remove(elements.size() - 1);
        elements.remove(elements.size() - 1);
        elements.add(combination);
      }
    }
  }

  private static void processOppositions(List<Character> elements, Rules rules) {
    if (elements.size() > 1) {
      Character mostRecentElement = elements.get(elements.size() - 1);
      Set<Character> oppositions = rules.getOppositions(mostRecentElement);
      if (oppositions != null) {
        for (int i = 0; i < elements.size() - 1; i++) {
          if (oppositions.contains(elements.get(i))) {
            elements.clear();
            return;
          }
        }
      }
    }
  }

  public static class Rules {

    private Map<String, Character> _combinations;
    private Map<Character, Set<Character>> _oppositions;

    public Rules(String[] lineParts) {
      _combinations = new HashMap<String, Character>();
      _oppositions = new HashMap<Character, Set<Character>>();
      int numCombinations = Integer.parseInt(lineParts[0]);
      for (int i = 0; i < numCombinations; i++) {
        addCombination(lineParts[i + 1]);
      }

      int numOppositions = Integer.parseInt(lineParts[numCombinations + 1]);
      for (int i = 0; i < numOppositions; i++) {
        addOpposition(lineParts[i + numCombinations + 2]);
      }
      assert numCombinations + numOppositions + 4 == lineParts.length;
    }

    public Character getCombination(Character char1, Character char2) {
      return _combinations.get(char1.toString() + char2.toString());
    }

    public Set<Character> getOppositions(Character c) {
      return _oppositions.get(c);
    }

    private void addCombination(String str) {
      assert str.length() == 3;
      Character firstBase = str.charAt(0);
      Character secondBase = str.charAt(1);
      Character result = str.charAt(2);
      _combinations.put(firstBase.toString() + secondBase.toString(), result);
      _combinations.put(secondBase.toString() + firstBase.toString(), result);
      // System.out.println("Combination " + str);
    }

    private void addOpposition(String str) {
      assert str.length() == 2;
      Character firstBase = str.charAt(0);
      Character secondBase = str.charAt(1);

      Set<Character> firstBaseOppositions = _oppositions.get(firstBase);
      if (firstBaseOppositions == null) {
        firstBaseOppositions = new HashSet<Character>();
        _oppositions.put(firstBase, firstBaseOppositions);
      }
      firstBaseOppositions.add(secondBase);

      Set<Character> secondBaseOppositions = _oppositions.get(secondBase);
      if (secondBaseOppositions == null) {
        secondBaseOppositions = new HashSet<Character>();
        _oppositions.put(secondBase, secondBaseOppositions);
      }
      secondBaseOppositions.add(firstBase);

      // System.out.println("Opposition " + str);
    }
  }

}
