package codejam;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;

public class BooleanTree {
	public static void parseFile(File f) throws Exception {
		BufferedReader reader = new BufferedReader(new FileReader(f));
		int numTestCases = Integer.parseInt(reader.readLine());
		for (int i = 0; i < numTestCases; i++) {			
			String[] lineParts = reader.readLine().split(" ");
			int numNodes = Integer.parseInt(lineParts[0]);
			int desiredValue = Integer.parseInt(lineParts[1]);
			Node[] nodes = new Node[numNodes + 1];
			for (int j = 0; j < numNodes; j++) {
				String line = reader.readLine();
				String[] values = line.split(" ");
				if (values.length == 2) {
				  nodes[j + 1] = new Node(j + 1, Integer.parseInt(values[0]) == 1, Integer.parseInt(values[1]) == 1);
				}  else {
				  nodes[j + 1] = new Node(j + 1, Integer.parseInt(values[0]) == 1);	
				}
				
			}

            System.out.println("Case #" + (i + 1) + ": " + processNodes(nodes, desiredValue == 1));
		}
		
	}
	
	public static void main(String[] args) throws Exception {
		parseFile(new File("C:/Documents and Settings/Alan/Desktop/A-small-attempt1.in"));
	}
	
	public static String processNodes(Node[] nodes, boolean desiredValue) {
		int changeCount = nodes[1].numChanges(desiredValue, nodes);
		if (changeCount == -1) {
			return "IMPOSSIBLE";
		} else {
			return "" + changeCount;
		}
	}
	
	private static class Node {
		boolean _leaf;
		boolean _changeable;
		boolean _isAnd;
		boolean _value;
		int _nodeNumber;
		
		public Node(int nodeNumber, boolean value) {
			_nodeNumber = nodeNumber;
			_leaf = true;
			_value = value;
		}
		
		public Node(int nodeNumber, boolean isAnd, boolean changeable) {
			_nodeNumber = nodeNumber;
			_leaf = false;
			_isAnd = isAnd;
			_changeable = changeable;
		}
		
		public boolean value(Node[] nodes) {
			if (_leaf) {
				return _value;
			} else {
			  boolean child1 = nodes[_nodeNumber * 2].value(nodes);
			  boolean child2 = nodes[_nodeNumber * 2 + 1].value(nodes);
			  if (_isAnd) {
				  return child1 && child2;
			  } else {
				  return child1 || child2;
			  }
			}
		}
		
		public int numChanges(boolean desiredValue, Node[] nodes) {
			if (value(nodes) == desiredValue) {
				return 0;
			} else {
				if (_leaf) {
				  return -1;	
				} else {
					boolean child1 = nodes[_nodeNumber * 2].value(nodes);
					boolean child2 = nodes[_nodeNumber * 2 + 1].value(nodes);	
					
					int child1Changes = (child1 == desiredValue ? 0 : nodes[_nodeNumber * 2].numChanges(desiredValue, nodes));
					int child2Changes = (child2 == desiredValue ? 0 : nodes[_nodeNumber * 2 + 1].numChanges(desiredValue, nodes));
					
					if (_changeable) {
					  if (desiredValue == true) {
						  // If we want it to be true, see which child requires the fewest changes
						  int fewestChanges = fewestChanges(child1Changes, child2Changes);
						  if (fewestChanges == -1) {
							  return -1;
						  } else {
							  return fewestChanges + (_isAnd ? 1 : 0);
						  }
					  } else {
						  // We want it to be false
						  int fewestChanges = fewestChanges(child1Changes, child2Changes);
						  if (fewestChanges == -1) {
							  return -1;
						  } else {
							  return fewestChanges + (_isAnd ? 0 : 1);
						  }
					  }
					} else {
						if (desiredValue == true) {
							if (_isAnd) {
							  if (child1Changes == -1 || child2Changes == -1) {
								  return -1;
							  } else {
								  return child1Changes + child2Changes;
							  }
							} else {
								return fewestChanges(child1Changes, child2Changes);
							}
						} else {
							if (_isAnd) {
								return fewestChanges(child1Changes, child2Changes);	
							} else {
								if (child1Changes == -1 || child2Changes == -1) {
									  return -1;
								  } else {
									  return child1Changes + child2Changes;
								  }
							}
						}
						
					}
					
				}
			}
		}

		private int fewestChanges(int changes1, int changes2) {
			if (changes1 == -1) {
				return changes2;
			} else if (changes2 == -1) {
			  return changes1;	
			} else if (changes1 < changes2) {
				return changes1;
			} else {
				return changes2;
			}
		}
		
		public boolean changeValueIfPossible(boolean desiredValue, Node[] nodes) {
			if (_leaf || 
					!_changeable || 
					(desiredValue == true && !_isAnd) || 
					(desiredValue == false && _isAnd) || 
					value(nodes) == desiredValue ) {
				return false;
			} else {
				_isAnd = (!_isAnd);
				return true;
			}
		}
		
		
	}
	
	private static class ChangeResults {
	  boolean changed;
	  boolean newValue;
	}
}
