import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayDeque;
import java.util.Arrays;
import java.util.Queue;
import java.util.StringTokenizer;

public class H implements Runnable {
    public static void main(String[] args) {
        new Thread(new H()).run();
    }

    BufferedReader br;
    StringTokenizer in;
    PrintWriter out;

    public String nextToken() throws IOException {
        while (in == null || !in.hasMoreTokens()) {
            in = new StringTokenizer(br.readLine());
        }

        return in.nextToken();
    }

    public int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    public long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    public double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    public class Building {
        int x1, y1, x2, y2;

        public Building(int x1, int y1, int x2, int y2) {
            this.x1 = x1;
            this.y1 = y1;
            this.x2 = x2;
            this.y2 = y2;
        }
    }

    int[] dx = {1, 1, 0, -1, -1, -1, 0, 1};
    int[] dy = {0, 1, 1, 1, 0, -1, -1, -1};

    public int[][] buildGraph(int w, int h, Building[] b) {
        int[][] d = new int[b.length + 2][b.length + 2];
        for (int i = 0; i < d.length; i++) {
            Arrays.fill(d[i], Integer.MAX_VALUE);
        }

        boolean[][] map = new boolean[w][h];
        for (int i = 0; i < b.length; i++) {
            for (int x = b[i].x1; x <= b[i].x2; x++) {
                for (int y = b[i].y1; y <= b[i].y2; y++) {
                    map[x][y] = true;
                }
            }
        }

        for (int i = 0; i < b.length; i++) {
            Queue<Integer> queue = new ArrayDeque<Integer>();
            int[][] dist = new int[w][h];

            for (int k = 0; k < w; k++) {
                Arrays.fill(dist[k], Integer.MAX_VALUE);
            }

            for (int x = b[i].x1; x <= b[i].x2; x++) {
                for (int y = b[i].y1; y <= b[i].y2; y++) {
                    queue.add(x);
                    queue.add(y);
                    dist[x][y] = 0;
                }
            }

            while (!queue.isEmpty()) {
                int x = queue.poll();
                int y = queue.poll();
                for (int k = 0; k < 8; k++) {
                    int xx = x + dx[k];
                    int yy = y + dy[k];
                    if (xx >= 0 && xx < w && yy >= 0 && yy < h && !map[xx][yy] && dist[xx][yy] == Integer.MAX_VALUE) {
                        queue.add(xx);
                        queue.add(yy);
                        dist[xx][yy] = dist[x][y] + 1;
                    }
                }
            }

            for (int j = 0; j < b.length; j++) {
                for (int x = Math.max(b[j].x1 - 1, 0); x <= Math.min(b[j].x2 + 1, w - 1); x++) {
                    for (int y = Math.max(b[j].y1 - 1, 0); y <= Math.min(b[j].y2 + 1, h - 1); y++)
                        d[i][j] = Math.min(d[i][j], dist[x][y]);
                }
            }

            for (int y = 0; y < h; y++) {
                d[i][b.length] = Math.min(d[i][b.length], dist[0][y]);
                d[i][b.length + 1] = Math.min(d[i][b.length + 1], dist[w - 1][y]);
            }

            d[b.length][i] = d[i][b.length];
            d[b.length + 1][i] = d[i][b.length + 1];
        }
        return d;
    }

    public void solve() throws IOException {
        int w = nextInt();
        int h = nextInt();
        int n = nextInt();

        if (n == 0) {
            out.println(w);
            return;
        }

        Building[] b = new Building[n];

        int[][] d = new int[n + 2][n + 2];

        for (int i = 0; i < n; i++) {
            b[i] = new Building(nextInt(), nextInt(), nextInt(), nextInt());
        }

        d = buildGraph(w, h, b);

        int INF = Integer.MAX_VALUE / 2;
        int[] dist = new int[n + 2];
        Arrays.fill(dist, INF);
        dist[n] = 0;
        boolean[] was = new boolean[n + 2];
        for (int i = 0; i < dist.length; i++) {
            int mi = -1;
            for (int j = 0; j < dist.length; j++) {
                if ((mi == -1 || dist[mi] > dist[j]) && !was[j])
                    mi = j;
            }
            was[mi] = true;
            for (int j = 0; j < dist.length; j++) {
                if (d[mi][j] != Integer.MAX_VALUE) {
                    dist[j] = Math.min(dist[j], dist[mi] + d[mi][j]);
                }
            }
        }

        out.println(dist[n + 1]);
    }

    public void run() {
        try {
            br = new BufferedReader(new FileReader("input.txt"));
            out = new PrintWriter("output.txt");

            int t = nextInt();
            for (int i = 0; i < t; i++) {
                out.print("Case #" + (i + 1) + ": ");
                solve();
            }

            out.close();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
    }
}
