/**
 * 
 */
package practice;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;

/**
 * @author akshay.iyer
 *
 */
public class MineSweeper {

	private static String mInputFileName;
	private static String mOutputFileName;
	private static Scanner mScanner;
	private static PrintWriter mPrintWriter;

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		// TODO Auto-generated method stub
		mInputFileName = args[0];
		mOutputFileName = args[1];
		
		try {
			mScanner = new Scanner(new File(mInputFileName));
			mPrintWriter = new PrintWriter(new File(mOutputFileName));
			initiate();
		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}


	}

	private static void initiate() {
		int numCases = readCases();
		
		for(int i = 0; i < numCases; i++)
			readCase(i+1);

		mPrintWriter.close();
	}
	
	private static int readCases() {
		int numCases = mScanner.nextInt();
		mScanner.nextLine();
		return numCases;
	}
	
	private static int[][] field, mineMap;
	private static int rows, cols, mines;
	private static int totalMinesCleared = 0;

	
	private static void readCase(int caseNum) {
		mPrintWriter.println("Case #" + caseNum + ": ");
		
		rows = mScanner.nextInt();
		cols = mScanner.nextInt();
		mines = mScanner.nextInt();
		
		field = new int[rows][cols];
		mineMap = new int[rows][cols];
		
		for(int i = 0; i < rows; i++) {
			for(int j = 0; j < cols; j++) {
				field[i][j] = 8;
				if(i == 0)
					field[i][j]-=3;
				if(i == rows-1)
					field[i][j]-=3;
				if(j == 0)
					field[i][j] -= 3;
				if(j == cols - 1)
					field[i][j] -= 3;
				
				if(i == 0 && j == 0)
					field[i][j]++;
				if(i == 0 && (j == cols- 1))
					field[i][j]++;
				if((i == rows-1) && j == 0)
					field[i][j]++;
				if((i == rows-1)&&(j == cols-1))
					field[i][j]++;
				
				mineMap[i][j] = field[i][j];
			}
		}
		
		totalMinesCleared = 0;
		for(int i = 0; i < rows; i++) {
			for(int j = 0; j < cols; j++) {
				int prevNeighbor = field[i][j];
				field[i][j] = 0; 
				totalMinesCleared++;
				if(mines == (rows * cols - totalMinesCleared)) {
					printField(0, 0);
					return;
				}
				if(sweepField(i, j)) {
					printField(i, j);
					return;
				}
				totalMinesCleared--;
				field[i][j] = prevNeighbor; 
			}
		}
		mPrintWriter.println("Impossible");
	}
	
	private static void printField(int startRow, int startCol) {
		for(int r = 0; r < rows; r++) {
			for(int c = 0; c < cols; c++) {
				if(r == startRow && c == startCol)
					mPrintWriter.print("c");
				else if(mineMap[r][c] != field[r][c]) {
					mPrintWriter.print(".");
				} else {
					mPrintWriter.print("*");
				}
			}
			mPrintWriter.println("");
		}
	}

	private static boolean sweepField(int r, int c) {
		updateNeighbors(r, c, false);
		if(mines == (rows * cols - totalMinesCleared)) {
			return true;
		}
		if(mines > (rows * cols - totalMinesCleared)) {
			updateNeighbors(r, c, true);
			return false;
		}
		
		//iterate through each neighbor and set to 0.
		int prevNeighbor = 0;
		if(c > 0) {
			if(field[r][c-1] > 0) {
				prevNeighbor = field[r][c-1];
				field[r][c-1] = 0;
				if(sweepField(r, c-1))
					return true;
				field[r][c-1] = prevNeighbor;
			}
		}
		if(c < cols - 1) {
			if(field[r][c+1] > 0) {
				prevNeighbor = field[r][c+1];
				field[r][c+1] = 0;
				if(sweepField(r, c+1))
					return true;
				field[r][c+1] = prevNeighbor;
			}
		}
		if(r > 0) {
			if(field[r-1][c] > 0) {
				prevNeighbor = field[r-1][c];
				field[r-1][c] = 0;
				if(sweepField(r-1, c))
					return true;
				field[r-1][c] = prevNeighbor;
			}
			if(c > 0) {
				if(field[r-1][c-1] > 0) {
					prevNeighbor = field[r-1][c-1];
					field[r-1][c-1] = 0;
					if(sweepField(r-1, c-1))
						return true;
					field[r-1][c-1] = prevNeighbor;
				}
			}
			if(c < cols - 1) {
				if(field[r-1][c+1] > 0) {
					prevNeighbor = field[r-1][c+1];
					field[r-1][c+1] = 0;
					if(sweepField(r-1, c+1))
						return true;
					field[r-1][c+1] = prevNeighbor;
				}
			}
		}
		if(r < rows - 1) {
			if(field[r+1][c] > 0) {
				prevNeighbor = field[r+1][c];
				field[r+1][c] = 0;
				if(sweepField(r+1, c))
					return true;
				field[r+1][c] = prevNeighbor;
			}
			if(c > 0) {
				if(field[r+1][c-1] > 0) {
					prevNeighbor = field[r+1][c-1];
					field[r+1][c-1] = 0;
					if(sweepField(r+1, c-1))
						return true;
					field[r+1][c-1] = prevNeighbor;
				}
			}
			if(c < cols - 1) {
				if(field[r+1][c+1] > 0) {
					prevNeighbor = field[r+1][c+1];
					field[r+1][c+1] = 0;
					if(sweepField(r+1, c+1))
						return true;
					field[r+1][c+1] = prevNeighbor;
				}
			}	
		}

		updateNeighbors(r, c, true);
		return false;
	}
	
	private static void updateNeighbors(int r, int c, boolean increase) {
		int update = 0;
		
		if(increase)
			update = 1;
		else
			update = -1;
		
		if(r > 0) {
			if(field[r-1][c] > 0) {
				field[r-1][c] += update;
			}
		}
		if(r < rows - 1) {
			if(field[r+1][c] > 0) { 
				field[r+1][c] += update;
			}
		}
		if(c > 0) {
			if(field[r][c-1] > 0) {
				field[r][c-1] += update;
			}
			if(r > 0) {
				if(field[r-1][c-1] > 0) {
					field[r-1][c-1] += update;
				}
			} 
			if(r < rows-1) {
				if(field[r+1][c-1] > 0) {
					field[r+1][c-1] += update;
				}
			}
		}
		if (c < cols - 1) {
			if(field[r][c+1] > 0) {
				field[r][c+1] += update;
			}
			if(r > 0) {
				if(field[r-1][c+1] > 0) {
					field[r-1][c+1] += update;
				}
			}
			if(r < rows-1) {
				if(field[r+1][c+1] > 0) {
					field[r+1][c+1] += update;
				}
			}
		}
		
		totalMinesCleared = 0;
		for(int i = 0; i < rows; i++) {
			for(int j = 0; j < cols; j++) {
				if(field[i][j] != mineMap[i][j]) {
					totalMinesCleared++;
				}
			}
		}
	}
}
