import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.util.Arrays;
import java.util.Locale;
import java.util.Scanner;

/*
 *  @author ShadowfoX
 *  
 *  The program takes the input from the program arguments if provided,
 *  otherwise the input file needs to be hard-coded in main()
 *  
 *  The program generates an output file by the name Output.txt
 *  along with printing the values in the console.
 */
public class DeceitfulWar {

	private static BufferedReader br;

	private static int numberOfTestCases;

	private static long start;
	
	private static PrintWriter writer;

	// assume Unicode UTF-8 encoding
	private static final String CHARSET_NAME = "UTF-8";

	// assume language = English, country = US for consistency with System.out.
	private static final Locale LOCALE = Locale.US;
	
	public static void readStringFile(String fileName) throws IOException{   	    
    	ClassLoader classLoader = MagicTrick.class.getClassLoader();
        File classpathRoot = new File(classLoader.getResource("").getPath());
        String fileLocation = classpathRoot.getPath();        
        boolean found = false;
		try {
			br = new BufferedReader(new FileReader(fileLocation + "\\" + fileName));
			found = true;
		} catch (FileNotFoundException e) {
			try {
				br = new BufferedReader(new FileReader(fileLocation.substring(0, fileLocation.length() - 4) + "\\src\\" + fileName));
				found = true;
			}catch(FileNotFoundException e1){
				e1.printStackTrace();
			}
			if(!found)
				e.printStackTrace();
		}
    }

	public static void main(String[] args) throws IOException {
		start = System.currentTimeMillis();
		if(args.length != 0 && args[0] != null){
			readStringFile(args[0]);	
    	}else{
    		readStringFile("D-large.in");
    	}    
    	
		try {
			writer = new PrintWriter("Output.txt", "UTF-8");
		} catch (FileNotFoundException | UnsupportedEncodingException e) {			
			e.printStackTrace();
		}    		
		numberOfTestCases = Integer.valueOf(br.readLine());		
		int testCaseNumber = 1;
		while(testCaseNumber <= numberOfTestCases){
			calculateNumberOfPointsForNaomi(testCaseNumber);
			testCaseNumber++;
		}
		writer.close();
		long now = System.currentTimeMillis();
//		System.out.println((now - start) / 1000.0);
	}

	private static void calculateNumberOfPointsForNaomi(int testCaseNumber) throws NumberFormatException, IOException {
		int N = Integer.valueOf(br.readLine());		
		String w1 = br.readLine();
		String w2 = br.readLine();
		String[] w1Array = w1.split(" ");
		String[] w2Array = w2.split(" ");
		double[] naomiWeights = new double[N];
		double[] kenWeights = new double[N];
		for(int i=0; i<N; i++){
			naomiWeights[i] = Double.valueOf(w1Array[i]);
			kenWeights[i] = Double.valueOf(w2Array[i]);
		}
		Arrays.sort(naomiWeights);
		Arrays.sort(kenWeights);
		
		int warPoints = playWar(naomiWeights, kenWeights, N);		
		int deceitfulWarPoints = playDeceitfulWar(naomiWeights, kenWeights, N);
		System.out.println("Case #" + testCaseNumber + ": " + deceitfulWarPoints + " " + warPoints);
		writer.println("Case #" + testCaseNumber + ": " + deceitfulWarPoints + " " + warPoints);
	}

	private static int playDeceitfulWar(double[] naomiWeights,
			double[] kenWeights, int N) {
		int removed = 0;
		while(!checkIfAllNaomiWeightsGreaterThanKenWeights(naomiWeights, kenWeights, N)){
			naomiWeights[removed] = 0.0;
			removed++;
			kenWeights[N-1] = 0.0;
			Arrays.sort(naomiWeights);
			Arrays.sort(kenWeights);
		}
		int naomiPoints = 0;
		for(int i=0; i<N; i++){
			if(naomiWeights[i] != 0.0)
				naomiPoints++;			
		}
		return naomiPoints;
	}

	private static boolean checkIfAllNaomiWeightsGreaterThanKenWeights(
			double[] naomiWeights, double[] kenWeights, int N) {
		for(int i=0; i<N; i++){
			if(kenWeights[i] > naomiWeights[i])
				return false;			
		}
		return true;		
	}

	private static int playWar(double[] naomiWeights, double[] kenWeights, int N) {
		int i=N-1;
		int j=N-1;
		int kenPoints = 0;
		while(i>=0 && j>=0){
			while(j>=0){				
				if(kenWeights[i] > naomiWeights[j]){
					kenPoints++;
					i--;
					j--;
					break;
				} else {
					j--;
					break;
				}
			}			
		}
		return N-kenPoints;
	}

}
