package alanparra;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.Scanner;

public class ThemePark {

	public static void main(String[] args) throws Exception {
		if (args.length != 1) {
			System.out.println("Usage: java " + ThemePark.class.getName() + " <filename>");
			return;
		} else if (!new File(args[0]).exists()) {
			System.out.println("File " + args[0] + " do not exists!");
			return;
		}

		String outputName = args[0];
		int dotIndex = outputName.lastIndexOf('.');
		if (dotIndex > 0) {
			outputName = outputName.substring(0, dotIndex);
		}
		outputName += ".out";

		System.out.println("start time = " + new Date());

		Scanner input = null;
		PrintWriter output = null;
		try {
			input = new Scanner(new FileInputStream(args[0]));
			output = new PrintWriter(outputName);

			int cases = input.nextInt();
			for (int i = 0; i < cases; i++) {
				solveNextCase(i + 1, input, output);
			}
		} finally {
			if (input != null) {
				input.close();
			}
			if (output != null) {
				output.close();
			}
		}

		System.out.println("end time = " + new Date());
	}

	private static void solveNextCase(int caseNumber, Scanner input, PrintWriter output) throws IOException {
		int r = input.nextInt();
		int k = input.nextInt();
		int n = input.nextInt();

		int[] groups = new int[n];
		for (int i = 0; i < groups.length; i++) {
			groups[i] = input.nextInt();
		}

		Map<Integer, QueueData> indexToData = new HashMap<Integer, QueueData>();

		long euros = 0;
		int index = 0;
		while (r > 0) {
			QueueData data = indexToData.get(index);
			if (data == null) {

				// calculate data
				int startIndex = index;
				int currentK = 0;
				int currentN = 0;

				while (currentN < n) {

					// add passengers
					currentK += groups[index];

					// check passenger limit
					if (currentK > k) {
						currentK -= groups[index];
						break;
					}

					// increment index and currentN
					currentN++;
					if (++index == n) {
						index = 0;
					}
				}

				// update our money :)
				euros += currentK;

				// update index cache
				indexToData.put(startIndex, new QueueData(index, currentK));

			} else {

				// use cache
				euros += data.getEuros();
				index = data.getEndIndex();
			}
			r--;
		}

		System.out.printf("Case #%d: %s\n", caseNumber, euros);
		output.printf("Case #%d: %s\n", caseNumber, euros);
	}

	private static class QueueData {

		private final int endIndex;
		private final int euros;

		public QueueData(int endIndex, int euros) {
			this.endIndex = endIndex;
			this.euros = euros;
		}

		public int getEndIndex() {
			return endIndex;
		}

		public int getEuros() {
			return euros;
		}

	}

}
