package alanparra;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.*;

public class FairWarning {

	public static void main(String[] args) throws Exception {
		if (args.length != 1) {
			System.out.println("Usage: java " + FairWarning.class.getName() + " <filename>");
			return;
		} else if (!new File(args[0]).exists()) {
			System.out.println("File " + args[0] + " do not exists!");
			return;
		}

		String outputName = args[0];
		int dotIndex = outputName.lastIndexOf('.');
		if (dotIndex > 0) {
			outputName = outputName.substring(0, dotIndex);
		}
		outputName += ".out";

		System.out.println("start time = " + new Date());

		Scanner input = null;
		PrintWriter output = null;
		try {
			input = new Scanner(new FileInputStream(args[0]));
			output = new PrintWriter(outputName);

			int cases = input.nextInt();
			for (int i = 0; i < cases; i++) {
				solveNextCase(i + 1, input, output);
			}
		} finally {
			if (input != null) {
				input.close();
			}
			if (output != null) {
				output.close();
			}
		}

		System.out.println("end time = " + new Date());
	}

	private static void solveNextCase(int caseNumber, Scanner input, PrintWriter output) throws IOException {
		int n = input.nextInt();
		int[] events = new int[n];

		for (int i = 0; i < events.length; i++) {
			events[i] = input.nextInt();
		}

		Set<Integer> candidates = new TreeSet<Integer>(new Comparator<Integer>() {

			public int compare(Integer o1, Integer o2) {
				return o2.compareTo(o1);
			}

		});

		// find candidates
		for (int i = 0; i < events.length - 1; i++) {
			int eventA = events[i];
			for (int j = i + 1; j < events.length; j++) {
				int eventB = events[j];
				if (eventA != eventB) {
					candidates.add(Math.abs(eventA - eventB));
				}
			}
		}

		// find factors
		Set<Integer> factors = new TreeSet<Integer>();
		for (int candidateA : candidates) {
			for (int candidateB : candidates) {
				if (candidateA != candidateB) {
					factors.add(BigInteger.valueOf(candidateA).gcd(BigInteger.valueOf(candidateB)).intValue());
				}
			}
		}

		factors.addAll(candidates);

		// test factors
		int divisor = 1;
		for (int factor : factors) {
			boolean found = true;
			int remainder = events[0] % factor;
			for (int i = 1; i < events.length; i++) {
				int event = events[i];
				if (event % factor != remainder) {
					found = false;
					break;
				}
			}

			if (found) {
				divisor = factor;
				break;
			}
		}

		// final result
		int timeForParty;
		if (divisor == 1) {
			timeForParty = 0;
		} else {
			timeForParty = divisor - events[0] % divisor;
		}
		output.printf("Case #%d: %d\n", caseNumber, timeForParty);
	}

	private static class QueueData {

		private final int endIndex;
		private final int euros;

		public QueueData(int endIndex, int euros) {
			this.endIndex = endIndex;
			this.euros = euros;
		}

		public int getEndIndex() {
			return endIndex;
		}

		public int getEuros() {
			return euros;
		}

	}

}
