package round2;

import com.google.common.collect.HashMultiset;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.Lists;
import com.google.common.collect.Multiset;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.InputMismatchException;
import java.util.List;
import java.util.Scanner;

public class C {
    private static final String PROBLEM = "round2/C-small-attempt0";
    private final Scanner in;
    public C(Scanner in) {
        this.in = in;
    }

    Multiset<String> englishWords;
    Multiset<String> frenchWords;
    Multiset<String> bothWords;
    List<String[]> lines;
    int bestVal;

    private void tryNext(int index) {
        if (index == lines.size()) {
            int curVal = bothWords.elementSet().size();
            if (curVal < bestVal) {
                bestVal = curVal;
            }
            return;
        }

        // try english
        List<String> addedToBoth = Lists.newArrayList();
        for (String s : lines.get(index)) {
            englishWords.add(s);
            if (frenchWords.contains(s)) {
                bothWords.add(s);
                addedToBoth.add(s);
            }
        }
        tryNext(index + 1);
        for (String s : lines.get(index)) {
            englishWords.remove(s);
        }
        for (String s : addedToBoth) {
            bothWords.remove(s);
        }

        // try french
        addedToBoth = Lists.newArrayList();
        for (String s : lines.get(index)) {
            frenchWords.add(s);
            if (englishWords.contains(s)) {
                bothWords.add(s);
                addedToBoth.add(s);
            }
        }
        tryNext(index + 1);
        for (String s : lines.get(index)) {
            frenchWords.remove(s);
        }
        for (String s : addedToBoth) {
            bothWords.remove(s);
        }
    }

    private String runCase() {
        int numLines = Integer.parseInt(in.nextLine());

        englishWords = HashMultiset.create();
        frenchWords = HashMultiset.create();
        bothWords = HashMultiset.create();

        String[] englishLine = in.nextLine().split(" ");
        String[] frenchLine = in.nextLine().split(" ");
        for (String s : englishLine) {
            englishWords.add(s);
        }
        for (String s : frenchLine) {
            frenchWords.add(s);
            if (englishWords.contains(s)) {
                bothWords.add(s);
            }
        }

        lines = Lists.newArrayList();
        for (int i = 0; i < numLines - 2; i++) {
            lines.add(in.nextLine().split(" "));
        }

        bestVal = Integer.MAX_VALUE;

        tryNext(0);
        return String.format("%d", bestVal);
    }

    private List<Integer> nextIntList(int n) {
        ImmutableList.Builder<Integer> builder = ImmutableList.builder();
        for (int i = 0; i < n; i++) {
            builder.add(in.nextInt());
        }
        return builder.build();
    }

    private void runCases() throws FileNotFoundException {
        int numCases = Integer.parseInt(in.nextLine());
        PrintWriter writer = new PrintWriter(PROBLEM + ".out");
        for (int casenum = 1; casenum <= numCases; casenum++) {
            String result = runCase();
            System.out.printf("Case #%d: %s%n", casenum, result);
            writer.printf("Case #%d: %s%n", casenum, result);
            writer.flush();
        }
    }

    public static void main(String[] args) throws FileNotFoundException {
        Scanner in = new Scanner(new File(PROBLEM + ".in"));
        new C(in).runCases();
    }
}
