package round3;

import com.google.common.collect.ImmutableList;
import com.google.common.collect.Ordering;
import com.google.common.collect.TreeMultiset;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.*;

public class A {
    private static final String PROBLEM = "round3/A-large";
    private final Scanner in;
    public A(Scanner in) {
        this.in = in;
    }

    private String runCase() {
        int numEmployees = in.nextInt();
        int maxDifference = in.nextInt();

        List<Long> salaries = nextSeq(numEmployees);
        List<Long> managers = nextSeq(numEmployees);

        List<Employee> employees = new ArrayList<>();
        for (int i = 0; i < numEmployees; i++) {
            int manager;
            if (i == 0) {
                manager = -1;
            } else {
                manager = (int)(long)managers.get(i) % i;
            }
            employees.add(new Employee(i, manager, (int)(long)salaries.get(i)));
        }

        for (int i = 0; i < employees.size(); i++) {
            computeRequiredSalary(employees, i);
        }

        List<Employee> sortedEmployees = Ordering.from(new Comparator<Employee>() {
            @Override
            public int compare(Employee o1, Employee o2) {
                return Integer.valueOf(o1.maxRequiredSalary).compareTo(o2.maxRequiredSalary);
            }
        }).sortedCopy(employees);

        int maxSeen = 0;

        TreeMultiset<Integer> minRequiredSalaries = TreeMultiset.create();
        for (Employee employee : sortedEmployees) {
            long maxSalary = employee.maxRequiredSalary;
            long minSalary = maxSalary - maxDifference;
            minRequiredSalaries.add(employee.minRequiredSalary);
            while (!minRequiredSalaries.isEmpty() &&
                    minRequiredSalaries.firstEntry().getElement() < minSalary) {
                minRequiredSalaries.remove(minRequiredSalaries.firstEntry().getElement());
            }
            maxSeen = Math.max(maxSeen, minRequiredSalaries.size());
        }
        return String.format("%d", maxSeen);
    }

    void computeRequiredSalary(List<Employee> employees, int index) {
        Employee employee = employees.get(index);
        if (index == 0) {
            employee.minRequiredSalary = employee.salary;
            employee.maxRequiredSalary = employee.salary;
            return;
        }

        if (employee.minRequiredSalary != -1) {
            return;
        }
        computeRequiredSalary(employees, employee.manager);
        Employee parent = employees.get(employee.manager);
        employee.minRequiredSalary = Math.min(parent.minRequiredSalary, employee.salary);
        employee.maxRequiredSalary = Math.max(parent.maxRequiredSalary, employee.salary);
    }

    static class Employee {
        final int index;
        final int manager;
        final int salary;
        int minRequiredSalary = -1;
        int maxRequiredSalary = -1;
        public Employee(int index, int manager, int salary) {
            this.index = index;
            this.manager = manager;
            this.salary = salary;
        }

        @Override
        public String toString() {
            return "Employee{" +
                    "index=" + index +
                    ", manager=" + manager +
                    ", salary=" + salary +
                    ", minRequiredSalary=" + minRequiredSalary +
                    ", maxRequiredSalary=" + maxRequiredSalary +
                    '}';
        }
    }

    List<Long> nextSeq(int len) {
        long start = in.nextLong();
        long A = in.nextLong();
        long C = in.nextLong();
        long R = in.nextLong();

        List<Long> result = new ArrayList<>();
        result.add(start);
        long current = start;
        for (int i = 1; i < len; i++) {
            current = (current * A + C) % R;
            result.add(current);
        }
        return result;
    }

    private List<Integer> nextIntList(int n) {
        ImmutableList.Builder<Integer> builder = ImmutableList.builder();
        for (int i = 0; i < n; i++) {
            builder.add(in.nextInt());
        }
        return builder.build();
    }

    private void runCases() throws FileNotFoundException {
        int numCases = in.nextInt();
        PrintWriter writer = new PrintWriter(PROBLEM + ".out");
        for (int casenum = 1; casenum <= numCases; casenum++) {
            String result = runCase();
            System.out.printf("Case #%d: %s%n", casenum, result);
            writer.printf("Case #%d: %s%n", casenum, result);
            writer.flush();
        }
    }

    public static void main(String[] args) throws FileNotFoundException {
        Scanner in = new Scanner(new File(PROBLEM + ".in"));
        new A(in).runCases();
    }
}

/*
 * Uses Google Guava: https://github.com/google/guava
 */