package round2;

import com.google.common.collect.ImmutableList;
import com.google.common.collect.Lists;
import com.google.common.primitives.Doubles;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Scanner;

public class B {
    private static final String PROBLEM = "round2/B-large";
    private final Scanner in;
    public B(Scanner in) {
        this.in = in;
    }

    private String runCase() {
        int numSources = in.nextInt();
        double targetVolume = in.nextDouble();
        double targetTemp = in.nextDouble();

        List<Source> sources = Lists.newArrayList();
        for (int i = 0; i < numSources; i++) {
            sources.add(new Source(in.nextDouble(), in.nextDouble()));
        }

        List<Source> exactTempSources = Lists.newArrayList();
        List<Source> coldSources = Lists.newArrayList();
        List<Source> hotSources = Lists.newArrayList();

        for (Source source : sources) {
            if (source.temp == targetTemp) {
                exactTempSources.add(source);
            } else if (source.temp < targetTemp) {
                coldSources.add(source);
            } else {
                hotSources.add(source);
            }
        }

        Collections.sort(hotSources, (o1, o2) -> Doubles.compare(o1.temp, o2.temp));
        Collections.sort(coldSources, (o1, o2) -> -Doubles.compare(o1.temp, o2.temp));

        double curRate = 0;
        for (Source source : exactTempSources) {
            curRate += source.rate;
        }

        int coldInd = 0;
        double coldUsage = 0.0;
        int hotInd = 0;
        double hotUsage = 0.0;

        while (coldInd < coldSources.size() && hotInd < hotSources.size()) {
            Source cold = coldSources.get(coldInd);
            Source hot = hotSources.get(hotInd);

            double coldDiff = targetTemp - cold.temp;
            double hotDiff = hot.temp - targetTemp;

            double numMaxColds = cold.rate * coldDiff * (1 - coldUsage);
            double numMaxHots = hot.rate * hotDiff * (1 - hotUsage);

            if (numMaxHots < numMaxColds) {
                // Advance hot to end
                double coldUsageIncrease = numMaxHots / cold.rate / coldDiff;
                curRate += coldUsageIncrease * cold.rate;
                curRate += (1.0 - hotUsage) * hot.rate;

                coldUsage += coldUsageIncrease;
                if (coldUsage > 1.0000000000001) {
                    throw new RuntimeException("Crap! Got " + coldUsage);
                }
                hotUsage = 0.0;
                hotInd++;
            } else {
                // Advance cold to end
                double hotUsageIncrease = numMaxColds / hot.rate / hotDiff;
                curRate += hotUsageIncrease * hot.rate;
                curRate += (1.0 - coldUsage) * cold.rate;

                hotUsage += hotUsageIncrease;
                if (hotUsage > 1.0000000000001) {
                    throw new RuntimeException("Crap! Got " + coldUsage);
                }
                coldUsage = 0.0;
                coldInd++;
            }
        }

        if (curRate < 0.00000000001) {
            return "IMPOSSIBLE";
        }

        return String.format("%.010f", targetVolume / curRate);
    }

    private static class Source {
        private final double rate;
        private final double temp;
        public Source(double rate, double temp) {
            this.rate = rate;
            this.temp = temp;
        }
    }

    private List<Integer> nextIntList(int n) {
        ImmutableList.Builder<Integer> builder = ImmutableList.builder();
        for (int i = 0; i < n; i++) {
            builder.add(in.nextInt());
        }
        return builder.build();
    }

    private void runCases() throws FileNotFoundException {
        int numCases = in.nextInt();
        PrintWriter writer = new PrintWriter(PROBLEM + ".out");
        for (int casenum = 1; casenum <= numCases; casenum++) {
            String result = runCase();
            System.out.printf("Case #%d: %s%n", casenum, result);
            writer.printf("Case #%d: %s%n", casenum, result);
            writer.flush();
        }
    }

    public static void main(String[] args) throws FileNotFoundException {
        Scanner in = new Scanner(new File(PROBLEM + ".in"));
        new B(in).runCases();
    }
}
