package traintimetables;


import java.io.*;
import java.util.*;

/**
 * A Java Program to calculate how many trains are needed to leave two stations.
 * The Program reads in a data file containing the departure and arrival times
 * of 2 stations and stores them into 4 arrays. Using these four arrays the program
 * is able to determine how many trains can return trips and this, how many extra 
 * trains are needed to leave the stations. 
 * @author Alan Woodley
 */
public class TrainTimetables {

    /**
     * Converts a time formatted in HH:MM to minutes
     * @param str - A time in HH::MM format
     * @return an integer containing the number of minutes from 00:00
     */
    private int ConvertToMinutes(String str){
        // split the string in hours and minutes
        String[] strArr = str.split(":");
        // return HH * 60 + MM
        return (Integer.parseInt(strArr[0]) * 60 + Integer.parseInt(strArr[1]));
    
    }

    /**
     * 
     * @param available - an array of integers showing the times that trains are able to leave
     * @param departing - an array of integers showing the times that trains are scheduled to leave
     * @return an integer that states how many extra trains are need to leave the station 
     */
    private int StartAtStation(int[] available,  int[] departing){

        // sort the arrays
        Arrays.sort(available);
        Arrays.sort(departing);
        
        // declare indexes into the arrays
        int a = 0;
        int d = 0;        
       
        // traverse through the times of trains need to depart and see if any trains 
        // have already arrived and are ready to leave
        while(d < departing.length){
            if(a >= available.length) break;
            
            // if the next train available to depart (i.e. if a train has arrived and 
            // turned around) then we'll use it
            if(available[a] <= departing[d]) a++;

            // see what time the next train needs to depart 
            d++;
        }
        
        
        // return the difference between how many need to depart in total
        // and how many departed from those available
        return departing.length - a;
    }

    
    public void DoTrainTimetable(String infile, String outfile){
        
        try {
            BufferedReader reader = new BufferedReader(new FileReader(infile));
            BufferedWriter writer = new BufferedWriter(new FileWriter(outfile));

            // Read in the text file to get the number of timetables
            String line = reader.readLine().trim();
            int num_occ = Integer.parseInt(line);
            // For each timetable
            for(int i=0; i < num_occ; i++) {
                // Read in the text file to get the turnaround time
                line = reader.readLine().trim();
                int turn_around = Integer.parseInt(line);
                
               // Read in the text file to get the number of trains departing each station
                line = reader.readLine().trim();
                String[] lineArr = line.split(" ");
                int A_num = Integer.parseInt(lineArr[0]);
                int B_num = Integer.parseInt(lineArr[1]);
                
                 // declare int arrays for the times that the trains are available to 
                // leave the station and when they are scheduled to depart
                               
                int[] A_available = new int[B_num]; 
                int[] A_departing = new int[A_num];
                int[] B_available = new int[A_num]; 
                int[] B_departing = new int[B_num];

                // for each of the trains departing station A, store the departure time
                // and the time it is available to leave station B (arrival time + turnaround)
                // in the respective arrays (but make sure to convert the time into seconds first)
                for(int a=0; a< A_num; a++){
                    line = reader.readLine().trim();
                    lineArr = line.split(" ");
                    A_departing[a] = ConvertToMinutes(lineArr[0]);
                    B_available[a] = ConvertToMinutes(lineArr[1]) + turn_around;
                }
                
                // ditto for station B
                for(int b=0; b< B_num; b++){
                    line = reader.readLine().trim();
                    lineArr = line.split(" ");
                    B_departing[b] = ConvertToMinutes(lineArr[0]);
                    A_available[b] = ConvertToMinutes(lineArr[1]) + turn_around;
                }
                
               // now see how many trains need to start from station A
               int A_start = StartAtStation(A_available, A_departing);
                
                // same for B
               int B_start = StartAtStation(B_available, B_departing);
               
               // now print the results
//               System.out.println("Case #" + (i+1)  + ": " + A_start + " " + B_start);
               writer.write("Case #" + (i+1)  + ": " + A_start + " " + B_start + "\n");               
               
             
            } // for num_occurances
            
            reader.close();
            writer.close();
            
        } catch (Exception e){ 
            e.printStackTrace();
        }            

            
    }
    
    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
  
//        String infile = "B-large.in";
//        String outfile = "B-large.out";

        String infile = "B-small-attempt0.in";
        String outfile = "B-small-attempt0.out";

//        String infile = "TTTestIn.txt";
//        String outfile = "TTTestOut.txt";
        
        TrainTimetables me = new TrainTimetables();
        me.DoTrainTimetable(infile, outfile);
        
    }

}
