import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;
import java.util.Set;
import java.util.TreeSet;

class MaxFlow {
    class Edge {
        int to;
        int cap;
        int rev;
        
        Edge(int to, int cap, int rev) {
            this.to = to;
            this.cap = cap;
            this.rev = rev;
        }
    }
    
    int V;
    Edge[][] G;
    int[] len;
    int[] level;
    int[] iter;
    int INF = Integer.MAX_VALUE;
    
    MaxFlow(int n) {
        V = n;
        G = new Edge[n][4];
        len = new int[n];
        Arrays.fill(len, 0);
        level = new int[n];
        iter = new int[n];
    }
    
    void addEdge(int from, int to, int cap) {
        expand(from);
        expand(to);
        G[from][len[from]++] = new Edge(to, cap, len[to]);
        G[to][len[to]++] = new Edge(from, 0, len[from] - 1);
    }
    
    void expand(int index) {
        if (G[index].length == len[index]) {
            Edge[] tmp = new Edge[len[index] * 2];
            for (int i = 0; i < len[index]; i++)
                tmp[i] = G[index][i];
            G[index] = tmp;
        }
    }
    
    void bfs(int s) {
        Arrays.fill(level, -1);
        Queue<Integer> que = new LinkedList<Integer>();
        level[s] = 0;
        que.add(s);
        while (!que.isEmpty()) {
            int v = que.poll();
            for (int i = 0; i < len[v]; i++) {
                Edge e = G[v][i];
                if (e.cap > 0 && level[e.to] < 0) {
                    level[e.to] = level[v] + 1;
                    que.add(e.to);
                }
            }
        }
    }
    
    int dfs(int v, int t, int f) {
        if (v == t) return f;
        for (int i = iter[v]; i < len[v]; i++, iter[v]++) {
            Edge e = G[v][i];
            if (e.cap > 0 && level[v] < level[e.to]) {
                int d = dfs(e.to, t, Math.min(f, e.cap));
                if (d > 0) {
                    e.cap -= d;
                    G[e.to][e.rev].cap += d;
                    return d;
                }
            }
        }
        return 0;
    }
    
    int maxFlow(int s, int t) {
        int flow = 0;
        for (;;) {
            bfs(s);
            if (level[t] < 0) return flow;
            Arrays.fill(iter, 0);
            int f;
            while ((f = dfs(s, t, INF)) > 0) {
                flow += f;
            }
        }
    }
}

public class HelloWorld {
    
    public static void main(String[] args) {
        try {
//            BufferedReader br = new BufferedReader(new FileReader("D:/codejam/a.txt"));
//            BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(System.out));
            
            BufferedReader br = new BufferedReader(new FileReader("D:/codejam/C-small-attempt0.in"));
            BufferedWriter bw = new BufferedWriter(new FileWriter("D:/codejam/C-small-result.txt"));
//            BufferedReader br = new BufferedReader(new FileReader("D:/codejam/B-small-attempt1.in"));
//            
//            BufferedReader br = new BufferedReader(new FileReader("D:/codejam/B-large.in"));
//            BufferedWriter bw = new BufferedWriter(new FileWriter("D:/codejam/B-large-result.txt"));

            String line;

            line = br.readLine();
            int T = Integer.parseInt(line);
            
            for (int cas = 1; cas <= T; cas++) {
                line = br.readLine();
                String[] strs = line.split(" ");
                int w = Integer.parseInt(strs[0]);
                int h = Integer.parseInt(strs[1]);
                int b = Integer.parseInt(strs[2]);
                
                boolean[][] table = new boolean[w][h];
                for (int k = 0; k < b; k++) {
                    line = br.readLine();
                    strs = line.split(" ");
                    int x0 = Integer.parseInt(strs[0]);
                    int y0 = Integer.parseInt(strs[1]);
                    int x1 = Integer.parseInt(strs[2]);
                    int y1 = Integer.parseInt(strs[3]);
                    
                    for (int i = x0; i <= x1; i++) for (int j = y0; j <= y1; j++) {
                        table[i][j] = true;
                    }
                }
                MaxFlow flow = new MaxFlow(h * w * 2 + 2);
                int src = h*w*2;
                int dest = src+1;
                int n = h * w;
                
                for (int i = 0; i < w; i++) for (int j = 0; j < h; j++) {
                    flow.addEdge(i*h+j, i*h+j + n, 1);
                    for (int p = -1; p <= 1; p++)
                        for (int q = -1; q <= 1; q++) {
                            if (Math.abs(q) + Math.abs(p) == 1) {
                                int ni = i + p;
                                int nj = j + q;
                                if (ni >= 0 && ni < w && nj >= 0 && nj < h && !table[ni][nj]) {
                                    flow.addEdge(i*h+j + n, ni*h+nj, 1);
                                }
                            }
                        }
                }
                
                for (int i = 0; i < w; i++) {
                    if (!table[i][0])
                        flow.addEdge(src, i*h, 1);
                    if (!table[i][h-1])
                        flow.addEdge(n + i*h+(h-1), dest, 1);
                }
                
                
                
                
                bw.write("Case #" + cas + ": " + flow.maxFlow(src, dest));
                bw.newLine();
                bw.flush();
            }
            
            br.close();
            bw.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

}
