package year2017.round1c;

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.nio.file.Files;
import java.text.DecimalFormat;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Iterator;

public class A {
	
	public static void main(String [] args) throws IOException {
		try {
			solveFile("year2017r1c/A-example");
			solveFile("year2017r1c/A-small-attempt3");
			//solveFile("year2017r1c/A-large");
		} catch (IOException e) {
			System.out.println(e);
		}
	}
	private static Iterator<String> lines;
	
	private static void solveFile(String fileName) throws IOException {
		lines = Files.readAllLines(new File(fileName+".in").toPath()).iterator();
		PrintWriter output = new PrintWriter(fileName+".out");
		int numLines = Integer.parseInt(lines.next());
		for (int lineNum = 1; lineNum <= numLines; lineNum++) {
			outln("solving case "+lineNum);
			output.println("Case #"+lineNum+": "+solve());
		}
		output.close();
		System.out.println("done");
	}
	
	private static void outln(String s) {
		System.out.println(s);		
	}
	
	private static String solve() {
		String[] NK = lines.next().split(" ");
		int N = Integer.parseInt(NK[0]);
		int K = Integer.parseInt(NK[1]);
		
		Pancake[] fullStack = new Pancake[N];
		
		for (int i = 0; i < N; i++) {
			Pancake pancake = new Pancake(lines.next().split(" "));
			fullStack[i] = pancake;
		}
		Pancake[] sortedBySide = fullStack.clone();
		Arrays.sort(sortedBySide, bySide);
		outln("original "+Arrays.toString(fullStack));
		outln("by side "+Arrays.toString(sortedBySide));
		Pancake lowSide = sortedBySide[K-1];
		Pancake bestR = null;
		for (int i=0; i<K; i++) {
			if (bestR == null || sortedBySide[i].R > bestR.R) {
				bestR = sortedBySide[i];
			}
		}
		double bestTotalGain = 0;
		Pancake bestReplacement = null;
		for (int i=K; i<N; i++) {
			Pancake candidate = sortedBySide[i];
			outln("checking candidate "+i+" "+candidate);
			if (candidate.R <= bestR.R) {
				continue;
			}
			double areaGain = candidate.area() - bestR.area();
			double sideLoss = candidate.side() - lowSide.side();
			double totalGain = areaGain + sideLoss;
			if (totalGain > bestTotalGain) {
				bestReplacement = candidate;
				bestTotalGain = totalGain;
			}
		}
		if (bestReplacement != null) {
			outln("replacing "+bestR+" with "+bestReplacement);
			bestR = bestReplacement;
			sortedBySide[K-1] = bestReplacement;
		}
		outln("bestR is "+bestR);
		double totalSide = 0;
		for (int i = 0; i<K; i++) {
			totalSide += sortedBySide[i].side();
		}
		DecimalFormat format = new DecimalFormat("#.000000000");
		return format.format(Math.PI * (totalSide + bestR.area()));
	}
	
    static final Comparator<Pancake> bySide = 
        new Comparator<Pancake>() {
			public int compare(Pancake p1, Pancake p2) {
				return 0-Double.compare(p1.side(), p2.side());
			}
    	};
}

class Pancake {
	public final double R;
	public final double H;
	public boolean chosen = false;
	
	public Pancake(String[] RH) {
		R = Double.parseDouble(RH[0]);
		H = Double.parseDouble(RH[1]);
	}
	public double area() {
		return R*R;
	}
	public double side() {
		return 2*R*H;
	}
	public String toString() {
		return R+"/"+H;
	}
}
