import java.io.*;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class DeceitfulWar {

    private static void print(double[] a) {
        for (double e : a) {
            System.out.printf("%.3f ", e);
        }
        System.out.println();
    }

    private class Pair {
        int p1, p2;

        private Pair(int p1, int p2) {
            this.p1 = p1;
            this.p2 = p2;
        }
    }

    private List<Double> fromArray(double[] x) {
        List<Double> l = new ArrayList<Double>();
        for (double d : x) {
            l.add(d);
        }
        return l;
    }

    private double[] fromString(int n, String s) {
        double[] v = new double[n];
        String[] vals = s.split(" ");
        int i = 0;
        for (String val : vals) {
            v[i++] = Double.parseDouble(val);
        }
        return v;
    }

    public Pair solve(int caseNumber, int n, String ns, String ks) {
        Pair p = solve(fromString(n, ns), fromString(n, ks));
        System.out.printf("Case #%d: %d %d\n", caseNumber, p.p1, p.p2);
        return p;
    }

    public Pair solve(double[] nv, double[] kv) {
        int war = 0, dWar = 0;
        int n = nv.length;
        Arrays.sort(nv);
        Arrays.sort(kv);

//        print(nv);
//        print(kv);

        List<Double> naomiValues = fromArray(nv);
        List<Double> kenValues = fromArray(kv);
        List<Double> d_kenValues = fromArray(kv);

        for (int i = 0; i < n; i++) {
            Double nValue= naomiValues.remove(0);

            int kPos = findFirstGreater(kenValues, nValue);
            int d_kPos = findFirstGreater(d_kenValues, nValue);

            if (kPos == -1) {
                //naomi's value is greater than all ken's values
                kenValues.remove(0);
                war++;
                //dWar++;
            } else {
                Double kValue = kenValues.remove(kPos);
            }

            //deceitful
            if (d_kPos == -1 || nValue > d_kenValues.get(0)) {
                d_kenValues.remove(0);
                dWar++;
            } else {
                d_kenValues.remove(d_kenValues.size() - 1);
            }

        }
        return new Pair(dWar, war);
    }

    private int findFirstGreater(List<Double> list, double val) {
        for (int i = 0; i < list.size(); i++) {
            if (list.get(i) > val) {
                return i;
            }
        }
        return -1;
    }


    public static void main(String[] args) throws Exception {

        InputStream is = new FileInputStream("/tmp/warinput.dat");
        PrintWriter wr = new PrintWriter(new File("/tmp/waroutput.dat"));
        BufferedReader br = new BufferedReader(new InputStreamReader(is));

        DeceitfulWar dw = new DeceitfulWar();
        int n = Integer.parseInt(br.readLine());
        for (int i = 0; i < n; i++) {
            int nt = Integer.parseInt(br.readLine());
            String ns = br.readLine();
            String ks = br.readLine();
            dw.solve(i + 1, nt, ns, ks);
        }

        /*dw.solve(1, "2", "1");
        dw.solve(1, "1", "2");
        dw.solve(2, "1 3", "2 4");
        dw.solve(2, "1 5", "3 4");
        dw.solve(2, "0.7 0.2", "0.8 0.3");
        dw.solve(3, "0.5 0.1 0.9", "0.6 0.4 0.3");
        dw.solve(9, "0.186 0.389 0.907 0.832 0.959 0.557 0.300 0.992 0.899", "0.916 0.728 0.271 0.520 0.700 0.521 0.215 0.341 0.458");
*/
        br.close();
        is.close();
        wr.close();
    }


}
