import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.TreeSet;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class Google2Grass {

	public static boolean allEqRow(int[][] matriz, int nRows, int nCols,
			int row_i, int value) {
		int[] row = matriz[row_i];
		for (int i = 0; i < nCols; i++) {
			if (row[i] != value) {
				return false;
			}
		}
		return true;
	}

	public static boolean allEqCol(int[][] matriz, int nRows, int nCols,
			int col_i, int value) {
		for (int i = 0; i < nRows; i++) {
			if (matriz[i][col_i] != value) {
				return false;
			}
		}
		return true;
	}

	public static int min(int[] array) {
		int min = array[0];
		for (int i = 1; i < array.length; i++) {
			min = Math.min(min, array[i]);
		}
		return min;
	}

	public static boolean eval(int[][] matriz, int nRows, int nCols, int base) {
		if (nRows == 1 || nCols == 1) {
			return true;
		}

		int minimum = -1;
		// obtain the minimum
		if (nRows == 1) {
			minimum = min(matriz[0]);
		} else if (nRows == 2) {
			minimum = Math.min(min(matriz[0]), min(matriz[1]));
		} else {
			minimum = Math.min(min(matriz[0]), min(matriz[nRows - 1]));
			for (int i = 1; i < nRows - 1; i++) {
				minimum = Math.min(minimum, matriz[i][0]);
				if (matriz[i].length > 1) {
					minimum = Math
							.min(minimum, matriz[i][matriz[i].length - 1]);
				}
			}
		}
		if (minimum <= base) {
			return false;
		}

		TreeSet rowsToRemove = new TreeSet();
		TreeSet colsToRemove = new TreeSet();

		// validate rows to delete
		for (int i = 0; i < nRows; i++) {
			if (matriz[i][0] == minimum && matriz[i][nCols - 1] == minimum
					&& allEqRow(matriz, nRows, nCols, i, minimum)) {
				rowsToRemove.add(i);
			}
		}

		for (int j = 0; j < nCols; j++) {
			if (matriz[0][j] == minimum && matriz[nRows - 1][j] == minimum
					&& allEqCol(matriz, nRows, nCols, j, minimum)) {
				colsToRemove.add(j);
			}
		}

		final int nRowsNew = nRows - rowsToRemove.size();
		final int nColsNew = nCols - colsToRemove.size();
		if (nRowsNew == 0 || nColsNew == 0 || nRowsNew == 1 || nColsNew == 1) {
			return true;
		}
		int[][] simplifiedMatrix = new int[nRowsNew][];
		int ki = 0;
		for (int i = 0; i < nRows; i++) {
			if (!rowsToRemove.contains(i)) {
				int[] newRow = new int[nColsNew];
				int[] row = matriz[i];
				int kj = 0;
				for (int j = 0; j < nCols; j++) {
					if (!colsToRemove.contains(j)) {
						newRow[kj] = row[j];
						kj++;
					}
				}
				simplifiedMatrix[ki] = newRow;
				ki++;
			}
		}

		return eval(simplifiedMatrix, nRowsNew, nColsNew, minimum);
	}

	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		int t;
		t = Integer.parseInt(in.nextLine());
		ExecutorService executor = Executors.newFixedThreadPool(Runtime
				.getRuntime().availableProcessors());
		List<Future> futures = new ArrayList<Future>();
		for (int i = 0; i < t; i++) {
			String nm = in.nextLine();
			String[] nmSplit = nm.split(" ");
			final Integer N = Integer.parseInt(nmSplit[0]);
			final Integer M = Integer.parseInt(nmSplit[1]);
			final int[][] matriz = new int[N][];
			for (int row_i = 0; row_i < N; row_i++) {
				String rowString = in.nextLine();
				String[] rowStringSplit = rowString.split(" ");
				int[] row = new int[M];
				for (int col = 0; col < M; col++) {
					row[col] = Integer.parseInt(rowStringSplit[col]);
				}
				matriz[row_i] = row;
			}
			futures.add(executor.submit(new Callable<String>() {

				@Override
				public String call() throws Exception {
					boolean result = eval(matriz, N, M, 0);
					return result ? "YES" : "NO";
				}

			}));
		}
		int i = 1;
		for (Future future : futures) {
			try {
				System.out.println("Case #" + (i) + ": " + future.get());
			} catch (InterruptedException e) {
				e.printStackTrace();
			} catch (ExecutionException e) {
				e.printStackTrace();
			}
			i++;
		}
		executor.shutdown();
	}

}
