import java.util.ArrayList;
import java.util.Arrays;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Scanner;
import java.util.Set;
import java.util.TreeSet;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

//Threasure
public class Google4T {

	// less brute force approach
	public static List<Integer> eval(List<Integer> keys,
			List<Integer>[] cofres) {
		LinkedHashSet<Integer> noEscogidos= new LinkedHashSet<Integer>();
		for (int i=0; i< cofres.length; i++) {
			noEscogidos.add(i);
		}
		
		List<Integer> result = eval3(keys, cofres, noEscogidos, TIPO_HEURISTICA.SECUENCIAL);
		if (result != null) {
			return result;
		} else {
			return eval3(keys, cofres, noEscogidos, TIPO_HEURISTICA.SEGURA);
		}
	}

	/*
	public static List<Integer> eval2(List<Integer> keys,
			List<Integer>[] cofres, List<Integer> noEscogidos) {
		if (noEscogidos.size() == 0) {
			return new ArrayList<>();
		}
		for (Integer i : noEscogidos) {
			List<Integer> copiaLlaves = new ArrayList<Integer>(keys);
			if (!abrirCofre(i, copiaLlaves, cofres)) {
				continue;
			} else {
				List<Integer> copiaNoEscogidos = new ArrayList<>(noEscogidos);
				copiaNoEscogidos.remove(i);
				List<Integer> result = eval2(copiaLlaves, cofres, copiaNoEscogidos);
				if (result == null) {
					continue;
				} else {
					result.add(0, i);
					return result;
				}
			}
		}
		return null;
	}
	*/

	
	public static List<Integer> eval3(List<Integer> keys,
			List<Integer>[] cofres, Set<Integer> noEscogidos,  TIPO_HEURISTICA heuristica) {
		if (noEscogidos.size() == 0) {
			return new ArrayList<>();
		}
		int mejorOpcion = -1;
		int mejorValoracion = -1;
		for (Integer i : noEscogidos) {
			List<Integer> copiaLlaves = new ArrayList<Integer>(keys);
			int valoracion = convieneAbrirCofre(i, copiaLlaves, cofres, heuristica);
			if (valoracion > mejorValoracion) {
				mejorValoracion = valoracion;
				mejorOpcion = i;
			} 
		}
		if (mejorValoracion == -1) {
			return null;
		} else {
			List<Integer> copiaLlaves = new ArrayList<Integer>(keys);
			LinkedHashSet<Integer> copiaNoEscogidos = new LinkedHashSet<>(noEscogidos);
			abrirCofre(mejorOpcion, copiaLlaves, cofres);
			copiaNoEscogidos.remove(mejorOpcion);
			List<Integer> result = eval3(copiaLlaves, cofres, copiaNoEscogidos, heuristica);
			if (result == null) {
				return null;
			} else {
				result.add(0, mejorOpcion);
				return result;
			}
		}
	}	
	
	//very brute force aproach
	/*
	public static List<Integer> eval(List<Integer> keys, List<Integer>[] cofres) {
		List<List<Integer>> permutations = new ArrayList<List<Integer>>();
		List<Integer> ids = new ArrayList<Integer>();
		for (int i=0; i < cofres.length; i++) {
			ids.add(i);
		}	
    	permute(permutations, ids, 0);	
		for (List<Integer> permutation : permutations) {
			List<Integer> copykeys = new ArrayList<Integer>(keys);
			boolean found = true;
			for (Integer step: permutation) {
				boolean result = abrirCofre(step, copykeys, cofres);
				if (!result) {
					found = false;
				}
			}
			if (found) {
				return permutation;
			}
		}
		return null;
	}
	*/
	enum TIPO_HEURISTICA { SECUENCIAL, SEGURA}

	private static int convieneAbrirCofre(Integer step, List<Integer> keys,
			List<Integer>[] cofres, TIPO_HEURISTICA heuristica) {
		int oldKeySize = keys.size();
		List<Integer> cofre = cofres[step];
		Integer key = cofre.get(0);
		if (!keys.contains(key)) {
			return -1;
		}
		keys.remove(key);
		Integer nNewKeys = cofre.get(1);
		if (keys.size() == 0 && nNewKeys == 0) {
			return 0;
		}
		if (nNewKeys > 0) {
			for (int i = 0; i < nNewKeys; i++) {
				keys.add(cofre.get(2 + i));
			}
		}
		if (heuristica.equals(TIPO_HEURISTICA.SECUENCIAL)) {
			return 1;
		} else if (heuristica.equals(TIPO_HEURISTICA.SEGURA)) {
			int res;
			if (keys.contains(key)) {
				res = 40;
			} else {
				res = 1;
			}
			if (keys.size() > oldKeySize) {
				res += keys.size() - oldKeySize;
			}
			return res;
		}
		return 1;
	}
	
	private static boolean abrirCofre(Integer step, List<Integer> keys,
			List<Integer>[] cofres) {
		List<Integer> cofre = cofres[step];
		Integer key = cofre.get(0);
		if (!keys.contains(key)) {
			return false;
		}
		keys.remove(key);
		Integer nNewKeys = cofre.get(1);
		if (nNewKeys > 0) {
			for (int i = 0; i < nNewKeys; i++) {
				keys.add(cofre.get(2 + i));
			}
		}
		return true;
	}

	/*
	public static void permute(List<List<Integer>> permutations, List<Integer> arr, int k) {
		for (int i = k; i < arr.size(); i++) {
			java.util.Collections.swap(arr, i, k);
			permute(permutations, arr, k + 1);
			java.util.Collections.swap(arr, k, i);
		}
		if (k == arr.size() - 1) {
			permutations.add(new ArrayList(arr));
		}
	}
	*/
	   
	   
	/*
	    public static void main(String[] args){
//	    	System.out.println(eval(Arrays.asList(new Integer[]{1}), new List[]{
//	    		Arrays.asList(new Integer[]{1, 0}),
//	    		Arrays.asList(new Integer[]{1, 2, 1, 3}),
//	    		Arrays.asList(new Integer[]{2, 0}),
//	    		Arrays.asList(new Integer[]{3, 1, 2})
//	    		}));
	    	
	    	System.out.println(eval(Arrays.asList(new Integer[]{1, 1, 1}), new List[]{
	    		Arrays.asList(new Integer[]{1, 0}),
	    		Arrays.asList(new Integer[]{1, 0}),
	    		Arrays.asList(new Integer[]{1, 0})
    		}));

	    	System.out.println(eval(Arrays.asList(new Integer[]{2}), new List[]{
	    		Arrays.asList(new Integer[]{1, 1, 1})
    		}));
	    }
	    */
	
	public static List<Integer> readFromString(String string) {
		String[] sSplit = string.split(" ");
		List<Integer> list = new ArrayList<Integer>();
		for (int k=0; k < sSplit.length; k++) {
			list.add(Integer.valueOf(sSplit[k]));
		}
		return list;
	}

	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		int t;
		t = Integer.parseInt(in.nextLine());
		ExecutorService executor = Executors.newFixedThreadPool(Runtime
				.getRuntime().availableProcessors());
		List<Future> futures = new ArrayList<Future>();
		for (int i = 0; i < t; i++) {
			String kn = in.nextLine();
			String[] knSplit = kn.split(" ");
			final Integer K = Integer.parseInt(knSplit[0]);
			final Integer N = Integer.parseInt(knSplit[1]);
			final List<Integer> keyList = readFromString(in.nextLine());
			final List[] cofres = new List[N];
			for (int n=0; n< N; n++) {
				List<Integer> cofre = readFromString(in.nextLine());
				cofres[n] = cofre;
			}
			
			futures.add(executor.submit(new Callable<String>() {

				@Override
				public String call() throws Exception {
					List<Integer> result = eval(keyList,  cofres);
					if (result == null) {
						return "IMPOSSIBLE";
					} else {
						StringBuilder res = new StringBuilder();
						for (int i=0; i< result.size(); i++) {
							res.append(result.get(i)+1);
							if (i != result.size() -1) {
								res.append(" ");
							}
						}
						return res.toString();
					}
				}

			}));
		}
		int i = 1;
		for (Future future : futures) {
			try {
				System.out.println("Case #" + (i) + ": " + future.get());
			} catch (InterruptedException e) {
				e.printStackTrace();
			} catch (ExecutionException e) {
				e.printStackTrace();
			}
			i++;
		}
		executor.shutdown();
	}
}
