package gcj2016.r1b;

import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.Writer;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Scanner;

/**
 *
 * @author alecn2002 <alecn2002@gmail.com>
 */
public class A {
    
    private static final String[] digits = {
        "ZERO", "ONE", "TWO", "THREE", "FOUR", "FIVE", "SIX", "SEVEN", "EIGHT", "NINE"
//       Z       O/ZWU   W       R/Z      U       V/S     X    S/X        G
            // ZWUXG 02468
            // O/ZWU 1
            // R/Z   3
            // S/X   7
            // V/S   5
            // I     9
    };
    
    
    private static final List<Cache> digitsCached = cacheDigits(digits);
   
    private static class Cache extends HashMap<Character, Integer> {
        
        public Cache(String input) {
            for (Character c : input.toCharArray()) {
                if (!containsKey(c)) {
                    put(c, 1);
                } else {
                    put(c, get(c) + 1);
                }
            }
        }
        
        public Cache subtract(Cache other, int repeat) {
            for (Map.Entry entry : other.entrySet()) {
                Character key = (Character) entry.getKey();
                Integer v = (Integer) entry.getValue();
                if (this.containsKey(key)) {
                    v = this.get(key) - repeat * v;
                    if (v > 0) {
                        this.put(key, v);
                    } else {
                        this.remove(key);
                    }
                }
            }
            return this;
        }
        
        public Cache subtract(Cache other) {
            return subtract(other, 1);
        }

    }
    
   
    private static final List<Cache> cacheDigits(String[] input) {
        List<Cache> ans = new ArrayList<>(input.length);
        
        for (String s : input) {
            ans.add(new Cache(s));
        }
        
        return ans;
    }

    private static String solve(String s) {

        Map<Character, Integer> uniqs = new HashMap<>();
        
        uniqs.put('Z', 0);
        uniqs.put('W', 2);
        uniqs.put('U', 4);
        uniqs.put('X', 6);
        uniqs.put('G', 8);
        uniqs.put('O', 1);
        uniqs.put('R', 3);
        uniqs.put('S', 7);
        uniqs.put('V', 5);
        uniqs.put('I', 9);
        
        String order = "ZWUXGORSVI";
        
        List<Integer> digitsFound = new ArrayList<>();
        
        Cache cache = new Cache(s);
        
        for (Character c : order.toCharArray()) {
            if (cache.containsKey(c)) {
                int digit = uniqs.get(c);
                Cache digitCache = digitsCached.get(digit);
                Integer repeat = cache.get(c);
                for (int i = 0 ; i < repeat ; ++i) {
                    digitsFound.add(digit);
                }
                cache.subtract(digitCache, repeat);
            }
        }
        
        digitsFound.sort(null);
        
        StringBuilder sb = new StringBuilder(digitsFound.size());
        for (Integer digit : digitsFound) {
            sb.append(digit);
        }
        return sb.toString();
    }

    public static void main(String[] args) throws Exception {
        if (args.length != 1) {
            throw new Exception("Usage: QR_20160409 filename");
        }
        File in = new File(args[0] + ".in");
        try (Scanner sc = new Scanner(new FileReader(in))) {
            File out = new File(args[0] + ".out");
            try (Writer w = new FileWriter(out)) {
                final int T = sc.nextInt();
                sc.nextLine();
                for (int i = 0 ; i < T ; ++i) {
                    String ans = solve(sc.nextLine());
                    String fullAns = String.format("Case #%d: %s\n", i + 1, ans);
                    System.err.print(fullAns);
                    w.write(fullAns);
                }
            }
        }
    }
    
}
