package universe;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.LinkedHashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;

public class SavingTheUniverse {

	private static final boolean LOG_ENABLED = false;
	
	private static final String FILE_NAME = "C:\\eclipse-workspace\\google-code-jam\\google-code-jam\\src\\universe\\A-large.in";
//	private static final String FILE_NAME = "C:\\eclipse-workspace\\google-code-jam\\google-code-jam\\src\\universe\\extra-tests.in";
//	private static final String FILE_NAME = "C:\\eclipse-workspace\\google-code-jam\\google-code-jam\\src\\universe\\illegals.in";
//	private static final String FILE_NAME = "C:\\eclipse-workspace\\google-code-jam\\google-code-jam\\src\\universe\\A-small.in";
	
	public static void main(String[] args) throws Exception {
		SavingTheUniverse test = new SavingTheUniverse();
		test.run();
	}
	
	public void run() throws Exception {
		List<String> lines = readFile(FILE_NAME);
		int numCases = Integer.parseInt(lines.get(0));
		int index = 1;
		for (int i = 1; i <= numCases; i++) {
			TestData testData = new TestData();
			index = testData.parse(lines, index);

			String result = runTest(testData);
			System.out.println("Case #"+i+": " + result);
		}
		
		for (int i = index; i < lines.size(); i++) {
			assert lines.get(i).trim().length() == 0 : "Ignored line " + lines.get(i);
		}
	}

	public String runTest(TestData testData) throws Exception {
		int numSwitches = 0;
		List<String> remainingQueries = new LinkedList<String>(testData.queries);
		if (remainingQueries.isEmpty()) {
			return Integer.toString(numSwitches);
		}
		
		String currentEngine = chooseEngine(remainingQueries, testData.searchEngines, null);
		while (!remainingQueries.isEmpty()) {
			String nextQuery = remainingQueries.get(0);
			if (currentEngine.equals(nextQuery)) {
				currentEngine = chooseEngine(remainingQueries, testData.searchEngines, currentEngine);
				numSwitches++;
			} else {
				remainingQueries.remove(0);
			}
		}
		
		return Integer.toString(numSwitches);
	}
	
	private String chooseEngine(List<String> queries, Set<String> engines, String excludingEngine) {
		assert engines.containsAll(queries) : "Engines does not contain all queries: " + queries + " from choice of " + engines;
		
		String best = null;
		int bestIndex = 0;
		for (String engine : engines) {
			int firstIndex = queries.indexOf(engine);
			if (bestIndex >=0 && (firstIndex == -1 || firstIndex > bestIndex)) {
				best = engine;
				bestIndex = firstIndex;
			}
		}

		assert best != null : "Did not find best for " + queries + " from choice of " + engines;
		assert bestIndex != 0 : "Best " + best + " has index 0 for " + queries + " from choice of " + engines;
		assert !best.equals(excludingEngine) : "Chose " + best + " for " + queries + " from choice of " + engines;
		log("Chose " + best + " for " + queries + " from choice of " + engines);
		
		return best;
	}
	
	private static class TestData {
		public int numSearchEngines;
		public Set<String> searchEngines = new LinkedHashSet<String>();
		public int numQueries;
		public List<String> queries = new ArrayList<String>();
		
		public int parse(List<String> lines, int startIndex) {
			int index = startIndex;
			numSearchEngines = Integer.parseInt(lines.get(index++).trim());
			for (int i = 0; i < numSearchEngines; i++) {
				searchEngines.add(lines.get(index++));
			}
			numQueries = Integer.parseInt(lines.get(index++).trim());
			for (int i = 0; i < numQueries; i++) {
				queries.add(lines.get(index++));
			}

			return index;
		}
	}
	
	public void log(String message) {
		if (LOG_ENABLED) {
			System.out.println("LOG: " + message);
		}
	}
	
	public List<String> readFile(String fileName) throws Exception {
		File file = new File(fileName);
		BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(file)));
		try {
			List<String> result = new ArrayList<String>();
			String line;
			do {
				line = reader.readLine();
				if (line != null) {
					result.add(line);
				}
			} while (line != null);
			
			return result;
			
		} finally {
			reader.close();
		}
	}
}
