package trains;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.LinkedHashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;

public class TrainTimetable {

//	private static final String FILE_NAME = "C:\\eclipse-workspace\\google-code-jam\\google-code-jam\\src\\trains\\example.in";
//	private static final String FILE_NAME = "C:\\eclipse-workspace\\google-code-jam\\google-code-jam\\src\\trains\\extra-tests.in";
//	private static final String FILE_NAME = "C:\\eclipse-workspace\\google-code-jam\\google-code-jam\\src\\trains\\illegals.in";
	private static final String FILE_NAME = "C:\\eclipse-workspace\\google-code-jam\\google-code-jam\\src\\trains\\B-large.in";
	
	public static void main(String[] args) throws Exception {
		TrainTimetable test = new TrainTimetable();
		test.run();
	}
	
	public void run() throws Exception {
		List<String> lines = readFile(FILE_NAME);
		int numCases = Integer.parseInt(lines.get(0));
		int index = 1;
		for (int i = 1; i <= numCases; i++) {
			TestData testData = new TestData();
			index = testData.parse(lines, index);

			String result = runTest(testData, i);
			System.out.println("Case #"+i+": " + result);
		}
		
		for (int i = index; i < lines.size(); i++) {
			assert lines.get(i).trim().length() == 0 : "Ignored line " + lines.get(i);
		}
	}

	public String runTest(TestData testData, int testNum) throws Exception {
		// 0 <= NA, NB <= 100
		final int MAX_NUM_TRAINS = 200;

//		final int MAX_NUM_TRAINS = 4;

		for (int numTrains = 0; numTrains <= MAX_NUM_TRAINS; numTrains++) {
			for (int startA = 0; startA <= numTrains; startA++) {
				int startB = numTrains-startA;

				// numTrains=0,startA=0,startB=0
				// numTrains=1,startA=0,startB=1;startA=1,startB=0
				// numTrains=2,startA=0,startB=2;startA=1,startB=1;startA=2,startB=0
				// etc

				log("testing startA=" + startA + "; startB=" + startB);
				boolean possible = new TrainSystem(testData, startA, startB).isPossible();
				
				if (possible) {
					return startA + " " + startB;
				}
			}
		}
		
		throw new Exception("No solution found with " + MAX_NUM_TRAINS + " for test " + testNum + ": " + testData);
	}
		
	private static class TestData {
		public int turnaroundTime;
		public int numAtoB;
		public int numBtoA;
		public List<JourneyTime> journeyAtoB = new ArrayList<JourneyTime>();
		public List<JourneyTime> journeyBtoA = new ArrayList<JourneyTime>();
		
		public Set<String> searchEngines = new LinkedHashSet<String>();
		public int numQueries;
		public List<String> queries = new ArrayList<String>();
		
		public int parse(List<String> lines, int startIndex) {
			int index = startIndex;
			turnaroundTime = Integer.parseInt(lines.get(index++).trim());
			String[] numJourneys = lines.get(index++).trim().split(" ");
			assert numJourneys.length == 2;
			numAtoB = Integer.parseInt(numJourneys[0]);
			numBtoA = Integer.parseInt(numJourneys[1]);

			for (int i = 0; i < numAtoB; i++) {
				journeyAtoB.add(new JourneyTime(lines.get(index++).trim()));
			}
			for (int i = 0; i < numBtoA; i++) {
				journeyBtoA.add(new JourneyTime(lines.get(index++).trim()));
			}

			Collections.sort(journeyAtoB);
			Collections.sort(journeyBtoA);
			
			return index;
		}
	}

	enum Station {
		A,B
	}
	
	private class TrainSystem {
		final TestData testData;
		final Set<Train> stationA = new LinkedHashSet<Train>();
		final Set<Train> stationB = new LinkedHashSet<Train>();
		final int numStartAtA;
		final int numStartAtB;
		int time = 0;
		
		private class Train {
			int timeNextAvailable = 0;
			
			Train() {
			}

			public boolean isAvailable() {
				return timeNextAvailable <= time;
			}

			public void move(JourneyTime journey) {
				timeNextAvailable = journey.endTime + testData.turnaroundTime;
			}
			
			public String toString() {
				return "next=" + timeNextAvailable;
			}
		}

		public String toString() {
			return "{startA=" + numStartAtA + "; startB=" + numStartAtB + "; currentA=" + stationA.size() + "; currentB=" + stationB.size() + "}";
		}
		
		public String toVerboseString() {
			return toString() + " allA=" + stationA + "; allB=" + stationB;
		}
		
		TrainSystem(TestData testData, int numAtA, int numAtB) {
			this.testData = testData;
			this.numStartAtA = numAtA;
			this.numStartAtB = numAtB;
			
			for (int i = 0; i < numAtA; i++) {
				stationA.add(new Train());
			}
			for (int i = 0; i < numAtB; i++) {
				stationB.add(new Train());
			}
		}
		
		boolean isPossible() {
			List<JourneyTime> journeyAtoB = new LinkedList<JourneyTime>(testData.journeyAtoB);
			List<JourneyTime> journeyBtoA = new LinkedList<JourneyTime>(testData.journeyBtoA);
			
			while (!(journeyAtoB.isEmpty() && journeyBtoA.isEmpty())) {
				JourneyTime atobContender = journeyAtoB.isEmpty() ? null : journeyAtoB.get(0);
				JourneyTime btoaContender = journeyBtoA.isEmpty() ? null : journeyBtoA.get(0);
				assert !(atobContender == null && btoaContender == null);
				
				boolean moved;
				if (btoaContender == null || (atobContender != null && atobContender.compareTo(btoaContender) < 0)) {
					assert btoaContender == null || atobContender.startTime <= btoaContender.startTime;
					moved = moveAtoB(atobContender);
					if (!moved) {
						log("Not possible with " + toString() + "; stuck at " + atobContender + " from A to B");
						return false;
					} else {
						JourneyTime removed = journeyAtoB.remove(0);
						assert removed == atobContender : "removed=" + removed + "; expected=" + atobContender;
					}
				} else {
					assert atobContender == null || btoaContender.startTime <= atobContender.startTime;
					moved = moveBtoA(btoaContender);
					if (!moved) {
						log("Not possible with " + toString() + "; stuck at " + btoaContender + " from B to A");
						return false;
					} else {
						JourneyTime removed = journeyBtoA.remove(0);
						assert removed == btoaContender : "removed=" + removed + "; expected=" + btoaContender;
					}
				}
				
				if (!moved) {
					return false;
				}
			}

			log("Possible with " + toString());
			return true;
		}
		
		boolean moveAtoB(JourneyTime journey) {
			return move(journey, stationA, stationB);
		}

		boolean moveBtoA(JourneyTime journey) {
			return move(journey, stationB, stationA);
		}

		private boolean move(JourneyTime journey, Collection<Train> from, Collection<Train> to) {
			time = journey.startTime;
			
			Train trainToMove = null;
			for (Train train : from) {
				if (train.isAvailable()) {
					trainToMove = train;
				}
			}
			if (trainToMove != null) {
				trainToMove.move(journey);
				from.remove(trainToMove);
				to.add(trainToMove);
				return true;
			} else {
				return false;
			}
		}

	}
	
	private static class JourneyTime implements Comparable<JourneyTime> {
		final String description;
		final int startTime;
		final int endTime;
		
		public JourneyTime(String description) {
			this.description = description;
			String[] split = description.split(" ");
			String start = split[0];
			String end = split[1];
			
			startTime = timeToInt(start);
			endTime = timeToInt(end);
		}
		
		private int timeToInt(String time) {
			String[] split = time.split(":");
			int hours = Integer.parseInt(split[0]);
			int mins = Integer.parseInt(split[1]);
			return hours*60 + mins;
		}

		public int compareTo(JourneyTime o) {
			if (startTime < o.startTime) {
				return -1;
			} else if (startTime == o.startTime) {
				return 0;
			} else {
				return 1;
			}
		}
		
		public String toString() {
			return description;
		}
	}
	
	public void log(String message) {
//		System.out.println("LOG: " + message);
	}
	
	public List<String> readFile(String fileName) throws Exception {
		File file = new File(fileName);
		BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(file)));
		try {
			List<String> result = new ArrayList<String>();
			String line;
			do {
				line = reader.readLine();
				if (line != null) {
					result.add(line);
				}
			} while (line != null);
			
			return result;
			
		} finally {
			reader.close();
		}
	}
}
