package qualification17;

import java.io.*;
import java.util.Comparator;
import java.util.Objects;
import java.util.PriorityQueue;
import java.util.Scanner;

import static java.lang.Long.signum;

/**
 * Created by Alexander Schiewe on 08.04.2017.
 */
public class Stalls {

    public static void main(String[] args) throws IOException {
        String dataset = "small";
        String attempt = "1";
        String test = "2";
        Scanner in = new Scanner(new BufferedReader(new FileReader("data/qualification17/C-" + dataset + "-" + test + "-attempt" + attempt + ".in")));
        BufferedWriter writer = new BufferedWriter(new FileWriter("data/qualification17/C-" + dataset + "-" + test + "-attempt" + attempt + ".out"));
        int t = in.nextInt();
        for (int i = 1; i <= t; ++i) {
            long N = in.nextLong();
            long K = in.nextLong();
            Pair<Long, Long> solution = getSolution(N, K);
            writer.write("Case #" + i + ": " + solution.getValue() + " " + solution.getKey() + "\n");
            System.out.println("Case #" + i + ": " + solution.getValue() + " " + solution.getKey());
        }
        writer.close();
        in.close();
    }

    private static Pair<Long, Long> getSolution(long numberOfStalls, long numberOfGuests){
        Pair<Long, Long> initialField = new Pair<>(1L, numberOfStalls);
        PriorityQueue<Pair<Long, Long>> queue = new PriorityQueue<>(11, new Comparator<Pair<Long, Long>>() {
            @Override
            public int compare(Pair<Long, Long> longLongPair, Pair<Long, Long> t1) {
                return -1 * signum((longLongPair.getValue() - longLongPair.getKey()) - (t1.getValue() - t1.getKey()));
            }
        });
        queue.add(initialField);
        Pair<Long, Long> biggestField;
        for(long guest = 1; guest < numberOfGuests; guest++){
            biggestField = queue.poll();
            if(Objects.equals(biggestField.getValue(), biggestField.getKey())){
                continue;
            }
            long newPosition = findMiddle(biggestField.getKey(), biggestField.getValue());
            //System.out.println("Guest " + guest + ", Position: " + newPosition);
            if(newPosition != biggestField.getKey()){
                queue.add(new Pair<>(biggestField.getKey(), newPosition - 1));
            }
            if(newPosition != biggestField.getValue()){
                queue.add(new Pair<>(newPosition + 1, biggestField.getValue()));
            }
        }
        biggestField = queue.poll();
        long position = findMiddle(biggestField.getKey(), biggestField.getValue());
        //System.out.println("Guest " + numberOfGuests + ", Position: " + position);
        return new Pair<>(Math.min(position - biggestField.getKey(), biggestField.getValue() - position), Math.max(position - biggestField.getKey(), biggestField.getValue() - position));
    }

    private static long findMiddle(long left, long right){
        long length = right - left;
        return left + length / 2;
    }

    private static Pair<Integer, Integer> getSolution(int numberOfStalls, int numberOfGuests){
        boolean[] occupied = new boolean[numberOfStalls+2];
        occupied[0] = true;
        occupied[numberOfStalls+1] = true;
        if(numberOfGuests == 1){
            return getMinMaxOfGuest(occupied);
        }
        for(int guest = 0; guest < numberOfGuests - 1; guest++){
            System.out.println("Guest " + guest);
            getMinMaxOfGuest(occupied);
        }
        System.out.println("Last guest");
        return getMinMaxOfGuest(occupied);
    }

    private static Pair<Integer, Integer> getMinMaxOfGuest(boolean[] occupied){
        int[] bestSolution = new int[3];
        for(int stall = 0; stall < occupied.length / 2; stall++){
            if(stall % 1000 == 0){
                System.out.println("Stall " + stall);
            }
            if(occupied[occupied.length / 2 +stall]){
                continue;
            }
            if(occupied.length / 2 + stall >= occupied.length){
                continue;
            }
            int maxMinDistance = computeMaxMinDistance(occupied, occupied.length / 2 +stall);
            if(bestSolution[1] < maxMinDistance){
                int maxMaxDistance = computeMaxMaxDistance(occupied, stall);
                bestSolution[0] = stall;
                bestSolution[1] = maxMinDistance;
                bestSolution[2] = maxMaxDistance;
            }
            if(bestSolution[1] == maxMinDistance){
                int maxMaxDistance = computeMaxMaxDistance(occupied, stall);
                if(maxMaxDistance > bestSolution[2] ||maxMaxDistance == bestSolution[2] && occupied.length / 2 +stall < bestSolution[0]){
                    bestSolution[0] = stall;
                    bestSolution[1] = maxMinDistance;
                    bestSolution[2] = maxMaxDistance;
                }
            }
            if(occupied.length / 2 - stall < 0){
                continue;
            }
            if(occupied[occupied.length / 2 - stall]){
                continue;
            }
            maxMinDistance = computeMaxMinDistance(occupied, occupied.length / 2 - stall);
            if(bestSolution[1] < maxMinDistance){
                int maxMaxDistance = computeMaxMaxDistance(occupied, stall);
                bestSolution[0] = stall;
                bestSolution[1] = maxMinDistance;
                bestSolution[2] = maxMaxDistance;
            }
            if(bestSolution[1] == maxMinDistance){
                int maxMaxDistance = computeMaxMaxDistance(occupied, stall);
                if(maxMaxDistance > bestSolution[2] || maxMaxDistance == bestSolution[2] && occupied.length / 2 - stall < bestSolution[0]){
                    bestSolution[0] = stall;
                    bestSolution[1] = maxMinDistance;
                    bestSolution[2] = maxMaxDistance;
                }
            }
        }
        occupied[bestSolution[0]] = true;
        return new Pair<>(bestSolution[1], bestSolution[2]);
    }

    private static int computeMaxMinDistance(boolean[] occupied, int startIndex){
        int maxMinDistance = 0;
        for(int i = 1; i < occupied.length; i++){
            if(occupied[startIndex + i] || occupied[startIndex - i]){
                break;
            }
            maxMinDistance++;
        }
        return maxMinDistance;
    }

    private static int computeMaxMaxDistance(boolean[] occupied, int startIndex){
        int maxMaxDistance = 0;
        boolean foundLeft = false;
        boolean foundRight = false;
        for(int i = 1; i < occupied.length; i++){
            //Check to left
            if(startIndex - i > 0){
                foundLeft = foundLeft || occupied[startIndex - i];
            }
            if(startIndex + i < occupied.length){
                foundRight = foundRight || occupied[startIndex + i];
            }
            if(foundLeft && foundRight){
                break;
            }
            maxMaxDistance++;
        }
        return maxMaxDistance;
    }

    private static class Pair<K,V>{
        K key;
        V value;
        public Pair(K key, V value){
            this.key = key;
            this.value = value;
        }
        public K getKey(){
            return key;
        }
        public V getValue(){
            return value;
        }
    }
}
