package C;

import java.io.BufferedWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Arrays;
import java.util.Scanner;

public class Small {
    private final Charset ENCODING = StandardCharsets.UTF_8;

    public static void main(String[] args) throws IOException {
        new Small().run(Paths.get(args[0]), Paths.get(args[1]));
    }

    private void run(Path input, Path output) throws IOException {
        try (BufferedWriter writer = Files.newBufferedWriter(output, ENCODING)) {
            try (Scanner scanner = new Scanner(input, ENCODING.name())) {
                int t = scanner.nextInt();
                for(int x=1; x<=t; x++){
                    int N = scanner.nextInt();
                    int J = scanner.nextInt();

                    char[] digits = new char[N];
                    Arrays.fill(digits, '0');
                    digits[0] = digits[N-1] = '1';

                    writer.write("Case #" + x + ":");
                    writer.newLine();

                    for(int y=0; y<J; y++){
                        int[] divisors = nearestCoinJam(digits);
                        if(divisors == null){
                            break;
                        } else {
                            writer.write(new String(digits) + " ");
                            for(int z=0; z<divisors.length; z++){
                                writer.write(divisors[z] + (z < divisors.length - 1 ? " " : ""));
                            }
                            writer.newLine();
                            boolean success = increment(digits);
                            if(!success){
                                break;
                            }
                        }
                    }
                }
            }
        }
    }

    private boolean increment(char[] digits){
        int value = Integer.parseInt(new String(digits, 1, digits.length - 2), 2) + 1;
        char[] result = Integer.toBinaryString(value).toCharArray();
        for(int x=digits.length - 2, y=result.length - 1; x > 0 && y >= 0; x--, y--){
            digits[x] = result[y];
        }
        int N = digits.length - 2;
        return (value & ((1 << N) - 1)) != 0; //was there overflow?
    }

    private long parse(char[] digits, int base){
        return Long.parseLong(new String(digits), base);
    }

    private int[] nearestCoinJam(char[] digits){
        while(!isCoinJam(digits)){
            boolean successful = increment(digits);
            if(!successful){
                return null;
            }
        }

        int[] factors = new int[9];
        outer: for(int base = 2; base <= 10; base++) {
            long value = parse(digits, base);
            long sqrt = (long) Math.sqrt(value) + 1;
            for (long x = 2; x < sqrt && x < value; x++) {
                if(value % x == 0){
                    factors[base - 2] = (int)x;
                    continue outer;
                }
            }
        }

        return factors;
    }

    private boolean isCoinJam(char[] digits){
        for(int base = 2; base <= 10; base++){
            BigInteger value = new BigInteger(new String(digits), base);
            if(value.isProbablePrime(2048)){
                return false;
            }
        }
        return true;
    }
}
