import java.io.*;
import java.util.*;
import java.math.BigInteger;
import java.util.Map.Entry;

import javax.script.Compilable;
import javax.xml.crypto.NodeSetData;

import static java.lang.Math.*;

public class C extends PrintWriter {

    private static final String input = "C-large.in";
    private static final String output = "output.txt";

    class Node implements Comparable<Node> {
        final int id;
        final double time;

        public Node(int id, double time) {
            this.id = id;
            this.time = time;
        }

        @Override
        public int compareTo(Node node) {
            return Double.compare(time, node.time);
        }
    }

    double solve(int n, double[] s, double[] v, double[][] d, int f, int t) {
        double[] res = new double[n];
        Arrays.fill(res, Double.POSITIVE_INFINITY);
        res[f] = 0;

        PriorityQueue<Node> queue = new PriorityQueue<Node>();
        queue.add(new Node(f, 0.0));

        while (!queue.isEmpty()) {
            Node node = queue.poll();

            int i = node.id;
            double time = node.time;

            for (int j = 0; j < n; j++) {
                if (s[i] >= d[i][j]) {
                    double temp = time + d[i][j] / v[i];

                    if (temp < res[j]) {
                        res[j] = temp;
                        queue.add(new Node(j, temp));
                    }

                }
            }

        }

        return res[t];
    }

    void runTestsFromFile() {
        int tests = nextInt();
        for (int test = 1; test <= tests; test++) {
            int n = nextInt(), m = nextInt();

            double[] s = new double[n];
            double[] v = new double[n];

            for (int i = 0; i < n; i++) {
                s[i] = nextInt();
                v[i] = nextInt();
            }

            double[][] d = new double[n][n];

            for (int i = 0; i < n; i++) {
                for (int j = 0; j < n; j++) {
                    int val = nextInt();
                    if (val < 0) {
                        if (i == j) {
                            d[i][j] = 0;
                        } else {
                            d[i][j] = Double.POSITIVE_INFINITY;
                        }
                    } else {
                        d[i][j] = val;
                    }
                }
            }

            for (int k = 0; k < n; k++) {
                for (int i = 0; i < n; i++) {
                    for (int j = 0; j < n; j++) {
                        d[i][j] = min(d[i][j], d[i][k] + d[k][j]);
                    }
                }
            }

            printf(Locale.ENGLISH, "Case #%d:", test);
            for (int i = 0; i < m; i++) {
                int f = nextInt() - 1, t = nextInt() - 1;
                double ans = solve(n, s, v, d, f, t);
                printf(Locale.ENGLISH, " %.9f", ans);
            }
            println();
        }
    }

    void run() {
        // stress();
        runTestsFromFile();

    }

    int[][] nextMatrix(int n, int m) {
        int[][] matrix = new int[n][m];
        for (int i = 0; i < n; i++)
            for (int j = 0; j < m; j++)
                matrix[i][j] = nextInt();
        return matrix;
    }

    String next() {
        while (!tokenizer.hasMoreTokens())
            tokenizer = new StringTokenizer(nextLine());
        return tokenizer.nextToken();
    }

    boolean hasNext() {
        while (!tokenizer.hasMoreTokens()) {
            String line = nextLine();
            if (line == null) {
                return false;
            }
            tokenizer = new StringTokenizer(line);
        }
        return true;
    }

    int[] nextArray(int n) {
        int[] array = new int[n];
        for (int i = 0; i < n; i++) {
            array[i] = nextInt();
        }
        return array;
    }

    int nextInt() {
        return Integer.parseInt(next());
    }

    long nextLong() {
        return Long.parseLong(next());
    }

    double nextDouble() {
        return Double.parseDouble(next());
    }

    String nextLine() {
        try {
            return reader.readLine();
        } catch (IOException err) {
            return null;
        }
    }

    public C(OutputStream outputStream) {
        super(outputStream);
    }

    static BufferedReader reader;
    static StringTokenizer tokenizer = new StringTokenizer("");
    static Random rnd = new Random();
    static boolean OJ;

    public static void main(String[] args) throws IOException {
        C solution = new C(new FileOutputStream(output));
        reader = new BufferedReader(new FileReader(new File(input)));
        solution.run();
        solution.close();
        reader.close();
    }
}