import java.io.*;
import java.util.*;
import java.math.BigInteger;
import java.util.Map.Entry;

import static java.lang.Math.*;

public class B extends PrintWriter {

	private static final String input = "B-small-attempt0.in";
	private static final String output = "B-output.txt";

	double eps = 1e-9;

	class Pipe implements Comparable<Pipe> {
		double r, c;

		Pipe(double r, double c) {
			this.r = r;
			this.c = c;
		}

		public int compareTo(Pipe p) {
			return Double.compare(c, p.c);
		}

	}

	double solve(Pipe[] pipe, double v, double x) {
		int n = pipe.length;
		boolean tooHot = true, toCold = true;

		double sum = 0;

		for (Pipe p : pipe) {
			if (p.c <= x + eps) {
				tooHot = false;
			}

			if (x <= p.c + eps) {
				toCold = false;
			}

			sum += p.r;
		}

		if (toCold || tooHot) {
			return Double.NaN;
		}

		if (abs(pipe[n - 1].c - pipe[0].c) <= eps) {
			return v / sum;
		}

		double r0 = pipe[0].r, c0 = pipe[0].c;
		double r1 = pipe[n - 1].r, c1 = pipe[n - 1].c;

		double t1 = (x - c0) * v / (r1 * (c1 - c0));
		double t0 = (v - t1 * r1) / r0;
		return max(t0, t1);

	}

	void run() {
		int t = nextInt();

		for (int test = 1; test <= t; test++) {
			int n = nextInt();
			double v = nextDouble(), x = nextDouble();

			Pipe[] pipe = new Pipe[n];

			for (int i = 0; i < n; i++) {
				pipe[i] = new Pipe(nextDouble(), nextDouble());
			}
			Arrays.sort(pipe);
			double ans = solve(pipe, v, x);

			if (Double.isInfinite(ans) || Double.isNaN(ans)) {
				printf("Case #%d: IMPOSSIBLE%n", test);
			} else {
				printf(Locale.ENGLISH, "Case #%d: %.9f%n", test, ans);
			}

		}
	}

	public static boolean nextPermutation(int[] permutation) {
		int n = permutation.length, a = n - 2;
		while (0 <= a && permutation[a] >= permutation[a + 1]) {
			a--;
		}
		if (a == -1) {
			return false;
		}

		int b = n - 1;
		while (permutation[b] <= permutation[a]) {
			b--;
		}

		swap(permutation, a, b);
		for (int i = a + 1, j = n - 1; i < j; i++, j--) {
			swap(permutation, i, j);
		}
		return true;
	}

	public static void swap(int[] array, int i, int j) {
		if (i == j)
			return;
		array[i] ^= array[j];
		array[j] ^= array[i];
		array[i] ^= array[j];
	}

	int[][] nextMatrix(int n, int m) {
		int[][] matrix = new int[n][m];
		for (int i = 0; i < n; i++)
			for (int j = 0; j < m; j++)
				matrix[i][j] = nextInt();
		return matrix;
	}

	String next() {
		while (!tokenizer.hasMoreTokens())
			tokenizer = new StringTokenizer(nextLine());
		return tokenizer.nextToken();
	}

	boolean hasNext() {
		while (!tokenizer.hasMoreTokens()) {
			String line = nextLine();
			if (line == null) {
				return false;
			}
			tokenizer = new StringTokenizer(line);
		}
		return true;
	}

	int[] nextArray(int n) {
		int[] array = new int[n];
		for (int i = 0; i < n; i++) {
			array[i] = nextInt();
		}
		return array;
	}

	int nextInt() {
		return Integer.parseInt(next());
	}

	long nextLong() {
		return Long.parseLong(next());
	}

	double nextDouble() {
		return Double.parseDouble(next());
	}

	String nextLine() {
		try {
			return reader.readLine();
		} catch (IOException err) {
			return null;
		}
	}

	public B(OutputStream outputStream) {
		super(outputStream);
	}

	static BufferedReader reader;
	static StringTokenizer tokenizer = new StringTokenizer("");
	static Random rnd = new Random();
	static boolean OJ;

	public static void main(String[] args) throws IOException {
		B solution = new B(new FileOutputStream(output));
		reader = new BufferedReader(new FileReader(new File(input)));
		solution.run();
		solution.close();
		reader.close();
	}
}