import java.io.*;
import java.util.*;
import java.math.BigInteger;
import java.util.Map.Entry;

import static java.lang.Math.*;

public class C extends PrintWriter {

    private static final String input = "C-small-2-attempt0.in";
    private static final String output = "output.txt";

    class Segment implements Comparable<Segment> {
        final int l, r, mid, min, max;

        public Segment(int l, int r) {
            this.l = l;
            this.r = r;
            this.mid = (l + r) / 2;

            this.min = mid - l;
            this.max = r - mid;
        }

        @Override
        public String toString() {
            return max + " " + min;
        }

        @Override
        public int compareTo(Segment s) {
            int cmp;

            if ((cmp = Integer.compare(s.min, min)) != 0) {
                return cmp;
            }

            if ((cmp = Integer.compare(s.max, max)) != 0) {
                return cmp;
            }

            if ((cmp = Integer.compare(mid, s.mid)) != 0) {
                return cmp;
            }

            return 0;
        }

    }

    Segment solve(int n, int m) {
        PriorityQueue<Segment> queue = new PriorityQueue<>(n + m);

        queue.add(new Segment(1, n));

        while (--m >= 1) {
            Segment segment = queue.poll();

            int lr = segment.mid - 1;
            int rl = segment.mid + 1;

            if (segment.l <= lr) {
                queue.add(new Segment(segment.l, lr));
            }

            if (rl <= segment.r) {
                queue.add(new Segment(rl, segment.r));
            }
        }

        return queue.peek();
    }

    void runTestsFromFile() {

        int tests = nextInt();
        for (int test = 1; test <= tests; test++) {
            int n = nextInt(), m = nextInt();

            Segment ans = solve(n, m);

            printf(Locale.ENGLISH, "Case #%d: %s%n", test, ans.toString());
        }
    }

    void run() {
        // stress();
        runTestsFromFile();

    }

    int[][] nextMatrix(int n, int m) {
        int[][] matrix = new int[n][m];
        for (int i = 0; i < n; i++)
            for (int j = 0; j < m; j++)
                matrix[i][j] = nextInt();
        return matrix;
    }

    String next() {
        while (!tokenizer.hasMoreTokens())
            tokenizer = new StringTokenizer(nextLine());
        return tokenizer.nextToken();
    }

    boolean hasNext() {
        while (!tokenizer.hasMoreTokens()) {
            String line = nextLine();
            if (line == null) {
                return false;
            }
            tokenizer = new StringTokenizer(line);
        }
        return true;
    }

    int[] nextArray(int n) {
        int[] array = new int[n];
        for (int i = 0; i < n; i++) {
            array[i] = nextInt();
        }
        return array;
    }

    int nextInt() {
        return Integer.parseInt(next());
    }

    long nextLong() {
        return Long.parseLong(next());
    }

    double nextDouble() {
        return Double.parseDouble(next());
    }

    String nextLine() {
        try {
            return reader.readLine();
        } catch (IOException err) {
            return null;
        }
    }

    public C(OutputStream outputStream) {
        super(outputStream);
    }

    static BufferedReader reader;
    static StringTokenizer tokenizer = new StringTokenizer("");
    static Random rnd = new Random();
    static boolean OJ;

    public static void main(String[] args) throws IOException {
        C solution = new C(new FileOutputStream(output));
        reader = new BufferedReader(new FileReader(new File(input)));
        solution.run();
        solution.close();
        reader.close();
    }
}