import java.io.*;
import java.util.*;
import java.math.BigInteger;
import java.util.Map.Entry;

import static java.lang.Math.*;

public class C extends PrintWriter {

    private static final String input = "C-large.in";
    private static final String output = "C-output.txt";

    int inc(Map<Pair, Integer> cnt, Pair pair) {
        Integer val = cnt.get(pair);
        if (val == null) {
            cnt.put(pair, 1);
            return 1;
        } else {
            int upd = val + 1;
            cnt.put(pair, upd);
            return upd;
        }
    }

    public int[] randomPermutation(int n) {
        int[] permutation = new int[n];
        for (int i = 0; i < n; i++) {
            permutation[i] = i;
            int j = rnd.nextInt(i + 1);
            swap(permutation, i, j);
        }

        return permutation;
    }

    private List<Triplet> solve(int j, int p, int s, int k) {
        List<Triplet> all = new ArrayList<Triplet>();

        List<Triplet> best = new ArrayList<Triplet>();

        for (int x = 1; x <= j; x++) {
            for (int y = 1; y <= p; y++) {
                for (int z = 1; z <= s; z++) {
                    all.add(new Triplet(x, y, z));
                }
            }
        }

        int n = all.size();

        for (int iter = 0; iter <10000000 / n; iter++) {
            int[] permutation = randomPermutation(n);
            Map<Pair, Integer> jp = new HashMap<>(), ps = new HashMap<>(), sj = new HashMap<>();
            List<Triplet> cur = new ArrayList<Triplet>();

            for (int i = 0; i < n; i++) {
                Triplet triplet = all.get(permutation[i]);

                if (inc(jp, new Pair(triplet.a, triplet.b)) > k) {
                    break;
                }
                if (inc(ps, new Pair(triplet.b, triplet.c)) > k) {
                    break;
                }
                if (inc(sj, new Pair(triplet.c, triplet.a)) > k) {
                    break;
                }

                cur.add(triplet);
            }

            if (cur.size() > best.size()) {
                best = cur;
            }

            if (best.size() == n) {
                break;
            }
        }

        return best;
    }

    public static boolean nextPermutation(int[] permutation) {
        int n = permutation.length, a = n - 2;
        while (0 <= a && permutation[a] >= permutation[a + 1]) {
            a--;
        }
        if (a == -1) {
            return false;
        }

        int b = n - 1;
        while (permutation[b] <= permutation[a]) {
            b--;
        }

        swap(permutation, a, b);
        for (int i = a + 1, j = n - 1; i < j; i++, j--) {
            swap(permutation, i, j);
        }
        return true;
    }

    private static void swap(int[] permutation, int i, int j) {
        if (i == j) {
            return;
        }
        permutation[i] ^= permutation[j];
        permutation[j] ^= permutation[i];
        permutation[i] ^= permutation[j];
    }

    class Pair {
        final int a, b;

        public Pair(int a, int b) {
            this.a = a;
            this.b = b;
        }

        @Override
        public int hashCode() {
            final int prime = 31;
            int result = 1;
            result = prime * result + a;
            result = prime * result + b;
            return result;
        }

        @Override
        public boolean equals(Object obj) {
            if (this == obj)
                return true;
            if (obj == null)
                return false;
            if (getClass() != obj.getClass())
                return false;
            Pair other = (Pair) obj;
            if (a != other.a)
                return false;
            if (b != other.b)
                return false;
            return true;
        }
    }

    class Triplet {
        final int a, b, c;

        public Triplet(int a, int b, int c) {
            this.a = a;
            this.b = b;
            this.c = c;
        }

        @Override
        public int hashCode() {
            final int prime = 31;
            int result = 1;
            result = prime * result + a;
            result = prime * result + b;
            result = prime * result + c;
            return result;
        }

        @Override
        public boolean equals(Object obj) {
            if (this == obj)
                return true;
            if (obj == null)
                return false;
            if (getClass() != obj.getClass())
                return false;
            Triplet other = (Triplet) obj;
            if (a != other.a)
                return false;
            if (b != other.b)
                return false;
            if (c != other.c)
                return false;
            return true;
        }

        @Override
        public String toString() {
            return a + " " + b + " " + c;
        }
    }

    void run() {
        int tests = nextInt();

        for (int test = 1; test <= tests; test++) {
            int j = nextInt(), p = nextInt(), s = nextInt(), k = nextInt();

            List<Triplet> ans = solve(j, p, s, k);
            printf(Locale.ENGLISH, "Case #%d: %d%n", test, ans.size());
            for (Triplet triplet : ans) {
                println(triplet);
            }

            System.err.printf("%3d / %3d%n", test, tests);
        }
    }

    int[][] nextMatrix(int n, int m) {
        int[][] matrix = new int[n][m];
        for (int i = 0; i < n; i++)
            for (int j = 0; j < m; j++)
                matrix[i][j] = nextInt();
        return matrix;
    }

    String next() {
        while (!tokenizer.hasMoreTokens())
            tokenizer = new StringTokenizer(nextLine());
        return tokenizer.nextToken();
    }

    boolean hasNext() {
        while (!tokenizer.hasMoreTokens()) {
            String line = nextLine();
            if (line == null) {
                return false;
            }
            tokenizer = new StringTokenizer(line);
        }
        return true;
    }

    int[] nextArray(int n) {
        int[] array = new int[n];
        for (int i = 0; i < n; i++) {
            array[i] = nextInt();
        }
        return array;
    }

    int nextInt() {
        return Integer.parseInt(next());
    }

    long nextLong() {
        return Long.parseLong(next());
    }

    double nextDouble() {
        return Double.parseDouble(next());
    }

    String nextLine() {
        try {
            return reader.readLine();
        } catch (IOException err) {
            return null;
        }
    }

    public C(OutputStream outputStream) {
        super(outputStream);
    }

    static BufferedReader reader;
    static StringTokenizer tokenizer = new StringTokenizer("");
    static Random rnd = new Random();
    static boolean OJ;

    public static void main(String[] args) throws IOException {
        C solution = new C(new FileOutputStream(output));
        reader = new BufferedReader(new FileReader(new File(input)));
        solution.run();
        solution.close();
        reader.close();
    }
}
