import org.jetbrains.annotations.NotNull;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.util.PriorityQueue;
import java.util.Scanner;

public class Main {

    public static void main(String[] args) throws FileNotFoundException {
        try (Scanner input = new Scanner(new FileInputStream("C-small-2-attempt0.in"));
             PrintWriter output = new PrintWriter(new FileOutputStream("data2.out"))) {
            int T = input.nextInt();

            for (int test = 0; test < T; test++) {
                int N = input.nextInt();
                int K = input.nextInt();

                PriorityQueue<Interval> intervals = new PriorityQueue<>();
                intervals.add(new Interval(1, N));

                int y = -1, z = -1;

                for (int i = 0; i < K; i++) {
                    Interval interval = intervals.poll();
                    assert interval != null;

                    y = Math.max(interval.left, interval.right);
                    z = Math.min(interval.left, interval.right);

                    if (interval.start <= interval.chosenPoint - 1)
                        intervals.add(new Interval(interval.start, interval.chosenPoint - 1));

                    if (interval.chosenPoint + 1 <= interval.end)
                        intervals.add(new Interval(interval.chosenPoint + 1, interval.end));
                }

                System.out.printf("Case #%d: %d %d\n", test + 1, y, z);
                output.printf("Case #%d: %d %d\n", test + 1, y, z);
            }
        }
    }

    public static class Interval implements Comparable<Interval> {
        public final int start, end, chosenPoint, left, right;

        public Interval(int start, int end) {
            this.start = start;
            this.end = end;
            int length = end - start + 1;
            this.chosenPoint = start + (length + 1) / 2 - 1;
            this.left = chosenPoint - start;
            this.right = end - chosenPoint;
        }

        @Override
        public int compareTo(@NotNull Interval other) {
            int Min = Math.min(left, right);
            int otherMin = Math.min(other.left, other.right);

            // those S for which min(LS, RS) is maximal
            if (Min != otherMin)
                return -Integer.compare(Min, otherMin);

            int Max = Math.max(left, right);
            int otherMax = Math.max(other.left, other.right);

            // they choose the one among those where max(LS, RS) is maximal
            if (Max != otherMax)
                return -Integer.compare(Max, otherMax);

            // If there are still multiple tied stalls, they choose the leftmost stall among those.
            return Integer.compare(chosenPoint, other.chosenPoint);
        }
    }

    public static class Pair {
        int x, y;

        public Pair(int x, int y) {
            this.x = x;
            this.y = y;
        }

        public static Pair apply(int a, int b){
            return new Pair(a, b);
        }
    }

}
