package round1c.problemb;

import java.io.*;


public class SolveB
{
  // Launcher /////////////////////////////////////////////////////////////////////////////////

  public static void main(String[] args) throws IOException
  {
    long time = System.currentTimeMillis();

    BufferedReader in = new BufferedReader(new FileReader(args[0]));
    BufferedWriter out = new BufferedWriter(new FileWriter(args[1]));

    int testCount = Integer.parseInt(in.readLine());
    for (int testNumber = 0; testNumber < testCount; testNumber ++) {

      String dimensionsStr = in.readLine();

      SolveB solution = new SolveB(dimensionsStr);
      solution.calculate();

      StringBuilder result = new StringBuilder();
      result.append("Case #").append(testNumber + 1).append(": ").append(solution.getResult());

      out.write(result.toString());
      out.newLine();
    }

    in.close();
    out.close();

    System.out.println(System.currentTimeMillis() - time);
  }


  // Solution /////////////////////////////////////////////////////////////////////////////////


  private long destX;
  private long destY;

  private int n = 1;
  private long x, y;

  private StringBuffer path = new StringBuffer(10000);


  public SolveB(String dimensionsStr)
  {
    String[] dimensionsStrArray = dimensionsStr.trim().split(" ");
    destX = Long.parseLong(dimensionsStrArray[0]);
    destY = Long.parseLong(dimensionsStrArray[1]);
  }


  private void calculate()
  {
    n = 1;
    for (; ; ) {

      long diffX = Math.abs(destX - x);
      long diffY = Math.abs(destY - y);

      if (diffX == 0 && diffY == 0)
        break;

      long diffMax = Math.max(diffX, diffY);
      boolean xAvers = x < destX;
      boolean yAvers = y < destY;

      if (diffMax > n) {

        // Move to point quickly
        if (diffX > n && diffY > n && diffX < diffY ||
            diffX == diffMax) {

          if (xAvers) {
            jumpXAverse();
          }
          else {
            jumpXReverse();
          }
        }
        else {

          if (yAvers) {
            jumpYAverse();
          }
          else {
            jumpYReverse();
          }
        }
      }
      else {

        // Adjust position
        if (diffX >= 2 && diffY >= 2) {

          if (xAvers && yAvers) {
            // (2, 2)
            jumpXReverse();
            jumpYReverse();
            jumpXAverse();
            jumpYAverse();
          }
          else if (! xAvers && yAvers) {
            // (-2, 2)
            jumpXAverse();
            jumpYReverse();
            jumpXReverse();
            jumpYAverse();
          }
          else if (xAvers && ! yAvers) {
            // (2, -2)
            jumpXReverse();
            jumpYAverse();
            jumpXAverse();
            jumpYReverse();
          }
          else {
            // (-2, -2)
            jumpXAverse();
            jumpYAverse();
            jumpXReverse();
            jumpYReverse();            
          }
        }
        else if (diffX > 0) {
          // Adjust X by 1
          if (xAvers) {
            // (1, 0)
            jumpXReverse();
            jumpXAverse();
          }
          else {
            // (-1, 0)
            jumpXAverse();
            jumpXReverse();
          }
        }
        else {
          // Adjust Y by 1
          if (yAvers) {
            // (0, 1)
            jumpYReverse();
            jumpYAverse();
          }
          else {
            // (0, -1)
            jumpYAverse();
            jumpYReverse();
          }
        }
      }
    }
  }


  private void jumpXAverse()
  {
    x += n;
    path.append('E');
    n ++;
  }


  private void jumpXReverse()
  {
    x -= n;
    path.append('W');
    n ++;
  }


  private void jumpYAverse()
  {
    y += n;
    path.append('N');
    n ++;
  }


  private void jumpYReverse()
  {
    y -= n;
    path.append('S');
    n ++;
  }


  private String getResult()
  {
    return path.toString();
  }
}
