import java.io.*;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.function.Function;

// Aliaksei Svittsau
public class Round1CProblemC
{
  static final DecimalFormat DOUBLE_FORMAT = new DecimalFormat("#0.0000000000");

  public static void main(String[] args)
  {
    try {
      String inPathName = args[0];
      String inPathBase = inPathName.substring(0, inPathName.lastIndexOf('.'));

      File inFile = new File(inPathName);
      File outFile = new File(inPathBase + "_out.txt");

      BufferedReader in = new BufferedReader(new FileReader(inFile));
      BufferedWriter out = new BufferedWriter(new FileWriter(outFile));

      t = Integer.parseInt(in.readLine());
      for (int caseNumber = 1; caseNumber <= t; caseNumber ++) {
        readCaseInput(caseNumber, in);
        solveCase(caseNumber, out);
        //System.out.println(caseNumber);
      }
      out.close();
    }
    catch (Exception e) {
      e.printStackTrace();
    }
  }


  private static void readCaseInput(int caseNumber, BufferedReader in) throws IOException
  {
    String line1 = in.readLine();
    n = intParam(line1, 0);
    k = intParam(line1, 1);

    String line2 = in.readLine();
    u = doubleParam(line2, 0);

    s = new double[n];
    f = new double[n];

    String lineSF = in.readLine();
    for (int i1 = 0; i1 < n; i1 ++) {

      s[i1] = doubleParam(lineSF, i1);
      f[i1] = 1.0 - s[i1];
    }
  }


  static int t;

  static int n,k;
  static double u;
  static double[] s, f;


  private static void solveCase(int caseNumber, BufferedWriter out) throws IOException
  {
    double probability = fullProb(s);
    if (n == k) {

      List<Double> orderedUnits = new ArrayList<>(n);
      for (int i1 = 0; i1 < n; i1 ++) {
        orderedUnits.add(s[i1]);
      }
      Collections.sort(orderedUnits);

      while (u > 0.0) {

        double bottom = orderedUnits.get(0);
        if (bottom == 1.0)
          break;

        int items = 1;
        double next = -1;
        for (int i1 = 1; i1 < n; i1 ++) {
          if (orderedUnits.get(i1) == bottom) {
            items ++;
          }
          else {
            next = orderedUnits.get(i1);
            break;
          }
        }

        if (items == n)
          next = 1.0;

        double need = Math.min(u, ((double) items) * (next - bottom));
        u -= need;
        double bonus = need / items;
        for (int i1 = 0; i1 < items; i1 ++) {
          orderedUnits.set(i1, orderedUnits.get(i1) + bonus);
        }
      }

      probability = fullProb(orderedUnits);
    }

    writeCaseResult(out, caseNumber, cutTrailing(DOUBLE_FORMAT.format(probability).replace(',', '.')));
  }


  private static double fullProb(double[] s)
  {
    double res = 1.0;
    for (int i1 = 0; i1 < n; i1 ++) {
      res *= s[i1];
    }
    return res;
  }


  private static double fullProb(List<Double> s)
  {
    double res = 1.0;
    for (int i1 = 0; i1 < n; i1 ++) {
      res *= s.get(i1);
    }
    return res;
  }


  private static String cutTrailing(String str)
  {
    if (str.charAt(str.length() - 1) == '0') {
      int zeroIndex = str.length() - 1;
      while (str.charAt(zeroIndex - 1) == '0')
        zeroIndex --;
      if (str.charAt(zeroIndex - 1) == '.')
        zeroIndex ++;
      return str.substring(0, zeroIndex);
    }
    return str;
  }

  private static void writeCaseResult(BufferedWriter out, int caseNumber, String formattedResult) throws IOException
  {
    out.write("Case #" + caseNumber + ": " + formattedResult);
    out.newLine();
    out.flush();
  }


  private static int intParam(String inputLine, int sectionIndex)
  {
    return parseParam(inputLine, sectionIndex, Integer::parseInt);
  }


  private static long longParam(String inputLine, int sectionIndex)
  {
    return parseParam(inputLine, sectionIndex, Long::parseLong);
  }


  private static double doubleParam(String inputLine, int sectionIndex)
  {
    return parseParam(inputLine, sectionIndex, Double::parseDouble);
  }


  private static String stringParam(String inputLine, int sectionIndex)
  {
    return parseParam(inputLine, sectionIndex, Function.identity());
  }


  private static <T> T parseParam(String inputLine, int sectionIndex, Function<String, T> parsingFunction)
  {
    String resultStr = inputLine.split("\\s")[sectionIndex];
    return parsingFunction.apply(resultStr);
  }
}
