package acase;


public class PlayField
{
  private Mark[][] playground;


  public PlayField(String[] playgroundCodes)
  {
    playground = new Mark[][] {
        parseLine(playgroundCodes[0]),
        parseLine(playgroundCodes[1]),
        parseLine(playgroundCodes[2]),
        parseLine(playgroundCodes[3])
    };
  }


  private Mark[] parseLine(String playgroundLine)
  {
    return new Mark[] {
        Mark.valueOf(playgroundLine.charAt(0)),
        Mark.valueOf(playgroundLine.charAt(1)),
        Mark.valueOf(playgroundLine.charAt(2)),
        Mark.valueOf(playgroundLine.charAt(3))
    };
  }


  public Result playResult()
  {
    boolean incompleteExist = false;

    // Lines
    for (int row = 0; row < 4; row++) {

      LineStatus lineStatus = getLineStatus(
          playground[row][0], playground[row][1], playground[row][2], playground[row][3]
      );

      switch (lineStatus) {
        case X_WIN: return Result.X_WON;
        case O_WIN: return Result.O_WON;
        case INCOMPLETE:
          incompleteExist = true;
      }
    }

    // Columns
    for (int column = 0; column < 4; column++) {

      LineStatus lineStatus = getLineStatus(
          playground[0][column], playground[1][column], playground[2][column], playground[3][column]
      );

      switch (lineStatus) {
        case X_WIN: return Result.X_WON;
        case O_WIN: return Result.O_WON;
        case INCOMPLETE:
          incompleteExist = true;
      }
    }

    // Diagonals
    LineStatus lineStatus = getLineStatus(
          playground[0][0], playground[1][1], playground[2][2], playground[3][3]
      );
    switch (lineStatus) {
      case X_WIN: return Result.X_WON;
      case O_WIN: return Result.O_WON;
      case INCOMPLETE:
        incompleteExist = true;
    }


    lineStatus = getLineStatus(
          playground[0][3], playground[1][2], playground[2][1], playground[3][0]
      );
    switch (lineStatus) {
      case X_WIN: return Result.X_WON;
      case O_WIN: return Result.O_WON;
      case INCOMPLETE:
        incompleteExist = true;
    }

    return incompleteExist ? Result.GAME_NOT_COMPLETED : Result.DRAW;
  }


  private LineStatus getLineStatus(Mark... pts)
  {
    boolean xPresented = false;
    boolean oPresented = false;
    boolean spacePresented = false;
    for (Mark pt : pts) {

      switch (pt) {
        case X:
          xPresented = true;
          break;
        case O:
          oPresented = true;
          break;
        case E:
          spacePresented = true;
          break;
      }
    }

    if (!spacePresented) {
      if (xPresented && !oPresented)
        return LineStatus.X_WIN;
      else if (oPresented && !xPresented)
        return LineStatus.O_WIN;
      else 
        return LineStatus.FILLED_BLOCKED;
    }
    else {
      return LineStatus.INCOMPLETE;
    }
  }


  protected enum Mark
  {
    E ('.'),
    T ('T'),
    X ('X'),
    O ('O');

    private char code;

    Mark(char code)
    {
      this.code = code;
    }


    public static Mark valueOf(char code)
    {
      for (Mark option : Mark.values()) {
        if (code == option.code)
          return option;
      }
      return null;
    }
  }


  protected enum LineStatus
  {
    X_WIN,
    O_WIN,
    FILLED_BLOCKED,
    INCOMPLETE
  }


  protected enum Result
  {
    X_WON                     ("X won"),
    O_WON                     ("O won"),
    DRAW                      ("Draw"),
    GAME_NOT_COMPLETED        ("Game has not completed");

    private String description;


    Result(String description)
    {
      this.description = description;
    }


    public String getDescription()
    {
      return description;
    }
  }
}
