import java.io.*;
import java.util.Arrays;
import java.util.Optional;

public class task1
{
  private static int nCases;
  private static BufferedReader in;
  private static BufferedWriter out;

  // Case input parameters
  static boolean[] row;
  static int s, k;


  public static void main(String[] args)
  {
    try {
      String inName = args[0];
      String outName = inName + "_out.txt";
      in = new BufferedReader(new FileReader(inName));
      out = new BufferedWriter(new FileWriter(outName));

      nCases = Integer.parseInt(in.readLine());

      for (int caseNumber = 1; caseNumber <= nCases; caseNumber ++) {
        parseCaseInput(caseNumber, in.readLine());
        solveTheCase(caseNumber, out);
      }
    }
    catch (Throwable e) {
      e.printStackTrace();
    }
    finally {
      try {
        if (in != null) {
          in.close();
        }
        if (out != null) {
          out.flush();
          out.close();
        }
      }
      catch (IOException e) {
        e.printStackTrace();
      }
    }
  }


  private static void parseCaseInput(int caseNumber, String caseInput)
  {
    String[] inputSplit = caseInput.split("\\s");
    String rowStr = inputSplit[0];
    String kStr = inputSplit[1];

    s = rowStr.length();
    row = new boolean[s];
    for (int i1 = 0; i1 < s; i1 ++)
      row[i1] = rowStr.charAt(i1) == '+';
    k = Integer.parseInt(kStr);
  }


  private static void solveTheCase(int caseNumber, BufferedWriter out) throws IOException
  {
    Optional<Integer> forward = calculate(k, row);
    row = rotate(row);
    Optional<Integer> backward = calculate(k, row);

    out.write("Case #" + caseNumber + ": " + forward
      .map(x -> Math.min(x, backward.orElse(x)))
      .map(String::valueOf)
      .orElse("IMPOSSIBLE"));
    out.newLine();
  }

  private static Optional<Integer> calculate(int k, boolean[] row)
  {
    boolean[] state = Arrays.copyOf(row, row.length);
    int flipsCount = 0;

    int lastBadIndex = lastBadIndex(state, 0);
    while (lastBadIndex != -1) {

      if (lastBadIndex > s - k) {
        return Optional.empty();
      }
      else {
        flip(state, lastBadIndex, k);
        flipsCount ++;
      }

      lastBadIndex = lastBadIndex(state, lastBadIndex);
    }

    return Optional.of(flipsCount);
  }

  private static void flip(boolean[] state, int startIndex, int length)
  {
    for (int i1 = 0; i1 < length; i1++)
      state[startIndex + i1] = ! state[startIndex + i1];
  }

  private static int lastBadIndex(boolean[] data, int startIndex)
  {
    for (int i1 = startIndex; i1 < data.length; i1 ++)
      if (! data[i1])
        return i1;
    return -1;
  }

  private static boolean[] rotate(boolean[] data)
  {
    int n = data.length;
    boolean[] rotated = new boolean[n];
    for (int i1 = 0; i1 < n; i1 ++) {
      rotated[n - i1 - 1] = data[i1];
    }
    return rotated;
  }
}
