import java.io.*;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.function.Function;

// Aliaksei Svittsau
public class Round1CProblemA
{
  static final DecimalFormat DOUBLE_FORMAT = new DecimalFormat("#.0000000000");

  public static void main(String[] args)
  {
    try {
      String inPathName = args[0];
      String inPathBase = inPathName.substring(0, inPathName.lastIndexOf('.'));

      File inFile = new File(inPathName);
      File outFile = new File(inPathBase + "_out.txt");

      BufferedReader in = new BufferedReader(new FileReader(inFile));
      BufferedWriter out = new BufferedWriter(new FileWriter(outFile));

      t = Integer.parseInt(in.readLine());
      for (int caseNumber = 1; caseNumber <= t; caseNumber ++) {
        readCaseInput(caseNumber, in);
        solveCase(caseNumber, out);
        //System.out.println(caseNumber);
      }
      out.close();
    }
    catch (Exception e) {
      e.printStackTrace();
    }
  }


  private static void readCaseInput(int caseNumber, BufferedReader in) throws IOException
  {
    String line1 = in.readLine();
    n = intParam(line1, 0);
    k = intParam(line1, 1);

    p = new ArrayList<>(n);
    for (int i1 = 0; i1 < n; i1 ++) {
      String lineRH = in.readLine();
      p.add(new PanCake(intParam(lineRH, 0), intParam(lineRH, 1)));
    }

    Collections.sort(p);
    Collections.reverse(p);
  }


  static int t;

  static int n, k;
  static List<PanCake> p;



  private static void solveCase(int caseNumber, BufferedWriter out) throws IOException
  {
    double surface = 0.0;
    for (int i1 = 0; i1 <= n - k; i1 ++) {

      PanCake bottom = p.get(i1);
      List<PanCake> rest = new ArrayList<>(p.subList(i1 + 1, n));
      Collections.sort(rest, (left, right) -> Double.compare(right.gran, left.gran));
      rest = new ArrayList<>(rest.subList(0, k - 1));
      rest.add(bottom);

      surface = Math.max(surface, calcSurface(rest));
    }

    writeCaseResult(out, caseNumber, cutTrailing(DOUBLE_FORMAT.format(surface).replace(',', '.')));
  }


  private static String cutTrailing(String str)
  {
    if (str.charAt(str.length() - 1) == '0') {
      int zeroIndex = str.length() - 1;
      while (str.charAt(zeroIndex - 1) == '0')
        zeroIndex --;
      return str.substring(0, zeroIndex);
    }
    return str;
  }


  private static double calcSurface(List<PanCake> stack)
  {
    int r = 0;
    double gran = 0.0;

    for (int i1 = 0; i1 < stack.size(); i1 ++) {

      r = Math.max(r, stack.get(i1).r);
      gran += stack.get(i1).gran;
    }

    return Math.PI * ((double) r) * ((double) r) + gran;
  }


  private static void writeCaseResult(BufferedWriter out, int caseNumber, String formattedResult) throws IOException
  {
    out.write("Case #" + caseNumber + ": " + formattedResult);
    out.newLine();
    out.flush();
  }


  private static int intParam(String inputLine, int sectionIndex)
  {
    return parseParam(inputLine, sectionIndex, Integer::parseInt);
  }


  private static long longParam(String inputLine, int sectionIndex)
  {
    return parseParam(inputLine, sectionIndex, Long::parseLong);
  }


  private static double doubleParam(String inputLine, int sectionIndex)
  {
    return parseParam(inputLine, sectionIndex, Double::parseDouble);
  }


  private static String stringParam(String inputLine, int sectionIndex)
  {
    return parseParam(inputLine, sectionIndex, Function.identity());
  }


  private static <T> T parseParam(String inputLine, int sectionIndex, Function<String, T> parsingFunction)
  {
    String resultStr = inputLine.split("\\s")[sectionIndex];
    return parsingFunction.apply(resultStr);
  }


  static class PanCake implements Comparable<PanCake>
  {
    int r;
    int h;
    double gran;

    public PanCake(int r, int h)
    {
      this.r = r;
      this.h = h;

      this.gran = 2.0 * Math.PI * ((double) r) * ((double) h);
    }

    @Override
    public int compareTo(PanCake o)
    {
      return Integer.compare(r, o.r);
    }
  }
}
