import java.io.*;
import java.util.*;
import java.util.concurrent.Callable;
import java.util.concurrent.Future;
import java.util.concurrent.ScheduledThreadPoolExecutor;

public class Test implements Runnable {

    private PrintWriter out;

    final String file = "C-small";
    static Random rnd = new Random(42);

    static class InputData {
        int n;
        String[][] words;

        InputData(FastReader in) throws IOException {
            n = in.nextInt();
            words = new String[n][];
            for (int i = 0; i < n; ++i) {
                String line = in.in.readLine().trim();
                words[i] = line.split(" ");
            }
        }

        void solve(PrintWriter out) {
            int best = Integer.MAX_VALUE;
            HashSet<String> eng = new HashSet<String>();
            HashSet<String> fr = new HashSet<String>();
            Collections.addAll(eng, words[0]);
            Collections.addAll(fr, words[1]);
            for (int mask = 0; mask < (1 << n-2); ++mask) {
                HashSet<String> eng2 = new HashSet<String>();
                HashSet<String> fr2 = new HashSet<String>();
                for (int i = 0; i < n-2; ++i) {
                    if (checkBit(mask, i)) {
                        Collections.addAll(eng2, words[i + 2]);
                    }
                }
                int cur = 0;

                for (int i = 0; i < n-2; ++i) {
                    if (!checkBit(mask, i)) {
                        for (String w2 : words[i+2]) {
                            if (!fr.contains(w2)) {
                                fr2.add(w2);
                            }
                        }
                    }
                }
                for (String ww : fr) {
                    if (eng.contains(ww) || eng2.contains(ww)) {
                        ++cur;
                    }
                }
                for (String ww : fr2) {
                    if (eng.contains(ww) || eng2.contains(ww)) {
                        ++cur;
                    }
                }
                best = Math.min(best, cur);
            }
            out.println(best);
        }

        private boolean checkBit(int mask, int i) {
            return (mask & (1 << i)) != 0;
        }
    }

    static class Solver implements Callable<String> {

        InputData data;

        Solver(InputData data) {
            this.data = data;
        }

        @Override
        public String call() throws Exception {
            StringWriter out = new StringWriter();
            data.solve(new PrintWriter(out));
            return out.toString();
        }

    }

    public void run() {
        try {
            FastReader in = new FastReader(new BufferedReader(new FileReader(file + ".in")));
            out = new PrintWriter(file + ".out");

            ScheduledThreadPoolExecutor service = new ScheduledThreadPoolExecutor(16);

            int tests = in.nextInt();
            Future<String>[] ts = new Future[tests];
            for (int test = 0; test < tests; ++test) {
                ts[test] = service.submit(new Solver(new InputData(in)));
            }
            for (int test = 0; test < tests; ++test) {
                while (!ts[test].isDone()) {
                    Thread.sleep(500);
                }
                System.err.println("Test " + test);
                out.print("Case #" + (test + 1) + ": ");
                out.print(ts[test].get());
            }
            service.shutdown();

            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    static class FastReader {
        public FastReader(BufferedReader in) {
            this.in = in;
            eat("");
        }

        private StringTokenizer st;
        private BufferedReader in;

        void eat(String s) {
            st = new StringTokenizer(s);
        }

        String next() throws IOException {
            while (!st.hasMoreTokens()) {
                String line = in.readLine();
                if (line == null) {
                    return null;
                }
                eat(line);
            }
            return st.nextToken();
        }

        int nextInt() throws IOException {
            return Integer.parseInt(next());
        }

        long nextLong() throws IOException {
            return Long.parseLong(next());
        }

        double nextDouble() throws IOException {
            return Double.parseDouble(next());
        }
    }

    public static void main(String[] args) {
        Locale.setDefault(Locale.US);
        new Test().run();
    }

}
