import java.io.InputStreamReader;
import java.io.IOException;
import java.util.Locale;
import java.io.BufferedReader;
import java.io.OutputStream;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.io.File;
import java.util.StringTokenizer;
import java.math.BigInteger;
import java.io.FilenameFilter;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 * @author AlexFetisov
 */
public class Main {
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		InputStream inputStream;
		try {
			final String regex = "B-(small|large).*[.]in";
			File directory = new File(".");
			File[] candidates = directory.listFiles(new FilenameFilter() {
				public boolean accept(File dir, String name) {
					return name.matches(regex);
				}
			});
			File toRun = null;
			for (File candidate : candidates) {
				if (toRun == null || candidate.lastModified() > toRun.lastModified())
					toRun = candidate;
			}
			inputStream = new FileInputStream(toRun);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("b.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		PrintWriter out = new PrintWriter(outputStream);
		TaskB solver = new TaskB();
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i, in, out);
		out.close();
	}
}

class TaskB {
    public void solve(int testNumber, InputReader in, PrintWriter out) {
        int n = in.nextInt();
        double V = in.nextDouble();
        double X = in.nextDouble();
        double[] rate = new double[n];
        double[] t = new double[n];
        for (int i = 0; i < n; ++i) {
            rate[i] = in.nextDouble();
            t[i] = in.nextDouble();
        }

        out.print("Case #" + testNumber + ": ");

        if (n == 1) {
            if (DoubleUtils.compareTo(t[0], X) == 0) {
                out.printf("%.10f\n", V / rate[0]);
            } else {
                out.println("IMPOSSIBLE");
            }
            return;
        }

        if (DoubleUtils.compareTo(t[0], X) == 0 && (DoubleUtils.compareTo(t[1], X) == 0)) {
            double bestR = rate[0] + rate[1];
            out.printf("%.10f\n", V / bestR);
            return;
        }

        if (DoubleUtils.compareTo(t[0], X) == 0) {
            out.printf("%.10f\n", V / rate[0]);
            return;
        }

        if (DoubleUtils.compareTo(t[1], X) == 0) {
            out.printf("%.10f\n", V / rate[1]);
            return;
        }

        if (X < t[0] && X < t[1]) {
            out.println("IMPOSSIBLE");
            return;
        }
        if (X > t[0] && X > t[1]) {
            out.println("IMPOSSIBLE");
            return;
        }

        if (t[0] < t[1]) {
            double tt = t[0];
            t[0] = t[1];
            t[1] = tt;
            tt = rate[0];
            rate[0] = rate[1];
            rate[1] = tt;
        }
        // V1 + V2 = V => V1 + V1 * DX = V => KNOW V1, V2
        // V1 * X1 + V2 * X2 = X * V1 + X * V2 => V1 * (X1 - X) = V2 * (X - X2)

        double DT = 1 + (t[0] - X) / (X - t[1]);
        double V1 = V / DT;
        double V2 = V - V1;

        double t1 = V1 / rate[0];
        double t2 = V2 / rate[1];
        out.printf("%.10f\n", Math.max(t1, t2));
    }
}

class InputReader {
    private BufferedReader reader;
    private StringTokenizer stt;

    public InputReader(InputStream stream) {
        reader = new BufferedReader(new InputStreamReader(stream));
    }

    public String nextLine() {
        try {
            return reader.readLine();
        } catch (IOException e) {
            return null;
        }
    }

    public String nextString() {
        while (stt == null || !stt.hasMoreTokens()) {
            stt = new StringTokenizer(nextLine());
        }
        return stt.nextToken();
    }

    public int nextInt() {
        return Integer.parseInt(nextString());
    }

    public double nextDouble() {
        return Double.parseDouble(nextString());
    }

    public String next() {
        return nextString();
    }
}

class DoubleUtils {
    public static final double EPS = 1e-8;

    public static int compareTo(double a, double b) {
        if (doubleEqual(a, b)) {
            return 0;
        }
        if (a < b) {
            return -1;
        }
        return 1;
    }

    private static boolean doubleEqual(double a, double b) {
        return Math.abs(a - b) < EPS;
    }

}

