import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

public class CodeJam {

	Scanner in;
	PrintWriter out;

	final char up = '^';
	final char down = 'v';
	final char left = '<';
	final char right = '>';
	final char blank = '.';
	final char[] arrow = { up, down, left, right, blank };
	final int[] dx = { 0, 0, -1, 1, 0 };
	final int[] dy = { -1, 1, 0, 0, 0 };

	int getIdx(int line, int col) {
		int c = field[line][col];
		for (int i = 0; i < arrow.length; i++) {
			if (c == arrow[i]) {
				return i;
			}
		}
		throw new Error();
	}

	char[][] field;

	int bestCount;
	
	boolean used[][][];

	boolean canGo(int line, int col, int idx) {
		if (0 <= line && line < field.length && 0 <= col && col < field[0].length) {
			if (used[line][col][idx]) {
				return true;
			}
			used[line][col][idx] = true;
			int idx2 = getIdx(line, col);
			if (idx2 == 4) {
				idx2 = idx;
			}
			int nl = line + dy[idx2];
			int nc = col + dx[idx2];
			return canGo(nl, nc, idx2);
		} else {
			return false;
		}
	}
	
	boolean canBeWrong(int line, int col) {
		int dir = getIdx(line, col);
		line += dy[dir];
		col += dx[dir];
		return  !(0 <= line && line < field.length && 0 <= col && col < field[0].length);
	}
	
	boolean canGo(int line, int col) {
		int idx = getIdx(line, col);
		int nl = line + dy[idx];
		int nc = col + dx[idx];
		used[line][col][4] = true;
		if (idx == 4) {
			return true;
		} else {
			return canGo(nl, nc, idx);
		}
	}

	void check(int currPerm) {
		if (currPerm == 0) {
			currPerm = 0;
		}
		used = new boolean[field.length][field[0].length][5];
		for (int line = 0; line < field.length; line++) {
			for (int col = 0; col < field[0].length; col++) {
				if (!canGo(line, col)) {
					return;
				}
			}
		}
		if (bestCount > currPerm || bestCount == -1) {
			bestCount = currPerm;
		}
	}

	void gen(int pos, int currPerm) {
		if (pos == poses.size()) {
			check(currPerm);
			return;
		}
		int line = poses.get(pos).y;
		int col = poses.get(pos).x;
		
		if (bestCount != -1 && currPerm >= bestCount) {
			return;
		}
		if (!canBeWrong(line, col)) {
			gen(pos + 1, currPerm);
		}
		if (field[line][col] != blank) {
			char val = field[line][col];
			for (int i = 0; i < 4; i++) {
				if (val != arrow[i]) {
					field[line][col] = arrow[i];
					if (!canBeWrong(line, col)) {
						gen(pos + 1, currPerm + 1);
					}
					field[line][col] = val;
				}
			}
		}
	}
	
	static class Pos implements Comparable<Pos>{
		int x;
		int y;
		int dist;
		
		Pos(int x, int y, int dist) {
			this.x=x;
			this.y=y;
			this.dist=dist;
		}
		
		@Override
		public int compareTo(Pos second) {
			return this.dist - second.dist;
		}
	}
	List<Pos> poses;
	void solveFor() {
		bestCount = -1;
		int nRows = in.nextInt();
		int nCols = in.nextInt();
		field = new char[nRows][];
		for (int i = 0; i < nRows; i++) {
			field[i] = in.next().toCharArray();
			asserT(field[i].length == nCols);
		}
		poses = new ArrayList<Pos>();
		for (int line = 0; line < nRows; line++) {
			int distY = Math.min(line, nRows - 1 - line);
			for (int col = 0; col < nCols; col++) {
				int distX = Math.min(col, nCols - 1 - col);
				poses.add(new Pos(col, line, Math.min(distX, distY)));
			}
		}
		Collections.sort(poses);
		gen(0, 0);
		if (bestCount == -1) {
			out.println("IMPOSSIBLE");
		} else {
			out.println(bestCount);
		}
	}

	void asserT(boolean e) {
		if (!e) {
			throw new Error();
		}
	}

	void solve() {
		int n = in.nextInt();
		for (int test = 1; test <= n; test++) {
			out.print("Case #" + test + ": ");
			solveFor();
			out.flush();
		}
	}

	static private final String path = "C:\\jam\\C\\";
	static private final String problem = "A";
	static private final String tests = "A-small";

	void run() {
		try {
			in = new Scanner(new FileReader(path + problem + "\\" + tests + ".in"));
			out = new PrintWriter(path + problem + "\\" + tests + ".out3");
		} catch (IOException e) {
//			throw new Error(e);
			
			in = new Scanner(System.in);
			out = new PrintWriter(System.out);
			out.println(">");
			out.flush();
		}
		try {
			solve();
		} finally {
			out.close();
		}
	}

	public static void main(String[] args) {
		new CodeJam().run();
	}
}