import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

/**
 * 
 */

/**
 * @author alfonzzz
 * 
 */
public class BotTrustSolver {

    /**
     * @param args
     */
    public static void main(String[] args) {
	init();
	BotTrustSolver botTrustSolver = new BotTrustSolver();
	botTrustSolver.solve();
    }

    private static void init() {
	try {
	    System.setIn(new FileInputStream("in.txt"));
	    System.setOut(new PrintStream("out.txt"));
	} catch (FileNotFoundException e) {
	    e.printStackTrace();
	}
    }

    private final Scanner inputScanner = new Scanner(System.in);
    
    private Scanner testCaseScanner;
    
    private List<Bot> botOrder;
    
    private int counter = 0;

    private void solve() {
	// Number of test cases
	int T = inputScanner.nextInt();
	inputScanner.nextLine();
	for (int i = 1; i <= T; i++) {
	    initTestCase();
	    readTestCase();
	    solveTestCase();
	    printTestCase(i);
	}
    }
    
    private void initTestCase() {
	Bot.B.clear();
	Bot.O.clear();
	counter = 0;
    }

    private void readTestCase() {
	testCaseScanner = new Scanner(inputScanner.nextLine());
	// Number of buttons to be pressed
	int N = testCaseScanner.nextInt();
	botOrder = new ArrayList<Bot>(N);
	
	for (int i=0; i<N; i++) {
	    String botName = testCaseScanner.next();
	    Bot bot = Bot.valueOf(botName);
	    botOrder.add(bot);
	    
	    int instruction = testCaseScanner.nextInt();
	    bot.addInstruction(instruction);
	}
    }
    
    private void solveTestCase() {
	for (Bot b : botOrder) {
	    int currentPosition = b.getPosition();
	    int desiredPosition = b.getNextInstruction();
	    
	    // The number of steps for this but to complete the next instruction
	    int numSteps = Math.abs(desiredPosition - currentPosition) + 1;
	    
	    // Update counter
	    counter += numSteps;
	    
	    // Update bot position
	    b.setPosition(desiredPosition);
	    // Update bot's program counter
	    b.incrementPC();
	    
	    // Move other bot to new position in given steps (only if it hasn't completed it's instructions) 
	    Bot otherBot = Bot.getOtherBot(b);
	    if (otherBot.hasInstructions()) {
		int otherCurrentPosition = otherBot.getPosition();
		int otherDesiredPosition = otherBot.getNextInstruction();
		
		// Calculate how many moves (and in which direction) it will make in the given time
		int distance = otherDesiredPosition - otherCurrentPosition;
		int moves = (int) (Math.min(numSteps, Math.abs(distance)) * Math.signum(distance));
		
		// Calculate and set new position
		int newPosition = otherCurrentPosition + moves;
		otherBot.setPosition(newPosition);
	    }
	}
    }
    
    private final MessageFormat printFormat = new MessageFormat("Case #{0}: ");
    
    private void printTestCase(int num) {
	System.out.print(printFormat.format(new Object[] { num }));
	System.out.println(counter);
    }
    
    public static enum Bot {

	O, B;
	
	public static Bot getOtherBot(Bot b) {
	    if (b.equals(O)) {
		return B;
	    }
	    
	    return O;
	}
	
	private int position = 1;

	private final List<Integer> instructions = new ArrayList<Integer>();
	
	private int pc = 0;
	
	private Bot() {
	    clear();
	}
	
	public void clear() {
	    position = 1;
	    pc = 0;
	    instructions.clear();
	}
	
	public void addInstruction(int instruction) {
	    instructions.add(instruction);
	}
	
	public int getPosition() {
	    return position;
	}
	
	public void setPosition(int position) {
	    this.position = position;
	}
	
	public boolean hasInstructions() {
	    return pc < instructions.size();
	}
	
	public int getNextInstruction() {
	    return instructions.get(pc);
	}
	
	public void incrementPC() {
	    pc++;
	}
	
    }

}
