import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Scanner;
import java.util.Set;

/**
 * 
 */

/**
 * @author alfonzzz
 * 
 */
public class MagickaSolver {

    /**
     * @param args
     */
    public static void main(String[] args) {
	init();
	MagickaSolver magickaSolver = new MagickaSolver();
	magickaSolver.solve();
    }

    private static void init() {
	try {
	    System.setIn(new FileInputStream("in.txt"));
	    System.setOut(new PrintStream("out.txt"));
	} catch (FileNotFoundException e) {
	    e.printStackTrace();
	}
    }

    private final Scanner inputScanner = new Scanner(System.in);
    private Scanner testCaseScanner;

    private final CombinationMap combineMap = new CombinationMap();
    private final OppositionMap opposeMap = new OppositionMap();
    private final CountSet opposeCount = new CountSet();

    private String input;
    private String output;

    private void solve() {
	// Number of test cases
	int T = inputScanner.nextInt();
	inputScanner.nextLine();
	for (int i = 1; i <= T; i++) {
	    initTestCase();
	    readTestCase();
	    solveTestCase();
	    printTestCase(i);
	}
    }

    private void initTestCase() {
	combineMap.clear();
	opposeMap.clear();
	opposeCount.clear();

	input = "";
	output = "";
    }

    private void readTestCase() {
	testCaseScanner = new Scanner(inputScanner.nextLine());
	readCombine();
	readOppose();
	readInput();
    }

    private void readCombine() {
	// Number of combine elements
	int C = testCaseScanner.nextInt();
	for (int i = 0; i < C; i++) {
	    String combine = testCaseScanner.next();
	    char base1 = combine.charAt(0);
	    char base2 = combine.charAt(1);
	    char combination = combine.charAt(2);
	    combineMap.put(base1, base2, combination);
	}
    }

    private void readOppose() {
	// Number of opposed elements
	int D = testCaseScanner.nextInt();
	for (int i = 0; i < D; i++) {
	    String oppose = testCaseScanner.next();
	    char base1 = oppose.charAt(0);
	    char base2 = oppose.charAt(1);
	    opposeMap.put(base1, base2);
	}
    }

    private void readInput() {
	// Number of invoke elements
	int N = testCaseScanner.nextInt();
	input = testCaseScanner.next();
    }

    private void solveTestCase() {
	StringBuilder outputBuilder = new StringBuilder();

	for (char c : input.toCharArray()) {
	    // Output is empty, simply append
	    if (outputBuilder.length() == 0) {
		append(outputBuilder, c);
	    } else {
		// Output isn't empty
		char tail = outputBuilder.charAt(outputBuilder.length() - 1);
		// Check if combination exists
		char combination = combineMap.getCombination(tail, c);
		if (combination != CombinationMap.NULL) {
		    // Append combination
		    outputBuilder.delete(outputBuilder.length() - 1, outputBuilder.length());
		    append(outputBuilder, combination);
		    // Decrement count of tail in opposeCount
		    opposeCount.remove(tail);
		} else {
		    // Check if opposition exists
		    if (opposeMap.contains(c) && opposeCount.containsAtLeastOne(opposeMap.get(c))) {
			outputBuilder.delete(0, outputBuilder.length());
			opposeCount.clear();
		    } else { // No Combination and no opposition, simply append
			append(outputBuilder, c);
		    }
		}
	    }
	}

	output = outputBuilder.toString();
    }

    private void append(StringBuilder builder, char c) {
	builder.append(c);
	if (opposeMap.contains(c)) {
	    opposeCount.add(c);
	}
    }

    private void printTestCase(int num) {
	System.out.print("Case #" + num + ": [");

	StringBuilder formattedOutput = new StringBuilder();

	if (output.length() > 0) {
	    for (char c : output.toCharArray()) {
		formattedOutput.append(c).append(", ");
	    }
	    formattedOutput.delete(formattedOutput.length() - 2, formattedOutput.length());
	}

	System.out.print(formattedOutput.toString());

	System.out.println("]");
    }
    
    public static class CombinationMap {
	
	private static final int ALPHABET_SIZE = 26;
	public static final char NULL = ' ';

	private final char[][] combinationsMatrix = new char[ALPHABET_SIZE][ALPHABET_SIZE]; 
	
	public CombinationMap() {
	    clear();
	}
	
	public void clear() {
	    for (char[] charArray : combinationsMatrix) {
		Arrays.fill(charArray, NULL);
	    }
	}
	
	public void put(char c1, char c2, char combination) {
	    int i1 = resolveIndex(c1);
	    int i2 = resolveIndex(c2);
	    
	    combinationsMatrix[i1][i2] = combination;
	    combinationsMatrix[i2][i1] = combination;
	}
	
	public char getCombination(char c1, char c2) {	    	    
	    int i1 = resolveIndex(c1);
	    int i2 = resolveIndex(c2);

	    char combination = combinationsMatrix[i1][i2];
	    return combination;
	}
	
	private int resolveIndex(char c) {
	    return c % ALPHABET_SIZE;
	}
	
    }

    public static class OppositionMap {

	private static final int ALPHABET_SIZE = 26;
	private static final char NULL = ' ';
	
	private final char[][] oppositionMatrix = new char[ALPHABET_SIZE][ALPHABET_SIZE];
	
	private Set<Character> oppositions = new HashSet<Character>();
	
	public OppositionMap() {
	    clear();
	}

	public void clear() {
	    for (char[] charArray: oppositionMatrix) {
		Arrays.fill(charArray, NULL);
	    }
	    
	    oppositions.clear();
	}

	public void put(char c1, char c2) {
	    int i1 = resolveIndex(c1);
	    int i2 = resolveIndex(c2);
	    
	    oppositionMatrix[i1][i2] = c2;
	    oppositionMatrix[i2][i1] = c1;
	    
	    oppositions.add(c1);
	    oppositions.add(c2);
	    
	}

	public boolean contains(char c) {
	    return oppositions.contains(c);
	}

	public char[] get(char c) {
	    int i = resolveIndex(c);
	    return oppositionMatrix[i];
	}

	private static int resolveIndex(char c) {
	    return c % ALPHABET_SIZE;
	}

    }

    public static class CountSet {

	private static final int ALPHABET_SIZE = 26;

	private final int[] counterArray = new int[ALPHABET_SIZE];

	public CountSet() {
	    clear();
	}

	public void clear() {
	    Arrays.fill(counterArray, 0);
	}

	public void add(char c) {
	    int i = resolveIndex(c);
	    counterArray[i] = counterArray[i] + 1;
	}

	public void remove(char c) {
	    int i = resolveIndex(c);
	    counterArray[i] = Math.max(0, counterArray[i] - 1);
	}

	public boolean containsAtLeastOne(char... chars) {
	    for (char c : chars) {
		if (getCount(c) > 0) {
		    return true;
		}
	    }
	    return false;
	}

	public int getCount(char c) {
	    int i = resolveIndex(c);
	    return counterArray[i];
	}

	private int resolveIndex(char c) {
	    return c % ALPHABET_SIZE;
	}

    }

}
