import java.io.*;

/**
 * Matrix
 */
public class TicTacTockCheck {

    private static final int SIZE = 4;
    private static final int LINE_SIZE = 4;

    // valid chars are X O T .
    char[][] field;
    // transient
    private PrintStream out;

    public TicTacTockCheck() {
        field = new char[SIZE][];
        for(int i=0;i<SIZE;i++)
            field[i] = new char[SIZE];
    }

    public void solveAll(InputStream in, PrintStream out) throws IOException {
        this.out = out;
        BufferedReader reader = new BufferedReader(new InputStreamReader(in));
        int cases = Integer.parseInt(reader.readLine());
        for(int i=0;i<cases;i++) {
            for(int j=0;j<SIZE;j++) {
                System.arraycopy(reader.readLine().toCharArray(), 0, field[j], 0, SIZE);
            }
            reader.readLine(); // skip empty line
            out.print("Case #" + (i + 1) + ": ");
            solve();
        }
    }

    int possibilities[][] = {
            // start x, start y, delta x, delta y
            {0,0,1,0},
            {0,1,1,0},
            {0,2,1,0},
            {0,3,1,0},
            {0,0,0,1},
            {1,0,0,1},
            {2,0,0,1},
            {3,0,0,1},
            {0,0,1,1},
            {0,3,1,-1}
    };

    // solve current field
    private void solve() {
        boolean hasEmpty = false;

        outerLoop: for(int[] possibility : possibilities) {
            int x=possibility[0];
            int y=possibility[1];
            int dx=possibility[2];
            int dy=possibility[3];
            char base = field[y][x];
            for(int i=1;i<LINE_SIZE;i++) {
                x += dx;
                y += dy;
                switch (field[y][x]) {
                    case 'T':
                        break;
                    case '.':
                        hasEmpty = true;
                        continue outerLoop;
                    default:
                        if (base=='T') {
                            base = field[y][x];
                        } else {
                            if (field[y][x]!=base) continue outerLoop;
                        }
                }
            }
            // we get here only if we reached last index
            if (base=='X') {
                out.println("X won");
                return;
            } else {
                out.println("O won");
                return;
            }
        }
        if (hasEmpty) {
            out.println("Game has not completed");
        } else {
            out.println("Draw");
        }
    }

    public static void main(String[] args) throws Exception {
        InputStream in;
        PrintStream out;
        if (args.length>0) {
            in = new FileInputStream(args[0]);
        } else {
            in = System.in;
        }
        if (args.length>1) {
            out = new PrintStream(new FileOutputStream(args[1]));
        } else {
            out = System.out;
        }
        new TicTacTockCheck().solveAll(in, out);
    }
}
