import java.io.*;
import java.util.*;

public class Pirate {

    private int totalChests;
    int[] keys;
    Map<Integer,Chest> chests = new LinkedHashMap<Integer, Chest>();
    int searchCounter = 0;

    public static void main(String[] args) throws Exception {

        InputStream in;
        PrintStream out;
        if (args.length>0) {
            in = new FileInputStream(args[0]);
        } else {
            in = System.in;
        }
        if (args.length>1) {
            out = new PrintStream(new FileOutputStream(args[1]));
        } else {
            out = System.out;
        }
        new Pirate().solveAll(in, out);
    }

    private void solveAll(InputStream in, PrintStream out) throws IOException {
        BufferedReader reader = new BufferedReader(new InputStreamReader(in));
        int cases = Integer.parseInt(reader.readLine());
        for(int i=0;i<cases;i++) {
            int[] sizes = readIntLine(reader.readLine());
            totalChests = sizes[1];
            keys = readIntLine(reader.readLine());
            for(int j=0;j<totalChests;j++) {
                int[] chestInfo = readIntLine(reader.readLine());
                Chest chest = new Chest();
                chest.id = j+1;
                chest.lockType = chestInfo[0];
                for(int k=0;k<chestInfo[1];k++) {
                    chest.keys.add(chestInfo[k+2]);
                }
                chests.put(j, chest);
            }
            System.err.println("Trying case " + i);
//            if (i==2)
                out.println("Case #" + (i + 1) + ": " + solveCase());
            System.err.println("Search counter = " + searchCounter);
        }
    }

    private String solveCase() {
        System.err.println("Position");
        System.err.println("Keys: " + Arrays.toString(keys));
        System.err.println("Chests :");
        for(Chest chest : chests.values())
            System.err.println(chest);
        String solution = null;
        if (isEnoughKeys()) {
            searchCounter = 0;
            Situation initial = new Situation();
            for(int val : keys) increase(initial.keys, val);
            solution = recursiveSolve(initial);
        }
        return solution==null?"IMPOSSIBLE":solution;
    }

    private boolean isEnoughKeys() {
        Map<Integer,Integer> keyCounters = new HashMap<Integer, Integer>();
        for(int key : keys) {
            increase(keyCounters, key);
        }

        for(Chest chest : chests.values()) {
            for(int key : chest.keys)
                increase(keyCounters, key);
        }

        for(Chest chest : chests.values()) {
            if (!keyCounters.containsKey(chest.lockType)) {
                System.err.println("Not enough total keys.");
                return false;
            }
            decrease(keyCounters, chest.lockType);
        }
        return true;
    }

    private String recursiveSolve(Situation current) {
        searchCounter++;
//        System.err.println("Trying : " + current);
        if (current.isFinal()) {
            return current.getPath();
        }
        if (current.keys.isEmpty()) {
            // abort to prevent search
//            System.err.println("Failed on (no keys) " + current.getPath());
            return null;
        }
        List<Situation> possible = getOptions(current);
        for(Situation down : possible) {
            String underneath = recursiveSolve(down);
            if (underneath!=null) {
                return underneath;
            }
        }
//        if (possible.isEmpty())
//            System.err.println("Failed on (no matching chests) " + current.getPath());
        return null;
    }

    private List<Situation> getOptions(Situation current) {
        List<Situation> result = new ArrayList<Situation>();
        for(Chest chest : chests.values()) {
            if (
                    !chest.keys.isEmpty() &&
                    !(chest.keys.size()==1 && chest.keys.contains(chest.lockType)) &&
                    current.canOpen(chest)) {
                result.add(current.fromPrev(chest));
            }
        }
        // useless chests that open themselves
        for(Chest chest : chests.values()) {
            if (chest.keys.size()==1 && chest.keys.contains(chest.lockType)
                    && current.canOpen(chest)) {
                result.add(current.fromPrev(chest));
            }
        }
        // empty chest in last run
        for(Chest chest : chests.values()) {
            if (chest.keys.isEmpty()
                    && current.canOpen(chest)) {
                result.add(current.fromPrev(chest));
            }
        }

        return result;
    }

    private int[] readIntLine(String line) {
        String[] parts = line.split(" ");
        int[] result = new int[parts.length];
        for(int i=0;i<parts.length;i++) {
            result[i] = Integer.parseInt(parts[i]);
        }
        return result;
    }

    private static void increase(Map<Integer,Integer> map, Integer key) {
        Integer val = map.get(key);
        if (val==null) {
            map.put(key, 1);
        } else {
            map.put(key, val+1);
        }
    }

    private static void decrease(Map<Integer,Integer> map, Integer key) {
        Integer val = map.get(key);
        if (val==null) {
            System.err.println("Assertion!");
        }
        if (val==1) {
            map.remove(key);
        } else {
            map.put(key, val-1);
        }
    }

    private static void addAll(Map<Integer,Integer> map, Collection<Integer> integers) {
        for(Integer key : integers) {
            increase(map, key);
        }
    }

    private static void addAll(Map<Integer,Integer> map, Map<Integer,Integer> integers) {
        for(Map.Entry<Integer,Integer> entry : integers.entrySet()) {
            addToKey(map, entry.getKey(), entry.getValue());
        }
    }

    private static void addToKey(Map<Integer, Integer> map, Integer key, Integer value) {
        Integer val = map.get(key);
        if (val==null) {
            map.put(key, value);
        } else {
            map.put(key, val+value);
        }
    }

    public class Situation {
        Map<Integer,Integer> keys = new HashMap<Integer, Integer>();
        Set<Integer> visitedChests = new HashSet<Integer>();
        List<Integer> path = new ArrayList<Integer>();


        Situation() {
        }

        Situation fromPrev(Chest chest) {
            Situation newSit = new Situation();
            addAll(newSit.keys, chest.keys);
            addAll(newSit.keys, keys);
            decrease(newSit.keys, chest.lockType);
            newSit.visitedChests.addAll(visitedChests);
            newSit.visitedChests.add(chest.id);
            newSit.path.addAll(path);
            newSit.path.add(chest.id);
            return newSit;
        }

        boolean canOpen(Chest chest) {
            return !visitedChests.contains(chest.id) && keys.containsKey(chest.lockType);
        }

        boolean isFinal() {
            return visitedChests.size()==totalChests;
        }

        String getPath() {
            StringBuilder builder = new StringBuilder();
            if (!path.isEmpty()) {
                for(Integer key : path) {
                    builder.append(key).append(" ");
                }
                builder.delete(builder.length()-1, builder.length());
            }
            return builder.toString();
        }

        @Override
        public String toString() {
            return "Situation{" +
                    "keys=" + keys +
                    ", visitedChests=" + visitedChests +
                    '}';
        }
    }

    private static class Chest {
        int id;
        int lockType;
        Collection<Integer> keys = new ArrayList<Integer>();

        @Override
        public String toString() {
            return "Chest{" +
                    "id=" + id +
                    ", lockType=" + lockType +
                    ", keys=" + keys +
                    '}';
        }
    }
}
