import java.io.*;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

/**
 * Template to read multiple tasks and solve them
 */
public class Solver {

    private class Task {
        public int maxLevel;
        public int[] audienceLevels;
    }

    private class Solution {
        int friends;

        public Solution(int friends) {
            this.friends = friends;
        }

        @Override
        public String toString() {
            return Integer.toString(friends);
        }
    }

    final InputStream in;
    final PrintStream out;

    public Solver(InputStream in, PrintStream out) {
        this.in = in;
        this.out = out;
    }

    /**
     * Read input.
     * First line is number of tasks.
     * Parse tasks and solve them.
     * @throws IOException if reading fails
     */
    public void solveAll() throws IOException {
        BufferedReader reader = new BufferedReader(new InputStreamReader(in));
        int cases = Integer.parseInt(reader.readLine());
        for(int i=0;i<cases;i++) {
            Task task = parseTask(reader);
            out.println("Case #" + (i + 1) + ": " + solve(task).toString());
        }
    }

    private Task parseTask(BufferedReader reader) throws IOException {
        String line[] = reader.readLine().split(" ");
        Task task = new Task();
        task.maxLevel = Integer.parseInt(line[0]);
        task.audienceLevels = new int[task.maxLevel+1];
        for(int i=0;i<=task.maxLevel;i++) {
            task.audienceLevels[i] = Integer.parseInt(line[1].substring(i,i+1));
        }
        return task;
    }

    private Solution solve(Task task) {
        int friends = 0;
        int standing = 0;
        for(int i=0;i<=task.maxLevel;i++) {
            if (task.audienceLevels[i]==0) continue;
            if (i>standing) {
                int extras = i-standing;
                friends += extras;
                standing += extras;
            }
            standing += task.audienceLevels[i];
        }

        return new Solution(friends);
    }

    public static void main(String[] args) throws IOException {
        InputStream in;
        PrintStream out;
        if (args.length>0) {
            in = new FileInputStream(args[0]);
        } else {
            in = System.in;
        }
        if (args.length>1) {
            out = new PrintStream(new FileOutputStream(args[1]));
        } else {
            out = System.out;
        }
        new Solver(in, out).solveAll();
    }
}
