/*
 * This code is meant to run under the Java Runtime Environment, version 1.7 or
 * later.
 */

package round1b.a;

import java.io.BufferedReader;
import java.io.FileReader;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class Main1 {
	
	// This is used to work around the inability of Eclipse to use a file as
	// System.in when running a program.
	private static final String IN_FILE_NAME = "A-small-attempt0.in";

	public static void main(String[] args) throws Exception {
		Scanner in = new Scanner(new BufferedReader(new FileReader(IN_FILE_NAME)));
		
		long numCases = in.nextLong();
		
		for (long i = 1; i <= numCases; i++) {
			int n = in.nextInt();
			String[] words = new String[n];
			for (int j = 0; j < n; j++) {
				words[j] = in.next();
			}
			
			Long result = solve(words);
			String resultStr = (result == null) ?
				"Fegla Won" : result.toString();
			
			System.out.println(String.format("Case #%s: %s", i, resultStr));
		}
		
		in.close();
	}
	
	// Returns null if no solution.
	private static Long solve(String[] words) {
		// Decode words.
		StrUnit[][] decodedWords = new StrUnit[words.length][];
		for (int i = 0; i < words.length; i++) {
			decodedWords[i] = decode(words[i]);
			
			// Check that all decoded words have same number of units.
			if (i > 0) {
				if (decodedWords[i].length != decodedWords[0].length) {
					return null;
				}
			}
		}
		
		// For each unit from position 0 to end, change number of repeats in
		// that unit so it is the same for all words.
		int numUnits = decodedWords[0].length;
		long result = 0;
		for (int i = 0; i < numUnits; i++) {
			StrUnit[] ithUnits = new StrUnit[words.length];
			for (int j = 0; j < words.length; j++) {
				ithUnits[j] = decodedWords[j][i];
			}
			Long ithResult = movesToMakeSame(ithUnits);
			if (ithResult == null) {
				return null;
			}
			else {
				result += ithResult;
			}
		}
		
		return result;
	}
	
	private static StrUnit[] decode(String str) {
		List<StrUnit> result = new ArrayList<StrUnit>();
		StrUnit nextUnit = new StrUnit(str.charAt(0), 1);
		result.add(nextUnit);
		for (int i = 1; i < str.length(); i++) {
			char nextChar = str.charAt(i);
			if (nextChar == nextUnit.letter) {
				nextUnit.repeats++;
			}
			else {
				nextUnit = new StrUnit(nextChar, 1);
				result.add(nextUnit);
			}
		}
		
		return result.toArray(new StrUnit[result.size()]);
	}
	
	// Returns null if can't make same.
	private static Long movesToMakeSame(StrUnit[] units) {
		assert(units.length > 0);
		
		if (!areAllSameChar(units)) {
			return null;
		}
		
		// Compute mean.  (This is the number we will get all the nums to
		// equal.)
		long sum = 0;
		for (StrUnit su : units) {
			sum += su.repeats;
		}
		long mean = Math.round(sum / (double) units.length);
		
		long result = 0;
		for (StrUnit su : units) {
			result += Math.abs(su.repeats - mean);
		}
		
		return result;
	}
	
	private static boolean areAllSameChar(StrUnit[] units) {
		assert(units.length > 0);
		
		char first = units[0].letter;
		for (int i = 1; i < units.length; i++) {
			if (first != units[i].letter) {
				return false;
			}
		}
		
		return true;
	}
	
	private static class StrUnit {
		char letter;
		int repeats;
		
		public StrUnit(char letter, int numOccurrences) {
			this.letter = letter;
			this.repeats = numOccurrences;
		}
	}
}
