/*
 * This code is meant to run under the Java Runtime Environment, version 1.7 or
 * later.
 */

package round2.a;

import java.io.BufferedReader;
import java.io.FileReader;
import java.util.Scanner;

public class Main0 {
	
	// This is used to work around the inability of Eclipse to use a file as
	// System.in when running a program.
	private static final String IN_FILE_NAME = "A-small-attempt3.in";

	public static void main(String[] args) throws Exception {
		Scanner in = new Scanner(new BufferedReader(new FileReader(IN_FILE_NAME)));
		
		long numCases = in.nextLong();
		
		for (long i = 1; i <= numCases; i++) {
			int numFiles = in.nextInt();
			int discSize = in.nextInt();
			long[] fileSizeCounts = new long[discSize+1];
			int minFileSize = Integer.MAX_VALUE;
			int maxFileSize = 0;
			for (long j = 0; j < numFiles; j++) {
				int fileSize = in.nextInt();
				fileSizeCounts[fileSize]++;
				minFileSize = Math.min(minFileSize, fileSize);
				maxFileSize = Math.max(maxFileSize, fileSize);
			}
			
			long result = solve(discSize, fileSizeCounts, minFileSize,
				maxFileSize, numFiles);
			String resultStr = ""+result;
			
			System.out.println(String.format("Case #%s: %s", i, resultStr));
		}
		
		in.close();
	}
	
	private static long solve(int discSize, long[] fileSizeCounts,
		int minFileSize, int maxFileSize, int numFiles)
	{
		// Fill one disc at a time.
		long discsFilled = 0;
		while (numFiles > 0) {
			int[] fillResult = fillDisc(discSize, fileSizeCounts, minFileSize,
				maxFileSize, numFiles);
			minFileSize = fillResult[0];
			maxFileSize = fillResult[1];
			numFiles = fillResult[2];
			discsFilled++;
			
			// TODO: Remove this?
			assert(numFiles >= 0);
			int fileCount = 0;
			for (long count : fileSizeCounts) {
				assert(count >= 0);
				fileCount += (int) count;
			}
			assert(fileCount == numFiles);
		}
		assert(numFiles == 0);
		
		return discsFilled;
	}
	
	// Returns:
	// - New min file size.
	// - New max file size.
	// - New num files.
	// Also modifies fileSizeCounts appropriately.
	private static int[] fillDisc(int discSize, long[] fileSizeCounts,
		int minFileSize, int maxFileSize, int numFiles)
	{
		assert(numFiles > 0);
		
		// Remove largest file.
		int[] firstRemovalResult = removeFile(fileSizeCounts, minFileSize,
			maxFileSize, numFiles, maxFileSize);
		
		// If possible, pair it with another file as large as possible without
		// overflowing disc.
		int largestPartner = discSize - firstRemovalResult[3];
		if (firstRemovalResult[2] > 0
			&& largestPartner >= firstRemovalResult[0])
		{
			int[] secondRemovalResult = removeFile(fileSizeCounts,
				firstRemovalResult[0], firstRemovalResult[1],
				firstRemovalResult[2], largestPartner);
//			System.out.println("=== Disc filled (2 files).");
//			System.out.println("=== Extra space: " + (discSize - (firstRemovalResult[3] + secondRemovalResult[3])));
			assert(firstRemovalResult[3] + secondRemovalResult[3] <= discSize);
			return secondRemovalResult;
		}
		else {
//			System.out.println("=== Disc filled (1 file).");
//			System.out.println("=== Extra space: " + (discSize - firstRemovalResult[3]));
			return firstRemovalResult;
		}
	}
	
	// Removes the largest file having size no greater than fileSizeToRemove.
	// Returns:
	// - New min file size.
	// - New max file size.
	// - New num files.
	// - Size of file removed.
	// Also modifies fileSizeCounts appropriately.
	private static int[] removeFile(long[] fileSizeCounts, int minFileSize,
		int maxFileSize, int numFiles, int fileSizeToRemove)
	{
		assert(numFiles > 0);
		assert(fileSizeToRemove >= minFileSize);
		if (fileSizeToRemove > maxFileSize) {
			fileSizeToRemove = maxFileSize;
		}
		
		// Find largest file no larger than fileSizeToRemove.
		int actualFileSizeToRemove = fileSizeToRemove;
		while (fileSizeCounts[actualFileSizeToRemove] == 0) {
			actualFileSizeToRemove--;
		}
		
		// Remove file.
		fileSizeCounts[actualFileSizeToRemove]--;
		int newNumFiles = numFiles-1;
		int newMinFileSize = minFileSize;
		int newMaxFileSize = maxFileSize;
		if (newNumFiles > 0) {
			while (fileSizeCounts[newMinFileSize] == 0) {
				newMinFileSize++;
			}
			while (fileSizeCounts[newMaxFileSize] == 0) {
				newMaxFileSize--;
			}
		}
		
//		System.out.println("=== Removed file of size: " + actualFileSizeToRemove);
//		System.out.println("=== (Should be no more than " + fileSizeToRemove + ".)");
		
//		System.out.println(String.format("New min, new max, new num files: %s, %s, %s", newMinFileSize, newMaxFileSize, newNumFiles));
		int[] result = {newMinFileSize, newMaxFileSize, newNumFiles,
			actualFileSizeToRemove};
		return result;
	}
}