package util;

import java.io.File;
import java.util.Enumeration;
import java.util.Hashtable;

public class Histogram {
	
	public static String start = "*";
	public static String end = "!";
	
	
	protected Hashtable<String,Integer> table;
	protected Hashtable<String,Integer> index;
	
	private int count = 0;
	
	private String name;
	protected double drichlet = 1;
	public static int vocabSize;
	private String[] keys;
	
	public Histogram(){
		table = new Hashtable<String,Integer>();
		index = new Hashtable<String,Integer>();
	}
	public Histogram(String in){
		name = in;
		table = new Hashtable<String,Integer>();
		index = new Hashtable<String,Integer>();
	}
	public Histogram(int size){
		table = new Hashtable<String,Integer>(size);
		index = new Hashtable<String,Integer>(size);
	}
	public String getName(){
		return this.name;
	}
	public void setKeys(String in[]){
		this.keys = in;
	}
	
	public void put(String in){
		int temp;
		count++;
		if(table.containsKey(in)){
			temp = table.get(in);
			table.put(in, temp + 1 );
		}
		else {
			table.put(in,1);
		}
	}
	
	public int get(String in){
		if(table.containsKey(in))
			return table.get(in); 
		else return 0;
	}
	public boolean contains(String in){
		return table.containsKey(in);
	}
	
	public String toString(){
		String out = this.name + " \n ";
		String keys[] = Util.getKeys(this.table);
		for (int i = 0; i < keys.length; i++) {
			try{
				out+=keys[i]+"\t"+this.get(keys[i])+"\t";
			}catch(Exception e){
				System.out.println("malformed line.");
			}
//			System.out.println(keys[i]);
		}
		out+="total : "+this.getCount()+"\n";
		return out;
	}
	
	public void writeFile(String filename){
		File f = new File(filename);
		if(f.exists()) f.delete();
		String temp;
		int count = 0;
		for(Enumeration<String> e = table.keys(); e.hasMoreElements();) {
			temp = (String) e.nextElement();
			count++;
//			System.out.println(count +"\t" + this.size());
			Util.append2File(filename,temp+"\t"+this.get(temp)+"\n");
		}
	}
	
	public void load(String filename, boolean readNum){
		this.table.clear();
		FileLiner in = new FileLiner(filename);
		String temp[], line;
		int count = 0;
		while((line = in.getLine()) != null){
//			System.out.println(count);
			temp = line.split("\t");
			if(readNum)
				this.insert(temp[0],(int)Double.parseDouble(temp[1]));
			else
				this.insert(temp[0],0);
			index.put(temp[0],count);
			count++;
//			System.out.println(Integer.parseInt(temp[1]));
		}
		in.close();
	}
	
	public void load(String[] in){
		for (int i = 0; i < in.length; i++) {
			this.put(in[i]);
		}
	}
	
	public int size(){
		return this.table.size();
	}
	public String[] getKeys(){
		return Util.getKeys(this.table);
	}
	public double getNormalized(String string) {
		int out = this.get(string);
		if(this.size() > 0)
			return (((double)out + this.drichlet) / ((double)this.getCount() + 1 + ((this.drichlet) * (double) this.size())));
		else {
			return (((double)out + this.drichlet) / ((double)this.getCount() + 1 + ((this.drichlet) * Histogram.vocabSize )));
		}
	}
	public void insert(String str,int in){
		if(!this.table.containsKey(str))
			this.table.put(str,in);
		else 
			this.table.put(str, table.get(str) + in);
		count += in;
	}
	public void include(Histogram hist2) {
		int count1, count2;
		if(hist2.keys != null){
			for (int i = 0; i < hist2.keys.length; i++) {
				count1 = this.get(hist2.keys[i]);
				count2 = hist2.get(hist2.keys[i]);
//				System.out.println(count1 + "\t" + count2 + "\t" + keys[i]);
				this.remove(hist2.keys[i]);
				this.insert(hist2.keys[i],count1+count2);
			}
			return;
		}

		String keys[] = hist2.getKeys();
//		System.out.println(hist2.toString());
		for (int i = 0; i < keys.length; i++) {
			count1 = this.get(keys[i]);
			count2 = hist2.get(keys[i]);
//			System.out.println(count1 + "\t" + count2 + "\t" + keys[i]);
			this.remove(keys[i]);
			this.insert(keys[i],count1+count2);
		}
	}
	public void prune(int threshold){
		String keys[] = this.getKeys();
		for (int i = 0; i < keys.length; i++) {
			if(this.get(keys[i]) < threshold)
				this.remove(keys[i]);
		}
	}
	private void remove(String key) {
		int keyCount = this.get(key);
		count -= keyCount;
		this.table.remove(key);
	}
	
	public void removeOne(String key){
		int keyCount = this.get(key);
		count -= 1;
		table.put(key,keyCount - 1);
	}

	public int getCount(){
		return count;
	}
	
	public double getDrichlet(){
		return this.drichlet;
	}
	public void setDrichlet(double d){
		this.drichlet = d;
	}
	
	public double verify(){
		double out = 0;
		String temp;
		for(Enumeration<String> e = table.keys(); e.hasMoreElements();) {
			temp = (String) e.nextElement();
			out += this.getNormalized(temp);
		}
		return out;
	}

	public double getProb(String[] words){
		double out = 0;
		for (int i = 0; i < words.length; i++) {
			out += Math.log(this.getNormalized(words[i]));
		}
		out += Math.log(this.getNormalized(start) + Math.log(this.getNormalized(end)));
		return out;
	}
	
	public int getIndex(String in){
		return index.get(in);
	}
	public void writeFile(String filename, boolean b) {
		File f = new File(filename);
		if(f.exists()) f.delete();
		String temp;
		int count = 0;
		for(Enumeration<String> e = table.keys(); e.hasMoreElements();) {
			temp = (String) e.nextElement();
			count++;
			System.out.println(count +"\t" + this.size());
			if(b)
				Util.append2File(filename,temp+"\t"+this.get(temp)+"\n");
			else Util.append2File(filename,temp+"\n");
		}		
	}

}

