package qualifier.minesweeper;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class InputParser {

	private static final String NON_NUMERIC_INPUT_ERROR = "The input file contains non-numeral characters.";
	private static final String READER_ERROR = "The file you provided could not be read.";

	/**
	 * Given an input file, parse its contents to create test cases
	 * @param inputFile		The file to read and parse
	 * @return				A list of test cases generated from the input file
	 */
	public static List<GameBoard> getGameBoards(File inputFile) {
		List<GameBoard> gameBoards = new ArrayList<GameBoard>();
		Integer numTestCases = null;
		
		try {
			BufferedReader reader = new BufferedReader( new FileReader( inputFile ) );
			// First line always contains the number of test cases
			numTestCases = Integer.parseInt( reader.readLine() );
			
			for ( int i = 0; i < numTestCases; i++ ) {
				GameBoard board = getTestCaseFromReader( reader );
				if ( board != null ) {
					gameBoards.add( board );
				}
			}
			
		} catch (FileNotFoundException e) {
			// This is checked by the solver, and should never occur
			System.err.println( e.getMessage() );
		} catch (NumberFormatException e) {
			System.err.println( NON_NUMERIC_INPUT_ERROR );
		} catch (IOException e) {
			System.err.println( READER_ERROR );
		}
		
		return gameBoards;
	}
	
	/**
	 * Get the next input line and create a test case from it
	 * @param reader					BufferedReader containing the input
	 * @return							CookieTestCase initialized with the arguments from the file
	 */
	private static GameBoard getTestCaseFromReader(BufferedReader reader) throws NumberFormatException, IOException {
		// Get the input settings from the file
		String[] argumentStrings = reader.readLine().split( " " );
		
		int rows = Integer.parseInt( argumentStrings[0] );
		int cols = Integer.parseInt( argumentStrings[1] );
		int mines= Integer.parseInt( argumentStrings[2] );
		
		// Create a test case with the supplied arguments
		return new GameBoard( rows, cols, mines );
	}
}
