package qualifier.magicTrick;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.List;
import java.util.ArrayList;


public class SimpleInputParser {

	private static final String NON_NUMERIC_INPUT_ERROR = "The input file contains non-numeral characters.";
	private static final String READER_ERROR = "The file you provided could not be read.";

	/**
	 * Given an input file, parse its contents to create test cases
	 * @param inputFile		The file to read and parse
	 * @return				A list of test cases generated from the input file
	 */
	public static List<TestCase> getTestCases(File inputFile) {
		List<TestCase> testCases = new ArrayList<TestCase>();
		Integer numTestCases = null;
		
		try {
			BufferedReader reader = new BufferedReader( new FileReader( inputFile ) );
			numTestCases = Integer.parseInt( reader.readLine() );
			
			for ( int i = 0; i < numTestCases; i++ ) {
				TestCase testCase = getTestCaseFromReader( reader );
				if ( testCase != null ) {
					testCases.add( testCase );
				}
			}
			
		} catch (FileNotFoundException e) {
			// This is checked by the solver, and should never occur
			System.err.println( e.getMessage() );
		} catch (NumberFormatException e) {
			System.err.println( NON_NUMERIC_INPUT_ERROR );
		} catch (IOException e) {
			System.err.println( READER_ERROR );
		}
		
		return testCases;
	}

	private static TestCase getTestCaseFromReader(BufferedReader reader) throws NumberFormatException, IOException {
		int firstCardRowNum = Integer.parseInt( reader.readLine() );
		int[] firstCards = new int[16];
		
		/**
		 * The next four lines represent the cards
		 */
		for ( int i = 0; i < 4; i++ ) {
			String cardRow[] = reader.readLine().split( " " );
			// We're taking a line of four digits at a time and adding it into a 16-element array
			int baseIndex = ( 4 * i );
			
			for ( int j = 0; j < 4; j++ ) {
				firstCards[ baseIndex + j ] = Integer.parseInt( cardRow[j] );
			}
		}
		
		
		int secondCardRowNum = Integer.parseInt( reader.readLine() );
		int[] secondCards = new int[16];
		/**
		 * The next four lines represent the cards
		 */
		for ( int i = 0; i < 4; i++ ) {
			String cardRow[] = reader.readLine().split( " " );
			// We're taking a line of four digits at a time and adding it into a 16-element array
			int baseIndex = ( 4 * i );
			
			for ( int j = 0; j < 4; j++ ) {
				secondCards[ baseIndex + j ] = Integer.parseInt( cardRow[j] );
			}
		}
		
		return new TestCase( firstCardRowNum, firstCards, secondCardRowNum, secondCards);
	}

}
