import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Stack;


public class Magicka {

	public static void main(String[] args) throws IOException {
		if (args.length < 2) {
			return;
		}
		BufferedReader reader = new BufferedReader(new FileReader(args[0]));
		BufferedWriter writer = new BufferedWriter(new FileWriter(args[1]));
		Magicka magicka = new Magicka();
		int N = Integer.valueOf(reader.readLine());
		for (int i = 0; i < N; i++) {
			magicka.init(reader.readLine());
			writer.append("Case #" + (i + 1) + ": ");
			writer.append(String.valueOf(magicka.start()));
			writer.newLine();
		}
		reader.close();
		writer.close();
	}
	
	public class Combo {
		int e1;
		int e2;
		char c;
		
		public Combo(String s) {
			e1 = elementMap.get(s.charAt(0));
			e2 = elementMap.get(s.charAt(1));
			c = s.charAt(2);
		}
		
		public Character combine(int e1, int e2) {
			return (this.e1 == e1 && this.e2 == e2) || (this.e1 == e2 && this.e2 == e1) ? c : null;
		}
		
		@Override
		public String toString() {
			return String.format("%c%c->%c", elements[e1], elements[e2], c);
		}
	}
	
	public class Opposition {
		int e1;
		int e2;
		
		public Opposition(String s) {
			e1 = elementMap.get(s.charAt(0));
			e2 = elementMap.get(s.charAt(1));
		}
		
		public Integer oppose(int e) {
			if (e != e1 && e != e2) {
				return null;
			}
			return e == e1 ? e2 : e1;
		}
		
		@Override
		public String toString() {
			return String.format("%c<->%c", elements[e1], elements[e2]);
		}
	}

	private static final Map<Character, Integer> elementMap = new HashMap<Character, Integer>();
	private static final char[] elements = {'Q', 'W', 'E', 'R', 'A', 'S', 'D', 'F'};
	
	private List<Combo> combos = new ArrayList<Combo>();
	private List<Opposition> oppos = new ArrayList<Opposition>();
	private Stack<Character> list = new Stack<Character>();
	private int[] input = null;
	private int[] count = {0, 0, 0, 0, 0, 0, 0, 0};
	
	public Magicka() {
		elementMap.clear();
		elementMap.put('Q', 0);
		elementMap.put('W', 1);
		elementMap.put('E', 2);
		elementMap.put('R', 3);
		elementMap.put('A', 4);
		elementMap.put('S', 5);
		elementMap.put('D', 6);
		elementMap.put('F', 7);
	}
	
	private void init(String s) {
		combos.clear();
		oppos.clear();
		list.clear();
		input = null;
		Arrays.fill(count, 0);
		
		String[] seq = s.split(" ");
		int index = 0;
		
		// Combine Rules
		int combine = Integer.valueOf(seq[index++]);
		for (int i = 0; i < combine; i++) {
			combos.add(new Combo(seq[index++]));
		}
		// Opposition Rules
		int opposed = Integer.valueOf(seq[index++]);
		for (int i = 0; i < opposed; i++) {
			oppos.add(new Opposition(seq[index++]));
		}
		
		// Elements
		int num = Integer.valueOf(seq[index++]);
		input = new int[num];
		for (int i = 0; i < num; i++) {
			input[i] = elementMap.get(seq[index].charAt(i));
		}
		
		// Test
		System.out.println(combos);
		System.out.println(oppos);
		System.out.println(Arrays.toString(input));
		System.out.println();
	}
	
	private List<Character> start() {
		for (int i = 0; i < input.length; i++) {
			int e = input[i];
			if (!list.isEmpty()) {
				Integer lastElement = elementMap.get(list.peek());
				Character combined = checkCombo(lastElement, e);
				if (combined != null) {
					// Do combine
					count[lastElement]--;
					list.pop();
					list.push(combined);
				} else {
					Integer opposed = checkOpposition(e);
					if (opposed != null && count[opposed] > 0) {
						// Do opposed
						list.clear();
						Arrays.fill(count, 0);
					} else {
						// Add element
						addElement(e);
					}
				}
			} else {
				// Add element
				addElement(e);
			}
			System.out.println(Arrays.toString(count));
		}
		System.out.println();
		return list;
	}
	
	private Character checkCombo(Integer e1, int e2) {
		if (e1 != null) {
			for (Combo combo : combos) {
				Character result = combo.combine(e1, e2);
				if (result != null) {
					return result;
				}
			}
		}
		return null;
	}
	
	private Integer checkOpposition(int e1) {
		for (Opposition oppo : oppos) {
			Integer result = oppo.oppose(e1);
			if (result != null) {
				return result;
			}
		}
		return null;
	}
	
	private void addElement(int e) {
		list.push(elements[e]);
		count[e]++;
	}
}
