import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.LinkedList;
import java.util.Queue;


public class BotTrust {

	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		if (args.length < 2) {
			return;
		}
		BufferedReader reader = new BufferedReader(new FileReader(args[0]));
		BufferedWriter writer = new BufferedWriter(new FileWriter(args[1]));
		BotTrust botTrust = new BotTrust();
		int N = Integer.valueOf(reader.readLine());
		for (int i = 0; i < N; i++) {
			writer.append("Case #" + (i + 1) + ": ");
			botTrust.init(reader.readLine());
			writer.append(String.valueOf(botTrust.start()));
			writer.newLine();
		}
		reader.close();
		writer.close();
	}

	public static class Action {
		boolean isO;
		int buttonPos;
		int index;
		
		public Action(String color, int buttonPos, int index) {
			this.isO = "O".equals(color);
			this.buttonPos = buttonPos;
			this.index = index;
		}
		
		@Override
		public String toString() {
			return String.format("%d:%s%d", index, isO ? "O" : "B", buttonPos);
		}
	}
	
	private Queue<Action> queueO = new LinkedList<Action>();
	private Queue<Action> queueB = new LinkedList<Action>();
	private int posO = 1;
	private int posB = 1;
	private Action actionO = null;
	private Action actionB = null;
	boolean doActionO = true;
	
	private void init(String s) {
		// Clean up
		queueO.clear();
		queueB.clear();
		posO = posB = 1;
		actionO = actionB = null;
		doActionO = true;
		
		String[] seq = s.split(" ");
		int num = Integer.valueOf(seq[0]);
		for (int i = 1; i < seq.length; i += 2) {
			Action a = new Action(seq[i], Integer.valueOf(seq[i+1]), (i - 1) >> 1);
			if (a.isO) {
				queueO.add(a);
			} else {
				queueB.add(a);
			}
		}
		assert(num == queueO.size() + queueB.size());
//		System.out.println(queueO);
//		System.out.println(queueB);
	}
	
	private int start() {
		int result = 0;
		while (!queueO.isEmpty() || !queueB.isEmpty()) {
			actionO = queueO.peek();
			actionB = queueB.peek();
			doActionO = doActionO(actionO, actionB);
			int time = 0;
			int timeO = getTime(actionO, posO);
			int timeB = getTime(actionB, posB);
			if (doActionO) {
				// Calculate time
				time = timeO + 1;
				
				// Update position
				posO = actionO.buttonPos;
				posB = getNewPos(actionB, posB, timeB, time);
				
				// Dequeue action
				queueO.remove();
			} else {
				time = timeB + 1;
				posB = actionB.buttonPos;
				posO = getNewPos(actionO, posO, timeO, time);
				queueB.remove();
			}
			result += time;
//			System.out.println(String.format("%d %d %d", result, posO, posB));
		}
//		System.out.println();
		return result;
	}
	
	private boolean doActionO(Action o, Action b) {
		if (o == null) {
			return false;
		}
		if (b == null) {
			return true;
		}
		return o.index < b.index;
	}
	
	private int getNewPos(Action action, int pos, int time, int timeAvailable) {
		if (time == 0) {
			return pos;
		}
		if (time <= timeAvailable) {
			return action.buttonPos;
		}
		if (pos > action.buttonPos) {
			return pos - timeAvailable;
		} else {
			return pos + timeAvailable;
		}
	}
	
	private int getTime(Action action, int pos) {
		if (action == null) {
			return 0;
		}
		return Math.abs(pos - action.buttonPos);
	}
}
