import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;


public class RPI {

	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		if (args.length < 2) {
			return;
		}
		BufferedReader reader = new BufferedReader(new FileReader(args[0]));
		BufferedWriter writer = new BufferedWriter(new FileWriter(args[1]));
		Integer T = Integer.valueOf(reader.readLine());
		RPI rpi = new RPI();
		for (int i = 0; i < T; i++) {
			Integer N = Integer.valueOf(reader.readLine());
			int[][] matrix = new int[N][N];
			for (int j = 0; j < N; j++) {
				String s = reader.readLine();
				for (int k = 0; k < N; k++) {
					char c = s.charAt(k);
					if (c == '.') {
						matrix[j][k] = -1;
					} else if (c == '0') {
						matrix[j][k] = 0;
					} else if (c == '1') {
						matrix[j][k] = 1;
					}
				}
			}
			double[] result = rpi.calculateAll(N, matrix);
			writer.write("Case #" + (i + 1) + ":");
			writer.newLine();
			for (double score : result) {
				writer.write(String.valueOf(score));
				writer.newLine();
			}
		}
		reader.close();
		writer.close();
	}
	
	public double[] calculateAll(int N, int[][] matrix) {
		double[] result = new double[N];
		double[] owpCache = new double[N];
		for (int team = 0; team < N; team++) {
			// wp
			double wp = calculateWP(N, matrix, team, null);
			
			// owp
			owpCache[team] = 0;
			int opps = 0;
			for (int i = 0; i < N; i++) {
				if (matrix[team][i] != -1) {
					owpCache[team] += calculateWP(N, matrix, i, team);
					opps++;
				}
			}
			owpCache[team] /= opps;
			result[team] = 0.25 * wp + 0.5 * owpCache[team];
		}
		for (int team = 0; team < N; team++) {
			double oowp = 0;
			int opps = 0;
			for (int i = 0; i < N; i++) {
				if (matrix[team][i] != -1) {
					oowp += owpCache[i];
					opps++;
				}
			}
			oowp /= opps;
			result[team] += 0.25 * oowp;
		}
		return result;
	}
	
	private double calculateWP(int N, int[][] matrix, int team, Integer oppTeam) {
		int games = 0, won = 0;
		for (int i = 0; i < N; i++) {
			if (oppTeam != null && oppTeam == i) {
				continue;
			}
			if (matrix[team][i] != -1) {
				games++;
				if (matrix[team][i] == 1) {
					won++;
				}
			}
		}
		return games == 0 ? 0 : won / Double.valueOf(games);
	}
}
