package ru.altazar.contest2017.round1b;

import ru.altazar.Problem;

import java.io.BufferedReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;

public class StableNeighbors extends Problem {

    @Override
    protected String solveCase(BufferedReader reader) throws IOException {
        String[] split = reader.readLine().split(" ");

        int numUnicorns = Integer.parseInt(split[0]);
        int numRed = Integer.parseInt(split[1]);
        int numOrange = Integer.parseInt(split[2]);
        int numYellow = Integer.parseInt(split[3]);
        int numGreen = Integer.parseInt(split[4]);
        int numBlue = Integer.parseInt(split[5]);
        int numViolet = Integer.parseInt(split[6]);

        String solution = solve(numRed, numYellow, numBlue);
        if (solution == null) {
            return "IMPOSSIBLE";
        }
        return solution;
    }


    private String solve(int r, int y, int b) {
        List<ColorCount> unicorns = new ArrayList<>();
        unicorns.add(new ColorCount(Color.R, r));
        unicorns.add(new ColorCount(Color.Y, y));
        unicorns.add(new ColorCount(Color.B, b));

        unicorns.removeIf(cc -> cc.count == 0);

        Comparator<ColorCount> c = Comparator.comparingInt(u -> u.count);
        unicorns.sort(c.reversed());

        int total = r + y + b;
        char[] stalls = new char[total];
        for (int i = 0; i < stalls.length; i++) {
            stalls[i] = '\0';
        }

        int indx = 0;
        while (!unicorns.isEmpty()) {
            ColorCount unicornType = unicorns.get(0);
            unicornType.count--;
            if (unicornType.count == 0) {
                unicorns.remove(unicornType);
            }

            stalls[indx] = unicornType.color.name().charAt(0);

            int left = indx == 0 ? total - 1 : indx - 1;
            int right = indx == total - 1 ? 0 : indx + 1;
            if (stalls[left] == stalls[indx] || stalls[right] == stalls[indx]) {
                return null;
            }

            if (indx + 2 <= total - 1) {
                indx = indx + 2;
            } else {
                indx = 1;
            }
        }

        return String.valueOf(stalls);
    }


    private static class ColorCount {
        Color color;
        int count;

        public ColorCount(Color color, int count) {
            this.color = color;
            this.count = count;
        }
    }

    private enum Color {
        R, Y, B;
    }
}
