package jam.first;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.net.URL;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.Locale;

public class GoroSort {

	public final static void main(String[] args) throws Exception {
		new GoroSort();
	}

	private GoroSort() throws Exception {
		// Reading
		URL inURL = this.getClass().getResource("./testgoro.in");
		if (inURL == null)
			throw new FileNotFoundException("input file not found");

		File in = new File(inURL.getPath());
		FileReader reader = new FileReader(in);
		BufferedReader buffreader = new BufferedReader(reader);

		File out = new File(inURL.getPath().replace(".in", ".out"));
		FileWriter writer = new FileWriter(out);
		BufferedWriter buffwriter = new BufferedWriter(writer);

		InputTokens inputtokens = new InputTokens();
		OutputTokens outputtokens = new OutputTokens();

		inputtokens.read(buffreader);
		// End Reading

		int testcases = inputtokens.getInt(0, 0);

		for (int i = 1; i < testcases * 2 + 1; i += 2) {
			// new testcase
			
			// initialization
			int length = inputtokens.getInt(i, 0);
			ArrayList<Integer> numbers = new ArrayList<Integer>(length);

			for (int k = 0; k < length; k++) {
				numbers.add(inputtokens.getInt(i + 1, k));
			}
			
			//elaboration
			int correct = 0;
			int permutations = 1;
			float entropy = 0;
			
			for (int k = 0; k < numbers.size(); k++) {
				int distance = Math.abs(numbers.get(k)-(k+1));
				if(distance==0)correct++;
				else entropy+=1;				
			}
			
			for(int k =numbers.size()-correct;k>0;k--){
				permutations*=k;
			}
			

			// output
			int testcase = ((i - 1) / 2 + 1);
			NumberFormat nf = NumberFormat.getNumberInstance(Locale.US);
			DecimalFormat df = (DecimalFormat)nf;
			df.applyPattern("0.000000");
			outputtokens.set(testcase - 1, 0, "Case");
			outputtokens.set(testcase - 1, 1, "#" + testcase + ":");
			outputtokens.set(testcase - 1, 2, df.format(entropy));
		}

		// end testcase

		// Writing
		outputtokens.write(buffwriter);
		// End Writing
	}

	// Utility class for deserializing
	class InputTokens {

		ArrayList<String[]> rawtokens = new ArrayList<String[]>();

		void read(BufferedReader reader) throws Exception {
			String line;
			while ((line = reader.readLine()) != null) {
				rawtokens.add(line.split("\\s"));
			}
			reader.close();
		}

		Integer getInt(int row, int column) {
			String token = rawtokens.get(row)[column];
			return Integer.valueOf(token);
		}

		Character getChar(int row, int column) {
			String token = rawtokens.get(row)[column];
			if (token.length() > 1)
				throw new IllegalArgumentException("Not a char");
			return token.charAt(0);
		}

		String get(int row, int column) {
			String token = rawtokens.get(row)[column];
			return token;
		}

		Integer size() {
			int total = 0;
			for (String[] row : rawtokens) {
				for (String token : row) {
					total++;
				}
			}
			return total;
		}

		Integer size(int row) {
			int total = 0;
			if (row >= rawtokens.size())
				throw new IllegalArgumentException("Row out of range");
			for (String token : rawtokens.get(row)) {
				total++;
			}
			return total;
		}

	}

	// Utility class for serializing
	class OutputTokens {

		ArrayList<ArrayList<String>> rawtokens = new ArrayList<ArrayList<String>>();

		void write(BufferedWriter writer) throws Exception {
			for (ArrayList<String> row : rawtokens) {
				boolean first = true;
				for (String token : row) {
					if (first) {
						first = false;
					} else {
						writer.write(' ');
					}
					writer.write(token);
				}
				writer.write('\n');
			}
			writer.close();
		}

		void set(int row, int column, Object value) {
			while (rawtokens.size() <= row) {
				rawtokens.add(new ArrayList<String>());
			}

			if ((rawtokens.get(row).size() > column)
					&& (rawtokens.get(row).get(column) != null))
				throw new IllegalArgumentException("Element already set");

			rawtokens.get(row).add(column, value.toString());
		}

		Integer size() {
			int total = 0;
			for (ArrayList<String> row : rawtokens) {
				for (String token : row) {
					total++;
				}
			}
			return total;
		}

		Integer size(int row) {
			int total = 0;
			if (row >= rawtokens.size())
				throw new IllegalArgumentException("Row out of range");
			for (String token : rawtokens.get(row)) {
				total++;
			}
			return total;
		}

	}

}
