/**
 * 
 */
package com.laperradaonline.codejam.tictactoe;

import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Carlos Alberto
 * 
 */
public class GameSetParser {
	private Reader reader;

	private int available = 16;

	private List<int[]> verticalResults;
	private int[] diagonalResults;

	private int[] diagonal2Results;

	private int empty;

	public GameSetParser(Reader reader) {
		this.reader = reader;
		this.available = 16;
		this.empty = 0;
		this.verticalResults = new ArrayList<int[]>();
		this.diagonalResults = new int[2];
		this.diagonal2Results = new int[2];
		for (int i = 0; i < 4; i++) {
			this.verticalResults.add(new int[2]);
		
		}

	}

	public String parse() throws IOException {
		String result = "Game has not completed";
		int i = 0;
		try {
			for (i = 0; i < 4; i++) {
				int[] lineResult = calculateLineResult(i);
				result = checkWinner(lineResult);
				
				if (result != null) {
					skipToEnd(i);
					return result;
				}
			
			}
		} catch (PrematureEnding ex) {
			skipToEnd(i);
			return "Game has not completed";
		}

		result = checkForWinner(this.verticalResults);

		if (result != null) {
			return result;
		}

		result = checkWinner(this.diagonalResults);

		if (result != null) {
			return result;
		}

		result = checkWinner(this.diagonal2Results);

		if (result != null) {
			return result;
		}
		
		if (this.empty == 0){
			return "Draw";
		}

		return "Game has not completed";
	}

	private String checkForWinner(List<int[]> theResults) {

		for (int[] lineResult : theResults) {

			String result = checkWinner(lineResult);
			if (result != null) {
				return result;
			}
		}
		return null;
	}

	private void skipToEnd(int i) throws IOException {
		reader.skip(this.available + (3 - i)  );

	}

	private String checkWinner(int[] lineResult) {
		if (lineResult[0] == 4) {
			return "O won";
		}

		if (lineResult[1] == 4) {
			return "X won";
		}
		return null;
	}

	private int[] calculateLineResult(int row) throws IOException,
			PrematureEnding {
		int lineResult[] = new int[2];
		int c;
		
		while (Character.isWhitespace(c = reader.read()));
		for (int column = 0; column < 4 && !Character.isWhitespace(c ) && c>-1; column++) {
			System.out.print(String.format("%c",c));
			this.available--;
			switch (c) {
			case 'O':
				lineResult[0]++;
				this.verticalResults.get(column)[0]++;
				addDiagonal(row, column,  1, 0);
				break;
			case 'X':
				lineResult[1]++;
				this.verticalResults.get(column)[1]++;
				addDiagonal(row, column,  0, 1);
				break;
			case 'T':
				lineResult[0]++;
				lineResult[1]++;
				this.verticalResults.get(column)[0]++;
				this.verticalResults.get(column)[1]++;
				addDiagonal(row, column,  1, 1);
				break;
			case '.':
				this.empty++;
				if (this.empty== 10) {
					throw new PrematureEnding();
				}
				break;
			}
			
			c = reader.read();
		}
		System.out.println();
		return lineResult;
	}

	private void addDiagonal( int row,int column,  int oRes, int xRes) {
		if (column == row) {
			this.diagonalResults[0] += oRes;
			this.diagonalResults[1] += xRes;
		} else {
			int iCol = Math.abs(column - 3);
			if (row == iCol) {
				this.diagonal2Results[0] += oRes;
				this.diagonal2Results[1] += xRes;
			}
		}

	}
}
