import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Reader;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 
 */

/**
 * @author Carlos
 *
 */
class Solver {
	

	private class DigitRepresentation {
		private List<String> str;
		
		private int digit;

		/**
		 * @return the digit
		 */
		public int getDigit() {
			return digit;
		}

		@Override
		public String toString() {
			return String.valueOf(this.getDigit());
		}
		
		public DigitRepresentation(int digit, String str) {
			this.str = new LinkedList<String>();
			
			int length = str.length();
			
			for (int index = 0; index < length; index++) {
				this.str.add( String.valueOf( str.charAt(index)));
			}
			
			this.digit = digit;
		}


		public String removeFrom(String theString2) {
			StringBuilder sb = new StringBuilder(theString2);
			
			for (String theChar : this.str) {
				int index = sb.indexOf(theChar);
				if (index < 0) {
					return null;
				}
				
				sb.deleteCharAt(index);
			}
			
			
			return sb.toString();
		}
	};

	private int testCase;


	private List<DigitRepresentation> digitRepresentations;


	private String theString;
	

	/**
	 * @return the testCase
	 */
	public int getTestCase() {
		return testCase;
	}

	public Solver(BufferedReader bReader, int testCase) {
		
		this.testCase = testCase;
		
		try {
			this.theString = bReader.readLine();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	
		digitRepresentations = new LinkedList<Solver.DigitRepresentation>();
		
		digitRepresentations.add(new DigitRepresentation(0, "ZREO"));
		digitRepresentations.add(new DigitRepresentation(1, "NOE"));
		digitRepresentations.add(new DigitRepresentation(2, "WTO"));
		digitRepresentations.add(new DigitRepresentation(3, "HTREE"));
		digitRepresentations.add(new DigitRepresentation(4, "FROU"));
		digitRepresentations.add(new DigitRepresentation(5, "VFIE"));
		digitRepresentations.add(new DigitRepresentation(6, "XSI"));
		digitRepresentations.add(new DigitRepresentation(7, "VSNEE"));
		digitRepresentations.add(new DigitRepresentation(8, "GHTEI"));
		digitRepresentations.add(new DigitRepresentation(9, "NNIE"));		
	}

	public String getAnswer() {
		
		List<DigitRepresentation> available = new LinkedList<Solver.DigitRepresentation>(this.digitRepresentations);
				
		return getPhoneNumber(available, this.theString).toString();
	}

	private StringBuilder getPhoneNumber(List<DigitRepresentation> available,
			String theString2) {
		

		
		if (theString2.length() ==0) {
				return new StringBuilder();
		} else {
			int avaSize = available.size();
			for (int index = 0; index < avaSize; index++ ) {
				DigitRepresentation current = available.get(index);
				
				String remaining = current.removeFrom (theString2);
				
				if ( remaining != null) {
					List<DigitRepresentation> tmpAvailable = new LinkedList<Solver.DigitRepresentation>();
					
					for (int index2 = index; index2 < avaSize; index2++ ) {
						tmpAvailable.add(available.get(index2));
					}
					
					StringBuilder sb =this.getPhoneNumber(tmpAvailable, remaining);
					
					if (sb != null) {
						sb.insert(0, current.getDigit());
						return sb;
					}
					
					
				}
			}
		}

		
		return null;
	}


	

	
	




}


public class Main {

	private File inputFile;
    private File outputFile;
    public Main(String filename) {
        this.inputFile = new File(filename);

        int lastIndex = filename.lastIndexOf('.');

        this.outputFile = new File (filename.substring(0, lastIndex)+".out");
    }

    private void run() {
        FileReader reader = null;
        BufferedReader bReader = null;
        FileWriter writer = null;
        try
        {
            writer = new FileWriter(outputFile);
            reader = new FileReader(inputFile);
            bReader = new BufferedReader(reader);
            String line;
            if (( line = bReader.readLine())!=null) {


                int resting = Integer.parseInt(line);

                for (int index = 1;  index <= resting; index++ ) {
                    Solver solver = new Solver(bReader,index);
                    String outStr = String.format("Case #%d: %s\r\n", solver.getTestCase() ,solver.getAnswer());
                    writer.write(outStr);
                    System.out.print(outStr);
                }


            }

        } catch (Exception ex){
            ex.printStackTrace();
        } finally {

            if (writer != null){
                try {
                    writer.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

            safeCloseReader(bReader);
            safeCloseReader(reader);
        }

    }


    private void safeCloseReader( Reader reader) {
        if (reader != null){
            try {
                reader.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }
    /**
     * @param args
     */
    public static void main(String[] args) {

        Main main = new Main(args[0]);
        main.run();
    }

}
