/**
 * 
 */
package jamcoin;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Reader;
import java.math.BigInteger;
import java.util.LinkedList;
import java.util.List;

/**
 * @author Carlos
 *
 */

class Solver {

	private int length;
	private int maxCount;

	private static List<BigInteger> primes;

	public static void loadPrimes() {
		primes = new LinkedList<BigInteger>();

		File primesFile = new File("primes.txt");

		FileReader reader = null;
		BufferedReader bReader = null;

		try {
			reader = new FileReader(primesFile);
			bReader = new BufferedReader(reader);
			String line;
			while ((line = bReader.readLine()) != null) {
				if (line.isEmpty()) {
					break;
				}

				primes.add(new BigInteger(line));
			}

		} catch (Exception ex) {
			ex.printStackTrace();
		} finally {

			if (bReader != null) {
				try {
					bReader.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
			if (reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}

		}

	}

	private BigInteger[] divisors;

	public Solver(BufferedReader bReader) {
		try {
			String[] tokens = bReader.readLine().split(" ");

			this.length = Integer.parseInt(tokens[0]);
			this.maxCount = Integer.parseInt(tokens[1]);

			this.divisors = new BigInteger[9];

		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	public String getAnswer() {

		StringBuffer buff = new StringBuffer();

		if (this.length >= 2) {

			long top = (long) Math.pow(2, this.length - 1);

			long dynamicPart = (long) Math.pow(2, this.length - 2) - 1;
			
			long validCoins = 0;

			for (long i = 0; i <= dynamicPart; i++) {

				long coinInt = top + (i << 1) + 1;

				String candidate = Long.toBinaryString(coinInt);

				if (checkDivisors(candidate)) {

					buff.append("\r\n");
					buff.append(candidate);
					buff.append(String.format(" %d %d %d %d %d %d %d %d %d", this.divisors));

					validCoins++;
					if (validCoins >= this.maxCount) {
						break;
					}
					
					

				}
			}
		}

		return buff.toString();
	}

	private boolean checkDivisors(String candidate) {

		for (int i = 0; i < this.divisors.length; i++) {
			BigInteger number = new BigInteger(candidate, (i + 2));
			BigInteger divisor = findDivisor(number);
			if (divisor == BigInteger.ZERO) {
				return false;
			}
			this.divisors[i] = divisor;
		}

		return true;
	}

	private BigInteger findDivisor(BigInteger number) {

		long top = Solver.primes.size() - 1;

		for (int i = 0; i < top; i++) {
			BigInteger testDivisor = Solver.primes.get(i);
			if (testDivisor.compareTo(number) >= 0) {
				break;
			}

			if (number.mod(testDivisor) == BigInteger.ZERO) {
				return testDivisor;
			}

		}

		return BigInteger.ZERO;
	}

}

public class Main {

	private File inputFile;
	private File outputFile;

	public Main(String filename) {
		this.inputFile = new File(filename);

		int lastIndex = filename.lastIndexOf('.');

		this.outputFile = new File(filename.substring(0, lastIndex) + ".out");
	}

	private void run() {
		FileReader reader = null;
		BufferedReader bReader = null;
		FileWriter writer = null;
		try {
			writer = new FileWriter(outputFile);
			reader = new FileReader(inputFile);
			bReader = new BufferedReader(reader);
			String line;
			if ((line = bReader.readLine()) != null) {

				int resting = Integer.parseInt(line);

				for (int index = 1; index <= resting; index++) {
					Solver solver = new Solver(bReader);
					String outStr = String.format("Case #%d: %s\r\n", index, solver.getAnswer());
					writer.write(outStr);
					System.out.print(outStr);
				}

			}

		} catch (Exception ex) {
			ex.printStackTrace();
		} finally {

			if (writer != null) {
				try {
					writer.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}

			safeCloseReader(bReader);
			safeCloseReader(reader);
		}

	}

	private void safeCloseReader(Reader reader) {
		if (reader != null) {
			try {
				reader.close();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}

	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {

		Main main = new Main(args[0]);

		Solver.loadPrimes();

		main.run();
	}

}
