import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Scanner;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

class AlienDictionary
{
	int L, D, N;
	ArrayList<String> dictionary;
	public AlienDictionary(int L, int D, int N) 
	{
		this.L=L;
		this.D=D;
		this.N=N;
		dictionary=new ArrayList<String>();
	}
	public void addToDirectory(String word)
	{
		dictionary.add(word);
	}
	public boolean isdictionaryFull()
	{
		return dictionary.size()==D;
	}
	public int getMatchCount(String test)
	{
		int count=0;
		Pattern pattern=Pattern.compile(test);
		Matcher matcher;
		for(String word:dictionary)
		{
			matcher=pattern.matcher(word);
			if(matcher!=null &&matcher.matches())
			{
				count++;
			}
		}
		return count;
	}

}
class AlienFileParser
{
	AlienDictionary dictionary;
	ArrayList<String> cases;
	void createDictionary(String header)
	{
		String dim[]=header.split(" ");
		int L=Integer.parseInt(dim[0]);
		int D=Integer.parseInt(dim[1]);
		int N=Integer.parseInt(dim[2]);
		dictionary=new AlienDictionary(L, D, N);
	}
	public AlienFileParser(String file) throws FileNotFoundException 
	{
		Scanner in=new Scanner(new File(file));
		String header=in.nextLine();
		String word;
		createDictionary(header);
		while(in.hasNextLine() &&!dictionary.isdictionaryFull())
		{
			dictionary.addToDirectory(in.nextLine());
		}
		cases=new ArrayList<String>();
		while(in.hasNextLine())
		{
			word=in.nextLine();
			word=word.replace('(', '[');
			word=word.replace(')',']');
			cases.add("^"+word+"$");
		}
	}
	public AlienDictionary getDictionary() {
		return dictionary;
	}
	public void setDictionary(AlienDictionary dictionary) {
		this.dictionary = dictionary;
	}
	public ArrayList<String> getCases() {
		return cases;
	}
	public void setCases(ArrayList<String> cases) {
		this.cases = cases;
	}
	
}
class AlienFileWriter{
	PrintWriter out;
	public AlienFileWriter(String file) throws FileNotFoundException
	{
		out=new PrintWriter(file.split("\\.")[0]+".out");
	}
	void write(int caseId,int count)
	{
		out.println("Case #"+caseId+": "+count);
	}
	void close()
	{
		out.close();
	}
}
public class AlienLanguageDecoder {

	public static void main(String args[])
	{
		try{
			if(args.length!=1)
			{
				System.out.print("Usage: AlienLanguageDecoder <filename>");
			}
			AlienFileParser parser=new AlienFileParser(args[0]);
			AlienDictionary dictionary=parser.getDictionary();
			ArrayList<String> cases=parser.getCases();
			AlienFileWriter writer=new AlienFileWriter(args[0]);
			int i=1;
			for(String word:cases)
			{
				writer.write(i,dictionary.getMatchCount(word));
				i++;
			}
			writer.close();
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
		
	}
	
}
