import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Scanner;
class NameGenerator
{
	private char c;
	public NameGenerator()
	{
		c='a';
	}
	public char getNextName()
	{
		return c++;
	}
	
}
class Basin
{
	private char names[][];
	private int rows;
	private int cols;
	public Basin(int rows, int cols)
	{
		this.rows=rows;
		this.cols=cols;
		this.names=new char[rows][cols];
	}
	public void set(int row, int col, char value) {
		names[row][col]=value;
	}
	public char get(int row, int col)
	{
		return names[row][col];
	}
	public String toString()
	{
		StringBuffer output=new StringBuffer();
		for(int row=0;row<rows;row++)
		{
			for(int col=0;col<cols;col++)
			{
				output.append(names[row][col]);
				if(col<cols-1)
					output.append(" ");
			}
			if(row<rows-1)
				output.append("\n");
		}
		return output.toString();
	}
}
class GeoMap
{
	private int altitude[][];
	private int rows;
	private int cols;
	private NameGenerator nameGenerator;
	public GeoMap(int rows, int cols)
	{
		this.rows=rows;
		this.cols=cols;
		altitude=new int[rows][cols];
	}
	public void set(int row, int col, int value) {
		altitude[row][col]=value;
	}
	public int get(int row, int col)
	{
		return altitude[row][col];
	}
	public Basin generateBasin()
	{
		Basin basin=new Basin(rows, cols);
		nameGenerator=new NameGenerator();
		for(int row=0;row<rows;row++)
		{
			for(int col=0;col<cols;col++)
			{
				markSink(basin, row, col);
			}
		}		
		return basin;
	}
	private char markSink(Basin basin, int row, int col)
	{
		char color=basin.get(row, col);
		
		if(color!=0)
			return color;
		int minRow=row;
		int minCol=col;
		
		if(row>0 && altitude[minRow][minCol]>altitude[row-1][col]) //move north
		{
			minRow=row-1;
			minCol=col;
		}
		if(col>0 && altitude[minRow][minCol]>altitude[row][col-1]) //move west 
		{
			minRow=row;
			minCol=col-1;
		}
		if(col<cols-1 &&altitude[minRow][minCol]>altitude[row][col+1]) //move east
		{
			minRow=row;
			minCol=col+1;
		}
		if(row<rows-1 && altitude[minRow][minCol]>altitude[row+1][col]) //move south
		{
			minRow=row+1;
			minCol=col;
		}
		if(minRow==row && minCol==col) // sink
		{
			color=nameGenerator.getNextName();
		}
		else //non sink
		{
			color=markSink(basin, minRow, minCol);
		}
		basin.set(row,col,color);
		return color;
		
	}
	public String toString()
	{
		StringBuffer output=new StringBuffer();
		for(int row=0;row<rows;row++)
		{
			for(int col=0;col<cols;col++)
			{
				output.append(altitude[row][col]);
				if(col<cols-1)
					output.append(" ");
			}
			if(row<rows-1)
				output.append("\n");
		}
		return output.toString();
	}
	
}
class MapFileParser
{
	private ArrayList<GeoMap> maps;
	public MapFileParser(String fileName) throws FileNotFoundException
	{
		Scanner in=new Scanner(new File(fileName));
		int num=Integer.parseInt(in.nextLine());
		int rows;
		int cols;
		String line;
		String components[];
		maps=new ArrayList<GeoMap>();
		for(int i=0;i<num;i++)
		{
			line=in.nextLine();
			components=line.split(" ");
			rows=Integer.parseInt(components[0]);
			cols=Integer.parseInt(components[1]);
			GeoMap map=new GeoMap(rows, cols);
			for(int row=0;row<rows;row++)
			{
				line=in.nextLine();
				components=line.split(" ");
				for(int col=0;col<cols;col++)
				{
					int value=Integer.parseInt(components[col]);
					map.set(row,col, value);
				}
			}
			maps.add(map);
		}
	}
	public ArrayList<GeoMap> getMaps() {
		return maps;
	}
}
class BasinWriter
{

	private PrintWriter out;
	public BasinWriter(String file) throws FileNotFoundException
	{
		out=new PrintWriter(file.split("\\.")[0]+".out");
	}
	void write(int caseId,Basin basin)
	{
		out.println("Case #"+caseId+":\n"+basin);
		System.out.println("Case #"+caseId+":\n"+basin);
	}
	void close()
	{
		out.close();
	}
	
}
public class BasinLocator {
	public static void main(String args[])
	{
		try{
			if(args.length!=1)
			{
				System.out.print("Usage: BasinLocator <filename>");
			}
			MapFileParser parser=new MapFileParser(args[0]);
			BasinWriter writer=new BasinWriter(args[0]);
			ArrayList<GeoMap> mapList=parser.getMaps();
			int caseId=1;
			for(GeoMap map:mapList)
			{
				Basin basin=map.generateBasin();
				writer.write(caseId, basin);
				caseId++;
			}
			writer.close();
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}

}

