package com.google.codejam.amyth;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.BreakIterator;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class Magika {
	private final static String DIR_NM = "./magika/";
	private final static String EOL = "$";
	private final static String ALL_CHAR="[A-Z]*";
	private static Integer totalTestCase;
	private static List<Magik> dataList;

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		String fileName = args[0];

		try {
			readAndBuild(DIR_NM + fileName);
		}

		catch (IOException e) {
			e.printStackTrace();

		}
		
		try{
		    // Create file 
		    FileWriter fstream = new FileWriter(DIR_NM+args[0]+".out");
	        BufferedWriter out = new BufferedWriter(fstream);
	        for (int caseId = 1; caseId <= totalTestCase; caseId++) {
			String output = startMagika(caseId);
			System.out.print("Case #" + caseId + ": ");
			System.out.println(output);
			out.write("Case #" + caseId + ": ");
			out.write(output);
			if(caseId != totalTestCase)
				out.newLine();
			}
//	      Close the output stream
	        out.close();
	    }catch (Exception e){//Catch exception if any
	      System.err.println("Error: " + e.getMessage());
	    }
		
	}
	
	private static String startMagika(int caseId) {
		Magik magikObj = dataList.get(caseId-1);
		char[] dataChar = magikObj.getDataChars();
		StringBuilder sb = new StringBuilder();
		sb.append(dataChar[0]);
		boolean done = false;
			for(int j=1;j<magikObj.getCharlength();j++)
			{	sb.append(dataChar[j]);
				if(magikObj.getCombinelength() >0){
					for (MagikPattern p : magikObj.getCombineLogicList()) {
						sb = p.matchAndReplace(sb.toString(),false);
					}
				}
				
				if(magikObj.getOpposelength() > 0){
					for (MagikPattern p : magikObj.getOpposeLogicList()) {
						sb = p.matchAndReplace(sb.toString(),true);
					}
				}
				
			}
		StringBuilder sb1 = new StringBuilder();
		for(int k=0;k<sb.length();k++){
			sb1.append(sb.charAt(k));
			if(k < sb.length()-1)
				sb1.append(", ");
		}
		sb1.insert(0, '[');sb1.insert(sb1.length(), ']');
		return sb1.toString();
	}

	private static void readAndBuild(String dataPath) throws IOException {
		File f = new File(dataPath);
		BufferedReader bf = new BufferedReader(new FileReader(f));
		String text = bf.readLine();

		if (text != null) {
//			first text will be number of test cases
			totalTestCase = Integer.valueOf(text);
			dataList = new ArrayList<Magik>(totalTestCase);
			Magik testObj = null;
			MagikPattern mp = null;
			do {
				text = bf.readLine();
				testObj = new Magik();
				dataList.add(testObj);
				if (text != null) {
					BreakIterator bi = BreakIterator.getWordInstance();
					bi.setText(text);
					int combineCount = Integer.valueOf(text.substring(0, bi.next()));
					if(combineCount != 0){
						List combineLogicList = new ArrayList<MagikPattern>(combineCount*2);
						testObj.setCombineLogicList(combineLogicList);
						for (int i=0;i<combineCount;i++){
							String combineRule = String.valueOf(text.substring(bi.next(), bi.next()));
							String regEx = combineRule.substring(0, 2)+EOL;
							mp = new MagikPattern(); mp.setPttrn(Pattern.compile(regEx));mp.setReplaceString(combineRule.substring(2));
							combineLogicList.add(mp);
							regEx = combineRule.charAt(1)+""+combineRule.charAt(0)+EOL;
							mp = new MagikPattern(); mp.setPttrn(Pattern.compile(regEx));mp.setReplaceString(combineRule.substring(2));
							combineLogicList.add(mp);
						}
					}
					
					int opposeCount = Integer.valueOf(text.substring(bi.next(), bi.next()));
					if(opposeCount !=0){
						List opposeLogicList = new ArrayList<MagikPattern>(opposeCount*2);
						testObj.setOpposeLogicList(opposeLogicList);
						for(int i=0;i<opposeCount;i++){
							String opposeRule = String.valueOf(text.substring(bi.next(), bi.next()));
							String regEx = opposeRule.charAt(0)+ALL_CHAR+opposeRule.charAt(1);
							mp = new MagikPattern(); mp.setPttrn(Pattern.compile(regEx));mp.setReplaceString("");
							opposeLogicList.add(mp);
							regEx = opposeRule.charAt(1)+ALL_CHAR+opposeRule.charAt(0);
							mp = new MagikPattern(); mp.setPttrn(Pattern.compile(regEx));mp.setReplaceString("");
							opposeLogicList.add(mp);
						}
					}
					int charCount = Integer.valueOf(text.substring(bi.next(), bi.next()));
					String dataChar = String.valueOf(text.substring(bi.next(), bi.next()));
					testObj.setDataChars(dataChar.toCharArray());
					testObj.setCharlength(charCount);
					testObj.setCombinelength(combineCount*2);
					testObj.setOpposelength(opposeCount*2);

				}
			}while (text != null && !text.equals(""));
			}
		}


}

class MagikPattern{
	private Pattern pttrn;
	private String replaceString;
	public StringBuilder matchAndReplace(String str,boolean isOppose){
		Matcher m = pttrn.matcher(str);
		while(m.find()){
			
			if(isOppose){
				str = "";
				break;
			}
			str = m.replaceAll(replaceString);
		}
			
		return new StringBuilder(str);
	}
	public Pattern getPttrn() {
		return pttrn;
	}
	public void setPttrn(Pattern pttrn) {
		this.pttrn = pttrn;
	}
	public String getReplaceString() {
		return replaceString;
	}
	public void setReplaceString(String replaceString) {
		this.replaceString = replaceString;
	}
	
}

class Magik{
	private char[] dataChars;
	private List<MagikPattern> combineLogicList;
	private List<MagikPattern> opposeLogicList;
	private Integer combinelength,opposelength,charlength;
	public Integer getCharlength() {
		return charlength;
	}
	public void setCharlength(Integer charlength) {
		this.charlength = charlength;
	}
	public Integer getCombinelength() {
		return combinelength;
	}
	public void setCombinelength(Integer combinelength) {
		this.combinelength = combinelength;
	}
	public List<MagikPattern> getCombineLogicList() {
		return combineLogicList;
	}
	public void setCombineLogicList(List<MagikPattern> combineLogicList) {
		this.combineLogicList = combineLogicList;
	}
	public char[] getDataChars() {
		return dataChars;
	}
	public void setDataChars(char[] dataChars) {
		this.dataChars = dataChars;
	}
	public Integer getOpposelength() {
		return opposelength;
	}
	public void setOpposelength(Integer opposelength) {
		this.opposelength = opposelength;
	}
	public List<MagikPattern> getOpposeLogicList() {
		return opposeLogicList;
	}
	public void setOpposeLogicList(List<MagikPattern> opposeLogicList) {
		this.opposeLogicList = opposeLogicList;
	}
	
}
