import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class MagicTrick {
	private List<Input> inputs = new ArrayList<Input>();

	public MagicTrick( String file ) {
		init( file );
	}

	public void runTricks() {
		int caseNum = 1;

		for ( Input input : inputs ) {
			haveWeMagic( caseNum++, input );
		}
	}

	public void haveWeMagic( int caseNum, Input input ) {
		Set<Integer> firstPicks = new HashSet<Integer>();

		for ( int c = 0; c < 4; ++c ) {
			firstPicks.add( input.firstGrid[input.firstPick - 1][c] );
		}

		Set<Integer> pos = new HashSet<Integer>();
		for ( int c = 0; c < 4; ++c ) {
			int cur = input.secondGrid[input.secondPick - 1][c];

			if ( firstPicks.contains( cur ) ) {
				pos.add( cur );
			}
		}

		abracadabra( caseNum, new ArrayList<Integer>( pos ) );
	}

	private void abracadabra( int caseNum, List<Integer> pos ) {
		System.out.print( "Case #" + caseNum + ": " );

		if ( pos.size() == 1 ) {
			System.out.println( pos.get( 0 ) );
		} else if ( pos.isEmpty() ) {
			System.out.println( "Volunteer cheated!" );
		} else {
			System.out.println( "Bad magician!" );
		}
	}

	private void init( String file ) {
		try {
			BufferedReader reader = new BufferedReader( new FileReader( file ) );
			int numInputs = Integer.parseInt( reader.readLine().trim() );

			for ( int i = 0; i < numInputs; ++i ) {
				int firstPick = Integer.parseInt( reader.readLine().trim() );
				int[][] firstGrid = grid( reader );
				int secondPick = Integer.parseInt( reader.readLine().trim() );
				int[][] secondGrid = grid( reader );

				inputs.add( new Input( firstPick, secondPick, firstGrid, secondGrid ) );
			}

			reader.close();
		} catch ( IOException ioe ) {
			ioe.printStackTrace();
		}
	}

	private int[][] grid( BufferedReader reader ) throws IOException {
		int[][] grid = new int[ 4 ][];

		for ( int r = 0; r < 4; ++r ) {
			String[] cards = reader.readLine().split( " " );
			int[] row = new int[ 4 ];

			for ( int c = 0; c < 4; ++c ) {
				row[c] = Integer.parseInt( cards[c] );
			}

			grid[r] = row;
		}

		return grid;
	}

	private static class Input {
		private int firstPick;
		private int secondPick;
		private int[][] firstGrid;
		private int[][] secondGrid;

		public Input( int firstPick, int secondPick, int[][] firstGrid, int[][] secondGrid ) {
			this.firstPick = firstPick;
			this.secondPick = secondPick;
			this.firstGrid = firstGrid;
			this.secondGrid = secondGrid;
		}

	}

	public static void main( String[] args ) {
		new MagicTrick( args[0] ).runTricks();
	}
}
