package com.kempf.codejam.round1.D;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Arrays;
import java.util.StringTokenizer;

class D {
	private StringBuilder buffer = new StringBuilder( 16384 );
	private Model[][] backtrack;
	private int N;
	private ConstraintManager conMan;
	private int bestScore;
	private Model[][] bestSolution;
	private int sols;
	private int limit;

	void solve() throws IOException {
		InputReader reader = new InputReader( System.in );
		int T = reader.nextInt();
		long start = System.currentTimeMillis();

		for ( int t = 0; t < T; ++t ) {
			buffer.append( "Case #" ).append( t + 1 ).append( ": " );

			N = reader.nextInt();
			int placed = reader.nextInt();

			sols = 0;
			limit = 4 * N * N * N;
			conMan = new ConstraintManager( N );
			Model[][] originalRunway = runway( N );
			bestSolution = originalRunway;

			for ( int p = 0; p < placed; ++p ) {
				Model model = Model.parse( reader.next().charAt( 0 ) );
				int r = reader.nextInt() - 1;
				int c = reader.nextInt() - 1;
				originalRunway[r][c] = model;
				conMan.placeModel( r, c, model );
			}

			bestScore = conMan.score();
			backtrack = copy( originalRunway );
			backtrack( 0, 0 );
			output( originalRunway );
		}

		System.out.print( buffer );
		System.out.println( System.currentTimeMillis() - start );
	}

	private void output( Model[][] originalRunway ) {
		buffer.append( bestScore ).append( ' ' ).append( changes( originalRunway ) ).append( '\n' );

		for ( int r = 0; r < N; ++r ) {
			for ( int c = 0; c < N; ++c ) {
				if ( originalRunway[r][c] != bestSolution[r][c] ) {
					buffer.append( bestSolution[r][c].token ).append( ' ' ).append( r + 1 ).append( ' ' ).append( c + 1 ).append( '\n' );
				}
			}
		}
	}

	private int changes( Model[][] originalRunway ) {
		int cs = 0;

		for ( int r = 0; r < N; ++r ) {
			for ( int c = 0; c < N; ++c ) {
				if ( originalRunway[r][c] != bestSolution[r][c] ) {
					++cs;
				}
			}
		}

		return cs;
	}

	private void backtrack( int r, int c ) {
		if ( sols > limit ) {
			return;
		} else if ( r == N ) {
			int score = conMan.score();
			++sols;

			if ( score > bestScore ) {
				bestScore = score;
				bestSolution = copy( backtrack );
			}
		} else if ( c == N ) {
			backtrack( r + 1, 0 );
		} else {
			if ( backtrack[r][c] == Model.Twiggy ) {
				for ( Model model : Model.placeable() ) {
					if ( model == Model.Twiggy ) {
						backtrack( r, c + 1 );
					} else if ( conMan.satisfies( r, c, model ) ) {
						backtrack[r][c] = model;
						conMan.placeModel( r, c, model );
						backtrack( r, c + 1 );
						conMan.removeModel( r, c, model );
						backtrack[r][c] = Model.Twiggy;
					}
				}
			} else if ( backtrack[r][c] != Model.O ) {
				Model original = backtrack[r][c];
				conMan.removeModel( r, c, original );

				if ( conMan.satisfies( r, c, Model.O ) ) {
					conMan.placeModel( r, c, Model.O );
					backtrack[r][c] = Model.O;
					backtrack( r, c + 1 );
					conMan.removeModel( r, c, Model.O );
				}

				conMan.placeModel( r, c, original );
				backtrack[r][c] = original;
				backtrack( r, c + 1 );
			} else {
				backtrack( r, c + 1 );
			}
		}

	}

	private Model[][] copy( Model[][] src ) {
		Model[][] copy = new Model[ src.length ][ src.length ];

		for ( int r = 0; r < copy.length; ++r ) {
			System.arraycopy( src[r], 0, copy[r], 0, copy.length );
		}

		return copy;
	}

	private Model[][] runway( int N ) {
		Model[][] runway = new Model[ N ][ N ];

		for ( int r = 0; r < N; ++r ) {
			Arrays.fill( runway[r], Model.Twiggy );
		}

		return runway;
	}

	protected static class ConstraintManager {
		private Constraint[][][] cs;

		public ConstraintManager( int N ) {
			init( N );
		}

		public int score() {
			int score = 0;

			for ( int r = 0; r < cs.length; ++r ) {
				score += cs[r][0][0].score();
			}

			return score;
		}

		public boolean satisfies( int r, int c, Model model ) {
			for ( int i = 0; i < 4; ++i ) {
				if ( !cs[r][c][i].satisfies( model ) ) {
					return false;
				}
			}

			return true;
		}

		public void removeModel( int r, int c, Model model ) {
			for ( int i = 0; i < 4; ++i ) {
				cs[r][c][i].removeModel( model );
			}
		}

		public void placeModel( int r, int c, Model model ) {
			for ( int i = 0; i < 4; ++i ) {
				cs[r][c][i].placeModel( model );
			}
		}

		/**
		 * UGLY!
		 * Would clean this up in production code
		 * @param N
		 */
		private void init( int N ) {
			cs = new Constraint[ N ][ N ][ 4 ];

			for ( int r = 0; r < N; ++r ) {
				Constraint rowConstraint = new Constraint( false );

				for ( int c = 0; c < N; ++c ) {
					cs[r][c][0] = rowConstraint;
				}
			}

			for ( int c = 0; c < N; ++c ) {
				Constraint colConstraint = new Constraint( false );

				for ( int r = 0; r < N; ++r ) {
					cs[r][c][1] = colConstraint;
				}
			}

			for ( int r = 0; r < N; ++r ) {
				Constraint diagr = new Constraint( true );
				int c = 0;

				for ( int del = 0;; ++del ) {
					int nr = r + del;
					int nc = c + del;

					if ( nr == N || nc == N ) {
						break;
					}
					cs[nr][nc][2] = diagr;
				}
			}

			for ( int c = 1; c < N; ++c ) {
				Constraint diag = new Constraint( true );
				int r = 0;

				for ( int del = 0;; ++del ) {
					int nr = r + del;
					int nc = c + del;

					if ( nr == N || nc == N ) {
						break;
					}
					cs[nr][nc][2] = diag;
				}
			}

			for ( int r = N - 1; r >= 0; --r ) {
				int c = 0;
				Constraint diag = new Constraint( true );

				for ( int del = 0;; --del ) {
					int nr = r + del;
					int nc = c - del;

					if ( nr < 0 || nc == N ) {
						break;
					}
					cs[nr][nc][3] = diag;
				}
			}

			for ( int c = 1; c < N; ++c ) {
				int r = N - 1;
				Constraint diag = new Constraint( true );

				for ( int del = 0;; --del ) {
					int nr = r + del;
					int nc = c - del;

					if ( nc == N ) {
						break;
					}
					cs[nr][nc][3] = diag;
				}
			}
		}
	}

	protected static class Constraint {
		private boolean isDiagonal;
		private int[] cts = new int[ 3 ];

		public Constraint( boolean isDiagonal ) {
			this.isDiagonal = isDiagonal;
		}

		public boolean isDiagonal() {
			return isDiagonal;
		}

		public int score() {
			return cts[Model.O.ordinal()] * 2 + cts[Model.X.ordinal()] + cts[Model.P.ordinal()];
		}

		public boolean satisfies( Model model ) {
			if ( isDiagonal ) {
				if ( model == Model.X || cts[1] + cts[2] == 0 ) {
					return true;
				} else {
					return cts[Model.X.ordinal()] > 0 && cts[Model.O.ordinal()] + cts[Model.P.ordinal()] == 0;
				}
			} else {
				if ( model == Model.P || cts[0] + cts[1] == 0 ) {
					return true;
				} else {
					return cts[Model.P.ordinal()] > 0 && cts[Model.O.ordinal()] + cts[Model.X.ordinal()] == 0;
				}
			}
		}

		public void placeModel( Model model ) {
			++cts[model.ordinal()];
		}

		public void removeModel( Model model ) {
			--cts[model.ordinal()];
		}
	}

	protected static enum Model {
		X( 1, 'x' ), O( 2, 'o' ), P( 1, '+' ), Twiggy( 0, '.' );

		public static Model[] placeable() {
			return placeable;
		}

		public static Model parse( char c ) {
			switch ( c ) {
				case 'x' :
					return X;
				case 'o' :
					return O;
				case '+' :
					return P;
				default:
					return Twiggy;
			}
		}

		private int score;
		private char token;

		private Model( int score, char token ) {
			this.score = score;
			this.token = token;
		}

		private static final Model[] placeable = new Model[] { Model.O, Model.X, Model.P, Model.Twiggy };
	}

	static class InputReader {
		private BufferedReader reader;
		private StringTokenizer tokenizer;

		public InputReader( InputStream stream ) {
			reader = new BufferedReader( new InputStreamReader( stream ) );
			tokenizer = null;
		}

		public String readln() throws IOException {
			return reader.readLine();
		}

		public String next() {
			while ( tokenizer == null || !tokenizer.hasMoreTokens() ) {
				try {
					tokenizer = new StringTokenizer( reader.readLine() );
				} catch ( Throwable e ) {
					return null;
				}
			}

			return tokenizer.nextToken();
		}

		public double nextDouble() {
			String next = next();

			if ( next == null ) {
				return -1;
			}

			return Double.parseDouble( next );
		}

		public long nextLong() {
			String next = next();

			if ( next == null ) {
				return -1;
			}

			return Long.parseLong( next );
		}

		public int nextInt() {
			String next = next();

			if ( next == null ) {
				return -1;
			}

			return Integer.parseInt( next );
		}
	}

	public static void main( String args[] ) throws IOException {
		new D().solve();
	}

}
