import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;

public class CookieClickerAlpha {
	private List<Input> inputs = new ArrayList<Input>();

	public CookieClickerAlpha( String file ) {
		init( file );
	}

	public void getCookies() {
		int caseNum = 1;

		for ( Input input : inputs ) {
			farmCookies( caseNum++, input );
		}
	}

	public void farmCookies( int caseNum, Input input ) {
		double numFarms = 0.0;
		double time = 0.0;
		double cookiesPerSecond = 2.0;
		double bestCookieTime = input.desiredCookies / cookiesPerSecond;
		boolean baking = true;

		while ( baking ) {
			baking = false;
			double timeToNextFarm = input.farmCost / cookiesPerSecond;
			time += timeToNextFarm;
			numFarms += 1.0;
			cookiesPerSecond = 2.0 + input.extraCookiesPerFarm * numFarms;

			double timeAtCurrentRate = input.desiredCookies / cookiesPerSecond;
			if ( time + timeAtCurrentRate < bestCookieTime ) {
				bestCookieTime = time + timeAtCurrentRate;
				baking = true;
			}
		}

		formatQuickestCookieTime( caseNum, bestCookieTime );
	}

	private void formatQuickestCookieTime( int caseNum, double bestTime ) {
		System.out.print( "Case #" + caseNum + ": " );
		System.out.println( new DecimalFormat( "#0.0000000" ).format( bestTime ) );
	}

	private void init( String file ) {
		try {
			BufferedReader reader = new BufferedReader( new FileReader( file ) );
			int numInputs = Integer.parseInt( reader.readLine().trim() );

			for ( int i = 0; i < numInputs; ++i ) {
				String[] line = reader.readLine().trim().split( " " );
				inputs.add( new Input( Double.parseDouble( line[0] ), Double.parseDouble( line[1] ), Double.parseDouble( line[2] ) ) );
			}

			reader.close();
		} catch ( IOException ioe ) {
			ioe.printStackTrace();
		}
	}

	private static class Input {
		private double farmCost;
		private double extraCookiesPerFarm;
		private double desiredCookies;

		public Input( double farmCost, double extraCookiesPerFarm, double desiredCookies ) {
			this.farmCost = farmCost;
			this.extraCookiesPerFarm = extraCookiesPerFarm;
			this.desiredCookies = desiredCookies;
		}

	}

	public static void main( String[] args ) {
		new CookieClickerAlpha( args[0] ).getCookies();
	}

}
