package house.of.pancakes;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * Created by ana-mariamarcu on 4/9/16.
 */
public class HouseOfPancakes {
    public static void main(String[] args) throws IOException {
        new HouseOfPancakes().flip("/Users/ana-mariamarcu/Downloads/B-small-attempt4.in.txt");
    }

    private void flip(String inputFile) throws IOException {
        List<List<Integer>> values = readValuesFromInputFile(inputFile);
        List<Integer> answers = resolve(values);
        writeAnswersToFile(answers);
    }


    private List<List<Integer>> readValuesFromInputFile(String inputFile) throws IOException {
        List<String> lines = Files.readAllLines(Paths.get(inputFile));
        lines.remove(0);
        return lines.stream().map(s -> Arrays.asList(s.split("")).stream().map(s1 -> s1.equals("+") ? 1 : -1).collect(Collectors.toList())).collect(Collectors.toList());
    }

    private List<Integer> resolve(List<List<Integer>> values) {
        List<Integer> results = new ArrayList<>();
        for (List<Integer> value : values) {
            results.add(resolveOnePancakeStack(value, 0));
        }
        return results;
    }

    private Integer resolveOnePancakeStack(List<Integer> pancakeStack, Integer flips) {
        if (allFaceUp(pancakeStack)) {
            return flips;
        }
        if (allFaceDown(pancakeStack)){
            return flips+1;
        }
        if (pancakeStack.size() == 1) {
            return flips + 1;
        }
        if (lastPancakeIsFaceUp(pancakeStack)) {
            return resolveOnePancakeStack(pancakeStack.subList(0, pancakeStack.size() - 1), flips);
        }
        // for sure the last pancake is face down
        if (firstPancakeIsFaceDown(pancakeStack)) {
            if (pancakeStack.size() == 2) {
                return flips + 1;
            }
            //flip
            List<Integer> flipped = flip(pancakeStack);
            return resolveOnePancakeStack(flipped, flips + 1);
        }
        if (pancakeStack.size() == 2) {
            List<Integer> flipped = flip(pancakeStack);
            flipped.remove(flipped.size()-1);
            return resolveOnePancakeStack(flipped, flips+1);
        }
        // first pancake is face up
        // find first down pancake from top
        if (allFacedDownExceptFirst(pancakeStack)){
            List<Integer> flipped = flip(pancakeStack.subList(0, 1));
            flipped.addAll(pancakeStack.subList(1, pancakeStack.size()));
            return resolveOnePancakeStack(flipped, flips+1);
        }
        for (int index = 1; index < pancakeStack.size(); index++) {
            if (pancakeStack.get(index) < 0) {
                List<Integer> toFlip = null;
                List<Integer> rest = null;
                if (index == 1) {
                    toFlip = pancakeStack.subList(0, index + 1);
                    rest = pancakeStack.subList(index + 1, pancakeStack.size());
                } else {
                    toFlip = pancakeStack.subList(0, index);
                    rest = pancakeStack.subList(index, pancakeStack.size());
                }
                List<Integer> flipped = flip(toFlip);
                flipped.addAll(rest);
                return resolveOnePancakeStack(flipped, flips + 1);
            }
        }
        return flips;
    }

    private boolean allFaceDown(List<Integer> pancakeStack) {
        return pancakeStack.stream().filter(integer -> integer > 0).count() == 0;
    }

    private boolean allFacedDownExceptFirst(List<Integer> pancakeStack) {
        if (pancakeStack.get(0)<0){
            return false;
        }
        for (int i = 1; i < pancakeStack.size(); i++) {
            if (pancakeStack.get(i)>0){
                return false;
            }
        }
        return true;
    }

    private List<Integer> flip(List<Integer> pancakeStack) {
        Collections.reverse(pancakeStack);
        if (pancakeStack.size() == 2 && (pancakeStack.get(0) != pancakeStack.get(1))) {
            return pancakeStack;
        }

        return pancakeStack.stream().map(new Function<Integer, Integer>() {
            @Override
            public Integer apply(Integer integer) {
                return integer * (-1);
            }
        }).collect(Collectors.toList());
    }

    private boolean firstPancakeIsFaceDown(List<Integer> pancakeStack) {
        return pancakeStack.get(0) < 0;
    }

    private boolean lastPancakeIsFaceUp(List<Integer> pancakeStack) {
        return pancakeStack.get(pancakeStack.size() - 1) > 0;
    }

    private boolean allFaceUp(List<Integer> pancakeStack) {
        return pancakeStack.stream().filter(integer -> integer < 0).count() == 0;
    }

    private void writeAnswersToFile(List<Integer> answers) throws IOException {
        StringBuffer sb = new StringBuffer();
        int index = 1;
        for (Integer answer : answers) {
            sb.append("Case #").append(index).append(": ").append(answer).append("\n");
            index++;
        }
        Files.write(Paths.get("output.txt"), Arrays.asList(sb.toString()));
    }
}

