package com.coin;

import java.io.IOException;
import java.math.BigInteger;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.*;

public class Main {

    static final int BASE_RANGE = 10 - 2 + 1;

    static final int N = 16;
    static final int J = 50;

    static final BigInteger TWO = new BigInteger("2");

    private static void writeOutput(Map<String, List<BigInteger>> result) throws IOException {
        StringBuilder b = new StringBuilder();
        b.append("Case #1:\n");
        for (String s : result.keySet()) {
            b.append(s);
            b.append(' ');
            List<BigInteger> dividers = result.get(s);
            for (BigInteger d : dividers) {
                b.append(d);
                b.append(' ');
            }
            b.append('\n');
        }
        Files.write(Paths.get("./out" + new Date().getTime() + ".txt"), b.toString().getBytes());
    }
/*
    private static Map<BigInteger, Integer> factorization(BigInteger n) {
        Map<BigInteger, Integer> factorsWithPowers = new HashMap<>();
        BigInteger p = TWO;
        int k;
        while (p.longValue() < Math.sqrt(n.longValue())) {
            if (n.remainder(p).equals(BigInteger.ZERO)) {
                n = n.divide(p);
                k = 1;
                while (n.remainder(p).equals(BigInteger.ZERO)) {
                    k++;
                    n = n.divide(p);
                }
                factorsWithPowers.put(p, k);
            }
            p = p.nextProbablePrime();
        }
        return factorsWithPowers;
    }
    */
/*
    private static Set<BigInteger> permutation(Map<BigInteger, Integer> factorsWithPowers) {
        Set<BigInteger> result = new HashSet<>();
        result.addAll(factorsWithPowers.keySet());
        BigInteger tmp;
        for (BigInteger p : factorsWithPowers.keySet()) {
            tmp = p;
            int k = factorsWithPowers.get(p);
            for (int i = 2; i <= k; i++) {
                tmp = tmp.multiply(p);
                Set<BigInteger> current = new HashSet<>(result);
                for (BigInteger c : current) {
                    result.add(c.multiply(tmp));
                }
            }
        }
        return result;
    }
*/

    private static BigInteger partialFactorization(BigInteger n) {

        BigInteger p = TWO;
        while (p.longValue() < Math.sqrt(n.longValue())) {
            if (n.remainder(p).equals(BigInteger.ZERO)) {
                return p;
            }
            p = p.nextProbablePrime();
        }
        return BigInteger.ZERO;
    }

    public static Map<String, List<BigInteger>> performComputation() throws IOException {

        BigInteger from = TWO.pow(N - 1);
        BigInteger to = from.multiply(TWO);

        int n = 0;
        BigInteger k = from.add(BigInteger.ONE);


        BigInteger[] numbersOfDifferentBases = new BigInteger[BASE_RANGE];
        Map<String, List<BigInteger>> output = new HashMap<>();

        while (n < J && k.compareTo(to) == -1) {
            String representation = k.toString(2);

            for (int i = 0; i < BASE_RANGE; i++) {
                numbersOfDifferentBases[i] = new BigInteger(representation, i + 2);
            }

            boolean notPrime = true;
            int i = 0;
            while (i < BASE_RANGE && notPrime) {
                notPrime &= !numbersOfDifferentBases[i].isProbablePrime(1);
                i++;
            }

            boolean collision = false;
            if (notPrime) {
                List<BigInteger> factors = new LinkedList<>();
                i = 0;
                while (i < BASE_RANGE && !collision) {
                    BigInteger candidate = partialFactorization(numbersOfDifferentBases[i]);
                    if (candidate.equals(BigInteger.ZERO)) {
                        collision = true;
                        i = BASE_RANGE;
                    } else {
                        factors.add(candidate);
                    }
                    i++;
                }
                if (!collision) {
                    output.put(representation, factors);
                    n++;
                }
            }

            k = k.add(TWO);
        }
        return output;
    }

    public static void main(String[] args) throws IOException {
        writeOutput(performComputation());

    }

}



