import java.io.BufferedReader;
import java.io.IOException;
import java.io.PrintStream;
import java.math.BigInteger;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.Arrays;
import java.util.Scanner;
import java.util.stream.Collectors;

/**
 * @author Anastasiya Solodkaya.
 */
public class JamCoins {


    private static class BigLong {
        long part0;
        long part1;

        public BigLong(long part0, long part1) {
            this.part0 = part0;
            this.part1 = part1;
        }

        public BigLong(long part1) {
            this(0, part1);
        }
    }

    private PrintStream out;

    public JamCoins(PrintStream out) {
        this.out = out;
    }

    public static void main(String[] args) {
        new JamCoins(out("C-small-attempt0")).run();
    }

    private void run() {
        Scanner scanner = new Scanner(read("C-small-attempt0"));
        int cases = scanner.nextInt();
        int N = scanner.nextInt();
        int J = scanner.nextInt();

        out.println("Case #1:");
        int produced = 0;
        long start = (1L << N - 1) | 1L;
        long next = start;
        loop:
        while (produced < J) {
            next = next + 2;
            long[] divisors = findDivisors(next);
            if (divisors == null) {
                continue loop;
            }
            produced++;
            out.println(Long.toBinaryString(next) + " " + Arrays.stream(divisors).mapToObj(s -> s + "").collect(Collectors.joining(" ")));
        }
        out.close();
    }

    private long[] findDivisors(long next) {
        long[] divisors = new long[9];
        for (int i = 2; i <= 10; i++) {
            BigInteger inBase = base(next, i);
            long nonTrivialDivider = findNonTrivialDivider(inBase);
            if (nonTrivialDivider == -1) {
                return null;
            }
            divisors[i - 2] = nonTrivialDivider;
        }
        return divisors;
    }

    private long findNod(long[] divisors) {
        Arrays.sort(divisors);
        long d = divisors[0];
        for (int i = 1; i < divisors.length; i++) {
            if (d % divisors[i] != 0) {
                d *= divisors[i];
            }
        }
        return d;
    }

    private long findNonTrivialDivider(BigInteger value) {
        long n = 2;
//        while (n < value / 2) {
        while (n < 100) {
            if (value.mod(BigInteger.valueOf(n)).equals(BigInteger.ZERO)) {
                return n;
            }
            n++;
        }
        return -1;
    }

    private BigInteger base(long value, int base) {
//        out.println("value = " + value + ", base = " + base);
        BigInteger total = BigInteger.ZERO;
        long num = value;
        int idx = 0;
        while (num > 0) {
            if (num % 2 == 1) {
                total = total.add(BigInteger.valueOf(base).pow(idx));
            }
//            out.println("total = " + total);
            num = num >> 1L;
//            out.println("num = " + num);
            idx++;
        }
        return total;
    }


    private static BufferedReader read(String fileNameBase) {
        BufferedReader bufferedReader = null;
        try {
            bufferedReader = Files.newBufferedReader(Paths.get("samples/" + fileNameBase + ".in"));
        } catch (IOException e) {
            e.printStackTrace();
        }
        return bufferedReader;
    }

    private static PrintStream out(String fileNameBase) {
        PrintStream printStream = null;
        try {
            printStream = new PrintStream("samples/" + fileNameBase + ".out");
        } catch (IOException e) {
            e.printStackTrace();
        }
        return printStream;
    }
}
