import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.math.RoundingMode;

public class Question3 {

	private static int B;

	private static final BigDecimal SQRT_DIG = new BigDecimal(150);
	private static final BigDecimal SQRT_PRE = new BigDecimal(10).pow(SQRT_DIG.intValue());

	/**
	 * Private utility method used to compute the square root of a BigDecimal.
	 * 
	 * @author Luciano Culacciatti
	 * @url http://www.codeproject.com/Tips/257031/Implementing-SqrtRoot-in-
	 *      BigDecimal
	 */
	private static BigDecimal sqrtNewtonRaphson(BigDecimal c, BigDecimal xn, BigDecimal precision) {
		BigDecimal fx = xn.pow(2).add(c.negate());
		BigDecimal fpx = xn.multiply(new BigDecimal(2));
		BigDecimal xn1 = fx.divide(fpx, 2 * SQRT_DIG.intValue(), RoundingMode.HALF_DOWN);
		xn1 = xn.add(xn1.negate());
		BigDecimal currentSquare = xn1.pow(2);
		BigDecimal currentPrecision = currentSquare.subtract(c);
		currentPrecision = currentPrecision.abs();
		if (currentPrecision.compareTo(precision) <= -1) {
			return xn1;
		}
		return sqrtNewtonRaphson(c, xn1, precision);
	}

	/**
	 * Uses Newton Raphson to compute the square root of a BigDecimal.
	 * 
	 * @author Luciano Culacciatti
	 * @url http://www.codeproject.com/Tips/257031/Implementing-SqrtRoot-in-
	 *      BigDecimal
	 */
	public static BigDecimal bigSqrt(BigDecimal c) {
		return sqrtNewtonRaphson(c, new BigDecimal(1), new BigDecimal(1).divide(SQRT_PRE));
	}

	public static void main(String[] args) throws Exception {

		// System.out.println(BigIntSqRoot.bigIntSqRootFloor(new
		// BigInteger("111111111111111")).longValue());

		int[] primes = generatePrimes(10540999);

		BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream("questionC")));
		BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream("C-small.out")));
		// new OutputStreamWriter(System.out));

		int n = Integer.parseInt(reader.readLine());
		for (int nn = 0; nn < n; nn++) {
			writer.append("Case #1:");
			writer.newLine();

			String[] split = reader.readLine().split(" ");
			int A = Integer.parseInt(split[0]);
			B = Integer.parseInt(split[1]);

			printBin(primes, writer, "", A - 2);
		}

		writer.flush();
		writer.close();
	}

	private static boolean calc(int[] primes, BufferedWriter writer, String x) throws IOException {
		long[] e = new long[9];
		boolean jamcoin = true;
		ff: for (int b = 2; b <= 10; b++) {
			long y = Long.parseLong(x, b);

			// writer.append(x + " " + b + " " + y);
			// writer.newLine();

			for (int m = 0; m < primes.length; m++) {
				long p = primes[m];
				if (p * p > y) {
					jamcoin = false;
					break ff;
				}

				if (y % p == 0) {
					e[b - 2] = p;
					continue ff;
				}
			}

			jamcoin = false;
			break;
		}

		if (jamcoin) {
			writer.append(x + " ");
			boolean f = true;
			for (int m = 0; m < e.length; m++) {
				if (!f)
					writer.append(" ");
				writer.append(Long.toString(e[m]));
				f = false;
			}
			writer.newLine();
			return true;
		} else {
			// writer.append(x + " ");
			// writer.append("NOT A JAMCOIN");
			// writer.newLine();
			return false;
		}
	}

	public static void printBin(int[] primes, BufferedWriter writer, String soFar, int iterations) throws IOException {
		if (iterations == 0) {
			if (calc(primes, writer, "1" + soFar + "1")) {
				B--;
			}
		} else {
			if (B > 0)
				printBin(primes, writer, soFar + "0", iterations - 1);
			if (B > 0)
				printBin(primes, writer, soFar + "1", iterations - 1);
		}
	}

	private static int[] generatePrimes(int max) {
		boolean[] isComposite = new boolean[max + 1];
		for (int i = 2; i * i <= max; i++) {
			if (!isComposite[i]) {
				for (int j = i; i * j <= max; j++) {
					isComposite[i * j] = true;
				}
			}
		}
		int numPrimes = 0;
		for (int i = 2; i <= max; i++) {
			if (!isComposite[i])
				numPrimes++;
		}
		int[] primes = new int[numPrimes];
		int index = 0;
		for (int i = 2; i <= max; i++) {
			if (!isComposite[i])
				primes[index++] = i;
		}
		return primes;
	}

}
