import java.io.*;
import java.util.*;

public class TrainTimetable {
	private static enum Station {
		A,
		B
	}
	
	public static void main(String[] args) {
		if (args.length == 0) {
			System.out.println("You must specify an input file!");
			
			return;
		}
		
		BufferedReader reader = null;
		BufferedWriter writer = null;
		
		try {
			reader = new BufferedReader(new FileReader(args[0]));
			writer = new BufferedWriter(new FileWriter(args[0] + ".out"));
			
			int N = Integer.parseInt(reader.readLine());
			
			for (int i = 1; i <= N; ++i) {
				List<List<List<Date>>> schedules = new ArrayList<List<List<Date>>>(2);
				
				int T = Integer.parseInt(reader.readLine());
				
				String[] stringsNx = reader.readLine().split(" ");
				
				for (String stringNx : stringsNx) {
					int Nx = Integer.parseInt(stringNx);
					
					List<List<Date>> schedule = new ArrayList<List<Date>>(Nx);
					
					for (int j = 1; j <= Nx; ++j) {
						String[] times = reader.readLine().split(" ");

						String[] timeDeparture = times[0].split(":");
						String[] timeArrival = times[1].split(":");
						
						Calendar calDeparture = new GregorianCalendar();
						calDeparture.setTime(new Date(0));
						calDeparture.set(Calendar.HOUR_OF_DAY, Integer.parseInt(timeDeparture[0]));
						calDeparture.set(Calendar.MINUTE, Integer.parseInt(timeDeparture[1]));
						
						Calendar calReadyToGo = new GregorianCalendar();
						calReadyToGo.setTime(new Date(0));
						calReadyToGo.set(Calendar.HOUR_OF_DAY, Integer.parseInt(timeArrival[0]));
						calReadyToGo.set(Calendar.MINUTE, Integer.parseInt(timeArrival[1]));
						calReadyToGo.add(Calendar.MINUTE, T);
						
						Date dateDeparture = calDeparture.getTime();
						Date dateReadyToGo = calReadyToGo.getTime();
						
						List<Date> train = new ArrayList<Date>(2);
						
						train.add(dateDeparture);
						train.add(dateReadyToGo);
						
						schedule.add(train);
					}
					
					schedules.add(schedule);
				}
				
				Map<Station, Integer> trainCounts = findTrainCounts(schedules.get(0), schedules.get(1));
				
				writer.write(String.format("Case #%d: %d %d", i, trainCounts.get(Station.A), trainCounts.get(Station.B)));
				writer.newLine();
			}
		} catch (FileNotFoundException e) {
			System.out.println("File not found!");
		} catch (IOException e) {
			System.out.println(String.format("I/O error:\n%s", e.getMessage()));
		} finally {
			Collection<Closeable> closeables = new Vector<Closeable>(2);
			
			closeables.add(reader);
			closeables.add(writer);
			
			for (Closeable closeable : closeables) {
				if (closeable != null) {
					try {
						closeable.close();
					} catch (IOException e) {
						System.out.println("Error closing I/O objects!");
					}
				}
			}
		}
	}
	
	private static Map<Station, Integer> findTrainCounts(List<List<Date>> trainsAB, List<List<Date>> trainsBA) {
		Comparator<List<Date>> comparator = new Comparator<List<Date>>() {
			public int compare(List<Date> train1, List<Date> train2) {
				if (train1 == null && train2 == null) {
					return 0;
				} else if (train1 == null && train2 != null) {
					return Integer.MIN_VALUE;
				} else if (train1 != null && train2 == null) {
					return Integer.MAX_VALUE;
				} else {
					return train1.get(0).compareTo(train2.get(0));
				}
			}
		};
		
		Collections.sort(trainsAB, comparator);
		Collections.sort(trainsBA, comparator);
		
		Map<Station, Integer> trainCount = new HashMap<Station, Integer>(2);
		
		trainCount.put(Station.A, 0);
		trainCount.put(Station.B, 0);
		
		while (trainsAB.size() > 0 || trainsBA.size() > 0) {
			Station startStation = null;
			
			if (trainsAB.size() == 0) {
				startStation = Station.B;
			} else if (trainsBA.size() == 0) {
				startStation = Station.A;
			} else {
				startStation = comparator.compare(trainsAB.get(0), trainsBA.get(0)) <= 0 ? Station.A : Station.B;
			}
			
			runFirstTrain(trainsAB, trainsBA, startStation);
			
			trainCount.put(startStation, trainCount.get(startStation) + 1);
		}
		
		return trainCount;
	}
	
	private static void runFirstTrain(List<List<Date>> trainsAB, List<List<Date>> trainsBA, Station startStation) {
		Map<Station, List<List<Date>>> schedules = new HashMap<Station, List<List<Date>>>(2);
		schedules.put(Station.A, trainsAB);
		schedules.put(Station.B, trainsBA);
		
		Date readyToGo = null;
		
		for (
				List<Date> nextTrain = schedules.get(startStation).get(0);
				nextTrain != null;
				nextTrain = getNextTrain(schedules.get(startStation), readyToGo)) {
			List<List<Date>> schedule = schedules.get(startStation);
			
			readyToGo = nextTrain.get(1);
			
			schedule.remove(nextTrain);
			
			startStation = startStation == Station.A ? Station.B : Station.A;
		}
	}
	
	private static List<Date> getNextTrain(List<List<Date>> schedule, Date threshold) {
		for (List<Date> train : schedule) {
			if (train.get(0).before(threshold) == false) {
				return train;
			}
		}
		
		return null;
	}
}
