import java.util.Arrays;
import java.util.PriorityQueue;
import java.util.Scanner;


public class BathroomStalls {
	public static class Stall implements Comparable<Stall> {
		int stallNum;
		boolean occupied;
		int ls;
		int rs;
		Stall(int stallNum) {
			this.stallNum = stallNum;
			occupied = false;
			this.ls = 0;
			this.rs = 0;
		}
		@Override
		public int compareTo(Stall o) {
			
			if(!this.occupied && o.occupied) {
				return -1;
			}else if(this.occupied && !o.occupied) {
				return 1;
			}
			
			//choose the max of the mins
			int minA = Math.min(ls, rs);
			int minB = Math.min(o.ls, o.rs);
			if(minA < minB) {
				return 1; //reversed
			}else if(minA > minB) {
				return -1; //reversed
			}
			
			//choose the max of the maxes
			int maxA = Math.max(ls, rs);
			int maxB = Math.max(o.ls, o.rs);
			if(maxA < maxB) {
				return 1; //reversed
			}else if(maxA > maxB) {
				return -1; //reversed
			}
			
			//choose the leftmost
			if(this.stallNum < o.stallNum) {
				return -1;
			}else if(this.stallNum > o.stallNum) {
				return 1;
			}
			//they must be equal
			return 0;
		}
		public String toString() {
			String returnStr = "Stall Num: " + this.stallNum + ", LS: " + this.ls + ", RS: " + this.rs + ", Min: " + Math.min(ls, rs) + ", Max: " + Math.max(ls, rs);
			if(occupied) {
				returnStr = "*" + returnStr;
			}
			return returnStr;
		}
		
	}
	public static void main(String[] args) {
		Scanner sc = new Scanner(System.in);
		int t = sc.nextInt();
		for(int i=0; i<t; i++) {
			//test Case
			int n = sc.nextInt();
			int k = sc.nextInt();
			
			//create the stalls
			Stall[] stalls = new Stall[n+2];
			Stall[] sorted = new Stall[n+2];
			for(int j=0; j<sorted.length; j++) {
				Stall newS = new Stall(j);
				stalls[j] = newS;
				sorted[j] = newS;
			}
			
			//add in the bathroom guards
			stalls[0].occupied = true;
			stalls[stalls.length-1].occupied = true;
			
			updateLSRS(stalls);
			Arrays.sort(sorted);
			int[] lsrs = solve(k, stalls, sorted);
			System.out.println("Case #" + (i+1) + ": " + Math.max(lsrs[0], lsrs[1]) + " " + Math.min(lsrs[0], lsrs[1]));
		}
	}
	private static int[] solve(int k, Stall[] stalls, Stall[] sorted) {
		int ls = -1;
		int rs = -1;
		//printStalls(stalls);
		//printStalls(sorted);
		for(int i=0; i<k; i++) {
			//assign this person to the first stall
			sorted[0].occupied = true;
			ls = sorted[0].ls;
			rs = sorted[0].rs;
			updateLSRS(stalls);
			Arrays.sort(sorted);
			//printStalls(stalls);
		}
		
		int[] returnArr = new int[2];
		returnArr[0] = ls;
		returnArr[1] = rs;
		return returnArr;
	}
	private static void printStalls(Stall[] stalls) {
		System.out.println();
		for(int i=0; i<stalls.length; i++) {
			System.out.println(stalls[i]);
		}
		System.out.println();
	}
	private static void updateLSRS(Stall[] stalls) {
		for(int i=0; i<stalls.length; i++) {
			//update the ls
			int ls = 0;
			for(int j=i-1; j>=0; j--) {
				if(stalls[j].occupied) {
					break;
				}
				ls++;
			}
			
			//update rs
			int rs = 0;
			for(int j=i+1; j<stalls.length; j++) {
				if(stalls[j].occupied) {
					break;
				}
				rs++;
			}
			
			stalls[i].ls = ls;
			stalls[i].rs = rs;
		}
	}
}
