package watershed;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class WatershedMap
{
	private Map<MapPosition, PositionInfo> positions = new HashMap<MapPosition, PositionInfo>();
	
	public int maxX;
	public int maxY;
	
	public WatershedMap (int[][] heights)
	{
		this.maxY = heights.length -1;
		this.maxX = heights[0].length -1;
		for (int j=0; j<=maxY; j++) {
			for (int i=0; i<=maxX; i++) {
				MapPosition pos = new MapPosition (this, i, j);
				PositionInfo info = new PositionInfo();
				info.height = heights[j][i];
				
				this.positions.put(pos, info);
			}
		}
	}
	
	public void fillLabels()
	{
		char nextLabel = 'a';
		for (int j=0; j<=maxY; j++) {
			for (int i=0; i<=maxX; i++) {
				MapPosition p = new MapPosition (this, i, j);
				boolean labelUsed = this.fillBasin(p, nextLabel);
				if (labelUsed)  nextLabel = (char) (((int) nextLabel) + 1);
			}
			
		}
	}
	
	private boolean fillBasin (MapPosition p, char label)
	{
		PositionInfo info = positions.get (p);
		if (info.hasLabel())  return false;
		
		info.label = label;
		List<MapPosition> neighbors = p.getNeighbors();
		int minHeight = Integer.MAX_VALUE;
		MapPosition nextPos = null;
		PositionInfo nextInfo = null;
		for (int i=0; i<neighbors.size(); i++) {
			MapPosition candidate = neighbors.get(i);
			PositionInfo candInfo = positions.get (candidate);
			if ((candInfo.height < minHeight) && (candInfo.height < info.height)) {
				minHeight = candInfo.height;
				nextPos = candidate;
				nextInfo = candInfo;
			}
		}

		if (nextInfo == null) {
			return true;	// Sink
		} else if (nextInfo.hasLabel()) {
			this.replaceAllLabels(label, nextInfo.label);
			return false;
		} else {
			return this.fillBasin (nextPos, label);
		}
	}
	
	private void replaceAllLabels (char label0, char label1)
	{
		Iterator<PositionInfo> it = this.positions.values().iterator();
		while (it.hasNext()) {
			PositionInfo info = it.next();
			if (info.label == label0)  info.label = label1;
		}
	}
	
	public char getLabel (int x, int y)
	{
		MapPosition p = new MapPosition (this, x, y);
		PositionInfo i = this.positions.get (p);
		return i.label;
	}
	

	public static class MapPosition
	{
		private int x;
		private int y;
		
		private WatershedMap wmap;
		
		public static int DIR_N = 0;
		public static int DIR_W = 1;
		public static int DIR_E = 2;
		public static int DIR_S = 3;
		
		public MapPosition (WatershedMap _wmap, int _x, int _y)
		{
			this.wmap = _wmap;
			this.x = _x;
			this.y = _y;
		}
		public MapPosition getNeighbor (int dir)
		{
			if ((dir == DIR_N) && (y > 0)) {
				return new MapPosition (wmap, x, y-1);
			} else if ((dir == DIR_S) && (y < wmap.maxY)) {
				return new MapPosition (wmap, x, y+1);
			} else if ((dir == DIR_W) && (x > 0)) {
				return new MapPosition (wmap, x-1, y);
			} else if ((dir == DIR_E) && (x < wmap.maxX)) {
				return new MapPosition (wmap, x+1, y);
			} else {
				return null;
			}
		}
		
		public List<MapPosition> getNeighbors()
		{
			List<MapPosition> res = new ArrayList<MapPosition> (4);
			for (int i=0; i<4; i++) {
				MapPosition n = this.getNeighbor (i);
				if (n != null)  res.add (n);
			}
			return res;
		}

		public boolean equals(Object obj) {
			return hashCode() == obj.hashCode();
		}

		public int hashCode() {
			return x*1000 + y;
		}
	}
	
	public static class PositionInfo
	{
		int height;
		char label = '-';
		
		public boolean hasLabel()
		{
			return (label != '-');
		}
	}
	
	public static void main(String[] args)
			throws Exception
	{
		int[][] h = new int[][] {
				{9, 6, 3},
				{5, 9, 6},
				{3, 5, 9},
		};
		WatershedMap m = new WatershedMap (h);
		m.fillLabels();
		
		for (int j=0; j<=m.maxY; j++) {
			for (int i=0; i<=m.maxX; i++) {
				System.out.print (m.getLabel (i, j));
				
			}
			System.out.println();
		}
	}
}
