package fairwarning;

import java.io.FileReader;
import java.io.FileWriter;
import java.io.LineNumberReader;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.Set;
import java.util.TreeSet;


public class FairWarning
{
	public static BigInteger gcd (BigInteger[] numeros)
	{
		BigInteger gcd = numeros[0];
		for (int i=1; i<numeros.length && (gcd.compareTo(BigInteger.ONE) == 1); i++) {
			gcd = gcd.gcd (numeros[i]);
		}
		return gcd;
	}
	
	
	public static BigInteger calculate (BigInteger[] instantes)
	{
		// Se obtiene el array de diferencias
		BigInteger[] diferencias = new BigInteger [instantes.length - 1];
		for (int i=0; i<diferencias.length; i++) {
			diferencias[i] = instantes[i+1].subtract (instantes[i]);
			diferencias[i] = diferencias[i].abs();
		}
		
		// Se obtiene el máximo común divisor de todas: T
		BigInteger t = gcd (diferencias);
		if (t.equals(BigInteger.ZERO) || t.equals(BigInteger.ONE))  return BigInteger.ZERO;
		
		// Se obtiene la diferencia del primero respecto al siguiente múltiplo de T
		BigInteger resto = instantes[0].divideAndRemainder (t)[1];
		BigInteger diferencia = t.subtract (resto);
		return diferencia;
	}
	
	
	
	public static void main(String[] args)
		throws Exception
	{
		long t0 = System.currentTimeMillis();
		String sIn = "files/fairwarning/B-small-attempt1.in";
		if (args.length > 0)  sIn = args[0];
		String sOut = sIn;
		if (sOut.endsWith (".in")) sOut = sOut.substring (0, sOut.length() - 3);
		sOut = sOut + ".out";
		
		LineNumberReader in = new LineNumberReader (new FileReader (sIn));
		PrintWriter out = new PrintWriter (new FileWriter (sOut));
	
		String linea0 = in.readLine();
		int numCasos = Integer.parseInt (linea0);
		
		for (int i=0; i<numCasos; i++) {
			System.out.println ("Case #" + (i+1));
			String s = in.readLine();
			
			String[] trozos = s.split (" ");
			int n = Integer.parseInt(trozos[0]);
			
			Set<BigInteger> instantes0 = new TreeSet<BigInteger>();
			for (int j=0; j<n; j++) {
				instantes0.add (new BigInteger (trozos[j+1]));
			}
			BigInteger[] instantes = (BigInteger[]) instantes0.toArray (new BigInteger[0]);
			BigInteger res = calculate (instantes);
//			BigInteger[] instantes = new BigInteger [n];
//			for (int j=0; j<n; j++) {
//				instantes[j] = new BigInteger (trozos[j+1]);
//			}
//			BigInteger res = calculate (instantes);
			
			out.println ("Case #" + (i+1) + ": " + res);
		}
		
		
		out.close();
		
		long t1 = System.currentTimeMillis();
		long seg = ((t1 - t0) / 1000);
		double mins = seg / 60d;
		
		System.out.println ("OK - " + mins + " minutos");
	}
}
