import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.StringTokenizer;


public class Googlerese {
	public static void solve(BufferedReader reader, BufferedWriter writer, char[] map) throws IOException {
		int testCount = readIntFromLine(reader);
		
		for (int test = 1; test <= testCount; test++) {
			writer.append("Case #").append(Integer.toString(test)).append(": ");
			
			solveTestCase(reader, writer, map);
			
			writer.newLine();
		}
		writer.flush();
	}

	private static void solveTestCase(BufferedReader reader, BufferedWriter writer, char[] map) throws IOException {
		String line = reader.readLine();
		for (int i=0; i < line.length(); i++) {
			char inputChar = line.charAt(i);
			if (inputChar == ' ') {
				writer.append(inputChar);
			} else if (inputChar >= 'a' && inputChar <= 'z') {
				writer.append(map[inputChar - 'a']);
			}
		}
	}
	
	public static void solve(String inputFile, String outputFile, char[] map) throws IOException {
		File input = new File(inputFile);
		File output = new File(outputFile);
		
		if (!input.exists()) {
			throw new IllegalArgumentException("Input file doesn't exist: " + inputFile);
		}
		
		BufferedReader reader = null;
		BufferedWriter writer = null;
		try {
			reader = new BufferedReader(new FileReader(input));
			writer = new BufferedWriter(new FileWriter(output));
			solve(reader, writer, map);
		
		} finally {
			if (reader != null)
				reader.close();
			if (writer != null)
				writer.close();
		}
	}
	
	public static int readIntFromLine(BufferedReader reader) throws IOException {
		String line = reader.readLine();
		int testCount = Integer.parseInt(line);
		return testCount;
	}

	public static int[] readArrayFromLine(BufferedReader reader, int itemsCount) throws IOException {
		int[] items = new int[itemsCount];
		
		String line = reader.readLine();
		StringTokenizer tokenizer = new StringTokenizer(line);
		for (int i=0; i < itemsCount; i++) {
			items[i] = Integer.parseInt(tokenizer.nextToken());
		}
		return items;
	}
	
	public static char[] createConversionMap(String googlerese, String english) {
		char[] map = new char[26];
		boolean[] usedEnglishChars = new boolean[26];
		
		for (int i=0; i < googlerese.length(); i++) {
			char c = googlerese.charAt(i);
			if (c != ' ') {
				map[c - 'a'] = english.charAt(i);
				usedEnglishChars[english.charAt(i) - 'a'] = true;
			}
		}
	
		// check map
		StringBuilder missingGooglereseChars = new StringBuilder();
		StringBuilder missingEnglishChars = new StringBuilder();
		for (int i=0; i < map.length; i++) {
			if (map[i] == 0) {
				missingGooglereseChars.append(' ').append((char)(i + 'a'));
			}
			
			if (!usedEnglishChars[i]) {
				missingEnglishChars.append(' ').append((char)(i + 'a'));
			}
		}
		
		if (missingGooglereseChars.length() > 0) {
			System.out.println("The following googlerese chars are not in the map:" + missingGooglereseChars.toString());
			System.out.println("The following english chars are not in the map:   " + missingEnglishChars.toString());
		}
		
		return map;
	}

	private static void printConversionMap(char[] map) {
		System.out.println("Conversion map:");
		for (int i=0; i < map.length; i++) {
			System.out.print((char)(i + 'a') + " ");
		}
		System.out.println();
		for (int i=0; i < map.length; i++) {
			char c = map[i] == 0 ? '?' : map[i];
			System.out.print(c + " ");
		}
		System.out.println();
	}
	
	public static void main(String[] args) throws IOException {
		System.out.println("Start...");
		
		char[] map = createDefaultMap();
		printConversionMap(map);
		
		solve("res/input.txt", "res/output.txt", map);
		System.out.println("Done!");
	}

	public static char[] createDefaultMap() {
		String googlerese = "ejp mysljylc kd kxveddknmc " +
				"re jsicpdrysi rbcpc ypc rtcsra dkh wyfrepkym " +
				"veddknkmkrkcd de kr kd eoya kw aej tysr re ujdr lkgc jv q z";
		String english = "our language is impossible to understand " +
						 "there are twenty six factorial possibilities " +
						 "so it is okay if you want to just give up z q";
		
		char[] map = createConversionMap(googlerese, english);
		return map;
	}
}
