import java.io.*;
import java.util.*;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;


public class MultithreadedSolution {
    // to clean all blocks replace:
    // \/\/ begin clean[\s\S]*?\n([\t ]*)\/\/ end clean
    // \/\/ begin clean\n\n$1/\/ end clean

    private static class Result {
        private int testNum;

        private Result(int testNum) {
            this.testNum = testNum;
        }

        // todo add fields to print result of one test =================================================================
        // begin clean
        private double res;
        // end clean
    }

    private void printResult(Result result) throws IOException {
        out.print("Case #" + result.testNum + ": ");

        // todo print result of one test ===============================================================================
        // begin clean
        out.println(String.format(Locale.ENGLISH, "%.8f", result.res));
        // end clean
    }

    // begin clean

    // end clean


    private class Solver implements Callable<Result> {
        // todo add fields for input parameters ========================================================================
        // begin clean
        private int n;
        private int k;
        private int u;
        private int[] p;
        private double[][] prefixes = new double[53][];
        private double[][] suffixes = new double[53][];

        private int r() throws IOException {
            double d = nextDouble();
            return (int) (d * 10000 + 0.01);
        }

        private double[] mult(double[] a, double[] b) {
            int n = a.length;
            int m = b.length;
            double[] res = new double[n + m - 1];
            for (int i = 0; i < n; i++) {
                for (int j = 0; j < m; j++) {
                    res[i + j] += a[i] * b[j];
                }
            }
            return res;
        }

        private void calcFixes(int[] p) {
            double[] prev = new double[]{1.0};
            for (int i = 0; i + 1 < n; i++) {
                prefixes[i] = mult(prev, new double[]{1.0 - p[i] / 10000.0, p[i] / 10000.0});
                prev = prefixes[i];
            }
            prev = new double[]{1.0};
            for (int i = n - 1; i > 0; i--) {
                suffixes[i] = mult(prev, new double[]{1.0 - p[i] / 10000.0, p[i] / 10000.0});
                prev = suffixes[i];
            }
        }

        private double calc(int[] p, int k, int idx) {
            double[] a = new double[]{1.0 - p[idx] / 10000.0, p[idx] / 10000.0};
            if (idx > 0) {
                a = mult(a, prefixes[idx - 1]);
            }
            if (idx + 1 < n) {
                a = mult(a, suffixes[idx + 1]);
            }
            double res = 0.0;
            for (int i = k; i <= n; i++) {
                res += a[i];
            }
            return res;
        }
        // end clean

        private void readData() throws IOException {
            // todo read input parameters ==============================================================================
            // begin clean
            n = nextInt();
            k = nextInt();
            u = r();
            p = new int[n];
            for (int i = 0; i < n; i++) {
                p[i] = r();
            }
            // end clean
        }

        private void solve(Result result) throws IOException {
            // todo calculate and fill result fields ===================================================================
            // begin clean

            calcFixes(p);
            while (u > 0) {
                int bst = -1;
                double bstV = 0;
                for (int i = 0; i < n; i++) {
                    if (p[i] < 10000) {
                        p[i]++;
                        double v = calc(p, k, i);
                        p[i]--;
                        if (bst < 0 || bstV < v) {
                            bst = i;
                            bstV = v;
                        }
                    }
                }
                p[bst]++;
                u--;
                calcFixes(p);
            }
            result.res = calc(p, k, 0);
            // end clean
        }

        @Override
        public Result call() throws Exception {
            int testNum;
            synchronized (inLock) {
                testNum = ++lastTestNum;
                readData();
            }

            Result result = new Result(testNum);
            solve(result);
            log(">>> Solved test #" + testNum);
            return result;
        }
    }

    private static String inputFilename = "input.txt";
    private static String outputFilename = "output.txt";
    private BufferedReader in;
    private StringTokenizer line;
    private PrintWriter out;
    private boolean isDebug;
    private MyTimer timer = new MyTimer();

    private int lastTestNum = 0;
    private final Object inLock = new Object();
    private final Object logLock = new Object();

    private MultithreadedSolution(boolean isDebug) {
        this.isDebug = isDebug;
    }

    public static void main(String[] args) throws IOException {
        boolean isDebug = Arrays.asList(args).contains("DEBUG_MODE");
//        boolean isDebug = false;
        new MultithreadedSolution(isDebug).run();
    }

    private void run() throws IOException {
        in = new BufferedReader(new InputStreamReader(new FileInputStream(inputFilename)));
//        in = new BufferedReader(new InputStreamReader(System.in));

        out = new PrintWriter(outputFilename);
//        out = new PrintWriter(System.out);

        int threadPoolSize = Runtime.getRuntime().availableProcessors() * 2;
        log(">>> Thread pool size: " + threadPoolSize);
        ExecutorService executorService = Executors.newFixedThreadPool(threadPoolSize);

        int t = nextInt();

        ArrayList<Future<Result>> futureResults = new ArrayList<>(t);
        for (int i = 0; i < t; i++) {
            futureResults.add(executorService.submit(new Solver()));
        }

        ArrayList<Result> results = new ArrayList<>(t);
        for (Future<Result> f : futureResults) {
            try {
                results.add(f.get());
            } catch (Exception e) {
                e.printStackTrace();
                return;
            }
        }

        executorService.shutdown();

        Collections.sort(results, (o1, o2) -> o1.testNum - o2.testNum);

        for (Result r : results) {
            printResult(r);
        }

        in.close();
        out.flush();
        out.close();
    }

    private void log(String s) throws IOException {
        if (isDebug) {
            synchronized (logLock) {
                System.out.println(timer.getStr() + " " + s);
                System.out.flush();
            }
        }
    }

    private int[] nextIntArray(int n) throws IOException {
        int[] res = new int[n];
        for (int i = 0; i < n; i++) {
            res[i] = nextInt();
        }
        return res;
    }

    private long[] nextLongArray(int n) throws IOException {
        long[] res = new long[n];
        for (int i = 0; i < n; i++) {
            res[i] = nextLong();
        }
        return res;
    }

    private int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    private long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    private double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    private String nextToken() throws IOException {
        while (line == null || !line.hasMoreTokens()) {
            line = new StringTokenizer(in.readLine());
        }
        return line.nextToken();
    }

    private static class MyTimer {
        private long lastTime = 0;

        private MyTimer() {
            reset();
        }

        public void reset() {
            lastTime = System.currentTimeMillis();
        }

        public long getMillis() {
            return System.currentTimeMillis() - lastTime;
        }

        public String getStr() {
            return String.format(Locale.ENGLISH, "%.3fs", getMillis() / 1000.0);
        }
    }
}