import java.io.*;
import java.util.Arrays;
import java.util.HashSet;
import java.util.StringTokenizer;


public class Solution {
    private static String inputFilename = "input.txt";
    private static String outputFilename = "output.txt";
    private BufferedReader in;
    private StringTokenizer line;
    private PrintWriter out;
    private boolean isDebug;

    public Solution(boolean isDebug) {
        this.isDebug = isDebug;
    }

    private int n;
    private int m;

    public void solve() throws IOException {
        n = nextInt();
        m = nextInt();
        char[][] a = new char[n][];
        boolean[][] b = new boolean[n][m];
        for (int i = 0; i < n; i++) {
            a[i] = nextToken().toCharArray();
            for (int j = 0; j < m; j++) {
                if (a[i][j] == '.') {
                    b[i][j] = true;
                }
            }
        }
        Beam[][] beams = new Beam[n][m];
        IBeam[][][] intersBeams = new IBeam[n][m][2];
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                if (a[i][j] == '|' || a[i][j] == '-') {
                    HashSet<Integer> p1 = getPath(a, i, j, true);
                    HashSet<Integer> p2 = getPath(a, i, j, false);
                    if (p1 == null) {
                        if (p2 == null) {
                            out.println("IMPOSSIBLE");
                            return;
                        } else {
                            a[i][j] = '-';
                            for (int z : p2) {
                                b[z / m][z % m] = false;
                            }
                        }
                    } else {
                        if (p2 == null) {
                            a[i][j] = '|';
                            for (int z : p1) {
                                b[z / m][z % m] = false;
                            }
                        } else {
                            for (int z : p1) {
                                if (p2.contains(z)) {
                                    b[i][j] = false;
                                }
                            }
                            Beam bm = beams[i][j] = new Beam();
                            bm.x = i;
                            bm.y = j;
                            bm.p1 = new HashSet<>();
                            bm.p2 = new HashSet<>();
                            for (int z : p1) {
                                if (b[z / m][z % m]) {
                                    add(intersBeams[z / m][z % m], new IBeam(bm, 1));
                                    bm.p1.add(z);
                                }
                            }
                            for (int z : p2) {
                                if (b[z / m][z % m]) {
                                    add(intersBeams[z / m][z % m], new IBeam(bm, 2));
                                    bm.p2.add(z);
                                }
                            }
                        }
                    }
                }
            }
        }


        while (true) {
            boolean pp = false;
            for (int i = 0; i < n; i++) {
                for (int j = 0; j < m; j++) {
                    if (b[i][j] && intersBeams[i][j][0] != null && intersBeams[i][j][1] == null) {
                        pp = true;
                        IBeam ib = intersBeams[i][j][0];
                        intersBeams[i][j][0] = null;
                        HashSet<Integer> pr = ib.pn == 1 ? ib.bm.p2 : ib.bm.p1;
                        for (int z : pr) {
                            remove(intersBeams[z / m][z % m], ib.bm);
                        }
                        pr = ib.pn == 1 ? ib.bm.p1 : ib.bm.p2;
                        a[ib.bm.x][ib.bm.y] = ib.pn == 1 ? '|' : '-';
                        for (int z : pr) {
                            b[z / m][z % m] = false;
                            remove(intersBeams[z / m][z % m], ib.bm);
                        }
                    }
                }
            }
            for (int i = 0; i < n && !pp; i++) {
                for (int j = 0; j < m && !pp; j++) {
                    if (b[i][j] && intersBeams[i][j][1] != null) {
                        pp = true;
                        IBeam ib = intersBeams[i][j][1];
                        intersBeams[i][j][1] = null;
                        HashSet<Integer> pr = ib.pn == 1 ? ib.bm.p2 : ib.bm.p1;
                        for (int z : pr) {
                            remove(intersBeams[z / m][z % m], ib.bm);
                        }
                        pr = ib.pn == 1 ? ib.bm.p1 : ib.bm.p2;
                        a[ib.bm.x][ib.bm.y] = ib.pn == 1 ? '|' : '-';
                        for (int z : pr) {
                            b[z / m][z % m] = false;
                            remove(intersBeams[z / m][z % m], ib.bm);
                        }
                    }
                }
            }
            if (!pp) break;
        }

        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                if (b[i][j]) {
                    out.println("IMPOSSIBLE");
                    return;
                }
            }
        }
        out.println("POSSIBLE");
        for (int i = 0; i < n; i++) {
            out.println(new String(a[i]));
        }
    }

    private void remove(IBeam[] a, Beam bm) {
        if (a[1] != null && a[1].bm == bm) {
            a[1] = null;
            return;
        }
        if (a[0] != null && a[0].bm == bm) {
            a[0] = a[1];
            a[1] = null;
            return;
        }
    }

    private void add(IBeam[] a, IBeam bm) {
        if (a[0] == null) {
            a[0] = bm;
            return;
        }
        if (a[1] == null) {
            a[1] = bm;
            return;
        }
        throw new RuntimeException();
    }

    private static class Beam {
        private int x;
        private int y;
        private HashSet<Integer> p1;
        private HashSet<Integer> p2;
    }

    private static class IBeam {
        private Beam bm;
        private int pn;

        public IBeam(Beam bm, int pn) {
            this.bm = bm;
            this.pn = pn;
        }
    }

    private HashSet<Integer> getPath(char[][] a, int x, int y, boolean horiz) {
        HashSet<Integer> res = new HashSet<>();
        if (horiz) {
            {
                int dir = 1;
                if (!goPath(res, a, x + dx[dir], y + dy[dir], dir)) {
                    return null;
                }
            }
            {
                int dir = 3;
                if (!goPath(res, a, x + dx[dir], y + dy[dir], dir)) {
                    return null;
                }
            }
        } else {
            {
                int dir = 0;
                if (!goPath(res, a, x + dx[dir], y + dy[dir], dir)) {
                    return null;
                }
            }
            {
                int dir = 2;
                if (!goPath(res, a, x + dx[dir], y + dy[dir], dir)) {
                    return null;
                }
            }
        }
        return res;
    }

    // up, right, down, left
    private final int[] dx = new int[]{0, 1, 0, -1};
    private final int[] dy = new int[]{-1, 0, 1, 0};

    private final int[] s1 = new int[]{3, 2, 1, 0};
    private final int[] s2 = new int[]{1, 0, 3, 2};

    private boolean goPath(HashSet<Integer> res, char[][] a, int x, int y, int dir) {
        if (x < 0 || y < 0 || x >= n || y >= m || a[x][y] == '#') {
            return true;
        }
        if (a[x][y] == '.') {
            res.add(x * m + y);
            return goPath(res, a, x + dx[dir], y + dy[dir], dir);
        }
        if (a[x][y] == '\\') {
            dir = s1[dir];
            return goPath(res, a, x + dx[dir], y + dy[dir], dir);
        }
        if (a[x][y] == '/') {
            dir = s2[dir];
            return goPath(res, a, x + dx[dir], y + dy[dir], dir);
        }
        return false;
    }


    public static void main(String[] args) throws IOException {
        new Solution(Arrays.asList(args).contains("DEBUG_MODE")).run(args);
    }

    public void run(String[] args) throws IOException {
        if (isDebug) {
            in = new BufferedReader(new InputStreamReader(new FileInputStream(inputFilename)));
//            in = new BufferedReader(new InputStreamReader(System.in));
        } else {
            in = new BufferedReader(new InputStreamReader(System.in));
        }
//        out = new PrintWriter(System.out);
        out = new PrintWriter(outputFilename);

        int t = nextInt();
//        int t = 1;
        for (int i = 0; i < t; i++) {
            out.print("Case #" + (i + 1) + ": ");
            solve();
        }

        in.close();
        out.flush();
        out.close();
    }

    private int[] nextIntArray(int n) throws IOException {
        int[] res = new int[n];
        for (int i = 0; i < n; i++) {
            res[i] = nextInt();
        }
        return res;
    }

    private long[] nextLongArray(int n) throws IOException {
        long[] res = new long[n];
        for (int i = 0; i < n; i++) {
            res[i] = nextLong();
        }
        return res;
    }

    private int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    private long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    private double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    private String nextToken() throws IOException {
        while (line == null || !line.hasMoreTokens()) {
            line = new StringTokenizer(in.readLine());
        }
        return line.nextToken();
    }
}
