import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.Scanner;

public final class TrainTimetable {

    private class Time implements Comparable<Time> {

        private int hour;
        private int min;

        public Time(int h, int m) {
            hour = h;
            min = m;
        }

        public int getHour() {
            return hour;
        }

        public int getMin() {
            return min;
        }

        // return a new Time with some minutes more
        public Time plusMins(int minutes) {
            Time time = new Time(hour, min);
            time.min += minutes;
            if (time.min > 59) {
                time.hour += (time.min / 60);
                time.min = (time.min % 60);
            }
            return time;
        }

        public int compareTo(Time o) {
            int dif = this.hour - o.hour;
            if (dif == 0) {
                dif = this.min - o.min;
            }
            return dif;
        }

        @Override
        public String toString() {
            return String.format("%02d:%02d", hour, min);
        }

    }

    private class Trip {

        public final Time start;
        public final Time finish;

        public Trip(Time start, Time finish) {
            this.start = start;
            this.finish = finish;
        }

        @Override
        public String toString() {
            return String.format("%s %s", start, finish);
        }
    }

    public static void main(String[] args) {
        final File filein = new File("B-large.in");
        final File fileout = new File("output.txt");
        // don't exist? create!
        if (!fileout.exists()) {
            try {
                fileout.createNewFile();
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        Scanner scan = null;
        BufferedWriter writer = null;
        try {
            scan = new Scanner(filein);
            writer = new BufferedWriter(new FileWriter(fileout));

            final TrainTimetable tt = new TrainTimetable();

            Comparator<Trip> tripCompare = new Comparator<Trip>() {

                public int compare(Trip o1, Trip o2) {
                    int dif = o1.start.compareTo(o2.start);
                    if (dif == 0) {
                        dif = o1.finish.compareTo(o2.finish);
                    }
                    return dif;
                }

            };

            final int cases = scan.nextInt();
            for (int caseNum = 1; caseNum <= cases; caseNum++) {
                final int turnAroundTime = scan.nextInt();// time consumed to turn the train

                final int na = scan.nextInt();
                final int nb = scan.nextInt();

                final LinkedList<Trip> aTrips = new LinkedList<Trip>();
                final LinkedList<Trip> bTrips = new LinkedList<Trip>();
                // load A trip list
                for (int i = 0; i < na; i++) {
                    String tIni = scan.next();
                    String tEnd = scan.next();
                    aTrips.add(tt.buildTrip(tIni, tEnd));
                }
                // load B trip list
                for (int i = 0; i < nb; i++) {
                    String tIni = scan.next();
                    String tEnd = scan.next();
                    bTrips.add(tt.buildTrip(tIni, tEnd));
                }
                // sort the lists
                Collections.sort(aTrips, tripCompare);
                Collections.sort(bTrips, tripCompare);

                int va = 0;
                int vb = 0;

                while (!(aTrips.isEmpty() && bTrips.isEmpty())) {
                    if (aTrips.isEmpty()) {
                        vb += bTrips.size();
                        bTrips.clear();
                        break;
                    }
                    if (bTrips.isEmpty()) {
                        va += aTrips.size();
                        aTrips.clear();
                        break;
                    }

                    // peek the first () elements
                    final Trip at = aTrips.peek();
                    final Trip bt = bTrips.peek();

                    LinkedList<Trip> otherTripList;
                    Trip curTrip;
                    if (tripCompare.compare(at, bt) < 0) {
                        // tempo 'a'  menor
                        otherTripList = bTrips;
                        curTrip = at;
                        aTrips.remove();
                        // inc va
                        va++;
                    } else {
                        // tempo 'b'  menor
                        otherTripList = aTrips;
                        curTrip = bt;
                        bTrips.remove();
                        // inc vb
                        vb++;
                    }

                    boolean continueTrip = true;
                    while (continueTrip) {
                        continueTrip = false;
                        for (Iterator<Trip> iterator = otherTripList.iterator(); iterator.hasNext();) {
                            Trip otherTrip = iterator.next();
                            if (curTrip.finish.plusMins(turnAroundTime).compareTo(otherTrip.start) <= 0) {
                                continueTrip = true;
                                // remove from the list
                                iterator.remove();
                                curTrip = otherTrip;
                                if (otherTripList == aTrips) {
                                    otherTripList = bTrips;
                                } else {
                                    otherTripList = aTrips;
                                }
                                break;// break the for and go back to the while
                            }
                        }

                        // FIXME terminar isso aqui!
                    }
                }

                tt.writeCase(writer, caseNum, va, vb);
            }

        } catch (IOException ioe) {
            throw new RuntimeException(ioe);// BOOM
        } finally {
            if (scan != null) {
                scan.close();
            }
            if (writer != null) {
                try {
                    writer.close();
                } catch (IOException e) {
                    // who cares?
                }
            }
        }

    }

    public Trip buildTrip(String tIni, String tEnd) {
        Trip trip = new Trip(buildTime(tIni), buildTime(tEnd));
        return trip;
    }

    public Time buildTime(String strTime) {
        String[] splitted = strTime.split(":");
        int h = Integer.parseInt(splitted[0]);
        int m = Integer.parseInt(splitted[1]);
        return new Time(h, m);
    }

    public void writeCase(Writer writer, int num, int v1, int v2) throws IOException {
        writer.write(String.format("Case #%d: %d %d\r\n", num, v1, v2));
    }
}
