package com.andymur.codejam;

import java.io.*;
import java.util.ArrayList;
import java.util.List;

/**
 *
 */
public class CookieClickerRunner {

    private static final String inputFile = "C:\\codejam\\cookieclicker\\input.txt";
    private static final String outputFile = "C:\\codejam\\cookieclicker\\output.txt";
    private final static String testResultTemplate = "Case #%d: %.7f";

    private static double factoryCost = 0.0;
    private static double factoryPower = 0.0;
    private static double costOfWin = 0.0;

    private static int testCasesNum;

    private static double currentRate = 2.0;
    private static double currentScore = 0.0;

    private static List<Double> secondsBySteps = new ArrayList<Double>(100);

    public static void main(String[] args) throws IOException {
        BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(inputFile)));
        BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(outputFile)));

        testCasesNum = readInt(reader);

        for (int i = 0; i < testCasesNum; i++) {
            readTestCase(reader);

            String testCaseOutput = String.format(testResultTemplate, i + 1, solveProblem());

            System.out.println(testCaseOutput);
            writer.write(testCaseOutput);
            if (i < testCasesNum - 1)
                writer.newLine();
        }

        writer.close();
        reader.close();
    }

    private static double solveProblem() {
        //init
        currentRate = 2.0;
        currentScore = 0.0;
        secondsBySteps.clear();
        double result = 0.0;

        while(currentScore < costOfWin) {
            secondsBySteps.add(calculateStep());
        }

        for (double stepDelay: secondsBySteps) {
            result += stepDelay;
        }

        return result;
    }

    private static double calculateStep() {
        double delayIfBuyAndFinish = 0.0;
        double delayIfNotBuyAndFinish = 0.0;
        double delayForBuying = 0.0;

        double futurePossibleRate = currentRate + factoryPower;

        delayForBuying = factoryCost / currentRate;

        delayIfBuyAndFinish = delayForBuying + (costOfWin - 0) / futurePossibleRate;

        delayIfNotBuyAndFinish = (costOfWin - currentScore) / currentRate;

        currentRate += factoryPower;

        if (delayIfNotBuyAndFinish < delayIfBuyAndFinish) {
            //not buy and win
            currentScore = costOfWin + 1;
            return delayIfNotBuyAndFinish;
        } else {
            currentScore = 0;
            return delayForBuying;
        }

    }

    private static void readTestCase(BufferedReader reader) throws IOException {
        String [] values = reader.readLine().trim().split(" ");

        factoryCost = Double.parseDouble(values[0]);
        factoryPower = Double.parseDouble(values[1]);
        costOfWin = Double.parseDouble(values[2]);
    }

    private static int readInt(BufferedReader reader) throws IOException {
        return Integer.parseInt(reader.readLine().trim());
    }

}
