package com.andymur.codejam;

import java.io.*;

/**
 *
 */
public class MagicianRunner {

    private static final String inputFile = "C:\\codejam\\magician\\input.txt";
    private static final String outputFile = "C:\\codejam\\magician\\output.txt";
    private final static String testResultTemplate = "Case #%d: %s";
    private static final int ROWNUM = 4;
    private static final int CARDINROW = 4;
    private static final String BAD_MESSAGE = "Bad magician!";
    private static final int BAD_ERRCODE = -1;
    private static final String CHEAT_MESSAGE = "Volunteer cheated!";
    private static final int CHEAT_ERRCODE = -2;

    private static int [][] firstArrangement = new int[ROWNUM][CARDINROW];
    private static int [][] secondArrangement = new int[ROWNUM][CARDINROW];
    private static int firstRow;
    private static int secondRow;
    private static int testCasesNum;

    public static void main(String[] args) throws IOException {

        BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(inputFile)));
        BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(outputFile)));


        testCasesNum = readInt(reader);

        for (int i = 0; i < testCasesNum; i++) {
            String testCaseOutput = "";
            readTestCase(reader, firstArrangement, secondArrangement);

            int magicNumberResult = getMagicNumber(firstArrangement, secondArrangement, firstRow, secondRow);

            if (magicNumberResult > 0) {
                testCaseOutput = String.format(testResultTemplate, i + 1, magicNumberResult);
            } else if (magicNumberResult == BAD_ERRCODE) {
                testCaseOutput = String.format(testResultTemplate, i + 1, BAD_MESSAGE);
            } else if (magicNumberResult == CHEAT_ERRCODE) {
                testCaseOutput = String.format(testResultTemplate, i + 1, CHEAT_MESSAGE);
            }
            System.out.println(testCaseOutput);
            writer.write(testCaseOutput);
            if (i < testCasesNum - 1)
                writer.newLine();
        }

        reader.close();
        writer.close();
    }

    private static int getMagicNumber(int [][] firstArrangement, int [][] secondArrangement, int firstRow, int secondRow) {
        int foundTimes = 0;
        int magicCardValue = 0;

        for (int i = 0; i < CARDINROW; i++) {
            int cardValue = firstArrangement[firstRow][i];


            if (inArray(cardValue, secondArrangement[secondRow])) {
                foundTimes++;
                magicCardValue = cardValue;
            }

            if (foundTimes > 1) break;
        }

        if (foundTimes == 0) {
            return CHEAT_ERRCODE;
        } else if (foundTimes == 1) {
            return magicCardValue;
        } else {
            return BAD_ERRCODE;
        }
    }

    private static void printArrangement(int [][] arrangement) {
        for (int i = 0; i < arrangement.length; i++) {
            int[] row = arrangement[i];
            for (int j = 0; j < row.length; j++) {
                System.out.print(" " + arrangement[i][j]);
            }
            System.out.println("\n");
        }
    }

    private static boolean inArray(int needle, int [] haystack) {
        for (int i = 0; i < haystack.length; i++) {
            int element = haystack[i];

            if (needle == element) {
                return true;
            }
        }

        return false;
    }

    private static void readTestCase(BufferedReader reader, int [][] firstArrangement, int [][] secondArrangement) throws IOException {
        firstRow = readInt(reader) - 1;

        for (int i = 0; i < ROWNUM; i++) {
            firstArrangement[i] = readRow(reader);
        }

        secondRow = readInt(reader) - 1;

        for (int i = 0; i < ROWNUM; i++) {
            secondArrangement[i] = readRow(reader);
        }
    }


    private static int[] readRow(BufferedReader reader) throws IOException {
        String [] rowValues = reader.readLine().split(" ");

        int [] row = new int [CARDINROW];
        int i = 0;

        for (String rowValue: rowValues) {
            row[i++] = Integer.parseInt(rowValue);
        }

        return row;
    }

    private static int readInt(BufferedReader reader) throws IOException {
        return Integer.parseInt(reader.readLine().trim());
    }
}