package com.andymur.codejam;

import java.io.*;
import java.util.ArrayList;
import java.util.List;

/**
 *
 */
public class MineSweeperRunner {

    private static final String inputFile = "C:\\codejam\\minesweeper\\input.txt";
    private static final String outputFile = "C:\\codejam\\minesweeper\\output.txt";

    private static final String testResultTemplate = "Case #%d:\n";
    private static final String IMPOSSIBLE = "Impossible";

    private static final int MINE_CODE = 1;
    private static final int CELL_CODE = 0;
    private static final int CLICK_CODE = 2;
    private static final int VISITED_CODE = 3;

    private static final int DOWN = 0;
    private static final int RIGHT = 1;
    private static final int UP = 2;
    private static final int LEFT = 3;

    private static final char MINE_CHAR = '*';
    private static final char CELL_CHAR = '.';
    private static final char CLICK_CHAR = 'c';
    private static final char VISITED_CHAR = 'v';

    private static int testCasesNum;

    private static int rownum;
    private static int colnum;
    private static int minesnum;

    private static List<Integer> chosenV = new ArrayList<Integer>(100);
    private static List<Integer> chosenH = new ArrayList<Integer>(100);

    private static int[][] board;

    public static void main(String[] args) throws IOException {

        BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(inputFile)));
        BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(outputFile)));

        testCasesNum = readInt(reader);

        for (int i = 0; i < testCasesNum; i++) {
            int chosenVertical = 0;
            int chosenHorizontal = 0;

            readTestCase(reader);
            clearBoard();
            snailBoard();
            getChosen();

            String testCaseOutput = String.format(testResultTemplate, i + 1);
            System.out.print(testCaseOutput);
            writer.write(testCaseOutput);

            if (chosenV.size() > 0 && chosenH.size() > 0) {
                chosenVertical = chosenV.get(0);
                chosenHorizontal = chosenH.get(0);

                visitAllZeroAdjacented();

                if (isThereUnvisited()) {
                    System.out.println(IMPOSSIBLE);
                    writer.write(IMPOSSIBLE);
                } else {
                    resetAllVisited();
                    board[chosenVertical][chosenHorizontal] = CLICK_CODE;

                    printBoard();
                    printBoard(writer);
                }
            } else {
                System.out.println(IMPOSSIBLE);
                writer.write(IMPOSSIBLE);
            }

            if (i < testCasesNum - 1)
                writer.newLine();
        }

        writer.close();
        reader.close();
    }

    private static void getChosen() {
        int chosenIndex = 0;
        for (int i = 0; i < rownum; i++) {
            for (int j = 0; j < colnum; j++) {
                if (isNotMineCell(i, j) && getAdjacentMinesNumber(i, j) == 0) {
                    chosenV.add(i);
                    chosenH.add(j);
                }
            }
        }

    }

    private static void resetAllVisited() {
        for (int i = 0; i < rownum; i++) {
            for (int j = 0; j < colnum; j++) {
                if (board[i][j] == VISITED_CODE) {
                    board[i][j] = CELL_CODE;
                }
            }
        }
    }

    private static void visitAllZeroAdjacented() {
        int size = chosenV.size();
        int vert;
        int hor;

        for (int i = 0; i < chosenV.size(); i++) {
            vert = chosenV.get(i);
            hor = chosenH.get(i);
            board[vert][hor] = VISITED_CODE;
            visitZeroAdjacent(vert, hor);
        }
    }

    private static void visitZeroAdjacent(int vert, int hor) {

        if (vert > 0) {
            if (isNotMineCell(vert - 1, hor)) {
                board[vert - 1][hor] = VISITED_CODE;
            }
        }

        if (vert + 1 < rownum) {
            if (isNotMineCell(vert + 1, hor)) {
                board[vert + 1][hor] = VISITED_CODE;
            }
        }

        if (hor > 0) {
            if (isNotMineCell(vert, hor - 1)) {
                board[vert][hor - 1] = VISITED_CODE;
            }
        }

        if (hor + 1 < colnum) {
            if (isNotMineCell(vert, hor + 1)) {
                board[vert][hor + 1] = VISITED_CODE;
            }
        }

        if (vert > 0 && hor > 0) {
            if (isNotMineCell(vert - 1, hor - 1)) {
                board[vert - 1][hor - 1] = VISITED_CODE;
            }
        }

        if (vert > 0 && hor + 1 < colnum) {
            if (isNotMineCell(vert - 1, hor + 1)) {
                board[vert - 1][hor + 1] = VISITED_CODE;
            }
        }

        if (vert + 1 < rownum && hor > 0) {
            if (isNotMineCell(vert + 1, hor - 1)) {
                board[vert + 1][hor - 1] = VISITED_CODE;
            }
        }

        if (vert + 1 < rownum && hor + 1 < colnum) {
            if (isNotMineCell(vert + 1, hor + 1)) {
                board[vert + 1][hor + 1] = VISITED_CODE;
            }
        }

    }

    private static boolean isThereUnvisited() {
        for (int i = 0; i < rownum; i++) {
            for (int j = 0; j < colnum; j++) {
                if (board[i][j] == CELL_CODE) {
                    return true;
                }
            }
        }

        return false;
    }


    private static boolean isNotMineCell(int vert, int hor) {
        return board[vert][hor] != MINE_CODE;
    }

    private static boolean isMineCell(int vert, int hor) {
        return !isNotMineCell(vert, hor);
    }

    private static boolean isNotVisited(int vert, int hor) {
        return board[vert][hor] != VISITED_CODE;
    }

    private static int getAdjacentMinesNumber(int vert, int hor) {
        int adjacentMineNumber = 0;

        if (vert > 0) {
            if (isMineCell(vert - 1, hor)) {
                adjacentMineNumber++;
            }
        }

        if (vert + 1 < rownum) {
            if (isMineCell(vert + 1, hor)) {
                adjacentMineNumber++;
            }
        }

        if (hor > 0) {
            if (isMineCell(vert, hor - 1)) {
                adjacentMineNumber++;
            }
        }

        if (hor + 1 < colnum) {
            if (isMineCell(vert, hor + 1)) {
                adjacentMineNumber++;
            }
        }

        if (vert > 0 && hor > 0) {
            if (isMineCell(vert - 1, hor - 1)) {
                adjacentMineNumber++;
            }
        }

        if (vert > 0 && hor + 1 < colnum) {
            if (isMineCell(vert - 1, hor + 1)) {
                adjacentMineNumber++;
            }
        }

        if (vert + 1 < rownum && hor > 0) {
            if (isMineCell(vert + 1, hor - 1)) {
                adjacentMineNumber++;
            }
        }

        if (vert + 1 < rownum && hor + 1 < colnum) {
            if (isMineCell(vert + 1, hor + 1)) {
                adjacentMineNumber++;
            }
        }

        return adjacentMineNumber;
    }

    private static void snailBoard() {
        int minesLeft = minesnum;
        int levelNum = 0;

        while(minesLeft > 0) {
            minesLeft = snailLevel(levelNum, levelNum, rownum - levelNum - 1, colnum - levelNum - 1, minesLeft);
            levelNum++;
        }
    }

    //return minesleft;
    private static int snailLevel(int top, int left, int bottom, int right, int minesLeft) {
        int direction = DOWN;
        int vert = top;
        int hor = left;

        while (direction <= LEFT) {
            while(canPutMine(top, left, bottom, right, vert, hor, direction) && minesLeft > 0) {
                minesLeft--;
                board[vert][hor] = MINE_CODE;

                if (!((direction == DOWN && vert == bottom) || (direction == UP && vert == top)))
                    vert = newVert(vert, direction);

                if (!((direction == RIGHT && hor == right) || (direction == LEFT && hor == left)))
                    hor = newHor(hor, direction);
            }
            direction++;
        }

        return minesLeft;
    }

    private static int newVert(int oldVert, int direction) {
        if (direction == LEFT || direction == RIGHT) return oldVert;

        if (direction == DOWN) {
            return oldVert + 1;
        } else {
            return oldVert - 1;
        }
    }

    private static int newHor(int oldHor, int direction) {
        if (direction == DOWN || direction == UP) return oldHor;

        if (direction == RIGHT) {
            return oldHor + 1;
        } else {
            return oldHor - 1;
        }
    }

    private static boolean canPutMine(int top, int left, int bottom, int right, int vert, int hor, int direction) {
        int newVert = newVert(vert, direction);
        int newHor = newHor(hor, direction);

        if (newVert > bottom || newVert < top) {
            return false;
        }

        if (newHor > right || newHor < left) {
            return false;
        }

        return board[vert][hor] != MINE_CODE;
    }

    private static void clearBoard() {
        board = new int[rownum][colnum];
        chosenH.clear();
        chosenV.clear();
    }

    private static String[] boardToPrint() {
        String[] result = new String[rownum];

        for (int i = 0; i < rownum; i++) {
            int [] boardRow = board[i];
            char[] boardRowInChar = new char[colnum];

            for (int j = 0; j < colnum; j++) {
                if (boardRow[j] == MINE_CODE) {
                    boardRowInChar[j] = MINE_CHAR;
                } else if (boardRow[j] == CELL_CODE) {
                    boardRowInChar[j] = CELL_CHAR;
                } else if (boardRow[j] == CLICK_CODE) {
                    boardRowInChar[j] = CLICK_CHAR;
                } else if (boardRow[j] == VISITED_CODE) {
                    boardRowInChar[j] = VISITED_CHAR;
                }
            }

            result[i] = new String(boardRowInChar);
        }

        return result;
    }

    private static void printBoard(BufferedWriter writer) throws IOException {
        String[] stringBoard = boardToPrint();

        for (int i = 0; i < rownum; i++) {
            String boardLine = stringBoard[i];

            writer.write(boardLine);

            if (i < rownum - 1)
                writer.newLine();
        }
    }

    private static void printBoard() {
        String[] stringBoard = boardToPrint();

        for (int i = 0; i < rownum; i++) {
            String boardLine = stringBoard[i];
            System.out.println(boardLine);

        }
    }

    private static void readTestCase(BufferedReader reader) throws IOException {
        String [] values = reader.readLine().trim().split(" ");

        rownum = Integer.parseInt(values[0]);
        colnum = Integer.parseInt(values[1]);
        minesnum = Integer.parseInt(values[2]);
    }

    private static int readInt(BufferedReader reader) throws IOException {
        return Integer.parseInt(reader.readLine().trim());
    }
}
