package codejam.template;

import java.io.File;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.*;

public class CoinJam {

    private Set<String> results = new HashSet<>();
    private Map<String, List<String>> nonTrivialAnswers = new HashMap<>();
    private Random random = new Random();
    private static List<BigInteger> primes = new ArrayList<>();

    private void solve(PrintWriter pw, int n, int j) {

        BigInteger prime = new BigInteger("2");
        for (int k = 0; k < 1000; k++) {
            primes.add(prime);
            prime = prime.nextProbablePrime();
        }

        while(results.size()<j) {
            String test = "1" + getRandomBinaryDigits(n-2) + "1";
            if (validCoinJam(test)) {
                if (!results.contains(test)) {
                    results.add(test);
                    printResult(pw, test);
                }
            }
        }
    }

    private void printResult(PrintWriter pw, String result) {
        pw.print(result + " ");
        List<String> factors = nonTrivialAnswers.get(result);
        for (int k = 0; k < factors.size()-1 ; k++) {
            pw.print(factors.get(k) + " ");
        }
        pw.println(factors.get(8));
    }

    private boolean validCoinJam(String test) {
        List<String> nonTrivialList = new ArrayList<>();
        for (int radix = 2; radix < 11; radix ++) {
            BigInteger integer = new BigInteger(test, radix);
            if (integer.isProbablePrime(1)) {
                return false;
            } else {
                String factor = calculateFactor(integer);
                if (factor == null) {
                    return false;
                }
                else {
                    nonTrivialList.add(factor);
                }
            }
        }
        nonTrivialAnswers.put(test, nonTrivialList);
        return true;
    }

    private String calculateFactor(BigInteger integer) {
        for (BigInteger prime : primes){
            BigInteger[] result = integer.divideAndRemainder(prime);
            if(result[1].equals(BigInteger.ZERO)) {
                return prime.toString();
            }
        }
        return null;
    }

    private String getRandomBinaryDigits(int length) {
        String toReturn = "";
        while (toReturn.length() < length) {
            int randomInt = random.nextInt();
            if (randomInt % 2 == 0) {
                toReturn = toReturn + "0";
            } else {
                toReturn = toReturn + "1";
            }
        }

        return toReturn;
    }

    private void run() throws Exception {
        String name = "CoinJam-small";
        String path = "";

        Locale.setDefault(Locale.US);

        Scanner sc = new Scanner(new File(path + name + ".in"));
        PrintWriter pw = new PrintWriter(path + name + ".out");
//		Scanner sc = new Scanner(System.in);
//		PrintWriter pw = new PrintWriter(System.out);

        int testCases = sc.nextInt();
        for (int testCase = 1; testCase <= testCases; testCase++) {
            int n = sc.nextInt();
            int j = sc.nextInt();
            pw.println("Case #" + testCase + ":");
            solve(pw, n, j);
            pw.flush();
        }

        pw.close();
        sc.close();
    }

    public static void main(String[] args) throws Exception {
        new CoinJam().run();
    }
}