import java.io.File;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;


public class A {
	private static final String INPUT_FILE = "inputs/Asmall-in.txt";
	private static final boolean IS_DEBUG = false;
	
	private final Scanner inputScanner;
	private final int numCases;
	private final String[] outputLines;
	private final List<AComputeJob> jobs = new ArrayList<AComputeJob>();
	private final ExecutorService threadPool = Executors.newFixedThreadPool(4);
	
	public A() throws Exception {
		inputScanner = new Scanner(new File(INPUT_FILE));
		numCases = inputScanner.nextInt();
		outputLines = new String[numCases];
		
		for (int i = 0; i < numCases; i++) {
			jobs.add(new AComputeJob(i));
		}
		
		if (IS_DEBUG) {
			for (int i = 0; i < jobs.size(); i++) {
				jobs.get(i).call();
			}
		} else {
			threadPool.invokeAll(jobs);
		}
		
		FileOutputStream fos = new FileOutputStream("outputs/A-sol.txt");
		PrintStream ps = new PrintStream(fos);
		
		for (int i = 0; i < numCases; i++) {
			ps.println("Case #" + (i+1) + ": " + outputLines[i]);
		}
		
		fos.close();
		
	}
	
	private class AComputeJob implements Callable<Void> {
		private final int num;
		
		private Integer oPos, bPos;
		private int curTime = 0;
		private ArrayList<Integer> oTasks = new ArrayList<Integer>();
		private ArrayList<Integer> bTasks = new ArrayList<Integer>();
		private ArrayList<Pair> allTasks = new ArrayList<Pair>();
		
		private Robot oRobot;
		private Robot bRobot;
		
		public AComputeJob(int num) {
			this.num = num;
			
			oPos = bPos = 1;
			
			int numInstructions = inputScanner.nextInt();
			for (int i = 0; i < numInstructions; i++) {
				char type = inputScanner.next().charAt(0);
				int pos = inputScanner.nextInt();
				allTasks.add(new Pair(pos, type));
				if (type == 'O') {
					oTasks.add(pos);
				} else if (type == 'B') {
					bTasks.add(pos);
				}
				
			}
			
			oRobot = new Robot(oPos, 'O', oTasks);
			bRobot = new Robot(bPos, 'B', bTasks);
			
		}

		@Override
		public Void call() throws Exception {
			String output = "";
			
			while (allTasks.size() > 0) {
				boolean buttonPressed = false;
				buttonPressed |= makeMove(oRobot);
				buttonPressed |= makeMove(bRobot);
				
				if (buttonPressed)
					allTasks.remove(0);
				
				curTime++;
			}
			
			output = "" + curTime;
			
			outputLines[num] = output;
			System.out.println("JOB-" + num + ": Output is " + outputLines[num]);
			return null;
		}

		private boolean makeMove(Robot r) {
			if (IS_DEBUG) {
				System.out.println("Robot " + r.type + " is at " + r.pos);
			}
			
			if (r.tasks.size() == 0)
				return false;
			
			if (allTasks.get(0).type == r.type && allTasks.get(0).pos == r.pos) {
				//Push the button!
				r.tasks.remove(0);
				if (IS_DEBUG) {
					System.out.println("Robot " + r.type + " pushed the button.");
				}
				return true;
			} else if (r.tasks.get(0) != r.pos) {
				//Need to move
				if (r.tasks.get(0) > r.pos)
					r.pos++;
				else
					r.pos--;
				
				if (IS_DEBUG) {
					System.out.println("Robot " + r.type + " moved to " + r.pos);
				}
			} else {
				//Stay still, we're at the button, but it's not our turn.
			}
			return false;
		}
		
	}
	
	public class Pair {
		public int pos;
		public char type;
		public Pair(int pos, char type) {this.pos=pos;this.type=type;}
		public String toString() {return "" + type + pos;}
	}
	
	public class Robot {
		public Robot(int pos, char type, ArrayList<Integer> tasks) {
			super();
			this.pos = pos;
			this.type = type;
			this.tasks = tasks;
		}
		public int pos;
		public char type;
		public ArrayList<Integer> tasks;
		
	}
	
	public static void main(String[] args) throws Exception {
		new A();
	}

}
