import java.io.File;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;


public class A {
	private static final String INPUT_FILE = "inputs/Asmall-in.txt";
	private static final boolean IS_DEBUG = false;
	
	private final Scanner inputScanner;
	private final int numCases;
	private final String[] outputLines;
	private final List<AComputeJob> jobs = new ArrayList<AComputeJob>();
	private final ExecutorService threadPool = Executors.newFixedThreadPool(4);
	
	public A() throws Exception {
		inputScanner = new Scanner(new File(INPUT_FILE));
		numCases = inputScanner.nextInt();
		outputLines = new String[numCases];
		
		for (int i = 0; i < numCases; i++) {
			jobs.add(new AComputeJob(i));
		}
		
		if (IS_DEBUG) {
			for (int i = 0; i < jobs.size(); i++) {
				jobs.get(i).call();
			}
		} else {
			threadPool.invokeAll(jobs);
		}
		
		FileOutputStream fos = new FileOutputStream("outputs/A-sol.txt");
		PrintStream ps = new PrintStream(fos);
		
		for (int i = 0; i < numCases; i++) {
			ps.println("Case #" + (i+1) + ": " + outputLines[i]);
		}
		
		fos.close();
		System.exit(0);
	}
	
	private class AComputeJob implements Callable<Void> {
		private final int num;
		char [][] pat;
		int nRows, nCols;
		
		
		public AComputeJob(int num) {
			this.num = num;
			
			nRows = inputScanner.nextInt();
			nCols = inputScanner.nextInt();
			
			pat = new char[nRows][nCols];
			
			for (int i = 0; i < nRows; i++) {
				String row = inputScanner.next();
				for (int j = 0; j < nCols; j++) {
					pat[i][j] = row.charAt(j);
				}
			}
			
			
		}

		

		
		@Override
		public Void call() throws Exception {
			String output = "";
			StringBuffer sb = new StringBuffer();
			
			boolean failed = false;
			
			try {
				for (int i = 0; i < nRows && !failed; i++) {
					for (int j = 0; j < nCols && !failed; j++) {
						if (pat[i][j] == '#') {
							if (pat[i+1][j] == '#' && pat[i][j+1] == '#' && pat [i+1][j+1] == '#') {
								pat[i][j] = '/';
								pat[i][j+1] = '\\';
								pat[i+1][j] = '\\';
								pat[i+1][j+1] = '/';
							} else {
								failed = true;
							}
						}
					}
				}
			} catch (ArrayIndexOutOfBoundsException e) {
				failed = true;
			}
			
			if (failed) {
				sb.append("\nImpossible");
			} else {
				for (int i = 0; i < nRows; i++) {
					sb.append("\n");
					for (int j = 0; j < nCols; j++) {
						sb.append(pat[i][j]);
					}
				}
			}
			
			
			output = sb.toString();
			
			
			

			outputLines[num] = output;
			System.out.println("JOB-" + num + ": Output is " + outputLines[num]);
			return null;
		}

		
	}
	

	
	
	public static void main(String[] args) throws Exception {
		new A();
	}

}
