import java.io.File;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;


public class C {
	private static final String INPUT_FILE = "inputs/Csmall-in.txt";
	private static final boolean IS_DEBUG = false;
	
	private final Scanner inputScanner;
	private final int numCases;
	private final String[] outputLines;
	private final List<CComputeJob> jobs = new ArrayList<CComputeJob>();
	private final ExecutorService threadPool = Executors.newFixedThreadPool(4);
	
	public C() throws Exception {
		inputScanner = new Scanner(new File(INPUT_FILE));
		numCases = inputScanner.nextInt();
		outputLines = new String[numCases];
		
		for (int i = 0; i < numCases; i++) {
			jobs.add(new CComputeJob(i));
		}
		
		if (IS_DEBUG) {
			for (CComputeJob job : jobs) {
				job.call();
			}
		} else {
			threadPool.invokeAll(jobs);
		}
		
		FileOutputStream fos = new FileOutputStream("outputs/C-sol.txt");
		PrintStream ps = new PrintStream(fos);
		
		for (int i = 0; i < numCases; i++) {
			ps.println("Case #" + (i+1) + ": " + outputLines[i]);
		}
		
		fos.close();
		
	}
	
	private class CComputeJob implements Callable<Void> {
		private final int num;
		private final ArrayList<Integer> nums = new ArrayList<Integer>();
		private int max = 0;
		private boolean solFound = false;
		
		public CComputeJob(int num) {
			this.num = num;
			int numOfNums = inputScanner.nextInt();
			for (int i = 0; i < numOfNums; i++) {
				nums.add(inputScanner.nextInt());
			}
		}

		@Override
		public Void call() throws Exception {
			String output = "";
			int mask = 0;
			
			for (mask = 0; mask < (1 << nums.size()); mask++) {
				ArrayList<Integer> group1 = new ArrayList<Integer>();
				ArrayList<Integer> group2 = new ArrayList<Integer>();
				
				makeArrays(nums, mask, group1, group2);
				if (group1.isEmpty() || group2.isEmpty()) {
					continue;
				}
				if (xorSum(group1) != xorSum(group2)) {
					continue;
				}
				
				int myMax = Math.max(sum(group1), sum(group2));
				max = Math.max(max, myMax);
				solFound = true;
			}
			
			if (!solFound) {
				output = "NO";
			} else {
				output = "" + max;
			}
			
			outputLines[num] = output;
			System.out.println("JOB-" + num + ": Output is " + outputLines[num]);
			return null;
		}
		
	}

	public int sum(ArrayList<Integer> numbers) {
		int sum = 0;
		for (int num : numbers) {
			sum += num;
		}
		return sum;
	}
	
	public int xorSum(ArrayList<Integer> numbers) {
		int sum = 0;
		for (int num : numbers) {
			sum ^= num;
		}
		return sum;
	}
	
	public void makeArrays(ArrayList<Integer> startSet, int mask, ArrayList<Integer> posSet, ArrayList<Integer> negSet) {
		for (int i = 0; i < startSet.size(); i++) {
			if ((mask & (1 << i)) != 0) {
				posSet.add(startSet.get(i));
			} else {
				negSet.add(startSet.get(i));
			}
		}
		
		if (IS_DEBUG) {
			System.out.print("PosSet: ");
			for (Integer num : posSet) {
				System.out.print("" + num + " ");
			}
			System.out.print("   NegSet: ");
			for (Integer num : negSet) {
				System.out.print("" + num + " ");
			}
			System.out.println();
		}
	}
	
	public static void main(String[] args) throws Exception {
		new C();
		
		
	}

}
