import java.io.File;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;


public class C {
	private static final String INPUT_FILE = "inputs/Csmall-in.txt";
	private static final boolean IS_DEBUG = false;
	
	private final Scanner inputScanner;
	private final int numCases;
	private final String[] outputLines;
	private final List<CComputeJob> jobs = new ArrayList<CComputeJob>();
	private final ExecutorService threadPool = Executors.newFixedThreadPool(4);
	
	public C() throws Exception {
		inputScanner = new Scanner(new File(INPUT_FILE));
		numCases = inputScanner.nextInt();
		outputLines = new String[numCases];
		
		for (int i = 0; i < numCases; i++) {
			jobs.add(new CComputeJob(i));
		}
		
		if (IS_DEBUG) {
			for (CComputeJob job : jobs) {
				job.call();
			}
		} else {
			threadPool.invokeAll(jobs);
		}
		
		FileOutputStream fos = new FileOutputStream("outputs/C-sol.txt");
		PrintStream ps = new PrintStream(fos);
		
		for (int i = 0; i < numCases; i++) {
			ps.println("Case #" + (i+1) + ": " + outputLines[i]);
		}
		
		fos.close();
		
	}
	
	private class CComputeJob implements Callable<Void> {
		private final int num;
		int n, low, high;
		int [] others;
		
		public CComputeJob(int num) {
			this.num = num;
			
			n = inputScanner.nextInt();
			low = inputScanner.nextInt();
			high = inputScanner.nextInt();
			
			others = new int[n];
			
			for (int i = 0; i < n; i ++) {
				others[i] = inputScanner.nextInt();
			}
			
		}

		@Override
		public Void call() throws Exception {
			String output = "";
			boolean found = false;
			int sol = 0;
			
			for (int i = low; i <= high && !found; i++) {
				found = true;
				sol = i;
				for (int j = 0; j < n && found; j++) {
					if (!happyDivide(i,others[j])) {
						found = false;
					}
				}
				
			}
			
			output = found ? "" + sol : "NO";
			
			
			outputLines[num] = output;
			System.out.println("JOB-" + num + ": Output is " + outputLines[num]);
			return null;
		}

		private boolean happyDivide(int i, int j) {
			if (i%j == 0 || j%i == 0)
				return true;
			return false;
		}
		
	}

	
	public static void main(String[] args) throws Exception {
		new C();
		
		
	}

}
