import java.io.File;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;


public class B {
	private static final String INPUT_FILE = "inputs/Bsmall-in.txt";
	private static final boolean IS_DEBUG = false;
	
	private final Scanner inputScanner;
	private final int numCases;
	private final String[] outputLines;
	private final List<BComputeJob> jobs = new ArrayList<BComputeJob>();
	private final ExecutorService threadPool = Executors.newFixedThreadPool(4);
	
	public B() throws Exception {
		inputScanner = new Scanner(new File(INPUT_FILE));
		numCases = inputScanner.nextInt();
		outputLines = new String[numCases];
		
		for (int i = 0; i < numCases; i++) {
			jobs.add(new BComputeJob(i));
		}
		
		if (IS_DEBUG) {
			for (int i = 0; i < jobs.size(); i++) {
				jobs.get(i).call();
			}
		} else {
			threadPool.invokeAll(jobs);
		}
		
		FileOutputStream fos = new FileOutputStream("outputs/B-sol.txt");
		PrintStream ps = new PrintStream(fos);
		
		for (int i = 0; i < numCases; i++) {
			ps.println("Case #" + (i+1) + ": " + outputLines[i]);
		}
		
		fos.close();
		
		System.exit(0);
		
	}
	
	private class BComputeJob implements Callable<Void> {
		private final int num;
		
		private final Map<Character, Map<Character, Character>> combiners = new HashMap<Character, Map<Character, Character>>();
		private final Map<Character, List<Character>> destroyers = new HashMap<Character, List<Character>>();
		private final List<Character> seq = new ArrayList<Character>();
		
		public BComputeJob(int num) {
			this.num = num;
			
			// Get the parameters needed from the input scanner
			int numCombiners = inputScanner.nextInt();
			for (int i = 0; i < numCombiners; i++) {
				String combiner = inputScanner.next();
				char base1 = combiner.charAt(0);
				char base2 = combiner.charAt(1);
				char other = combiner.charAt(2);
				
				if (combiners.get(base1) == null) {
					combiners.put(base1, new HashMap<Character, Character>());
				}
				
				if (combiners.get(base2) == null) {
					combiners.put(base2, new HashMap<Character, Character>());
				}
				
				combiners.get(base1).put(base2, other);
				combiners.get(base2).put(base1, other);
			}
			
			int numDestroyers = inputScanner.nextInt();
			for (int i = 0 ; i < numDestroyers; i++) {
				String destroyer = inputScanner.next();
				char base1 = destroyer.charAt(0);
				char base2 = destroyer.charAt(1);
				
				if (destroyers.get(base1) == null) {
					destroyers.put(base1, new ArrayList<Character>());
				}
				if (destroyers.get(base2) == null) {
					destroyers.put(base2, new ArrayList<Character>());
				}
				
				destroyers.get(base1).add(base2);
				destroyers.get(base2).add(base1);
			}
			
			int numBases = inputScanner.nextInt();
			String bases = inputScanner.next();
			for (int i = 0; i < bases.length(); i++) {
				seq.add(bases.charAt(i));
			}
		}

		@Override
		public Void call() throws Exception {
			String output = "";
			ArrayList<Character> list = new ArrayList<Character>();
			
			for (char base : seq) {
				list.add(base);
				if (list.size() == 1)
					continue;
				
				//first combiners
				char last = list.get(list.size() - 2);
				if (combiners.containsKey(base)) {
					if (combiners.get(base).containsKey(last)) {
						char replace = combiners.get(base).get(last);
						list.remove(list.size()-1);
						list.remove(list.size()-1);
						list.add(replace);
						continue;
					}
				}
				
				//now destroyers
				if (destroyers.containsKey(base)) {
					List<Character> matches = destroyers.get(base);
					for (char match : matches) {
						if (list.contains(match)) {
							list.clear();
							break;
						}
					}
					
				}
			}
			
			StringBuilder sb = new StringBuilder();
			sb.append("[");
			for ( int i = 0; i < list.size(); i++) {
				sb.append(list.get(i));
				if (list.size() > (i+1)) {
					sb.append(", ");
				}
			}
			sb.append("]");
			output = sb.toString();
			
			outputLines[num] = output;
			System.out.println("JOB-" + num + ": Output is " + outputLines[num]);
			return null;
		}
		
	}
	
	public class CombinerPair {
		public CombinerPair(char other, char result) {
			super();
			this.other = other;
			this.result = result;
		}
		public char other;
		public char result;
		
	}
	
	public static void main(String[] args) throws Exception {
		new B();
	}

}
