import java.io.File;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;


public class A {
	private static final String INPUT_FILE = "inputs/Alarge-in.txt";
	private static final boolean IS_DEBUG = false;
	
	private final Scanner inputScanner;
	private final int numCases;
	private final String[] outputLines;
	private final List<AComputeJob> jobs = new ArrayList<AComputeJob>();
	private final ExecutorService threadPool = Executors.newFixedThreadPool(4);
	
	public A() throws Exception {
		inputScanner = new Scanner(new File(INPUT_FILE));
		numCases = inputScanner.nextInt();
		outputLines = new String[numCases];
		
		for (int i = 0; i < numCases; i++) {
			jobs.add(new AComputeJob(i));
		}
		
		if (IS_DEBUG) {
			for (int i = 0; i < jobs.size(); i++) {
				jobs.get(i).call();
			}
		} else {
			threadPool.invokeAll(jobs);
		}
		
		FileOutputStream fos = new FileOutputStream("outputs/A-sol.txt");
		PrintStream ps = new PrintStream(fos);
		
		for (int i = 0; i < numCases; i++) {
			ps.println("Case #" + (i+1) + ": " + outputLines[i]);
		}
		
		fos.close();
		System.exit(0);
	}
	
	private class AComputeJob implements Callable<Void> {
		private final int num;
		char [][] sched;
		double [] numWins;
		double [] numGames;
		double [] wp;
		double [] owp;
		double [] oowp;
		double [] rpi;
		int numTeams;
		
		public AComputeJob(int num) {
			this.num = num;
			
			numTeams = inputScanner.nextInt();
			sched = new char[numTeams][numTeams];
			numWins = new double[numTeams];
			numGames = new double[numTeams];
			wp = new double[numTeams];
			owp = new double[numTeams];
			oowp = new double[numTeams];
			rpi = new double[numTeams];
			
			for (int i = 0; i < numTeams; i++) {
				String teamSched = inputScanner.next();
				for (int j = 0; j < numTeams; j++) {
					sched[i][j] = teamSched.charAt(j);
				}
			}
			
			
			
			
			
		}

		

		private void makeWp(int t) {
			int numCurWins = 0;
			int numCurGames = 0;
			
			for (int i = 0; i < numTeams; i++) {
				if (sched[t][i] == '1') {
					numCurWins++;
					numCurGames++;
				} else if (sched[t][i] == '0') {
					numCurGames++;
				}
			}
			
			numWins[t] = numCurWins;
			numGames[t] = numCurGames;
			wp[t] = (double)numCurWins / (double)numCurGames;
			
		}
		
		private void makeOwp(int t) {
			double sum = 0.0;
			double divisor = 0.0;

			for (int j = 0; j < numTeams; j++) {
				if (sched[t][j] == '1') {
					sum += (numWins[j] / (numGames[j] - 1.0));
					divisor += 1.0;
				} else if (sched[t][j] == '0') {
					sum += ((numWins[j] - 1.0) / (numGames[j] - 1.0));
					divisor += 1.0;
				}
			}
			
			owp[t] = sum / divisor;

		}
		
		private void makeOowp(int t) {
			double sum = 0.0;
			double divisor = 0.0;
			
			for (int i = 0; i < numTeams; i++) {
				if (sched[t][i] == '0' || sched[t][i] == '1') {
					sum += owp[i];
					divisor += 1.0;
				}
			}
			
			oowp[t] = sum / divisor;
		}
		
		private void makeRpi(int t) {
			rpi[t] = 0.25 * wp[t] + 0.5 * owp[t] + 0.25 * oowp[t];
		}

		@Override
		public Void call() throws Exception {
			String output = "";
			StringBuffer sb = new StringBuffer();
			
			
			for (int i = 0; i < numTeams; i++) {
				makeWp(i);
			}
			
			for (int i = 0; i < numTeams; i++) {
				makeOwp(i);
			}
			
			for (int i = 0; i < numTeams; i++) {
				sb.append("\n");
				makeOowp(i);
				makeRpi(i);
				sb.append("" + rpi[i]);
			}
			
			output = sb.toString();
			
			
			

			outputLines[num] = output;
			System.out.println("JOB-" + num + ": Output is " + outputLines[num]);
			return null;
		}

		
	}
	

	
	
	public static void main(String[] args) throws Exception {
		new A();
	}

}
