import java.util.*;
import java.io.*;
import java.text.*;


public class FlySwatter {
	
	public Vector<Double> x,y;
	public double f, R, R1, t, r, g;
	
	public FlySwatter(double f, double R, double t, double r, double g) {
		this.f = f;
		this.R = R;
		this.t = t + f;
		this.r = r + f;
		this.g = g - 2*f;
		this.R1 = R - this.t;
		x = new Vector<Double>();
		y = new Vector<Double>();
	}
	
	public double findTriangleArea(double angle) {
		double sine = Math.sin(angle);
		return this.R1*this.R1*sine/2;
	}
	
	public double findCurveArea(double xl, double yl, double xr, double yr) {
		double sine = (Math.sqrt(Math.pow(xl-xr,2)+Math.pow(yl-yr,2)))/(2*this.R1);
		double curveAngle = 2*Math.asin(sine);
		return curveAngle/(2*Math.PI)*(Math.PI*Math.pow(this.R1,2))-this.findTriangleArea(curveAngle);
	}
	
	public double findResult() {
		double result = 0.0;
		if (this.g <= 0) 
			result = 0;
		else {
			int numPoint = x.size();
			for (int i = 0; i < numPoint; i++) {
				double xx = x.elementAt(i), yy = y.elementAt(i);
				if (inSmallRing(xx+g, yy+g))
					result += g*g;
				else if (!inSmallRing(xx+g, yy) && inSmallRing(xx, yy+g)) {
					double yr = yy, xr = Math.sqrt(this.R1*this.R1 - yr*yr);
					double yl = yy+g, xl = Math.sqrt(this.R1*this.R1 - yl*yl);
					double curveArea = this.findCurveArea(xl, yl, xr, yr);
					result = result + curveArea + (Math.abs(xr-xx)+Math.abs(xl-xx))*g/2;
				}
				else if (inSmallRing(xx+g, yy) && !inSmallRing(xx, yy+g)) {
					double xl = xx, yl = Math.sqrt(this.R1*this.R1 - xl*xl);
					double xr = xx+g, yr = Math.sqrt(this.R1*this.R1 - xr*xr);
					double curveArea = this.findCurveArea(xl, yl, xr, yr);
					result = result + curveArea + (Math.abs(yl-yy)+Math.abs(yr-yy))*g/2;
				}
				else if (!inSmallRing(xx+g, yy) && !inSmallRing(xx, yy+g)) {
					double yr = yy, xr = Math.sqrt(this.R1*this.R1 - yr*yr);
					double xl = xx, yl = Math.sqrt(this.R1*this.R1 - xl*xl);
					double curveArea = this.findCurveArea(xl, yl, xr, yr);
					result = result + curveArea + (Math.abs(xl-xr)*Math.abs(yl-yr))/2;
				}
				else {
					double xr = xx+g, yr = Math.sqrt(this.R1*this.R1 - xr*xr);
					double yl = yy+g, xl = Math.sqrt(this.R1*this.R1 - yl*yl);
					double curveArea = this.findCurveArea(xl, yl, xr, yr);
					result = result + curveArea + g*Math.abs(xl-xx) + (g+Math.abs(yr-yy))*(xr-xl)/2;
				}
			}
			result = result/(Math.PI*Math.pow(this.R, 2));
		}
		return result;
	}
	
	public boolean inSmallRing(double x, double y) {
		return (x*x+y*y < this.R1 * this.R1);
	}
	
	public void findListXY() {
		double xx = r;
		while (xx < this.R1) {
			double yy = r;
			while (this.inSmallRing(xx, yy)) {
				this.x.addElement(xx);
				this.y.addElement(yy);
				yy = yy + this.g + this.r*2; 
			}
			xx = xx + this.g + this.r*2;
		}
	}
	
	static public void main(String[] args) throws Exception {
		
		File fileinp = new File("file.inp");
		Scanner sc = new Scanner(fileinp);
		File fileout = new File("file.out");
		fileout.createNewFile();
		PrintWriter pw = new PrintWriter(new FileWriter("file.out"));
		
		int noOfTestCase = sc.nextInt();
		
		for (int index = 1; index <= noOfTestCase; index++) {
			FlySwatter fs = new FlySwatter(sc.nextDouble(), sc.nextDouble(), sc.nextDouble(), sc.nextDouble(), sc.nextDouble());
			fs.findListXY();
			double result = 1 - 4 * fs.findResult();
			DecimalFormat df = new DecimalFormat("0.000000");
			pw.println("Case #"+index+": "+ df.format(result));
		}
		
		pw.close();
	}
	
}
