package com.google.codejam;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

public class Magicka2011 {

	private File inputFile = new File("B-large.in");
	private File outputFile = new File("B-large.out");

	// Reader Writer references
	FileReader reader;
	BufferedReader bufReader;
	FileWriter writer;
	BufferedWriter buffWriter;
	
	private int numCases;
	private int cVal;
	private int dVal;
	private int nVal;
	private Map<String, String> combines;
	private Map<String, Set<String>> opposites;
	private String cStrings;
	private String dStrings;
	private String inputString;
	private boolean checkCombine;
	private boolean checkOpposites;
	
	private Set<String> outputStringSet;
	private String finalOutputString;
	private List<String> outputStringList;
	

	public void generateOutput(){
	
		try {
			reader = new FileReader(inputFile);
			writer = new FileWriter(outputFile);
			bufReader = new BufferedReader(reader);
			buffWriter = new BufferedWriter(writer);
			
			String caseLine = bufReader.readLine();
			numCases = Integer.parseInt(caseLine);
		
			for(int i=0; i< numCases; i++){
				
				caseLine = bufReader.readLine();
				
				this.initialize(caseLine);
				
				this.prepareOutputList();
				
				this.prepareOutputString();
				
				// Write the output to the output writer
				buffWriter.write("Case #" + (i+1) + ": " + finalOutputString);
				buffWriter.newLine();
			}
			
			buffWriter.close();	writer.close();
			bufReader.close();	reader.close();
			
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	private void prepareOutputString() {

		finalOutputString = "[";
		
		if(!outputStringList.isEmpty()){
			Iterator<String> listIter = outputStringList.iterator();

			while (listIter.hasNext()) {
				String string = (String) listIter.next();
				
				finalOutputString += string + ", ";
			}
			
			finalOutputString = finalOutputString.substring(0,finalOutputString.length() - 2);
		}
				
		finalOutputString += "]";
	}

	private void prepareOutputList() {

		char[] inputChars = inputString.toCharArray();
		
		for (char c : inputChars) {
			String nextChar = c + "";
			if(checkCombine || checkOpposites) {
				if(!outputStringList.isEmpty()){
					String prevChar = outputStringList.get(outputStringList.size() - 1);
					boolean charChanged = false;
					if(checkCombine){
						String newChar = this.checkCombination(prevChar + nextChar, nextChar);
						if(!newChar.equals(nextChar)){
							nextChar = newChar;
							charChanged = true;
						}
					}
					if(!charChanged && checkOpposites){
						boolean oppositeFound = this.checkOppositeVals(nextChar);
						if(oppositeFound){
							continue;
						}
					}
				}	
			}
			this.addToOutputs(nextChar);
		}
	}

	private boolean checkOppositeVals(String nextChar) {
		Set<String> oppositesSet = opposites.get(nextChar);
		boolean oppositeFound = false;
		
		if(oppositesSet != null){
			Iterator<String> setIter = oppositesSet.iterator();
			while (setIter.hasNext()) {
				String string = (String) setIter.next();
				
				if(outputStringSet.contains(string)){
					this.outputStringList = new LinkedList<String>();
					this.outputStringSet = new TreeSet<String>();
					oppositeFound = true;
					break;
				}
			}
		}
		
		return oppositeFound;
	}

	private String checkCombination(String string, String nextChar1) {

		if(combines.containsKey(string)){
			nextChar1 = combines.get(string);
			String prevChar = outputStringList.remove(outputStringList.size() - 1);
			if(!outputStringList.contains(prevChar)){
				outputStringSet.remove(prevChar);
			}
		}
		return nextChar1;
	}

	private void addToOutputs(String nextChar) {
		outputStringList.add(nextChar);
		outputStringSet.add(nextChar);
	}

	/**
	 * Initialize the Magicka engine for current test case
	 * 
	 * @param caseLine
	 */
	private void initialize(String caseLine) {

		checkCombine = false;
		checkOpposites = false;
		combines = new HashMap<String, String>();
		opposites = new HashMap<String, Set<String>>();
		cStrings = "";
		dStrings = "";
		
		outputStringList = new LinkedList<String>();
		outputStringSet = new TreeSet<String>();
		
		int lastIndex = caseLine.indexOf(" ");
		this.cVal = Integer.parseInt(caseLine.substring(0, lastIndex++));
		//System.out.println("C : " + cVal);
		
		int x=0;
		
		if(cVal != 0 ){
			checkCombine = true;
			x = (cVal * 3) + (cVal - 1);
			cStrings = caseLine.substring(lastIndex, lastIndex + x);
			//System.out.println("CStrings : " + cStrings);
			
			this.loadCombinations(cStrings);
			
			lastIndex = lastIndex + x + 1;
		}
		
		String substr = caseLine.substring(lastIndex);
		//System.out.println(substr);
		this.dVal = Integer.parseInt(caseLine.substring(lastIndex, lastIndex + substr.indexOf(" ")));
		//System.out.println("D : " + dVal);
		lastIndex += substr.indexOf(" ") + 1;
		
		if(dVal != 0){
			checkOpposites = true;
			x = (dVal * 2) + (dVal - 1);
			dStrings = caseLine.substring(lastIndex, lastIndex + x);
			//System.out.println("DStrings : " + dStrings);
			
			this.loadOpposites(dStrings);
			
			lastIndex = lastIndex + x + 1;
		}
		
		substr = caseLine.substring(lastIndex);
		this.nVal = Integer.parseInt(caseLine.substring(lastIndex, lastIndex + substr.indexOf(" ")));
		//System.out.println("N : " + nVal);
		lastIndex += substr.indexOf(" ") + 1;
		
		this.inputString = caseLine.substring(lastIndex);
		//System.out.println("Input : " + inputString);
	}

	private void loadOpposites(String dStrings2) {

		String[] oppositeCombs = dStrings2.split(" ");
		
		for (String string : oppositeCombs) {
			char[] charsArr = string.toCharArray();
			String charA = charsArr[0] + "";
			String charB = charsArr[1] + "";
			
			if(opposites.containsKey(charA)){
				opposites.get(charA).add(charB);
			} else {
				Set<String> oppositesSet = new TreeSet<String>();
				oppositesSet.add(charB);
				opposites.put(charA, oppositesSet);
			}
			
			if(opposites.containsKey(charB)){
				opposites.get(charB).add(charA);
			} else {
				Set<String> oppositesSet = new TreeSet<String>();
				oppositesSet.add(charA);
				opposites.put(charB, oppositesSet);
			}
			
		}
	}

	private void loadCombinations(String cStrings2) {

		String[] combinationStrings = cStrings2.split(" ");
		
		for (String string : combinationStrings) {
			char[] charsArr = string.toCharArray();
			String charA = charsArr[0] + "";
			String charB = charsArr[1] + "";
			String charC = charsArr[2] + "";

			combines.put(charA + charB, charC);
			combines.put(charB + charA, charC);
		}
	
	}

	public static void main(String[] args) {
		Magicka2011 cl = new Magicka2011();
		cl.generateOutput();
	}
}
