
package cj.round.two.a;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.text.DateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.StringTokenizer;

/**
 * 
 * @author ankur.goenka
 */
public class Base {
    /**
     * change problem number and create corresponding file inputfile:
     * baseDirPath + problemName+ "\\input\\" + problemName + attemptNumber +
     * ".txt"; example: C:\cj\A\input\A1.txt outputfile: baseDirPath +
     * problemName+ "\\output\\" + problemName + attemptNumber + "Out.txt";
     * example: C:\cj\A\output\A1Out.txt
     */

    public static String problemName = "A";
    public static String attemptNumber = "-large";

    public long newdirs = 0;

    public void process() throws Exception {

        int totalNumberOfTests = getInt();

        for (int testCaseNumber = 1; testCaseNumber <= totalNumberOfTests; testCaseNumber++) {
            newdirs = 0;
            HashMap<String, HashMap> rootDirsOnSystem = new HashMap<String, HashMap>();
            int numberOfOldDirs = getInt();
            int numberOfDirsToBeCreated = getInt();

            for (int oldDirNumber = 0; oldDirNumber < numberOfOldDirs; oldDirNumber++) {
                String oldDirName = getLine();
                StringTokenizer dirNames = new StringTokenizer(oldDirName, "/");
                addDirs(dirNames, rootDirsOnSystem, false);

            }
            
            for (int newDirNumber = 0; newDirNumber < numberOfDirsToBeCreated; newDirNumber++) {
                String newDirName = getLine();
                StringTokenizer dirNames = new StringTokenizer(newDirName, "/");
                addDirs(dirNames, rootDirsOnSystem, true);

            }

            printTestResult(testCaseNumber, newdirs);
        }

    }

    void addDirs(StringTokenizer dirNames, HashMap<String, HashMap> parentDirMap, boolean areNew) {
        if (dirNames.hasMoreTokens()) {
            String dirName = dirNames.nextToken();
            HashMap<String, HashMap> childMap = parentDirMap.get(dirName);
            if (childMap == null) {
                childMap = new HashMap<String, HashMap>();
                parentDirMap.put(dirName, childMap);
                if (areNew) {
                    mkDir();
                }
            }
            addDirs(dirNames, childMap, areNew);
        }
    }

    void mkDir() {
        newdirs++;
    }

    /**
     * Dont touch code below this
     */
    public StringTokenizer tokens = null;
    public BufferedReader in = null;
    public BufferedWriter out = null;

    public String baseDirPath = "C:\\cj\\";

    public static void main(String[] args) throws Exception {
        long startTime = System.currentTimeMillis();
        System.out.println("going to solve problem: '" + problemName + "' attempt number: '" + attemptNumber + "'");
        System.out.println("Start time: " + DateFormat.getDateTimeInstance().format(new Date()));
        Base base = null;
        try {
            base = new Base();
            base.init();
            base.process();
        } finally {
            base.cleanup();

            System.out.println("End time: " + DateFormat.getDateTimeInstance().format(new Date()));
            long endTime = System.currentTimeMillis();
            System.out.println("runtime: " + (endTime - startTime));
        }

    }

    public void cleanup() throws Exception {
        if (in != null) {
            in.close();
        }
        if (out != null) {
            out.flush();
            out.close();
        }
    }

    public void init() throws Exception {
        String inputFileName = baseDirPath + problemName + "\\input\\" + problemName + attemptNumber + ".txt";
        System.out.println("inputFile: " + inputFileName);
        in = new BufferedReader(new FileReader(inputFileName));

        String outputFileName = baseDirPath + problemName + "\\output\\" + problemName + attemptNumber + "Out.txt";
        System.out.println("outputFile: " + outputFileName);
        out = new BufferedWriter(new FileWriter(outputFileName));
    }

    public void print(String line) throws Exception {
        out.write(line);
    }

    public void println() throws Exception {
        out.newLine();
    }

    public void println(String line) throws Exception {
        out.write(line);
        out.newLine();
        System.out.println(line);
    }

    public void printTestResult(int caseNumber, String result) throws Exception {
        println("Case #" + caseNumber + ": " + result);
    }

    public void printTestResult(int caseNumber, long result) throws Exception {
        println("Case #" + caseNumber + ": " + result);
    }

    public void printTestResult(int caseNumber, int result) throws Exception {
        println("Case #" + caseNumber + ": " + result);
    }

    public String getLine() throws IOException {
        return in.readLine();
    }

    public String getString() throws IOException {
        while (tokens == null || !tokens.hasMoreTokens())
            tokens = new StringTokenizer(getLine());
        return tokens.nextToken();
    }

    public int getInt() throws IOException {
        return Integer.parseInt(getString());
    }

    public long getLong() throws IOException {
        return Long.parseLong(getString());
    }

    public double getDouble() throws IOException {
        return Double.parseDouble(getString());
    }

    public BigInteger getBigInt() throws IOException {
        return new BigInteger(getString());
    }
}
