package com.walltor;

import java.io.BufferedReader;
import java.io.FileReader;
import java.util.HashSet;
import java.util.Set;

public class Tomek {

	static final Box X = new Box('X');
	static final Box O = new Box('O');
	static final Box DOT = new Box('.');
	static final Box T = new Box('T');

	public static State checkState(String[] input) {

		Box[][] boxes = new Box[4][4];

		Set<Box> distinctBoxes = new HashSet<Box>();

		for (int i = 0; i < 4; i++) {
			for (int j = 0; j < 4; j++) {
				boxes[i][j] = new Box(input[i].charAt(j));
				distinctBoxes.add(boxes[i][j]);
			}
		}

		// check rows
		for (int i = 0; i < 4; i++) {
			Set<Box> row = new HashSet<Box>();
			for (int j = 0; j < 4; j++) {
				row.add(boxes[i][j]);
			}
			row.remove(T);

			if (row.size() == 1) {
				if (row.contains(X))
					return State.X_WON;
				else if (row.contains(O))
					return State.O_WON;
			}
		}

		// check cloumns
		for (int i = 0; i < 4; i++) {
			Set<Box> column = new HashSet<Box>();
			for (int j = 0; j < 4; j++) {
				column.add(boxes[j][i]);
			}
			column.remove(T);
			if (column.size() == 1) {
				if (column.contains(X))
					return State.X_WON;
				else if (column.contains(O))
					return State.O_WON;
			}
		}

		// First diagonal
		Set<Box> diagonal = new HashSet<Box>();
		for (int i = 0; i < 4; i++) {
			diagonal.add(boxes[i][i]);
		}
		diagonal.remove(T);
		if (diagonal.size() == 1) {
			if (diagonal.contains(X))
				return State.X_WON;
			else if (diagonal.contains(O))
				return State.O_WON;
		}

		// second diagonal
		diagonal = new HashSet<Box>();
		for (int i = 0; i < 4; i++) {
			diagonal.add(boxes[i][3 - i]);
		}
		diagonal.remove(T);
		if (diagonal.size() == 1) {
			if (diagonal.contains(X))
				return State.X_WON;
			else if (diagonal.contains(O))
				return State.O_WON;
		}

		// check draw
		if (distinctBoxes.contains(DOT))
			return State.INCOMPLETE;
		else
			return State.DRAW;

	}

	public static void main(String[] args) throws Exception {
		BufferedReader in = new BufferedReader(new FileReader("in.txt"));
		int testCases = Integer.parseInt(in.readLine());
		for (int i = 0; i < testCases; i++) {
			String[] input = new String[4];
			for (int l = 0; l < 4; l++) {
				input[l] = in.readLine();
			}
			System.out.print("Case #"+(i+1)+": ");
			switch (checkState(input)) {
			case X_WON:
				System.out.println("X won");
				break;
			case O_WON:
				System.out.println("O won");
				break;
			case DRAW:
				System.out.println("Draw");
				break;
			case INCOMPLETE:
				System.out.println("Game has not completed");
				break;
			}

			// Empty
			in.readLine();
		}
		in.close();
	}
}

class Box {
	char c;

	Box(char c) {
		this.c = c;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + c;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Box other = (Box) obj;
		if (c != other.c)
			return false;
		return true;
	}
}

enum State {
	X_WON, O_WON, DRAW, INCOMPLETE
}
