import java.io.*;
import java.util.Deque;
import java.util.LinkedList;

public class Treasure {
    static class Chest {
        int[] keys = new int[25];
        int key;

        void addKeysTo(int[] keys) {
            for (int i = 0; i < 25; i++) {
                keys[i] += this.keys[i];
            }
        }

        void removeKeysFrom(int[] keys) {
            for (int i = 0; i < 25; i++) {
                keys[i] -= this.keys[i];
            }
        }
    }

    public static void main(String[] args) throws IOException {
        LineNumberReader r = new LineNumberReader(new FileReader("/Users/ant/Downloads/D-small-attempt2.in"));
        PrintWriter w = new PrintWriter(new FileWriter("/Users/ant/Downloads/D-small-attempt2.out"));
        int c = Integer.parseInt(r.readLine());
        System.out.println(c + " cases");
        for (int i = 0; i < c; i++) {
            String s = r.readLine();
            int k = Integer.parseInt(s.split(" ")[0]);
            int n = Integer.parseInt(s.split(" ")[1]);
            int[] keys = readKeys(r, k);
            Chest[] chests = readChests(r, n);
            w.println("Case #" + (i + 1) + ": " + solveTreasure(keys, chests));
        }
        r.close();
        w.close();
    }

    private static String solveTreasure(int[] keys, Chest[] chests) {
        int[] chestsCount = new int[25];
        for (Chest chest : chests) {
            chestsCount[chest.key]++;
        }
        return solveTreasure(keys, chests, chestsCount, new boolean[chests.length], new LinkedList<Integer>());
    }

    private static String solveTreasure(int[] keys, Chest[] chests, int[] chestsCount, boolean[] used, Deque<Integer> solution) {
        boolean[] triedKeys = new boolean[used.length];
        while (true) {
            int b = findBestChest(keys, chests, used, triedKeys);
            if (b != -1) {
                Chest chest = chests[b];
                int key = chest.key;
                triedKeys[b] = true;
                used[b] = true;
                chest.addKeysTo(keys);
                solution.add(b + 1);
                keys[key]--;
                chestsCount[key]--;
                if (solution.size() == chests.length) {
                    return toStringSolution(solution);
                }
                if (!(chestsCount[key] != 0 && keys[key]==0) && canSolve(chests, keys, used, b)) {
                    String r = solveTreasure(keys, chests, chestsCount, used, solution);
                    if (!r.equals("IMPOSSIBLE")) {
                        return r;
                    }
                }
                chestsCount[key]++;
                keys[key]++;
                solution.removeLast();
                chest.removeKeysFrom(keys);
                used[b] = false;
            } else {
                break;
            }
        }
        return "IMPOSSIBLE";
    }

    private static boolean canSolve(Chest[] chests, int[] keys, boolean[] used, int b) {
        int[] keys_c = new int[keys.length];
        System.arraycopy(keys, 0, keys_c, 0, keys.length);
        for (int i = 0; i < chests.length; i++) {
            if (!used[i]) {
                keys_c[chests[i].key]--;
                chests[i].addKeysTo(keys_c);
            }
        }
        for (int aKeys_c : keys_c) {
            if (aKeys_c < 0) return false;
        }
        return true;
    }

    private static String toStringSolution(Deque<Integer> solution) {
        StringBuilder b = new StringBuilder();
        boolean first = true;
        for (Integer i : solution) {
            if (!first) {
                b.append(" ");
            }
            b.append(i);
            first = false;
        }
        return b.toString();
    }

    private static int findBestChest(int[] keys, Chest[] chests, boolean[] used, boolean[] tried) {
        int idx = -1;
        for (int i = 0; i < chests.length; i++) {
            if (keys[chests[i].key] > 0 && !used[i] && !tried[i]) {
                idx = i;
                break;
            }
        }
        return idx;
    }

    private static Chest[] readChests(LineNumberReader r, int n) throws IOException {
        Chest[] chests = new Chest[n];
        for (int i = 0; i < n; i++) {
            String[] s = r.readLine().split(" ");
            int t = Integer.parseInt(s[0]);
            int c = Integer.parseInt(s[1]);
            Chest chest = new Chest();
            chest.key = t;
            for (int j = 0; j < c; j++) {
                int key = Integer.parseInt(s[2 + j]);
                chest.keys[key]++;
            }
            chests[i] = chest;
        }
        return chests;
    }

    private static int[] readKeys(LineNumberReader r, int k) throws IOException {
        int[] keys = new int[25];
        String[] s = r.readLine().split(" ");
        for (int i = 0; i < k; i++) {
            int key = Integer.parseInt(s[i]);
            keys[key]++;
        }
        return keys;
    }
}
