import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.util.List;
import java.util.OptionalInt;
import java.util.SortedSet;
import java.util.TreeSet;
import static java.util.stream.Collectors.toList;

public class ProblemA {

	private static final Path IO_DIR = Paths.get("C:\\Users\\Terje\\Downloads");
	private static final SortedSet<Integer> DIGITS = new TreeSet<>();

	static {
		for (char ch = '0'; ch <= '9'; ch++) {
			DIGITS.add((int) ch);
		}
	}

	public static void main(String... args) throws NoSuchAlgorithmException, IOException {
//		Path input = generateRandomInput();
		Path input = IO_DIR.resolve("A-large.in");
		try (BufferedReader in = Files.newBufferedReader(input);
				BufferedWriter out = Files.newBufferedWriter(IO_DIR.resolve("problemA.out"))) {
			int T = Integer.parseInt(in.readLine());
			for (int i = 1; i <= T; i++) {
				int N = Integer.parseInt(in.readLine());
				OptionalInt solution = solve(N);
				out.write("Case #" + i + ": " + (solution.isPresent() ? solution.getAsInt() : "INSOMNIA"));
				out.newLine();
			}
		}
	}

	public static OptionalInt solve(int n) {
		if (n == 0) {
			return OptionalInt.empty();
		}

		int result = 0;
		SortedSet<Integer> digits = new TreeSet<>(DIGITS);
		while (!digits.isEmpty()) {
			result += n;
			Integer.toString(result)
					.chars()
					.forEach(i -> digits.remove(i));
		}
		return OptionalInt.of(result);
	}

	private static Path generateRandomInput() throws NoSuchAlgorithmException, IOException {
		int T = 100;
		List<String> lines = SecureRandom.getInstanceStrong()
				.ints(T, 0, 1_000_001)
				.mapToObj(Integer::toString)
				.collect(toList());
		lines.add(0, Integer.toString(T));
		Path result = IO_DIR.resolve("problemA.in");
		Files.write(result, lines);
		return result;
	}

}
