import java.io.*;
import java.util.*;

public class Dijkstra {
	public static void main(String[] args) {
		new Dijkstra().run();
	}

	BufferedReader br;
	StringTokenizer st;
	PrintWriter out;
	boolean eof = false;
	Random rand = new Random(12345);

	private void run() {
		Locale.setDefault(Locale.US);
		try {
			br = new BufferedReader(new FileReader(FNAME + ".in"));
			out = new PrintWriter(FNAME + ".out");
			solve();
			out.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(566);
		}
	}

	String nextToken() {
		while (st == null || !st.hasMoreTokens()) {
			try {
				st = new StringTokenizer(br.readLine());
			} catch (Exception e) {
				eof = true;
				return "0";
			}
		}
		return st.nextToken();
	}

	int nextInt() {
		return Integer.parseInt(nextToken());
	}

	long nextLong() {
		return Long.parseLong(nextToken());
	}

	double nextDouble() {
		return Double.parseDouble(nextToken());
	}

	String FNAME = "c";

	static class Quat {
		int sign;
		int letter;

		public Quat(int i, int j) {
			sign = i;
			letter = j;
		}

		public Quat(Quat quat) {
			sign = quat.sign;
			letter = quat.letter;
		}

		Quat multiply(Quat y) {
			Quat res = new Quat(table[letter][y.letter]);
			res.sign *= sign * y.sign;
			return res;
		}

		@Override
		public String toString() {
			String s = sign > 0 ? "" : "-";
			char[] c = new char[] { '1', 'i', 'j', 'k' };
			s += c[letter];
			return s;
		}

		static Quat[][] table = new Quat[][] {
				{ new Quat(1, 0), new Quat(1, 1), new Quat(1, 2),
						new Quat(1, 3) },
				{ new Quat(1, 1), new Quat(-1, 0), new Quat(1, 3),
						new Quat(-1, 2) },
				{ new Quat(1, 2), new Quat(-1, 3), new Quat(-1, 0),
						new Quat(1, 1) },
				{ new Quat(1, 3), new Quat(1, 2), new Quat(-1, 1),
						new Quat(-1, 0) }, };
	}

	private void solve() throws IOException {
		int testn = nextInt();
		loop: for (int test = 1; test <= testn; test++) {
			out.print("Case #" + test + ": ");
			int len = nextInt();
			int x = nextInt();
			char[] str = nextToken().toCharArray();
			Quat[] a = new Quat[len];
			for (int i = 0; i < a.length; i++) {
				a[i] = new Quat(1, str[i] - 'i' + 1);
			}
			Quat full = new Quat(1, 0);
			for (int i = 0; i < a.length; i++) {
				full = full.multiply(a[i]);
			}
			Quat total = power(full, x);
			if (total.sign != -1 || total.letter != 0) {
				out.println("NO");
				continue;
			}
			Quat[] p = new Quat[4];
			p[0] = new Quat(1, 0);
			for (int i = 1; i < p.length; i++) {
				p[i] = p[i - 1].multiply(full);
			}
			// Case one
			for (int n = 0; n < 4; n++) {
				for (int m = 0; m < 4; m++) {
					if ((n + m + 1) % 4 != x % 4 || n + m + 1 > x) {
						continue;
					}
					Quat first = p[n];
					Quat second = new Quat(1, 0);
					for (int i = 0; i < a.length; i++) {
						second = a[i];
						for (int j = i + 1; j < a.length; j++) {
							if (first.sign == 1 && first.letter == 1
									&& second.sign == 1 && second.letter == 2) {
								out.println("YES");
								continue loop;
							}
							second = second.multiply(a[j]);
						}
						first = first.multiply(a[i]);
					}
				}
			}
			// Case two
			for (int n = 0; n < 4; n++) {
				for (int m = 0; m < 4; m++) {
					for (int q = 0; q < 4; q++) {
						if ((n + m + q + 2) % 4 != x % 4 || n + m + q + 2 > x) {
							continue;
						}
						Quat first = p[n];
						Quat second = p[q];
						for (int i = 0; i < a.length; i++) {
							Quat sec = new Quat(second);
							for (int j = 0; j < a.length; j++) {
								if (first.sign == 1 && first.letter == 1
										&& sec.sign == 1 && sec.letter == 2) {
									out.println("YES");
									continue loop;
								}
								sec = sec.multiply(a[j]);
							}
							first = first.multiply(a[i]);
							second = a[i].multiply(second).multiply(
									new Quat(-1, 0));
						}
					}
				}
			}
			out.println("NO");
		}
	}

	private Quat power(Quat x, int n) {
		Quat res = new Quat(1, 0);
		while (n > 0) {
			if (n % 2 != 0) {
				res = res.multiply(x);
			}
			x = x.multiply(x);
			n >>= 1;
		}
		return res;
	}
}
