import java.io.*;
import java.util.*;

public class Streams {
	public static void main(String[] args) {
		new Streams().run();
	}

	BufferedReader br;
	StringTokenizer st;
	PrintWriter out;
	boolean eof = false;
	Random rand = new Random(12345);

	private void run() {
		Locale.setDefault(Locale.US);
		try {
			br = new BufferedReader(new FileReader(FNAME + ".in"));
			out = new PrintWriter(FNAME + ".out");
			solve();
			out.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(566);
		}
	}

	String nextToken() {
		while (st == null || !st.hasMoreTokens()) {
			try {
				st = new StringTokenizer(br.readLine());
			} catch (Exception e) {
				eof = true;
				return "0";
			}
		}
		return st.nextToken();
	}

	int nextInt() {
		return Integer.parseInt(nextToken());
	}

	long nextLong() {
		return Long.parseLong(nextToken());
	}

	double nextDouble() {
		return Double.parseDouble(nextToken());
	}

	String FNAME = "c";

	class Vertex {
		public Vertex(int i) {
			n = i;
			edges = new ArrayList<>();
		}

		int n;
		boolean u;
		ArrayList<Edge> edges;
	}

	class Edge {
		public Edge(Vertex x2, Vertex y2, int c2) {
			x = x2;
			y = y2;
			c = c2;
		}

		Vertex x, y;
		int c;
		Edge r;
	}

	class Graph {
		public Graph(int n) {
			ver = new Vertex[n];
			for (int i = 0; i < ver.length; i++) {
				ver[i] = new Vertex(i);
			}
		}

		Vertex[] ver;

		public void addEdge(int i, int j, int k) {
			Edge e = new Edge(ver[i], ver[j], k);
			Edge er = new Edge(ver[j], ver[i], 0);
			e.r = er;
			er.r = e;
			e.x.edges.add(e);
			er.x.edges.add(er);
		}

		public int maxFlow(int s, int t) {
			int flow = 0;
			while (true) {
				for (Vertex v : ver) {
					v.u = false;
				}
				if (!dfs(ver[s], ver[t])) {
					break;
				}
				flow++;
			}
			return flow;
		}

		private boolean dfs(Vertex x, Vertex t) {
			if (x.n == t.n) {
				return true;
			}
			x.u = true;
			for (Edge e : x.edges) {
				if (e.c > 0 && !e.y.u && dfs(e.y, t)) {
					e.c--;
					e.r.c++;
					return true;
				}
			}
			return false;
		}
	}

	private void solve() throws IOException {
		int testn = nextInt();
		for (int test = 1; test <= testn; test++) {
			out.print("Case #" + test + ": ");
			int w = nextInt();
			int h = nextInt();
			int build = nextInt();
			boolean[][] a = new boolean[w][h];
			for (int i = 0; i < build; i++) {
				int x1 = nextInt();
				int y1 = nextInt();
				int x2 = nextInt();
				int y2 = nextInt();
				for (int x = x1; x <= x2; x++) {
					for (int y = y1; y <= y2; y++) {
						a[x][y] = true;
					}
				}
			}
			int[][] base = new int[w][h];
			for (int i = 0; i < base.length; i++) {
				for (int j = 0; j < base[i].length; j++) {
					base[i][j] = (j * w + i) * 2;
				}
			}
			Graph g = new Graph(2 + 2 * w * h);
			for (int i = 0; i < a.length; i++) {
				if (!a[i][0]) {
					g.addEdge(0, base[i][0] + 1, 1);
				}
				if (!a[i][h - 1]) {
					g.addEdge(base[i][h - 1] + 2, 2 * w * h + 1,
							Integer.MAX_VALUE / 2);
				}
			}
			for (int i = 0; i < a.length; i++) {
				for (int j = 0; j < a[i].length; j++) {
					if (a[i][j]) {
						continue;
					}
					int k = base[i][j];
					g.addEdge(k + 1, k + 2, 1);
					for (int dir = 0; dir < dx.length; dir++) {
						int x = i + dx[dir];
						int y = j + dy[dir];
						if (x < 0 || w <= x || y < 0 || h <= y || a[x][y]) {
							continue;
						}
						int k2 = base[x][y];
						g.addEdge(k + 2, k2 + 1, Integer.MAX_VALUE / 2);
					}
				}
			}
			int flow = g.maxFlow(0, 2 * w * h + 1);
			out.println(flow);
			// for (int j = 0; j < a[0].length; j++) {
			// for (int i = 0; i < a.length; i++) {
			// System.out.print(a[i][j] ? "#" : ".");
			// }
			// System.out.println();
			// }
			// System.out.println(flow);
			// System.out.println();
			if (w <= 10 && h <= 10) {
				w += 0;
			}
		}
	}

	int[] dx = new int[] { 0, 1, 0, -1 };
	int[] dy = new int[] { 1, 0, -1, 0 };
}
