import java.io.*;
import java.util.*;
import java.math.*;

public class Charts implements Runnable {

	public static void main(String[] args) {
		new Thread(new Charts()).start();
	}

	BufferedReader br;
	StringTokenizer st;
	PrintWriter out;
	boolean eof = false;
	Random rand = new Random(this.hashCode());

	@Override
	public void run() {
		Locale.setDefault(Locale.US);
		try {
			br = new BufferedReader(new FileReader(FNAME + ".in"));
			out = new PrintWriter(FNAME + ".out");
			solve();
			out.close();
		} catch (Throwable e) {
			e.printStackTrace();
			System.exit(566);
		}
	}

	String nextToken() {
		while (st == null || !st.hasMoreTokens()) {
			try {
				st = new StringTokenizer(br.readLine());
			} catch (Exception e) {
				eof = true;
				return "0";
			}
		}
		return st.nextToken();
	}

	int nextInt() {
		return Integer.parseInt(nextToken());
	}

	long nextLong() {
		return Long.parseLong(nextToken());
	}

	double nextDouble() {
		return Double.parseDouble(nextToken());
	}

	String FNAME = "charts";

	class Stock {
		public Stock(int i, int k) {
			n = i;
			a = new int[k];
			edges = new ArrayList<Stock>();
		}

		int[] a;
		int n;
		ArrayList<Stock> edges;

		public boolean greaterThan(Stock s) {
			boolean ans = true;
			for (int i = 0; i < a.length; i++) {
				ans &= a[i] > s.a[i];
			}
			return ans;
		}
	}

	class Graph {
		public Graph(int n) {
			vertex = new Vertex[n];
			for (int i = 0; i < vertex.length; i++) {
				vertex[i] = new Vertex(i);
			}
		}

		class Vertex {
			@Override
			public String toString() {
				return n + " " + d + " " + inQueue;
			}

			public Vertex(int i) {
				n = i;
				edges = new ArrayList<Edge>();
			}

			ArrayList<Edge> edges;
			int d, n;
			boolean inQueue;
			Edge prev;
		}

		class Edge {
			public Edge(Vertex v1, Vertex v2, int c2, int p2) {
				x = v1;
				y = v2;
				c = c2;
				p = p2;
				f = 0;
			}

			Vertex x, y;
			int c, p, f;
			Edge r;

			public boolean relax() {
				if (c - f > 0 && y.d > x.d + p) {
					y.d = x.d + p;
					y.prev = this;
					return !y.inQueue;
				}
				return false;
			}
		}

		Vertex[] vertex;

		public void addEdge(int x, int y, int c, int p) {
			Edge e = new Edge(vertex[x], vertex[y], c, p);
			Edge er = new Edge(vertex[y], vertex[x], 0, -p);
			e.r = er;
			er.r = e;
			vertex[x].edges.add(e);
			vertex[y].edges.add(er);
		}

		public int minCostMaxFlow(int s, int t) {
			int flow = 0;
			int cost = 0;
			while (true) {
				for (int i = 0; i < vertex.length; i++) {
					vertex[i].d = Integer.MAX_VALUE / 2;
					vertex[i].inQueue = false;
					vertex[i].prev = null;
				}
				vertex[s].d = 0;
				vertex[s].inQueue = true;
				Queue<Vertex> q = new LinkedList<Vertex>();
				q.add(vertex[s]);
				while (!q.isEmpty()) {
					Vertex v = q.poll();
					for (Edge e : v.edges) {
						if (e.relax()) {
							q.add(e.y);
							e.y.inQueue = true;
						}
					}
				}
				if (vertex[t].prev == null) {
					break;
				}
				Edge e = vertex[t].prev;
				int f = Integer.MAX_VALUE / 2;
				while (e != null) {
					f = Math.min(f, e.c - e.f);
					e = e.x.prev;
				}
				e = vertex[t].prev;
				flow += f;
				while (e != null) {
					cost += f * e.p;
					e.f += f;
					e.r.f -= f;
					e = e.x.prev;
				}
			}
			return flow;
		}
	}

	private void solve() throws IOException {
		for (int test = 1, testn = nextInt(); test <= testn; test++) {
			out.print("Case #" + test + ": ");
			int n = nextInt();
			int k = nextInt();
			Stock[] a = new Stock[n];
			for (int i = 0; i < a.length; i++) {
				a[i] = new Stock(i, k);
				for (int j = 0; j < a[i].a.length; j++) {
					a[i].a[j] = nextInt();
				}
			}
			boolean[] in = new boolean[n];
			for (int i = 0; i < a.length; i++) {
				for (int j = 0; j < a.length; j++) {
					if (a[i].greaterThan(a[j])) {
						a[i].edges.add(a[j]);
						in[j] = true;
					}
				}
			}
			// int noIn = 0;
			// int noOut = 0;
			// for (int i = 0; i < in.length; i++) {
			// if (!in[i]) {
			// noIn++;
			// }
			// if (a[i].edges.size() == 0) {
			// noOut++;
			// }
			// }
			// int ans = Math.max(noIn, noOut);
			Graph g = new Graph(2 * n + 2);
			for (int i = 0; i < a.length; i++) {
				g.addEdge(0, 2 * i + 1, 1, 0);
				// g.addEdge(2 * i + 1, 2 * i + 2, 1, 0);
				for (Stock s : a[i].edges) {
					g.addEdge(2 * i + 1, 2 * s.n + 2, 1, 0);
				}
				g.addEdge(2 * i + 2, 2 * n + 1, 1, 0);
			}
			int ans = g.minCostMaxFlow(0, 2 * n + 1);
			out.println(n - ans);
		}
	}

}
