import java.io.*;
import java.util.*;

public class Joy implements Runnable {

	public static void main(String[] args) {
		new Thread(new Joy()).start();
	}

	BufferedReader br;
	StringTokenizer st;
	PrintWriter out;
	boolean eof = false;

	@Override
	public void run() {
		try {
			br = new BufferedReader(new FileReader(FNAME + ".in"));
			out = new PrintWriter(FNAME + ".out");
			solve();
			out.close();
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(566);
		}

	}

	String nextToken() {
		while (st == null || !st.hasMoreTokens()) {
			try {
				st = new StringTokenizer(br.readLine());
			} catch (Exception e) {
				eof = true;
				return "0";
			}
		}
		return st.nextToken();
	}

	int nextInt() {
		return Integer.parseInt(nextToken());
	}

	long nextLong() {
		return Long.parseLong(nextToken());
	}

	double nextDouble() {
		return Double.parseDouble(nextToken());
	}

	String FNAME = "c";

	class Item {
		HashSet<Integer> optionA;
		HashSet<Integer> optionB;
		int x, y;
		int dir;
	}

	private void solve() {
		long time = System.currentTimeMillis();
		int testn = nextInt();
		tests: for (int test = 1; test <= testn; test++) {
			System.out.println(test + ": " + (System.currentTimeMillis() - time));
			out.print("Case #" + test + ": ");
			int n = nextInt();
			int m = nextInt();
			char[][] c = new char[n][];
			for (int i = 0; i < c.length; i++) {
				c[i] = nextToken().toCharArray();
			}
			lasers = new ArrayList<>();
			for (int i = 0; i < c.length; i++) {
				for (int j = 0; j < c[i].length; j++) {
					if (c[i][j] == '-' || c[i][j] == '|') {
						Item it = buildNewItem(c, i, j);
						if (it.optionA == null && it.optionB == null) {
							out.println("IMPOSSIBLE");
							continue tests;
						}
						lasers.add(it);
					}
				}
			}
			cover = new HashSet[n * m];
			for (int i = 0; i < cover.length; i++) {
				cover[i] = new HashSet<>();
			}
			for (Item laser : lasers) {
				if (laser.optionA != null) {
					for (int x : laser.optionA) {
						cover[x].add(laser);
					}
				}
				if (laser.optionB != null) {
					for (int x : laser.optionB) {
						cover[x].add(laser);
					}
				}
			}
			covered = new boolean[n * m];
			for (int i = 0; i < c.length; i++) {
				for (int j = 0; j < c[i].length; j++) {
					if (c[i][j] != '.') {
						covered[i * m + j] = true;
					}
				}
			}
			boolean canBeDone = bruteforce(0);
			if (!canBeDone) {
				out.println("IMPOSSIBLE");
				continue;
			}
			out.println("POSSIBLE");
			for (Item laser : lasers) {
				if (laser.dir <= 0) {
					c[laser.x][laser.y] = '|';
				} else {
					c[laser.x][laser.y] = '-';
				}
			}
			for (int i = 0; i < c.length; i++) {
				for (int j = 0; j < c[i].length; j++) {
					out.print(c[i][j]);
				}
				out.println();
			}
		}
	}

	private boolean bruteforce(int x) {
		if (x >= covered.length) {
			return true;
		}
		if (covered[x]) {
			return bruteforce(x + 1);
		}
		ArrayList<Integer> changed = new ArrayList<>();
		for (Item laser : cover[x]) {
			if (laser.dir != 0) {
				continue;
			}
			if (laser.optionA != null && laser.optionA.contains(x)) {
				for (int y : laser.optionA) {
					if (!covered[y]) {
						covered[y] = true;
						changed.add(y);
					}
				}
				laser.dir = 1;
				if (bruteforce(x + 1)) {
					return true;
				}
				for (int y : changed) {
					covered[y] = false;
				}
				laser.dir = 0;
				changed.clear();
			}
			if (laser.optionB != null && laser.optionB.contains(x)) {
				for (int y : laser.optionB) {
					if (!covered[y]) {
						covered[y] = true;
						changed.add(y);
					}
				}
				laser.dir = -1;
				if (bruteforce(x + 1)) {
					return true;
				}
				for (int y : changed) {
					covered[y] = false;
				}
				laser.dir = 0;
				changed.clear();
			}
		}
		return false;
	}

	boolean[] covered;
	HashSet<Item>[] cover;
	ArrayList<Item> lasers;

	int[] dx = new int[] { 0, 1, 0, -1 };
	int[] dy = new int[] { 1, 0, -1, 0 };

	private Item buildNewItem(char[][] c, int x, int y) {
		HashSet<Integer>[] paths = new HashSet[dx.length];
		for (int i = 0; i < dx.length; i++) {
			paths[i] = getPath(c, x + dx[i], y + dy[i], i);
		}
		Item it = new Item();
		it.x = x;
		it.y = y;
		if (paths[0] != null && paths[2] != null) {
			it.optionA = new HashSet<>();
			it.optionA.addAll(paths[0]);
			it.optionA.addAll(paths[2]);
		}
		if (paths[1] != null && paths[3] != null) {
			it.optionB = new HashSet<>();
			it.optionB.addAll(paths[1]);
			it.optionB.addAll(paths[3]);
		}
		return it;
	}

	private HashSet<Integer> getPath(char[][] c, int x, int y, int d) {
		if (x < 0 || x >= c.length || y < 0 || y >= c[x].length || c[x][y] == '#') {
			return new HashSet<>();
		}
		if (c[x][y] == '-' || c[x][y] == '|') {
			return null;
		}
		if (c[x][y] == '.') {
			HashSet<Integer> path = getPath(c, x + dx[d], y + dy[d], d);
			if (path != null) {
				path.add(x * c[x].length + y);
			}
			return path;
		}
		if (c[x][y] == '/') {
			if (d == 0) {
				d = 3;
			} else if (d == 1) {
				d = 2;
			} else if (d == 2) {
				d = 1;
			} else if (d == 3) {
				d = 0;
			}
		}
		if (c[x][y] == '\\') {
			if (d == 0) {
				d = 1;
			} else if (d == 1) {
				d = 0;
			} else if (d == 2) {
				d = 3;
			} else if (d == 3) {
				d = 2;
			}
		}
		return getPath(c, x + dx[d], y + dy[d], d);
	}

}
