import java.io.PrintStream;
import java.math.BigInteger;
import java.util.Scanner;
import java.util.function.Supplier;
import java.util.stream.DoubleStream;
import java.util.stream.IntStream;
import java.util.stream.LongStream;
import java.util.stream.Stream;

public class RatherPerplexingShowdown {
    static void run() {
        int n = rdInt();
        int r = rdInt();
        int p = rdInt();
        int s = rdInt();

        String res = solve(n, r, p, s);

        if (res != null) {
            assert res.length() == 1 << n;
            assert res.matches("[RPS]+");
        }

        wrVal(res == null ? "IMPOSSIBLE" : res);
    }

    private static String solve(int n, int r, int p, int s) {
        int sz = 1 << n;
        int range = 1;
        for (int i = 1; i <= sz; ++i) range *= 3;

        char[] cs = new char[sz];
        char[] tcs = new char[sz];
        for (int x = 0; x < range; ++x) {
            int t = x;
            for (int i = 0; i < sz; ++i) {
                char c;
                int k = t % 3;
                t /= 3;
                if (k == 0) c = 'P';
                else if (k == 1) c = 'R';
                else c = 'S';
                cs[sz - 1 - i] = c;
            }
            if (check(sz, cs, tcs, r, p, s)) return new String(cs);
        }

        return null;
    }

    private static boolean check(int sz, char[] cs, char[] tcs, int r, int p, int s) {
        int nr = 0;
        int np = 0;
        int ns = 0;
        for (char c : cs) {
            if (c == 'R') nr++;
            else if (c == 'P') np++;
            else ns++;
        }
        if (nr != r || ns != s || np != p) return false;

        for (int i = 0; i < sz; ++i) tcs[i] = cs[i];
        while (sz > 1) {
            sz /= 2;
            for (int i = 0; i < sz; ++i) {
                char c1 = tcs[2 * i];
                char c2 = tcs[2 * i + 1];
                if (c1 == c2) return false;
                char c;
                if (c1 == 'R' && c2 == 'S') c = 'R';
                else if (c1 == 'S' && c2 == 'R') c = 'R';
                else if (c1 == 'S' && c2 == 'P') c = 'S';
                else if (c1 == 'P' && c2 == 'S') c = 'S';
                else if (c1 == 'P' && c2 == 'R') c = 'P';
                else c = 'P';
                tcs[i] = c;
            }
        }
        return true;
    }

    public static void main(String[] args) {
        int n = rdInt();
        for (int i = 0; i < n; ++i) {
            output.print("Case #" + (i + 1) + ":");
            outputSep = " ";
            run();
            output.print("\n");
        }
        output.flush();
    }

    static Scanner input = new Scanner(System.in);
    static int rdInt() { return rdT(() -> input.nextInt()); }
    static long rdLong() { return rdT(() -> input.nextLong()); }
    static double rdDbl() { return rdT(() -> input.nextDouble()); }
    static BigInteger rdBigInt() { return rdT(() -> input.nextBigInteger()); }
    static String rdStr() { return rdT(() -> input.next()); }
    static String rdLine() { return input.nextLine(); }
    static String[] rdStrs(int n) { return Stream.generate(() -> rdStr()).limit(n).toArray(x -> new String[x]); }
    static int[] rdInts(int n) { return IntStream.generate(() -> rdInt()).limit(n).toArray(); }
    static int[][] rdInts(int n, int m) { return Stream.generate(() -> rdInts(m)).limit(n).toArray(v -> new int[v][]); }
    static long[] rdLongs(int n) { return LongStream.generate(() -> rdLong()).limit(n).toArray(); }
    static double[] rdDbls(int n) { return DoubleStream.generate(() -> rdDbl()).limit(n).toArray(); }
    private static <T> T rdT(Supplier<T> supplier) { T t = supplier.get(); input.skip(" |\n|\r\n"); return t; }

    static PrintStream output = new PrintStream(System.out, true);
    static String outputSep = " ";
    static void wrVal(String v) { wrT(v); }
    static void wrVal(int v) { wrT(v); }
    static void wrVal(long v) { wrT(v); }
    static void wrVal(BigInteger v) { wrT(v); }
    static void wrVal(double v) { wrVal(v, 10); }
    static void wrVal(double v, int fracdigs) { wrT(String.format("%." + fracdigs + "f", v)); }
    static void wrVals(int[] vs) { for (int v : vs) wrVal(v); }
    static void wrVals(long[] vs) { for (long v : vs) wrVal(v); }
    static void wrVals(double[] vs) { for (double v : vs) wrVal(v); }
    static void wrVals(double[] vs, int fracdigs) { for (double v : vs) wrVal(v, fracdigs); }
    static void wrVals(String[] vs) { for (String v : vs) wrVal(v); }
    static void wrLn() { output.print("\n"); outputSep = ""; }
    private static void wrT(Object v) { output.print(outputSep); output.print(v); outputSep = " "; }

    static void verifyOK() {}
    static RuntimeException error() { throw new RuntimeException(); }
    static RuntimeException error(String s) { throw new RuntimeException(s); }
}
