package codejam2014;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.PrintWriter;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.Set;
import java.util.StringTokenizer;

public class Minesweeper {
	private static final String NAME = "C-small-attempt2";
	public static void main(String[] args) throws Exception {
		BufferedReader br = new BufferedReader(new FileReader(new File(NAME + ".in")));
		PrintWriter out = new PrintWriter(new File(NAME + ".out"));
		int numCases = Integer.parseInt(br.readLine());
		for(int CASE = 1; CASE <= numCases; CASE++){
			StringTokenizer st = new StringTokenizer(br.readLine());
			int rows = Integer.parseInt(st.nextToken());
			int cols = Integer.parseInt(st.nextToken());
			int numMines = Integer.parseInt(st.nextToken());
			boolean[][] mines = new boolean[rows][cols];
			fillMines(mines, numMines);
			int[][] grid = new int[rows][cols];
			for(int i = 0; i < rows; i++){
				for(int j = 0; j < cols; j++){
					int count = (mines[i][j]) ? 1 : 0;
					for(Point p: new Point(i, j).getNeighbors(rows, cols)){
						if(mines[p.x][p.y])
							count++;
					}
					grid[i][j] = count;
				}
			}
			Point c = search(mines, grid, rows*cols - numMines);
			if(c == null){
				mines = new boolean[cols][rows];
				fillMines(mines, numMines);
				grid = new int[cols][rows];
				for(int i = 0; i < cols; i++){
					for(int j = 0; j < rows; j++){
						int count = (mines[i][j]) ? 1 : 0;
						for(Point p: new Point(i, j).getNeighbors(cols, rows)){
							if(mines[p.x][p.y])
								count++;
						}
						grid[i][j] = count;
					}
				}
				c = search(mines, grid, rows*cols - numMines);
				if(c == null)
					out.println("Case #" + CASE + ":\nImpossible");
				else {
					StringBuilder str = new StringBuilder();
					for(int j = 0; j < rows; j++){
						for(int i = 0; i < cols; i++){
							if(c.x == i && c.y == j)
								str.append('c');
							else if(mines[i][j])
								str.append("*");
							else
								str.append(".");
						}
						str.append("\n");
					}
					out.print("Case #" + CASE + ":\n" + str);
				}
					
			} else {
				StringBuilder str = new StringBuilder();
				for(int i = 0; i < rows; i++){
					for(int j = 0; j < cols; j++){
						if(c.x == i && c.y == j)
							str.append('c');
						else if(mines[i][j])
							str.append("*");
						else
							str.append(".");
					}
					str.append("\n");
				}
				out.print("Case #" + CASE + ":\n" + str);
			}
		}
		out.close();
		System.exit(0);
	}
	
	private static Point fillMines(boolean[][] mines, int numMines) {
		if(numMines > 0) {
			for(int i = 0; i < mines.length - 2; i++){
				for(int j = 0; j < mines[i].length - 2; j++){
					mines[i][j] = true;
					numMines--;
					if(numMines == 0)
						return new Point(i, j);
				}
				if(numMines >= 2){
					for(int j = Math.max(0, mines[i].length - 2); j < mines[i].length; j++){
						mines[i][j] = true;
						numMines--;
						if(numMines == 0)
							return new Point(i, j);
					}
				}
			}
			
			int start = Math.max(0, mines.length - 2);
			for(int j = 0; j < mines[0].length; j++){
				for(int i = start; i < mines.length; i++){
					mines[i][j] = true;
					numMines--;
					if(numMines == 0)
						return new Point(i, j);
				}
			}
		}
		return new Point(0,0);
	}
	
	private static Point search(boolean[][] mines, int[][] grid, int goal){
//		for(Point start: lastMine.getNeighbors(grid.length, grid[0].length)){
		for(int i = 0; i < mines.length; i++){
			for(int j = 0; j < mines[i].length; j++){
				if(goal == 1 && mines[i][j] == false){
					return new Point(i, j);
				}
				if(grid[i][j] == 0) {
					Point start = new Point(i,j);
					if(bfs(mines, grid, start) == goal)
						return start;
					else
						return null;
				}
			}
		}

//		}
		return null;
	}
	
	private static int bfs(boolean[][] mines, int[][] grid, Point start){
		Set<Point> visited = new HashSet<Point>();
		LinkedList<Point> queue = new LinkedList<Point>();
		queue.add(start);
		int counter = 0;
		while(queue.size() > 0) {
			Point cur = queue.removeFirst();
			if(visited.contains(cur)) continue;
			visited.add(cur);
			counter++;
			if(grid[cur.x][cur.y] == 0) {
				for(Point next: cur.getNeighbors(grid.length, grid[0].length)){
					if(visited.contains(next) == false)
						queue.add(next);
				}
			}
		}
		return counter;
	}
	
//	private static void bfs(boolean[][] grid, int counter){
//		LinkedList<Integer> queue = new LinkedList<Integer>();
//		queue.add(0); queue.add(0);
//		while(counter > 0 && queue.size() > 0) {
//			int x1 = queue.removeFirst();
//			int y1 = queue.removeFirst();
//			if(grid[x1][y1]) continue;
//			grid[x1][y1] = true;
//			System.out.println(x1 + " " + y1 + " " + counter);
//			counter--;
//			for(int i = 0; i < 8; i++){
//				int x2 = x1 + dx[i];
//				int y2 = y1 + dy[i];
//				if(0 <= x2 && x2 < grid.length && 0 <= y2 && y2 < grid[0].length){
//					if(grid[x2][y2] == false){
//						queue.add(x2);
//						queue.add(y2);
//					}
//				}
//			}
//		}
//	}
}

class Point implements Comparable<Point>{
	int x, y;
	private static int[] dx = {1, 1, 0, -1, -1, -1, 0, 1};
	private static int[] dy = {0, -1, -1, -1, 0, 1, 1, 1};
	public Point(int x, int y){
		this.x = x; this.y = y;
	}
	
	public LinkedList<Point> getNeighbors(int width, int height){
		LinkedList<Point> neighbors = new LinkedList<Point>();
		for(int i = 0; i < 8; i++){
			int x = this.x + dx[i];
			int y = this.y + dy[i];
			if(0 <= x && x < width && 0 <= y && y < height){
				neighbors.add(new Point(x, y));
			}
		}
		return neighbors;
	}
	
	@Override
	public boolean equals(Object o){
		Point other = (Point) o;
		return (x == other.x) && (y == other.y);
	}
	
	@Override
	public int hashCode(){
		return x + 7 * 1337;
	}
	
	public String toString(){
		return "(" + x + ", " + y + ")";
	}

	@Override
	public int compareTo(Point o) {
		if(x < o.x) return -1;
		else if (x == o.x) {
			if(y < o.y) return -1;
			else if (y == o.y) return 0;
		}
		return 1;
	}
}
