import java.util.HashSet;
import java.util.List;
import java.util.Optional;
import java.util.Set;

import static java.util.stream.Collectors.joining;
import static java.util.stream.Collectors.toList;
import static java.util.stream.IntStream.range;
import static util.FileHandler.*;

public class CoinJam {
    private static final long ACTUAL_MAX = 100000;
    private static final long J = 50;

    private static final Set<Long> primes = new HashSet<>();

    public static void main(String[] args) {
        start();

        generatePrimes();

        System.out.println("Primes generated");

        OUT.println("Case #1:");

        int total = 0;
        for (long i = 32769; i < 65536; i += 2) {
            try {
                String base2Representation = Long.toString(i, 2);

                OUT.println(String.format(
                        "%s %s",
                        base2Representation,
                        computeBaseRepresentations(base2Representation)
                                .stream()
                                .map(CoinJam::findDivisor)
                                .map(String::valueOf)
                                .collect(joining(" "))));

                if (++total == J) {
                    break;
                }
            } catch (IllegalArgumentException e) {
                // Nothing to do, that's expected
            }
        }

        end();
    }

    private static void generatePrimes() {
        primes.add(2L);

        for (long number = 3; number < ACTUAL_MAX; number++) {
            if (isPrime(number)) {
                primes.add(number);
            }
        }
    }

    private static Long findDivisor(Long value) {
        boolean valueIsPrime = primes.contains(value);

        if (valueIsPrime) primes.remove(value);

        Optional<Long> divisor = primes.stream()
                .filter(prime -> value % prime == 0)
                .findFirst();

        if (valueIsPrime) primes.add(value);

        if (!divisor.isPresent()) {
            throw new IllegalArgumentException("Prime!");
        }

        return divisor.get();
    }

    private static boolean isPrime(long number) {
        return primes.stream().noneMatch(prime -> number % prime == 0);
    }

    private static List<Long> computeBaseRepresentations(String base2Representation) {
        return range(2, 11)
                .mapToObj(i -> Long.valueOf(base2Representation, i))
                .collect(toList());
    }

}
