import java.math.BigInteger;
import java.util.HashSet;
import java.util.List;
import java.util.Optional;
import java.util.Set;

import static java.math.BigInteger.ONE;
import static java.math.BigInteger.ZERO;
import static java.util.stream.Collectors.joining;
import static java.util.stream.Collectors.toList;
import static java.util.stream.IntStream.range;
import static util.FileHandler.*;

public class CoinJam {
    private static final long ACTUAL_MAX = 100000;
    private static final long J = 500;
    private static final BigInteger TWO = BigInteger.valueOf(2);

    private static final Set<BigInteger> primes = new HashSet<>();

    public static void main(String[] args) {
        start();

        generatePrimes();

        System.out.println("Primes generated");

        OUT.println("Case #1:");

        BigInteger i = BigInteger.valueOf(2).pow(31).add(ONE);
        int total = 0;
        while (true) { // we won't reach 2^32 anyway...
            try {
                String base2Representation = i.toString(2);
                String format = String.format(
                        "%s %s",
                        base2Representation,
                        computeBaseRepresentations(base2Representation)
                                .stream()
                                .map(CoinJam::findDivisor)
                                .map(BigInteger::toString)
                                .collect(joining(" ")));
                OUT.println(format);

                if (++total == J) {
                    break;
                }


            } catch (IllegalStateException e) {

            } finally {
                i = i.add(TWO);
            }
        }

        end();
    }

    private static void generatePrimes() {
        primes.add(TWO);

        for (long number = 3; number < ACTUAL_MAX; number++) {
            BigInteger bigInteger = BigInteger.valueOf(number);
            if (isPrime(bigInteger)) {
                primes.add(bigInteger);
            }
        }
    }

    private static BigInteger findDivisor(BigInteger value) {
        boolean valueIsPrime = primes.contains(value);

        if (valueIsPrime) primes.remove(value);

        Optional<BigInteger> divisor = primes.stream()
                .filter(prime -> value.mod(prime).equals(ZERO))
                .findFirst();

        if (valueIsPrime) primes.add(value);

        if (!divisor.isPresent()) {
            throw new IllegalStateException("Prime!");
        }

        return divisor.get();
    }

    private static boolean isPrime(BigInteger number) {
        return primes.stream().noneMatch(prime -> number.mod(prime).equals(ZERO));
    }

    private static List<BigInteger> computeBaseRepresentations(String base2Representation) {
        return  range(2, 11)
                .mapToObj(i -> new BigInteger(base2Representation, i))
                .collect(toList());
    }

}
