import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.util.ArrayList;


/**
 * Solver class for "Welcome to Code Jam".
 *
 * @author arcatdmz
 */
public class WelcomeToCodeJam extends CodeJamBase {
	public final static String welcome = "welcome to code jam";

	public static void main(String[] args) {
		new WelcomeToCodeJam(args);
	}
	public WelcomeToCodeJam(String[] args) {
		super(args);
	}

	@Override
	public void solve(BufferedReader reader, BufferedWriter writer) throws IOException {

		// Get the first line.
		String line = reader.readLine();

		try {
			int N = Integer.parseInt(line);

			// Check each line.
			for (int n = 1; n <= N; n ++) {
				writer.write("Case #"+n+": "+
						String.format("%04d",
								getNumber(reader.readLine())));
				writer.newLine();
			}

		} catch (NumberFormatException nfe) {
			System.err.println("Illegal file format.");
		}
	}

	private int getNumber(String line) {

		// Look for "welcome to code jam" in the given line.
		int welcomeIndex = 0;
		boolean firstCharLoop = true;
		ArrayList<Token> rootTokens = new ArrayList<Token>();
		ArrayList<Token> parentTokens = null;
		while (welcomeIndex < welcome.length()) {

			// Find a character.
			final char c = welcome.charAt(welcomeIndex);
			final ArrayList<Token> tokens =
					firstCharLoop ? rootTokens : new ArrayList<Token>();
			int index = 0;
			while ((index = line.indexOf(c, index)) >= 0) {

				// Setup a token object.
				Token token = new Token();
				token.welcomeIndex = welcomeIndex;
				token.index = index;

				// Find parent tokens.
				boolean parentFound = false;
				if (!firstCharLoop) {
					for (Token parentToken : parentTokens) {
						if (parentToken.index < token.index) {
							parentToken.children.add(token);
							parentFound = true;
						}
					}
				}

				// If at least one parent is found,
				// continue to find following tokens.
				if (parentFound || firstCharLoop) {
					tokens.add(token);
				}
				index ++;
			}
			parentTokens = tokens;
			if (firstCharLoop) {
				firstCharLoop = false;
			}
			welcomeIndex ++;
		}

		// Count up possible cases.
		int count = 0;
		for (Token token : rootTokens) {
			count += countUp(token);
		}
		return count;
	}

	private int countUp(Token token) {

		// If this token has previously counted up,
		// return the remembered value.
		if (token.count != -1) {
			return token.count;
		}

		// If this token has no children,
		if (token.children.size() == 0) {
			// return 1 if it is the last token.
			// Otherwise, return 0.
			return token.welcomeIndex == welcome.length()-1
					? 1 : 0;
		}

		// Count up children.
		int count = 0;
		for (Token childToken : token.children) {
			count += countUp(childToken);
		}
		token.count = count;
		return count;
	}

	private class Token {
		private int welcomeIndex;
		private int index;
		private int count = -1;
		private ArrayList<Token> children = new ArrayList<Token>();
	}
}
