import java.util.HashMap;
import java.util.HashSet;
import java.util.Map.Entry;

public class AlienLibrary {
	private HashMap<Character, AlienLibrary> childTokens;
	private HashSet<Character> finalStates;

	public AlienLibrary() {
		childTokens = new HashMap<Character, AlienLibrary>();
		finalStates = new HashSet<Character>();
	}

	/**
	 * Add a word to this library.
	 * @param string Word to be added.
	 */
	public void add(String string) {
		char c = string.charAt(0);

		if (string.length() > 1) {
			AlienLibrary childToken;
			if (childTokens.containsKey(c)) {
				childToken = childTokens.get(c);
			} else {
				childToken = new AlienLibrary();
				childTokens.put(c, childToken);
			}
			childToken.add(string.substring(1));

		} else {
			finalStates.add(c);
		}
	}

	/**
	 * Get how many words match the given pattern.
	 * @param candidate Pattern to be matched.
	 * @return Number of matched words.
	 */
	public int getMatched(AlienCandidate candidate) {
		int matched = 0;
		for (Entry<Character, AlienLibrary> entry : childTokens.entrySet()) {
			if (candidate.contains(entry.getKey())) {
				matched += entry.getValue().getMatched(candidate.getChildToken());
			}
		}
		for (char c : finalStates) {
			if (candidate.contains(c)) {
				matched ++;
			}
		}
		return matched;
	}
}
