package com.archerintel.codejam;

import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

public class DeceitfulWar {

	private static final String IN_FILE_NAME = "D-large.in";
	private static final String OUT_FILE_NAME = "D-large.out";
	private static final Charset ENCODING = StandardCharsets.ISO_8859_1;
	
	// Returns -1.0 if no element is found.
	// Assumes list is already in ascending order.
	public static int getSmallestLargerIndex(double num, List<Double> list) {
		int result;
		int index;
		int start;
		int end;
		
		// Do binary search on the sorted List:
		start = 0;
		end = list.size() - 1;
		while ((end - start) > 0) {
			index = start + (end - start) / 2;
			if (num < list.get(index)) {
				
				// Include index because it might be the smallest larger:
				end = index;
			} else {
				
				// Exclude index since it's smaller.
				start = index + 1;
			}
		}
		
		if (num < list.get(start)) {
			result = start;
		} else {
			result = -1;
		}
		
		return result;
	}
	
	// Assumes first and second are in ascending order.
	// Removes elements from second.
	public static int playWar(List<Double> first, List<Double> second) {
		int smallestLargerBlockIndex;
		int score = 0;
		
		for (Double block : first) {
			smallestLargerBlockIndex = getSmallestLargerIndex(block, second);
			
			// The second player plays the smallest block he can to beat the
			// first player's block:
			if (smallestLargerBlockIndex >= 0) {
				second.remove(smallestLargerBlockIndex);
			} else {
				// The list is sorted in ascending order so the first
				// element is the smallest:
				second.remove(0);
				++score;
			}
		}
		
		return score;
	}
	
	public static void main(String[] args) {
//		List<Double> dub = new ArrayList<>();
//		dub.add(0.1);
//		dub.add(0.2);
//		dub.add(0.3);
//		dub.add(0.4);
//		
//		double num = 0.41;
//		
//		System.out.println(getSmallestLargerIndex(num, dub));
		
		Scanner inScan = null;
		PrintWriter writer = null;
		int numTestCases;
		int numBlocks;
		List<Double> naomiBlocks;
		List<Double> naomiCopy;
		List<Double> kenBlocks;
		List<Double> kenCopy;
		double nextDouble;
		int warScore;
		int deceitfulWarScore;
		double smallestLargerBlock;
		double smallestBlock;
		
		// Set up the input and output:
		java.io.File unRead = new java.io.File(IN_FILE_NAME);
		try {
			inScan = new Scanner(unRead);
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
		
		try {
			writer = new PrintWriter(OUT_FILE_NAME);
		} catch (FileNotFoundException fnfExc) {
			fnfExc.printStackTrace();
		}
		
		// Read the input:
		numTestCases = inScan.nextInt();
	
		for (int i = 0; i < numTestCases; ++i) {
			
			inScan.nextLine();
			numBlocks = inScan.nextInt();
			
			// Input, sort, and copy Naomi's blocks:
			naomiBlocks = new ArrayList<>();
			inScan.nextLine();
			for (int j = 0; j < numBlocks; ++j) {
				nextDouble = inScan.nextDouble();
				naomiBlocks.add(nextDouble);
			}
			
			Collections.sort(naomiBlocks);
			
			naomiCopy = new ArrayList<>(naomiBlocks);
			
			// Input, sort, and copy Ken's blocks:
			kenBlocks = new ArrayList<>();
			inScan.nextLine();
			for (int j = 0; j < numBlocks; ++j) {
				nextDouble = inScan.nextDouble();
				kenBlocks.add(nextDouble);
			}
			
			Collections.sort(kenBlocks);
			
			kenCopy = new ArrayList<>(kenBlocks);
			
			// Play War:
			// In normal war, Ken can get a point for each of his blocks that
			// are greater than at least one of Naomi's blocks, without
			// replacement (two blocks can't get credit for beating the same
			// opponent blocks):
			warScore = playWar(naomiBlocks, kenCopy);
			
			// Play Deceitful War:
			// The situation is now reversed: Naomi can get a point for each
			// of her blocks that are greater than at least one of Ken's
			// blocks, without replacement:
			deceitfulWarScore = numBlocks - playWar(kenBlocks, naomiCopy);
			
			
			writer.println("Case #" + (i + 1) + ": " + deceitfulWarScore + " "
					       + warScore);
			
		}
		
		writer.close();
	}

}