package GettingTheDigits;

import java.io.File;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map.Entry;
import java.util.Scanner;

public class GettingTheDigits
{
	private static final String PROBLEM_NAME = GettingTheDigits.class.getSimpleName();
	private static final String WORK_DIR = "/Development/Projects/GCJ/16-1B/" + PROBLEM_NAME + "/";
//	private static final String INPUT_PATH = WORK_DIR + "sample.in";
//	private static final String INPUT_PATH = WORK_DIR + "A-small-attempt2.in";
	private static final String INPUT_PATH = WORK_DIR + "A-large.in";
//	private static final String INPUT_PATH = WORK_DIR + "debug.in";
	private static final String OUTPUT_PATH = INPUT_PATH.replace(".in", ".out");
	
	private static ArrayList<HashMap<Character, Integer>> digitMaps;
	
	private static String[] digitStrings = new String[] {
			"ZERO", // z
			"SIX", // x
			"TWO", // w
			"EIGHT", // g h
			"THREE", // r
			"FOUR",  // r
			"SEVEN", // s
			"FIVE", // v
			"ONE", // o 
			"NINE" };
	
	private static int[] digitNumbers = new int[] {
			0,
			6,
			2,
			8,
			3,
			4,
			7,
			5,
			1,
			9 };
	
	public static void main(String[] args) throws Exception
	{
		System.out.println("Solving " + PROBLEM_NAME + "...");
		System.out.println("Input: " + INPUT_PATH);
		System.out.println("Output: " + OUTPUT_PATH);
		
		PrintWriter out = new PrintWriter(OUTPUT_PATH, "US-ASCII");
		Scanner in = new Scanner(new File(INPUT_PATH), "US-ASCII");
		in.useLocale(Locale.US);
		
		int testCasesNumber = in.nextInt();
		in.nextLine();
		System.out.println("Test cases: " + testCasesNumber);
		
		digitMaps = new ArrayList<>();
		
		for (String digit : digitStrings)
		{
			digitMaps.add(mapCharsToNumbers(digit));
		}
		
		try
		{
			for (int testCase = 1; testCase <= testCasesNumber; testCase++)
			{
				System.out.println("Solving test case: " + testCase + "...");
				out.print("Case #" + testCase + ": ");
				new GettingTheDigits().solve(in, out);
				out.flush();
			}
		}
		finally
		{
			in.close();
			out.close();
		}
		
		System.out.println("All test cases solved!");
	}
	
	public void solve(Scanner in, PrintWriter out)
	{
		String S = in.next();
		HashMap<Character, Integer> map = mapCharsToNumbers(S);
		
		ArrayList<Integer> result = new ArrayList<>();
		int current = 0;
		while (!map.isEmpty())
		{
			if (checkContainsAllChars(map, digitMaps.get(current)))
			{
				decrementChars(map, digitMaps.get(current));
				result.add(digitNumbers[current]);
			}
			else
			{
				current++;
			}
		}
		
		Collections.sort(result);
		for (int digit : result)
			out.print(digit);
		
		out.println();
	}
	
	private void decrementChars(HashMap<Character, Integer> map, HashMap<Character, Integer> digitMap)
	{
		for (Entry<Character, Integer> entry : digitMap.entrySet())
		{
			Character c = entry.getKey();
			if (map.get(c) == entry.getValue())
			{
				map.remove(c);
			}
			else
			{
				map.put(c, map.get(c) - entry.getValue());
			}
		}
	}
	
	private boolean checkContainsAllChars(HashMap<Character, Integer> map,
			HashMap<Character, Integer> digitMap)
	{
		for (Entry<Character, Integer> entry : digitMap.entrySet())
		{
			if (!map.containsKey(entry.getKey())
				|| map.get(entry.getKey()) < entry.getValue())
				return false;
		}
		
		return true;
	}
	
	private static HashMap<Character, Integer> mapCharsToNumbers(String string)
	{
		HashMap<Character, Integer> map = new HashMap<>();
		
		for (int i = 0; i < string.length(); i++)
		{
			if (!map.containsKey(string.charAt(i)))
			{
				map.put(string.charAt(i), 1);
			}
			else
			{
				map.put(string.charAt(i), map.get(string.charAt(i)) + 1);
			}
		}
		
		return map;
	}
}
