package Dijkstra;

import java.io.File;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.Scanner;

public class Dijkstra
{
	private static final String PROBLEM_NAME = Dijkstra.class.getSimpleName();
	private static final String WORK_DIR = "/Development/Projects/GCJ/15-Q/" + PROBLEM_NAME + "/";
//	private static final String INPUT_PATH = WORK_DIR + "sample.txt";
	private static final String INPUT_PATH = WORK_DIR + "C-small-attempt1.in";
//	private static final String INPUT_PATH = WORK_DIR + "large.txt";
//	private static final String INPUT_PATH = WORK_DIR + "debug.txt";
	private static final String OUTPUT_PATH = INPUT_PATH + "-out.txt";
	
	public static void main(String[] args) throws Exception
	{
		System.out.println("Solving " + PROBLEM_NAME + "...");
		System.out.println("Input: " + INPUT_PATH);
		System.out.println("Output: " + OUTPUT_PATH);
		
		PrintWriter out = new PrintWriter(OUTPUT_PATH, "US-ASCII");
		Scanner in = new Scanner(new File(INPUT_PATH), "US-ASCII");
		in.useLocale(Locale.US);
		
		int testCasesNumber = in.nextInt();
		in.nextLine();
		System.out.println("Test cases: " + testCasesNumber);
		
		try
		{
			for (int testCase = 1; testCase <= testCasesNumber; testCase++)
			{
				System.out.println("Solving test case: " + testCase + "...");
				out.print("Case #" + testCase + ": ");
				new Dijkstra().solve(in, out);
				out.flush();
			}
		}
		finally
		{
			in.close();
			out.close();
		}
		
		System.out.println("All test cases solved!");
	}
	
	static final int P1 = 0;
	static final int Pi = 1;
	static final int Pj = 2;
	static final int Pk = 3;
	static final int M1 = 4;
	static final int Mi = 5;
	static final int Mj = 6;
	static final int Mk = 7;
	
	int m[][] =
	{
			{ P1, Pi, Pj, Pk, M1, Mi, Mj, Mk },
			{ Pi, M1, Pk, Mj, Mi, P1, Mk, Pj },
			{ Pj, Mk, M1, Pi, Mj, Pk, P1, Mi },
			{ Pk, Pj, Mi, M1, Mk, Mj, Pi, P1 },
			{ M1, Mi, Mj, Mk, P1, Pi, Pj, Pk },
			{ Mi, P1, Mk, Pj, Pi, M1, Pk, Mj },
			{ Mj, Pk, P1, Mi, Pj, Mk, M1, Pi },
			{ Mk, Mj, Pi, P1, Pk, Pj, Mi, M1 },
	};
	
	public void solve(Scanner in, PrintWriter out)
	{
		in.nextInt(); // skip L
		long X = in.nextLong();
		String part = in.next();
		
		StringBuilder sb = new StringBuilder();
		for (int i = 0; i < X; i++)
		{
			sb.append(part);
		}
		
		String s = sb.toString();
		boolean found = false;

		int c1 = P1;
		out: for (int i = 0; i < s.length();)
		{
			int p1 = reduce(s, i, Pi, c1);
			
			if (p1 == -1)
				break;
			
			int c2 = P1;
			for (int j = p1 + 1; j < s.length();)
			{
				int p2 = reduce(s, j, Pj, c2);
				
				if (p2 == -1)
					break;

				int c3 = P1;
				for (int k = p2 + 1; k < s.length();)
				{
					int p3 = reduce(s, k, Pk, c3);
					
					if (p3 == -1)
						break;
					
					if (p3 == s.length() - 1)
					{
						found = true;
						break out;
					}
					
					k = p3 + 1;
					c3 = Pk;
				}
				
				j = p2 + 1;
				c2 = Pj;
			}
			
			i = p1 + 1;
			c1 = Pi;
		}
		
		out.println(found ? "YES" : "NO");
	}
	
	private int reduce(String s, int p, int t, int c)
	{
		if (p >= s.length())
			return -1;
		
		int r = m[c][quat(s.charAt(p))];
		
		if (r == t)
			return p;
		
		for (int i = p + 1; i < s.length(); i++)
		{
			r = m[r][quat(s.charAt(i))];
			
			if (r == t)
				return i;
		}
		
		return -1;
	}
	
	private int quat(char c)
	{
		if (c == 'i')
			return Pi;
		else if (c == 'j')
			return Pj;
		else
			return Pk;
	}
}
