package gcj;

import java.io.*;
import java.util.*;

public class DeceitfulWar
{
    private static final String PROBLEM_NAME = DeceitfulWar.class.getSimpleName();
    private static final String WORK_DIR = "D:\\Programming\\GCJ\\Qualification\\" + PROBLEM_NAME + "\\";
//    private static final String INPUT_PATH = WORK_DIR + "sample.txt";
    private static final String INPUT_PATH = WORK_DIR + "small.txt";
//    private static final String INPUT_PATH = WORK_DIR + "large.txt";
    private static final String OUTPUT_PATH = INPUT_PATH.replace(".txt", "-out.txt");
    
    public static void main(String[] args) throws Exception
    {
        System.out.println("Solving " + PROBLEM_NAME + "...");
        System.out.println("Input: " + INPUT_PATH);
        System.out.println("Output: " + OUTPUT_PATH);
        
        PrintWriter out = new PrintWriter(OUTPUT_PATH, "US-ASCII");
        Scanner in = new Scanner(new File(INPUT_PATH), "US-ASCII");
        in.useLocale(Locale.US);
        
        int testCasesNumber = in.nextInt();
        in.nextLine();
        System.out.println("Test cases: " + testCasesNumber);
        
        try
        {
            for (int testCase = 1; testCase <= testCasesNumber; testCase++)
            {
//                System.out.println("Solving test case: " + testCase + "...");
                out.print("Case #" + testCase + ": ");
                new DeceitfulWar().solve(in, out);
                out.flush();
            }
        }
        finally
        {
            in.close();
            out.close();
        }
        
        System.out.println("All test cases solved!");
    }
    
    public void solve(Scanner in, PrintWriter out)
    {
        int N = in.nextInt(); // number of blocks
        
        int y = 0; // number of points Naomi will score if she plays Deceitful War optimally
        int z = 0; // number of points Naomi will score if she plays War optimally
        
        // Naomi's blocks weights
        TreeSet<Double> BN = new TreeSet<Double>(); // 0.00001 - 0.99999 (5 digits after decimal point)
        // Ken's blocks weights
        TreeSet<Double> BK = new TreeSet<Double>();
        // Ken's blocks weights copy
        TreeSet<Double> BK2 = new TreeSet<Double>();
        
        for (int i = 0; i < N; i++)
            BN.add(in.nextDouble());
        
        for (int i = 0; i < N; i++)
        {
            double d = in.nextDouble();
            BK.add(d);
            BK2.add(d);
        }
        
        // Deceitful War
        for (double chosenNaomi : BN)
        {
            double smallestKen = BK.first();
            if (chosenNaomi > smallestKen)
            {
                // Naomi tells Ken her block is heavier than Ken's heaviest
                // so he chooses lightest of his  
                BK.remove(smallestKen);
                
                y++; // Naomi scores
            }
            else
            {
                // Naomi tells Ken her block is a little lighter than Ken's heaviest
                // so he chooses heaviest of his
                BK.pollLast();
                
                // Naomi looses, but eliminates Ken's heaviest block
            }
        }
        
        // War
        for (Double chosenNaomi : BN)
        {
            Double smallestWinningKen = BK2.ceiling(chosenNaomi);
            if (smallestWinningKen == null)
            {
                BK2.pollFirst();
                z++; // Naomi scores
            }
            else
            {
                BK2.remove(smallestWinningKen); // Ken scores
            }
        }
        
        out.println(y + " " + z);
    }
}
