package gcj;

import java.io.*;
import java.util.*;

public class MinesweeperMaster
{
    private static final String PROBLEM_NAME = MinesweeperMaster.class.getSimpleName();
    private static final String WORK_DIR = "D:\\Programming\\GCJ\\Qualification\\" + PROBLEM_NAME + "\\";
//    private static final String INPUT_PATH = WORK_DIR + "sample.txt";
    private static final String INPUT_PATH = WORK_DIR + "small.txt";
//    private static final String INPUT_PATH = WORK_DIR + "large.txt";
    private static final String OUTPUT_PATH = INPUT_PATH.replace(".txt", "-out.txt");
    
    private int R;
    private int C;
    private int M;
    private int revealed;
    private char[][] f;
    private int TARGET_REVEALED;
    private boolean rotated = false;
    
    public static void main(String[] args) throws Exception
    {
        System.out.println("Solving " + PROBLEM_NAME + "...");
        System.out.println("Input: " + INPUT_PATH);
        System.out.println("Output: " + OUTPUT_PATH);
        
        PrintWriter out = new PrintWriter(OUTPUT_PATH, "US-ASCII");
        Scanner in = new Scanner(new File(INPUT_PATH), "US-ASCII");
        in.useLocale(Locale.US);
        
        int testCasesNumber = in.nextInt();
        in.nextLine();
        System.out.println("Test cases: " + testCasesNumber);
        
        try
        {
            for (int testCase = 1; testCase <= testCasesNumber; testCase++)
            {
                System.out.println("Solving test case: " + testCase + "...");
                out.print("Case #" + testCase + ": ");
                new MinesweeperMaster().solve(in, out);
                out.flush();
            }
        }
        finally
        {
            in.close();
            out.close();
        }
        
        System.out.println("All test cases solved!");
    }
    
    public void solve(Scanner in, PrintWriter out)
    {
        R = in.nextInt();
        C = in.nextInt();
        M = in.nextInt();
        TARGET_REVEALED = R * C - M;
        
        out.println();
        
        if (C <= 2 && R <= 2 && M > 0)
        {
            out.println("Impossible");
            return;
        }
        
        if (R > C)
        {
            int temp = C;
            C = R;
            R = temp;
            rotated = true;
        }
        
        f = new char[R][C];
        
        for (int i = 0; i < R; i++)
            for (int j = 0; j < C; j++)
                f[i][j] = '?';
        
        if (TARGET_REVEALED == 9 && C > 2 && R > 2)
        {
            for (int i = 0; i < 3; i++)
                for (int j = 0; j < 3; j++)
                    f[i][j] = '.';
            
            f[1][1] = 'c';
            printResponse(out, f);
            return;
        }
        
        if (checkPossibleToWinWithOneClick())
        {
            f[0][0] = 'c';
            printResponse(out, f);
        }
        else
        {
            out.println("Impossible");
        }
    }
    
    private boolean checkPossibleToWinWithOneClick()
    {
        for (int i = 0; i < R; i++)
        {
            reveal(i, 0);
            
            for (int j = 0; j < C - 1; j++)
            {
                if (i + 1 < R)
                    reveal(i + 1, j);
                
                reveal(i, j + 1);
                
                if (i + 1 < R)
                    reveal(i + 1, j + 1);
                
                if (revealed > TARGET_REVEALED)
                {
                    if (j > 0)
                    {
                        unreveal(i, j);
                        unreveal(i + 1, j);
                        unreveal(i, j + 1);
                        unreveal(i + 1, j + 1);
                        
                        int x = i + 2;
                        if (x < R && j > 3)
                        {
                            reveal(x, j - 1);
                            reveal(x, j - 2);
                            reveal(x, j - 3);
                        }
                    }
                    else
                    {
                        int x = i + 1;
                        
                        if (x < R)
                        {
                            unreveal(x, j);
                            unreveal(x, j + 1);
                        }
                        
                        if (i > 1)
                        {
                            if (C > 4)
                            {
                                unreveal(i, j + 3);
                                unreveal(i, j + 4);
                            }
                        }
                        else
                        {
                            if (i > 0)
                                unreveal(i - 1, C - 1);
                            
                            unreveal(i, C - 1);
                        }
                        
                        if (x < R && C > 2)
                        {
                            reveal(x, j);
                            reveal(x, j + 1);
                            reveal(x, j + 2);
                        }
                    }
                    
                    return revealed == TARGET_REVEALED;
                }
                else if (revealed == TARGET_REVEALED)
                {
                    return true;
                }
            }
        }
        
        return revealed == TARGET_REVEALED;
    }
    
    private void reveal(int i, int j)
    {
        if (f[i][j] == '?')
        {
            f[i][j] = '.';
            revealed++;
        }
    }
    
    private void unreveal(int i, int j)
    {
        if (f[i][j] == '.')
        {
            f[i][j] = '?';
            revealed--;
        }
    }
    
    private void printResponse(PrintWriter out, char[][] f)
    {
        if (rotated)
        {
            for (int i = 0; i < C; i++)
            {
                for (int j = 0; j < R; j++)
                {
                    if (f[j][i] == '?')
                        out.print("* ");
                    else
                        out.print(f[j][i] + " ");
                }
                
                out.println();
            }
        }
        else
        {
            for (int i = 0; i < R; i++)
            {
                for (int j = 0; j < C; j++)
                {
                    if (f[i][j] == '?')
                        out.print("* ");
                    else
                        out.print(f[i][j] + " ");
                }
                
                out.println();
            }
        }
    }
}
