import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.Arrays;
import java.io.BufferedWriter;
import java.util.InputMismatchException;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.io.File;
import java.io.Writer;
import java.io.FilenameFilter;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 * @author Andrey Rechitsky (arechitsky@gmail.com)
 */
public class Main {
	public static void main(String[] args) {
		InputStream inputStream;
		try {
			final String regex = "B-(small|large).*[.]in";
			File directory = new File(".");
			File[] candidates = directory.listFiles(new FilenameFilter() {
				public boolean accept(File dir, String name) {
					return name.matches(regex);
				}
			});
			File toRun = null;
			for (File candidate : candidates) {
				if (toRun == null || candidate.lastModified() > toRun.lastModified())
					toRun = candidate;
			}
			inputStream = new FileInputStream(toRun);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("b.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		FastScanner in = new FastScanner(inputStream);
		FastPrinter out = new FastPrinter(outputStream);
		TaskB solver = new TaskB();
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i, in, out);
		out.close();
	}
}

class TaskB {
    public void solve(int testNumber, FastScanner in, FastPrinter out) {
        int n = in.nextInt();
        int[] a = in.nextIntArray(n);
        Integer [] b = Boxer.box(Arrays.copyOf(a, n));
        Arrays.sort(b);
        int m = getSwapCount(Boxer.unbox(b),a);
        while (Permutation.nextPermutation(b)){
            if (isUpAndDown(Boxer.unbox(b))){
                int t = getSwapCount(Boxer.unbox(b),a);
                if (t<m) m = t;
            }
        }
        out.printLine(String.format("Case #%d: %d", testNumber, m));
    }

    private boolean isUpAndDown(int[]a){
        boolean isUp = true;
        for (int i = 0; i < a.length - 1; i++) {
            if (isUp && a[i+1]<a[i]) isUp = false;
            else if (!isUp && a[i+1]>a[i]) return false;
        }
        return true;
    }

    private int getSwapCount(int[] a1, int [] a2){
        for (int i = 0; i < a1.length; i++) {
            if (a1[i]!=a2[i]){
                for (int j = i+1; j < a2.length; j++) {
                    if (a1[i]==a2[j]){
                        int [] a3 = Arrays.copyOf(a2,a2.length);
                        a3[i] = a2[j];
                        a3[j] = a2[i];
                        return getSwapCount(a1,a3)+1;
                    }
                }
            }
        }
        return 0;
    }
}

class FastScanner {

    private InputStream stream;
    private byte[] buf = new byte[1024];
    private int curChar;
    private int numChars;
    private SpaceCharFilter filter;

    public FastScanner(InputStream stream) {
        this.stream = stream;
    }

    public int read() {
        if (numChars == -1)
            throw new InputMismatchException();
        if (curChar >= numChars) {
            curChar = 0;
            try {
                numChars = stream.read(buf);
            } catch (IOException e) {
                throw new InputMismatchException();
            }
            if (numChars <= 0)
                return -1;
        }
        return buf[curChar++];
    }

    public int nextInt() {
        int c = read();
        while (isSpaceChar(c))
            c = read();
        int sgn = 1;
        if (c == '-') {
            sgn = -1;
            c = read();
        }
        int res = 0;
        do {
            if (c < '0' || c > '9')
                throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while (!isSpaceChar(c));
        return res * sgn;
    }

    public String next() {
        int c = read();
        while (isSpaceChar(c))
            c = read();
        StringBuilder res = new StringBuilder();
        do {
            if (Character.isValidCodePoint(c))
                res.appendCodePoint(c);
            c = read();
        } while (!isSpaceChar(c));
        return res.toString();
    }

    public int[] nextIntArray(int size) {
        int[] array = new int[size];
        for (int i = 0; i < size; i++)
            array[i] = nextInt();
        return array;
    }

    public boolean isSpaceChar(int c) {
        if (filter != null)
            return filter.isSpaceChar(c);
        return isWhitespace(c);
    }

    public static boolean isWhitespace(int c) {
        return c == ' ' || c == '\t' || isEOL(c);
    }

    public static boolean isEOL(int c) {
        return c == '\n' || c == '\r' || c == -1;
    }

    public interface SpaceCharFilter {
        public boolean isSpaceChar(int ch);
    }
}

class FastPrinter {
    private final PrintWriter writer;

    public FastPrinter(OutputStream outputStream) {
        writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
    }

    public FastPrinter(Writer writer) {
        this.writer = new PrintWriter(writer);
    }

    public void close() {
        writer.close();
    }

    public void printLine(String s) {
        writer.println(s);
    }

    }

class Boxer {

    public static Integer[] box(int[] array) {
        Integer[] result = new Integer[array.length];
        for (int i = 0; i < array.length; i++) {
            result[i] = array[i];
        }
        return result;
    }

    public static int[] unbox(Integer[] array) {
        int[] result = new int[array.length];
        for (int i = 0; i < array.length; i++) {
            result[i] = array[i];
        }
        return result;
    }

    }

class Permutation {
    public static boolean nextPermutation(Comparable[] list) {
        int incrementing = findNextIncrementPosition(list);
        if (incrementing == -1) return false;

        swap(list, incrementing, findNextSwapPosition(list, incrementing));

        reverse(list, incrementing + 1, list.length - 1);
        return true;
    }

    private static void reverse(Comparable[] list, int start, int end) {
        while (start < end)
            swap(list, start++, end--);
    }

    private static int findNextIncrementPosition(Comparable[] list) {
        int pos = -1;
        for (pos = list.length - 2; pos > -1; pos--) {
            if (list[pos].compareTo(list[pos + 1]) < 0)
                break;
        }
        return pos;
    }

    private static int findNextSwapPosition(Comparable[] list, int pos) {
        for (int i = list.length - 1; i > pos; i--) {
            if (list[pos].compareTo(list[i]) < 0) return i;
        }
        throw new IllegalStateException();
    }

    private static void swap(Comparable[] list, int first, int second) {
        Comparable tmp = list[first];
        list[first] = list[second];
        list[second] = tmp;
    }
}

