import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.PriorityQueue;
import java.util.Set;
import java.util.StringTokenizer;


/*
 * Edges are implicit-- given by the time it takes to travel from one city to another.
 * We can still add edges for a city if we've already visited it. we just can't go backwards
 * For each item in the queue, different horses may be used.
 * Run a different dijkstras for different horses used?
 * If, at one node, we can switch horses, try switching horses and running dijkstras on the remaining ones.
 * If we've already visited some city, don't revisit for the current dijkstras.
 */




public class CodeJamRoundBProbC {
	static int N, Q;
	static Horse[] horses;
	static List<Edge>[] graph;
	static ArrayList<Set<Integer>> visitedForPath;
	public static void main(String[] args) {
		FastScanner sc = new FastScanner();
		int T = sc.nextInt();
		StringBuilder sb = new StringBuilder();
		for (int t = 1; t <= T; t++) {
			StringBuilder ans = new StringBuilder();
			N = sc.nextInt();
			Q = sc.nextInt();
			//System.out.println(N + " " + Q);
			horses = new Horse[N];
			graph = new ArrayList[N];
			
			for (int n = 0; n < N; n++) {
				horses[n] = new Horse(sc.nextLong(), sc.nextLong());
				graph[n] = new ArrayList<Edge>();
			}
			long d;
			for (int from = 0; from < N; from++) {
				for (int to =0; to < N; to++) {
					d = sc.nextLong();
					if (d != -1L) {
						graph[from].add(new Edge(to, d));
					}
				}
			}

			for (int q = 0; q < Q; q++) {
				visitedForPath = new ArrayList<Set<Integer>>();
				for (int n = 0; n < N; n++) {
					visitedForPath.add(new HashSet<Integer>());
				}
				int u = sc.nextInt()-1;
				int v = sc.nextInt()-1;
				ans.append(dijkstra(u, v) + " ");
			}
			//System.out.println(visitedForPath.size() + " = SIZE");
			sb.append("Case #" + t + ": " + ans.substring(0, ans.length()-1)+"\n");
			//System.out.print(sb.toString());
		}
		System.out.print(sb);

	}
	////////////public State (int target, Set<Integer> visited, long remainingEnergy, long currSpeed, double timeSoFar) {////
	public static double dijkstra(int start, int end) {
		PriorityQueue<State> pq = new PriorityQueue<State>();
		pq.add(new State(start, start, horses[start].energy, horses[start].speed, 0));
		visitedForPath.add(new HashSet<Integer>());
		while (!pq.isEmpty()) {
			State curr = pq.remove();
			//System.out.println(curr.target + " " + curr.timeSoFar + " " + curr.currSpeed);
			if (curr.target == end) {
				return curr.timeSoFar;
			}
			Set<Integer> visited = visitedForPath.get(curr.vIndex);
			if (!visited.contains(curr.target)) {
				visited.add(curr.target);
				//add edges for current horse
				for (Edge next : graph[curr.target]) {
					if (!visited.contains(next.to) && curr.remainingEnergy >= next.dist) {
						pq.add(new State(next.to, curr.vIndex, curr.remainingEnergy - next.dist, curr.currSpeed, curr.timeSoFar + ((next.dist * 1.0) / curr.currSpeed)));
					}
				}
				//add edges for switching horses
				if (horses[curr.target].speed > curr.currSpeed || horses[curr.target].energy > curr.remainingEnergy) {
					for (Edge next : graph[curr.target]) {
						if (!visited.contains(next.to) && horses[curr.target].energy >= next.dist || curr.remainingEnergy < next.dist) {
							//visitedForPath.get(next.to).addAll(visited);
							//System.out.println("ADDING" + next.to);
							pq.add(new State(next.to, next.to, horses[curr.target].energy - next.dist, horses[curr.target].speed, curr.timeSoFar + ((next.dist*1.0 / horses[curr.target].speed))));
						}
					}
					//visitedForPath.add(new HashSet<Integer>());
				}
			}
		}
		return -1;
	}




	public static class Edge {
		int to;
		long dist; 
		public Edge (int to, long dist) {
			this.to= to;
			this.dist = dist;
		}


	}
	public static class Horse {
		long energy;
		long speed;
		public Horse(long energy, long speed) {
			this.energy = energy;
			this.speed = speed;

		}

	}

	public static class State implements Comparable<State>{
		int target;
		//Set<Integer> visited;
		int vIndex;
		long remainingEnergy;
		long currSpeed;
		double timeSoFar;
		public State (int target, int vIndex, long remainingEnergy, long currSpeed, double timeSoFar) {
			this.target = target;
			this.vIndex = vIndex;
			this.remainingEnergy = remainingEnergy;
			this.currSpeed = currSpeed;
			this.timeSoFar = timeSoFar;
		}
		@Override
		public int compareTo(State o) {
			int c1 = Double.compare(timeSoFar, o.timeSoFar);
			return c1 != 0 ? c1 : -1 *  Long.compare(currSpeed, o.currSpeed);
		}



	}



	public static class FastScanner {
		BufferedReader br;
		StringTokenizer st;

		public FastScanner(Reader in) {
			br = new BufferedReader(in);
		}

		public FastScanner() {
			this(new InputStreamReader(System.in));
		}

		String next() {
			while (st == null || !st.hasMoreElements()) {
				try {
					st = new StringTokenizer(br.readLine());
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
			return st.nextToken();
		}

		int nextInt() {
			return Integer.parseInt(next());
		}

		long nextLong() {
			return Long.parseLong(next());
		}

		double nextDouble() {
			return Double.parseDouble(next());
		}

		String readNextLine() {
			String str = "";
			try {
				str = br.readLine();
			} catch (IOException e) {
				e.printStackTrace();
			}
			return str;
		}

		int[] readIntArray(int n) {
			int[] a = new int[n];
			for (int idx = 0; idx < n; idx++) {
				a[idx] = nextInt();
			}
			return a;
		}

		long[] readLongArray(int n) {
			long[] a = new long[n];
			for (int idx = 0; idx < n; idx++) {
				a[idx] = nextLong();
			}
			return a;
		}
	}

}
