import java.util.*;
import java.math.*;

public class Main{

  private final static int N = 16;
  private final static int J = 50;
  private final static int MAX_PRIME = 1000000;
  private final static boolean DEBUG = false;

  static BigInteger[] primes;

  public static BigInteger convertToBase(int[] num, int base){
    BigInteger b = BigInteger.valueOf(base);
    BigInteger e = BigInteger.ONE;
    BigInteger res = BigInteger.ZERO;

    for(int i=0; i<N; i++){
      if(num[i] == 1) res = res.add(e);
      e = e.multiply(b);
    }
    return res;
  }

  public static int getPrimeDivisor(BigInteger num){
    for(int i=0; i<primes.length; i++){
      if(primes[i].equals(num)) return -1;
      if(num.mod(primes[i]).equals(BigInteger.ZERO)) return primes[i].intValue();
    }
    return -1;
  }

  public static void computePrimeNumbers(){
    boolean[] is_prime = new boolean[MAX_PRIME+1];

    for(int i=2; i<=MAX_PRIME; i++) is_prime[i] = true;

    for(int i=2; i*i<=MAX_PRIME; i++){
      if(!is_prime[i]) continue;
      for(int j=2;i*j<=MAX_PRIME; j++) is_prime[i*j] = false;
    }

    int count = 0;
    for(int i=2; i<=MAX_PRIME; i++) if(is_prime[i]) count += 1;

    primes = new BigInteger[count];
    int pos = 0;
    for(int i=2; i<=MAX_PRIME; i++) if(is_prime[i]) primes[pos++] = BigInteger.valueOf(i);
  }

  public static int[] getRandomNumber(){
    Random rnd = new Random();
    int[] ra = new int[N];

    // Special required construction
    ra[0] = 1; ra[N-1] = 1;
    for(int i=1; i<N-1; i++) ra[i] = rnd.nextInt(2);
    return ra;
  }

  public static class Solution implements Comparable<Solution>{
    int[] num;
    int[] divisors;

    public Solution(int[] num, int[] divisors){
      this.num = num;
      this.divisors = divisors;
    }

    public String toString(){
      String s = "";
      for(int i=N-1; i>=0; i--){
        s = s.concat(Integer.toString(num[i]));
      }
      for(int i=0; i<divisors.length; i++){
        s = s.concat(" " + Integer.toString(divisors[i]));
      }
      return s;
    }

    @Override
    public int compareTo(Solution other){
      for(int i=N-1; i>=0; i--){
        if(num[i] != other.num[i]) return other.num[i] - num[i];
      }
      return 0;
    }
  }

  public static void main(String[] args){


    TreeSet<Solution> ts = new TreeSet<Solution>();
    computePrimeNumbers();


    while(ts.size() < J){
      int[] tp = getRandomNumber();
      // There might be collisions, but we don't care...
      int[] divisors = new int[9];
      for(int base=2; base<=10; base++){
        int nd = getPrimeDivisor(convertToBase(tp, base));
        divisors[base-2] = nd;
        if(nd == -1) break;
      }

      boolean valid = true;
      for(int i=0; i<9; i++) if(divisors[i] == -1) valid = false;

      if(DEBUG && valid){
        System.out.println(ts.size());
        Solution sol = new Solution(tp, divisors);
        System.out.println(sol.toString());

        for(int i=0; i<divisors.length; i++){
          BigInteger res = convertToBase(tp, i+2).divide(BigInteger.valueOf(divisors[i]));
          System.out.println((convertToBase(tp, i+2).toString().equals(res.multiply(BigInteger.valueOf(divisors[i])).toString())));
        }
      }
      if(valid) ts.add(new Solution(tp, divisors));
    }

    System.out.println("Case #1:");
    for(Solution sol: ts) System.out.println(sol.toString());

  }
}
