package com.google.codejam.aha;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.IOException;
import java.io.OutputStreamWriter;

public class RPI {
    /**
     * @param args
     */
    public static void main(String[] args) {
        String filename = args[0];
        try {
            new RPI().process(filename);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
    
    public void process(String filename) throws IOException {
        BufferedReader in = new BufferedReader(new FileReader(filename));
        BufferedWriter out = new BufferedWriter(new OutputStreamWriter(System.out));
        
        String line = in.readLine();
        int caseCount = Integer.parseInt(line);
        for (int i = 1; i <= caseCount; i++) {
            int teamCount = Integer.parseInt(in.readLine());
            String[] lines = new String[teamCount];
            for (int j = 0; j < teamCount; j++) {
                lines[j] = in.readLine();
            }
            String output = processCase(teamCount, lines);
            out.write("Case #" + i + ":\n" + output);
        }
        out.flush();
    }
    
    
    public String processCase(int teamCount, String[] lines) {
        Integer[][] schedule;
        
        double[] wins = new double[teamCount];
        double[] gamesCount = new double[teamCount];
        
        double[][] wp = new double[teamCount][teamCount];
        double[] owp = new double[teamCount];
        
        double[] rpi = new double[teamCount];
        
        schedule = new Integer[teamCount][teamCount];
        for (int i = 0; i < teamCount; i++) {
            for (int j = 0; j < teamCount; j++) {
                char c = lines[i].charAt(j);
                if (c == '.') {
                    schedule[i][j] = null;
                } else if (c == '0') {
                    schedule[i][j] = 0;
                } else if (c == '1') {
                    schedule[i][j] = 1;
                }
            }
        }
        
        for (int i = 0; i < teamCount; i++) {
            for (int j = 0; j < teamCount; j++) {
                Integer s = schedule[i][j];
                if (s != null) {
                    gamesCount[i]++;
                    if (s > 0) {
                        wins[i]++;
                    }
                }
            }
        }
        
        // compute wp
        for (int i = 0; i < teamCount; i++) {
            for (int j = 0; j < teamCount; j++) {
                Integer s = schedule[i][j];
                if (s != null) {
                    if (s > 0) {
                        wp[i][j] = (wins[i] - 1) / (gamesCount[i] - 1);
                    } else {
                        wp[i][j] = wins[i] / (gamesCount[i] - 1);
                    }
                } else {
                    wp[i][j] = wins[i] / gamesCount[i];
                }
            }
        }
        
        // compute owp
        for (int i = 0; i < teamCount; i++) {
            owp[i] = 0;
            for (int j = 0; j < teamCount; j++) {
                Integer s = schedule[i][j];
                if (s != null) {
                    owp[i] += wp[j][i];
                }
            }
            owp[i] /= gamesCount[i];
        }
        
        // compute rpi
        for (int i = 0; i < teamCount; i++) {
            double oowp = 0.0;
            for (int j = 0; j < teamCount; j++) {
                Integer s = schedule[i][j];
                if (s != null) {
                    oowp += owp[j];
                }
            }
            oowp /= gamesCount[i];
            
            rpi[i] = wp[i][i] * 0.25 + owp[i] * 0.5 + oowp * 0.25; 
        }
        
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < teamCount; i++) {
            sb.append(rpi[i]);
            sb.append("\n");
        }
        return sb.toString();
    }
}
