package com.google.codejam.aha;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.IOException;
import java.io.OutputStreamWriter;

public class CandySplitting {

    private int[] values;

    /**
     * @param args
     */
    public static void main(String[] args) {
        String filename = args[0];
        try {
            new CandySplitting().process(filename);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void process(String filename) throws IOException {
        BufferedReader in = new BufferedReader(new FileReader(filename));
        BufferedWriter out = new BufferedWriter(new OutputStreamWriter(System.out));
        
        String line = in.readLine();
        int caseCount = Integer.parseInt(line);
        for (int i = 1; i <= caseCount; i++) {
            int candyCount = Integer.parseInt(in.readLine());
            line = in.readLine();
            String output = processCase(candyCount, line);
            out.write("Case #" + i + ": " + output + "\n");
        }
        out.flush();
    }
    
    public String processCase(int candyCount, String line) {
        values = new int[candyCount];
        String[] words = line.split(" ");
        for (int i = 0; i < values.length; i++) {
            values[i] = Integer.parseInt(words[i]);
        }
        
        Integer result = chooseItem(0, new Pile(), new Pile());
        if (result != null)
            return result.toString();
        return "NO";
    }
    
    private Integer chooseItem(int index, Pile patrick, Pile sean) {
        if (index == values.length) {
            // all candy is split
            if (patrick.getXorValue() == sean.getXorValue() && !patrick.isEmpty() && !sean.isEmpty()) {
                return sean.getValue();
            } else {
                return null;
            }
        }
        if (!checkSetBits(index, patrick, sean)) {
            return null;
        }
        
        // current candy item
        int item = values[index];
        
        // give candy to sean
        Integer first = chooseItem(index + 1, patrick, sean.addValue(item));
        
        // give candy to patrick
        Integer second = chooseItem(index + 1, patrick.addValue(item), sean);
        if (first == null) {
            return second;
        } else if (second != null) {
            return Math.max(first, second);
        } else {
            return first;
        }
    }
    
    /** 
     * Check if it is still possible to split the remaining candy such that patrick is happy. 
     */
    private boolean checkSetBits(int index, Pile patrick, Pile sean) {
        for (int bit = 0; bit < 31; bit++) {
            int setBits = 0;
            for (int j = index; j < values.length; j++) {
                setBits += isBitSet(values[j], bit);
            }
            if (setBits % 2 != 0 && isBitSet(patrick.getXorValue(), bit) == isBitSet(sean.getXorValue(), bit)) {
                return false;
            }
        }
        return true;
    }
    
    private int isBitSet(int value, int bit) {
        return (value >> bit) & 0x0001;
    }
    
    private static class Pile {
        private int value = 0;
        private int xorValue = 0;
        private boolean empty = true;
        
        Pile addValue(int item) {
            Pile pile = new Pile();
            pile.value = value + item;
            pile.xorValue = xorValue ^ item;
            pile.empty = false;
            return pile;
        }
     
        public int getValue() {
            return value;
        }
        
        public int getXorValue() {
            return xorValue;
        }
        
        public boolean isEmpty() {
            return empty;
        }
        
        @Override
        public String toString() {
            return value + " - " + xorValue;
        }
    }
}
