package com.google.codejam.aha;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class Magicka {
    private Map<Character, Set<Character>> opposedElements;
    private Map<Combination, Character> combinations;

    /**
     * @param args
     */
    public static void main(String[] args) {
        String filename = args[0];
        try {
            new Magicka().process(filename);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void process(String filename) throws IOException {
        BufferedReader in = new BufferedReader(new FileReader(filename));
        BufferedWriter out = new BufferedWriter(new OutputStreamWriter(System.out));
        
        String line = in.readLine();
        int caseCount = Integer.parseInt(line);
        for (int i = 1; i <= caseCount; i++) {
            line = in.readLine();
            String output = processCase(line);
            out.write("Case #" + i + ": " + output + "\n");
        }
        out.flush();
    }
    
    public String processCase(String line) {
        opposedElements = new HashMap<Character, Set<Character>>();
        combinations = new HashMap<Combination, Character>();
        List<Character> elements = new ArrayList<Character>(100);
        
        WordReader reader = new WordReader(line);
        int combinationCount = Integer.parseInt(reader.next());
        for (int i = 0; i < combinationCount; i++) {
            addCombination(reader.next());
        }
        
        int opposedCount = Integer.parseInt(reader.next());
        for (int i = 0; i < opposedCount; i++) {
            String opposed = reader.next();
            char first = opposed.charAt(0);
            char second = opposed.charAt(1);
            
            addOpposedElement(first, second);
            addOpposedElement(second, first);
        }
        
        int castsCount = Integer.parseInt(reader.next());
        String casts = reader.next();
        for (int i = 0; i < castsCount; i++) {
            char cast = casts.charAt(i);
            
            // first check combinations
            if (elements.size() > 0) {
                Character result = getCombination(cast, elements.get(elements.size() - 1));
                if (result != null) {
                    elements.remove(elements.size() - 1);
                    elements.add(result);
                    continue;
                }
            }
            
            // check opposed elements
            Set<Character> opposed = opposedElements.get(cast);
            if (opposed != null) {
                boolean clear = false;
                for (Character element : elements) {
                    if (opposed.contains(element)) {
                        clear = true;
                        break;
                    }
                }
                if (clear) {
                    elements.clear();
                    continue;
                }
            }
            
            // simply add the element
            elements.add(cast);
        }
        
        return elements.toString();
    }

    private void addCombination(String combination) {
        char first = combination.charAt(0);
        char second = combination.charAt(1);
        char result = combination.charAt(2);
        
        combinations.put(new Combination(first, second), result);
    }
    
    private Character getCombination(char first, char second) {
        Combination key = new Combination(first, second);
        return combinations.get(key);
    }
    
    private void addOpposedElement(char first, char second) {
        Set<Character> list = opposedElements.get(first);
        if (list == null) {
            list = new HashSet<Character>();
            opposedElements.put(first, list);
        }
        list.add(second);
    }

    private class Combination {
        public char first;
        public char second;
        
        public Combination(char first, char second) {
            this.first = first;
            this.second = second;
        }

        @Override
        public int hashCode() {
            return (int)first ^ (int)second;
        }
        
        @Override
        public boolean equals(Object obj) {
            if (!(obj instanceof Combination)) return false;
            Combination other = (Combination)obj;
            return other.first == first && other.second == second
                || other.second == first && other.first == second;
        }
    }

    private class WordReader {
        private String[] words;
        int currentIndex = 0;
        
        public WordReader(String line) {
            words = line.split(" ");
        }
        
        public boolean hasNext() {
            return currentIndex < words.length;
        }
        
        public String next() {
            return words[currentIndex++];
        }
    }
}
