package com.google.codejam.aha;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.IOException;
import java.io.OutputStreamWriter;

public class BotTrustMain {

    /**
     * @param args
     */
    public static void main(String[] args) {
        String filename = args[0];
        try {
            new BotTrustMain().process(filename);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private static class Instruction {
        public Instruction(int button, char robot) {
            super();
            this.button = button;
            this.robot = robot;
            this.prevIndexSameRobot = -1;
            this.cost = 0; 
        }

        public int button;
        public char robot;
        
        public int prevIndexSameRobot;
        public int cost;
    }
    
    public void process(String filename) throws IOException {
        BufferedReader in = new BufferedReader(new FileReader(filename));
        BufferedWriter out = new BufferedWriter(new OutputStreamWriter(System.out));
        
        String line = in.readLine();
        int caseCount = Integer.parseInt(line);
        for (int i = 1; i <= caseCount; i++) {
            line = in.readLine();
            int cost = processLine(line);
            out.write("Case #" + i + ": " + cost + "\n");
        }
        out.flush();
    }
    
    public int processLine(String line) {
        int instructionsCount;
        String[] words = line.trim().split(" ");
        instructionsCount = Integer.parseInt(words[0]);
        Instruction[] instructions = new Instruction[instructionsCount];
        
        for (int i = 0; i < instructions.length; i++) {
            char robot = words[2 * i + 1].trim().charAt(0);
            int button = Integer.parseInt(words[2 * i + 2].trim());
            instructions[i] = new Instruction(button, robot);
        }
        
        for (int i = instructions.length - 1; i >= 0; i--) {
            Instruction instruction = instructions[i];
            for (int j = i - 1; j >= 0; j--) {
                if (instructions[j].robot == instruction.robot) {
                    instruction.prevIndexSameRobot = j;
                    break;
                }
            }
        }
        
        Instruction previous = null;
        for (int i = 0; i < instructions.length; i++) {
            Instruction instruction = instructions[i];
            if (previous == null) {
                instruction.cost = instruction.button; 
            } else {
                int costSameRobot;
                if (instruction.prevIndexSameRobot == -1) {
                    costSameRobot = instruction.button; 
                } else {
                    Instruction prevSameRobot = instructions[instruction.prevIndexSameRobot];
                    costSameRobot = prevSameRobot.cost + Math.abs(prevSameRobot.button - instruction.button) + 1;
                }
                int costFromPrev = previous.cost + 1;
                instruction.cost = Math.max(costSameRobot, costFromPrev);
            }
            previous = instruction;
        }
        
        return instructions[instructions.length - 1].cost;
    }

}
