package com.denodev.tour1a.b;

import com.google.common.base.Joiner;

import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author Arnaud DENOYELLE
 *
 *         Le 09 avr. 2016
 */
public class ProblemB {

  public static final String WORKSPACE = "/home/adenoyelle/gcj";
  public static final String OUTPUT = "output.txt";

  public static void main(String[] args) throws Exception {
    Path outputFilePath = Paths.get(WORKSPACE, OUTPUT);
    Files.deleteIfExists(outputFilePath);
    Files.createFile(outputFilePath);

    Path inputFilePath = Files.list(Paths.get(WORKSPACE))
        .filter(path -> path.toString().endsWith(".in"))
        .findFirst().get();

    List<String> lines = Files.readAllLines(inputFilePath);
    Iterator<String> iterator = lines.iterator();

    int nbPbs = Integer.valueOf(iterator.next());

    for (int testCase = 1; testCase <= nbPbs; testCase++) {
      int n = Integer.valueOf(iterator.next());
      List<Line> problem = new ArrayList<>();
      for (int i = 0; i < 2 * n - 1; i++) {
        List<Integer> numbers = Arrays
            .stream(iterator.next().split(" "))
            .map(Integer::parseInt)
            .collect(Collectors.toList());
        Line line = new Line();
        line.setNumbers(numbers);
        problem.add(line);
      }
      writeSol(outputFilePath, testCase, "" + go(problem, n));
    }
  }

  public static void writeSol(Path outputFile, int testCase, String solution) throws Exception {
    Files.write(outputFile, String.format("Case #%d: %s\n", testCase, solution).getBytes(), StandardOpenOption.APPEND);
  }

  public static String go(List<Line> lines, int n) {
    for (int i = 0; i < n; i++) {
      int smallestAtI = Integer.MAX_VALUE;
      for(Line line : lines) {
        if(line.getTag() == null) {
          smallestAtI = Math.min(smallestAtI, line.getNumbers().get(i));
        }
      }
      for(Line line : lines) {
        if(line.getTag() == null && line.getNumbers().get(i) == smallestAtI) {
          line.setTag(i);
        }
      }
    }

    Map<Integer, List<Line>> map = new HashMap<>();
    for(Line line : lines) {
      List<Line> list = map.get(line.getTag());
      if(list == null) {
        list = new ArrayList<>();
        map.put(line.getTag(), list);
      }
      list.add(line);
    }

    Integer missing = null;
    for (Map.Entry<Integer, List<Line>> entry : map.entrySet()) {
      if(entry.getValue().size() != 2) {
        missing = entry.getKey();
      }
    }

    Line missingRow = map.get(missing).get(0);

    List<Integer> result = new ArrayList<>();
    for(int i = 0; i< n; i++) {
      if(missing.equals(i)) {
        result.add(missingRow.getNumbers().get(i));
      } else {
        List<Line> lineList = map.get(i);
        if(lineList.get(0).getNumbers().get(missing).equals(missingRow.getNumbers().get(i))) {
          result.add(lineList.get(1).getNumbers().get(missing));
        } else {
          result.add(lineList.get(0).getNumbers().get(missing));
        }
      }
    }
    return Joiner.on(" ").join(result);
  }

}
