package com.denodev.gcj.problem2;

import com.sun.org.apache.regexp.internal.RE;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.*;

/**
 * @author Arnaud DENOYELLE
 *
 *         Le 08 avr. 2017
 */
public class Main {

  public static final char RED = 'R';
  public static final char ORANGE = 'O';
  public static final char YELLOW = 'Y';
  public static final char GREEN = 'G';
  public static final char BLUE = 'B';
  public static final char VIOLET = 'V';

  public static final String IMPOSSIBLE = "IMPOSSIBLE";

  public static final String INPUT_FILE_NAME = "B-small-attempt0.in";
  public static final String OUTPUT_FOLDER = "/Users/arnauddenoyelle/Documents/DENODEV/gcj2017";

  public static void main(String[] args) throws Exception {
    String outputFileName = INPUT_FILE_NAME.replaceAll("\\.in$", ".txt");
    Path outputFilePath = Paths.get(OUTPUT_FOLDER, outputFileName);
    Files.deleteIfExists(outputFilePath);
    Files.createFile(outputFilePath);

    BufferedReader br = new BufferedReader(new InputStreamReader(Main.class.getResourceAsStream(INPUT_FILE_NAME)));
    String line = br.readLine();
    int nbTests = Integer.valueOf(line);
    for (int i = 1; i <= nbTests; i++) {
      String[] parts = br.readLine().split(" ");
      int nbReds   = Integer.valueOf(parts[1]);
      int nbOrange = Integer.valueOf(parts[2]);
      int nbYellow = Integer.valueOf(parts[3]);
      int nbGreen  = Integer.valueOf(parts[4]);
      int nbBlue   = Integer.valueOf(parts[5]);
      int nbViolet = Integer.valueOf(parts[6]);

      String solve = solve(nbReds, nbOrange, nbYellow, nbGreen, nbBlue, nbViolet);
      Files.write(outputFilePath, String.format("Case #%d: %s\n", i, solve).getBytes(), StandardOpenOption.APPEND);
      System.out.println(solve);
    }

  }

  public static String solve(int nbRed, int nbOrange, int nbYellow, int nbGreen, int nbBlue, int nbViolet) {
    Stack<String> reds = new Stack<>();
    Stack<String> yellows = new Stack<>();
    Stack<String> blues = new Stack<>();

    //cas spécifiques : 1 seul bicolore
    if(nbRed == 0 && nbOrange == 1 && nbYellow == 0 && nbGreen == 0 && nbBlue == 0 && nbViolet == 0) {
      return ""+ORANGE;
    }

    if(nbRed == 0 && nbOrange == 0 && nbYellow == 0 && nbGreen == 1 && nbBlue == 0 && nbViolet == 0) {
      return ""+GREEN;
    }

    if(nbRed == 0 && nbOrange == 0 && nbYellow == 0 && nbGreen == 0 && nbBlue == 0 && nbViolet == 1) {
      return ""+VIOLET;
    }

    //cas spécifiques : uniquement bicolore avec complémentaire
    if(nbRed == nbGreen && nbOrange == 0 && nbYellow == 0 && nbBlue == 0 && nbViolet == 0) {
      //Red green
      return repeat("RG", nbRed);
    }

    if(nbRed == 0 && nbOrange == 0 && nbYellow == nbViolet && nbGreen == 0 && nbBlue == 0) {
      //Violet Yellow
      return repeat("VY", nbViolet);
    }

    if(nbRed == 0 && nbOrange == nbBlue && nbYellow == 0 && nbGreen == 0 && nbViolet == 0) {
      //Orange bleu
      return repeat("OB", nbOrange);
    }



    if(nbViolet > 0) {
      if(nbYellow <= nbViolet) {
        return IMPOSSIBLE;
      } else {
        yellows.add(chaine(VIOLET, YELLOW, nbViolet));
        yellows.addAll(genStrings(YELLOW, nbYellow - nbViolet - 1));
      }
    } else {
      yellows.addAll(genStrings(YELLOW, nbYellow));
    }

    if(nbOrange > 0) {
      if(nbBlue <= nbOrange) {
        return IMPOSSIBLE;
      } else {
        blues.add(chaine(ORANGE, BLUE, nbOrange));
        blues.addAll(genStrings(BLUE, nbBlue - nbOrange - 1));
      }
    } else {
      blues.addAll(genStrings(BLUE, nbBlue));
    }

    if(nbGreen > 0) {
      if(nbRed <= nbGreen) {
        return IMPOSSIBLE;
      } else {
        reds.add(chaine(GREEN, RED, nbGreen));
        reds.addAll(genStrings(RED, nbRed - nbGreen - 1));
      }
    } else {
      reds.addAll(genStrings(RED, nbRed));
    }

    return arrangeStacks(reds, yellows, blues);
  }

  public static List<String> genStrings(char c, int nbStrings) {
    List<String> result = new ArrayList<>();
    for(int i = 0; i< nbStrings; i++) {
      result.add(""+c);
    }
    return result;
  }

  public static String repeat(String s, int nbRepeat) {
    StringBuilder sb = new StringBuilder();
    for(int i = 0 ; i<nbRepeat; i ++) {
      sb.append(s);
    }
    return sb.toString();
  }

  public static String arrangeStacks(Stack<String> reds, Stack<String> yellows, Stack<String> blues) {
    Map<Character, Stack<String>> stackMap = new HashMap<>();
    stackMap.put(RED, reds);
    stackMap.put(YELLOW, yellows);
    stackMap.put(BLUE, blues);

    List<Pair> pairs = new ArrayList<>();
    pairs.add(new Pair(RED, reds.size()));
    pairs.add(new Pair(YELLOW, yellows.size()));
    pairs.add(new Pair(BLUE, blues.size()));
    pairs.sort(Comparator.comparing(Pair::getNbOccs).reversed());

    Character le1er = pairs.get(0).getC();
    Character le2eme = pairs.get(1).getC();
    Character le3eme = pairs.get(2).getC();

    StringBuilder sb = new StringBuilder();
    Stack<String> stack1 = stackMap.get(le1er);
    Stack<String> stack2 = stackMap.get(le2eme);
    Stack<String> stack3 = stackMap.get(le3eme);

    if(stack1.size() > stack2.size() + stack3.size()) {
      return IMPOSSIBLE;
    }

    int restants = stack1.size();
    for(int i = restants; i > 0; i--) {
      sb.append(stack1.pop());
      //S'il y en a trop, je tape dans les 2 stacks.
      if(!stack2.isEmpty() && !stack3.isEmpty() && stack2.size() + stack3.size() > restants) {
        sb.append(stack2.pop());
        sb.append(stack3.pop());
      } else {
        //Sinon, je tape dans la première non vide.
        if(!stack2.isEmpty()) {
          sb.append(stack2.pop());
        } else {
          sb.append(stack3.pop());
        }
      }
      restants--;
    }
    return sb.toString();
  }

  private static String chaine(char bi, char mono, int nbBi) {
    StringBuilder sb = new StringBuilder();
    sb.append(mono);
    for(int i = 0; i< nbBi; i++) {
      sb.append(bi);
      sb.append(mono);
    }
    return sb.toString();
  }

  public static class Pair {
    private char c;
    private int nbOccs;

    public Pair(char c, int nbOccs) {
      this.c = c;
      this.nbOccs = nbOccs;
    }

    public char getC() {
      return c;
    }

    public void setC(char c) {
      this.c = c;
    }

    public int getNbOccs() {
      return nbOccs;
    }

    public void setNbOccs(int nbOccs) {
      this.nbOccs = nbOccs;
    }
  }

}
