package com.denodev.problem3;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;

/**
 * @author Le 12 avril 2014.
 */
public class Matrix {

  public static final char BLANK = '.';
  public static final char MINE = '*';

  public static final char[][] SOLUTION_1 = {{'c'}};

  public static final char[][] SOLUTION_4 = {
          {'c', '.'},
          {'.', '.'}
  };
  public static final char[][] SOLUTION_6 = {
          {'c', '.', '.'},
          {'.', '.', '.'}
  };

  public static final char[][] REAL_ALGORITHM_STARTING_POINT = {
          {'c', '.', '.'},
          {'.', '.', '.'},
          {'.', '.', '*'},
  };
  public static final String IMPOSSIBLE = "Impossible";

  private int mines;
  private int empties;
  private char[][] matrix;

  public Matrix(int rows, int cols, int mines) {
    this.mines = mines;
    initMatrix(rows, cols);
  }

  public Matrix(char[][] matrix) {
    this.matrix = matrix;
  }

  private void map(char[][] other) {

    for (int row = 0; row < other.length; row++) {
      for (int col = 0; col < other[0].length; col++) {
        matrix[row][col] = other[row][col];
      }
    }

  }

  private void initMatrix(int rows, int cols) {
    this.matrix = new char[rows][cols];
    for (int row = 0; row < rows; row++) {
      for (int col = 0; col < cols; col++) {
        matrix[row][col] = MINE;
      }
    }
  }

  public void transpose() {
    char[][] newMatrix = new char[matrix[0].length][matrix.length];
    for (int row = 0; row < matrix.length; row++) {
      for (int col = 0; col < matrix[0].length; col++) {
        newMatrix[col][row] = matrix[row][col];
      }
    }
    matrix = newMatrix;
  }

  public int getNbRows() {
    return matrix.length;
  }

  public int getNbCols() {
    return matrix[0].length;
  }

  public String display() {
    if(matrix == null) {
      return IMPOSSIBLE;
    }

    StringBuilder sb = new StringBuilder();
    for (char[] aMatrix : matrix) {
      for (int col = 0; col < matrix[0].length; col++) {
        sb.append(aMatrix[col]);
      }
      sb.append("\n");
    }
    return sb.toString();
  }

  public Matrix solve() {
    empties = getNbRows() * getNbCols() - mines;

    if(empties <= 0) {
      matrix = null;
    } else if (getNbRows() == 1 || getNbCols() == 1) {
      solve1();
    } else if (getNbRows() == 2 || getNbCols() == 2) {
      solve2();
    } else {
      solve3();
    }
    return this;
  }

  /**
   * Specific 1-row solution :
   * <p/>
   * c.......******
   */
  public void solve1() {
    boolean transposed = false;
    if (getNbCols() == 1) {
      transpose();
      transposed = true;
    }
    matrix[0][0] = 'c';
    for (int col = 1; col < getNbCols() - mines; col++) {
      matrix[0][col] = BLANK;
    }

    if (transposed) {
      transpose();
    }
  }

  /**
   * Specific 2-row solution :
   * <p/>
   * c.....*****
   * ......*****
   */
  public void solve2() {

    if(empties == 1) {
      map(SOLUTION_1);
      return;
    }

    if (mines % 2 == 1) {
      matrix = null;
      return;
    }

    boolean transposed = false;
    if (getNbCols() == 2) {
      transpose();
      transposed = true;
    }

    int blankCols = getNbCols() - (mines / 2);

    for (int i = 0; i < blankCols; i++) {
      matrix[0][i] = BLANK;
      matrix[1][i] = BLANK;
    }
    matrix[0][0] = 'c';

    if (transposed) {
      transpose();
    }

  }

  public void solve3() {
    if (empties == 2 || empties == 3 || empties == 5 || empties == 7) {
      matrix = null;
    } else if (empties == 1) {
      map(SOLUTION_1);
    } else if (empties == 4) {
      map(SOLUTION_4);
    } else if (empties == 6) {
      map(SOLUTION_6);
    }  else {
      realAlgorithm();
    }
  }

  private void realAlgorithm() {
    map(REAL_ALGORITHM_STARTING_POINT);
    empties -= 8;

    /*
      The matrix looks like :
      c..**********
      ...**********
      ..F**********
      *************
      *************
      *************
     */

    /*
       Try to fill the first 2 columns by settings blanks 2 by 2.
       If only one 'empty' remains, [2, 2] is used as a fallback point
     */
    for (int row = 3; row < getNbRows(); row++) {
      if (empties == 0) {
        return;
      } else if (empties == 1) {
        setBlank(2, 2); //use the fallback point.
      } else {
        setBlank(row, 0);
        setBlank(row, 1);
      }
    }

    /*
      Now, the matrix looks like :
      c..**********
      ...**********
      ..F**********
      ..***********
      ..***********
      ..***********
      (F = Fallback point)
     */

    //Try to fill the first 2 lines, using [2, 2] as a fallback point.
    for (int col = 3; col < getNbCols(); col++) {
      if (empties == 0) {
        return;
      } else if (empties == 1) {
        setBlank(2, 2); //Use the fallback point.
      } else {
        setBlank(0, col);
        setBlank(1, col);
      }
    }

    /*
      Now, the matrix looks like :
      c............
      .............
      ..F**********
      ..***********
      ..***********
      ..***********
      (F = Fallback point)
     */

    //Now, fill empties one by one
    for (int row = 2; row < getNbRows(); row++) {
      for(int col =2; col < getNbCols(); col++) {
        if(empties == 0) {
          return;
        }
        setBlank(row, col);
      }
    }

    /*
      Now, the matrix looks like :
      c............
      .............
      .............
      .............
      ........*****
      ..***********
     */

  }

  public void setBlank(int row, int col) {
    matrix[row][col] = BLANK;
    empties--;
  }

  public static void main(String[] args) throws Exception {
    String inputFile="/home/adenoyelle/IdeaProjects/google-code-jam/2014/src/test/java/input3.txt";
    String outputFile="/home/adenoyelle/codejam/output3.txt";

    try (BufferedReader br = new BufferedReader(new FileReader(inputFile));
         BufferedWriter output = new BufferedWriter(new FileWriter(outputFile))) {
      int nbProblems = Integer.valueOf(br.readLine());

      for(int i = 1; i <= nbProblems; i++) {
        String[] parts = br.readLine().split(" ");

        Matrix pb3 = new Matrix(Integer.valueOf(parts[0]), Integer.valueOf(parts[1]), Integer.valueOf(parts[2]));

        StringBuilder sb = new StringBuilder();
        sb.append("Case #").append(i).append(":\n");
        String result = pb3.solve().display();
        sb.append(result);
        if(result.equals("Impossible")) {
          sb.append("\n");
        }
        output.write(sb.toString());
      }

    }
  }

}
