package com.denodev.gcj2017.problem_a;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.nio.file.*;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Arnaud DENOYELLE
 *
 *         Le 15 avr. 2017
 */
public class ProblemA {

  public static final String INPUT_FILE_NAME = "A-small-attempt0.in";
  public static final String OUTPUT_FOLDER = "/tmp/gcj2017";

  private static final Logger LOGGER = LoggerFactory.getLogger(ProblemA.class);

  public static void main(String[] args) throws Exception {
    LOGGER.info("Input file : " + INPUT_FILE_NAME);
    String outputFileName = INPUT_FILE_NAME.replaceAll("\\.in$", ".out");
    Path outputFilePath = Paths.get(OUTPUT_FOLDER, outputFileName);
    LOGGER.info("Output file : " + outputFilePath);

    if(Files.deleteIfExists(outputFilePath)) {
      LOGGER.info("Delete existing output file");
    }

    Files.createFile(outputFilePath);

    BufferedReader br = new BufferedReader(new InputStreamReader(ProblemA.class.getResourceAsStream(INPUT_FILE_NAME)));

    int nbTests = Integer.valueOf(br.readLine());
    for(int numTest = 1; numTest <= nbTests; numTest++) {
      LOGGER.info("Test case : "+numTest);

      String[] parts = br.readLine().split(" ");
      int n = Integer.valueOf(parts[0]);
      int k = Integer.valueOf(parts[1]);

      List<Pancake> pancakes = new ArrayList<>();
      for(int cake = 0; cake < n; cake++) {
        String[] pancakeParts = br.readLine().split(" ");
        pancakes.add(new Pancake(Double.valueOf(pancakeParts[0]), Double.valueOf(pancakeParts[1])));
      }

      for(int i = n; i > k ; i--) {
        Pancake pancakeToExclude = Pancake.getMVP(pancakes);
        pancakes = Pancake.allExcept(pancakes, pancakeToExclude);
      }

      String solution = Double.toString(Pancake.getTotalArea(pancakes));
      writeToSolution(outputFilePath, String.format("Case #%d: %s\n", numTest, solution));
    }

  }

  private static void writeToSolution(Path outputFilePath, String string) throws Exception {
    Files.write(outputFilePath, string.getBytes(), StandardOpenOption.APPEND);
  }

}
