import java.io.*;
import java.util.Arrays;
import java.util.Locale;
import java.util.Random;
import java.util.StringTokenizer;
import java.util.TreeSet;
import java.util.concurrent.Callable;
import java.util.concurrent.Future;
import java.util.concurrent.ScheduledThreadPoolExecutor;

public class A implements Runnable {

	private PrintWriter out;
	
	final String file = "src\\A-small";

	static class InputData {
		
		class Elem implements Comparable<Elem> {
			
			int value, ind;
			
			Elem(int value, int ind) {
				this.value = value;
				this.ind = ind;
			}

			@Override
			public int compareTo(Elem o) {
				if (value != o.value)
					return value - o.value;
				return ind - o.ind;
			}
			
		}

        int n, size;
        TreeSet<Elem> s;
        
		InputData(FastReader in) throws IOException {
            n = in.nextInt();
            size = in.nextInt();            
            s = new TreeSet<Elem>();
            for (int i = 0; i < n; i++)
            	s.add(new Elem(in.nextInt(), i));
		}
		
		void solve(PrintWriter out) {
			int res = 0;
			while (s.size() > 0) {
				res++;
				Elem h = s.pollLast();
				if (s.size() > 0) {
					Elem v = s.floor(new Elem(size - h.value, Integer.MAX_VALUE));
					if (v != null) {
						s.remove(v);
					}
				}
			}
			out.println(res);
		}

	}
	
	static class Solver implements Callable<String> {

		InputData data;
		
		Solver(InputData data) {
			this.data = data;
		}

		@Override
		public String call() throws Exception {
			StringWriter out = new StringWriter();
			data.solve(new PrintWriter(out));
			return out.toString();
		}
		
	}

	public void run() {
		try {
			FastReader in = new FastReader(new BufferedReader(new FileReader(file + ".in")));
			out = new PrintWriter(file + ".out");
			
			ScheduledThreadPoolExecutor service = new ScheduledThreadPoolExecutor(7);
			
			int tests = in.nextInt();
			Future<String>[] ts = new Future[tests];
			for (int test = 0; test < tests; ++test) {
				ts[test] = service.submit(new Solver(new InputData(in)));
			}
			for (int test = 0; test < tests; ++test) {
				while (!ts[test].isDone()) {
					Thread.sleep(500);
				}
				System.err.println("Test " + test);
				out.print("Case #" + (test + 1) + ": ");
				out.print(ts[test].get());
			}
			service.shutdown();
			
			out.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	static class FastReader {
		public FastReader(BufferedReader in) {
			this.in = in;
			eat("");
		}
		
		private StringTokenizer st;
		private BufferedReader in;
		
		void eat(String s) {
			st = new StringTokenizer(s);
		}
		
		String next() throws IOException {
			while (!st.hasMoreTokens()) {
				String line = in.readLine();
				if (line == null) {
					return null;
				}
				eat(line);
			}
			return st.nextToken();
		}
		
		int nextInt() throws IOException {
			return Integer.parseInt(next());
		}
		
		long nextLong() throws IOException {
			return Long.parseLong(next());
		}
		
		double nextDouble() throws IOException {
			return Double.parseDouble(next());
		}
	}
	
	public static void main(String[] args) {
		long t = System.currentTimeMillis();
		Locale.setDefault(Locale.US);
		new A().run();
		System.err.println(System.currentTimeMillis() - t);
	}
	
}
