import java.io.*;
import java.util.*;

public class AlphabetCake
{
	public static class CharSect implements Comparable<CharSect>
	{
		int rowMin = -1, colMin = -1, rowMax = -1, colMax = -1;
		boolean blockedLeft, blockedRight, blockedUp, blockedDown;
		char aChar;

		CharSect(char c)
		{
			this.aChar = c;

		}

		public void addElement(int r, int c)
		{
			if (rowMin == -1)
			{
				rowMin = r;
				rowMax = r;
				colMin = c;
				colMax = c;
			}
			else
			{
				rowMin = Math.min(rowMin, r);
				colMin = Math.min(colMin, c);
				rowMax = Math.max(rowMax, r);
				colMax = Math.max(colMax, c);
			}
		}

		public boolean noCollisions(char[][] array)
		{
			for (int r = rowMin; r <= rowMax; r++)
			{
				for (int c = colMin; c <= colMax; c++)
				{
					if (array[r][c] != aChar && array[r][c] != '?')
					{
						return false;
					}
				}
			}
			return true;
		}

		public void fill(char[][] array)
		{
			for (int r = rowMin; r <= rowMax; r++)
			{
				for (int c = colMin; c <= colMax; c++)
				{
					array[r][c] = aChar;
				}
			}
		}

		public boolean canExpand(char[][] array, int newR, int newC)
		{
			if (newR < 0 || newC < 0 || newR >= array.length || newC >= array[0].length) {return false;}

			for (int r = Math.min(rowMin, newR); r <= Math.max(rowMax, newR); r++)
			{
				for (int c = Math.min(colMin, newC); c <= Math.max(colMax, newC); c++)
				{
					if (array[r][c] != aChar && array[r][c] != '?')
					{
						return false;
					}
				}
			}
			return true;
		}

		public void greedyExpand(char[][] array)
		{
			boolean impossible = false;
			while (!impossible)
			{
				impossible = true;
				if (canExpand(array, rowMin - 1, colMin)) {rowMin--; impossible = false;}
				if (canExpand(array, rowMax + 1, colMin)) {rowMax++; impossible = false;}
				if (canExpand(array, rowMin, colMin - 1)) {colMin--; impossible = false;}
				if (canExpand(array, rowMin, colMax + 1)) {colMax++; impossible = false;}
			}

			fill(array);
		}

		public int getSize()
		{
			return (rowMax - rowMin + 1) * (colMax - colMin + 1);
		}

		@Override
		public int compareTo(CharSect o)
		{
			return o.getSize() - this.getSize();
		}
	}

	public static void main(String[] args) throws IOException
	{
//		BufferedReader f = new BufferedReader(new FileReader("test.in"));
		BufferedReader f = new BufferedReader(new FileReader("A-small-attempt0.in"));

		PrintWriter out = new PrintWriter(new BufferedWriter(new FileWriter("AlphabetCake.out")));

		int cases = Integer.parseInt(f.readLine());
		long start = System.nanoTime();

		for (long caseNo = 1; caseNo <= cases; caseNo++)
		{
			// initialize case
			String[] theCase = f.readLine().split("\\s");
			int rows = Integer.parseInt(theCase[0]);
			int cols = Integer.parseInt(theCase[1]);

			char[][] cakeGiven = new char[rows][cols];

			CharSect[] charToCharSect = new CharSect[26];
			ArrayList<CharSect> charSects = new ArrayList<CharSect>();

			for (int i = 0; i < rows; i++)
			{
				cakeGiven[i] = f.readLine().toCharArray();
				for (int j = 0; j < cols; j++)
				{
					char c = cakeGiven[i][j];
					if (c != '?')
					{
						if (charToCharSect[c-'A'] != null)
						{
							charToCharSect[c-'A'].addElement(i, j);
						}
						else
						{
							CharSect cs = new CharSect(c);
							cs.addElement(i, j);
							charToCharSect[c-'A'] = cs;
							charSects.add(cs);
						}
					}
				}
			}

			for (CharSect cs : charSects)
			{
//				if (!cs.noCollisions(cakeGiven)) {System.out.println("ahhhh");}
				cs.fill(cakeGiven);
			}

//			printReadable(cakeGiven);
//			for (CharSect c : charSects)
//			{
//				System.out.println(c.aChar + " " + c.getSize());
//			}

			Collections.sort(charSects);
			for (CharSect cs : charSects)
			{
				cs.greedyExpand(cakeGiven);
			}

			// print case
			String s = "Case #" + caseNo + ":";
			for (int r = 0; r < rows; r++)
			{
				s += "\n";
				for (int c = 0; c < cols; c++)
				{
					s += cakeGiven[r][c];
				}
			}

//			System.out.println(s);
			out.println(s);
//			System.out.println((System.nanoTime() - start) / caseNo / 1000000000.0 * cases);
//			System.out.println("-----------------------");
		}

		out.close();
	}

//	public static void printReadable(char[][] array)
//	{
//		String s = Arrays.deepToString(array);
//		String[] ss = s.split("\\],");
//
//		for (String sss : ss)
//		{
//			System.out.println(sss);
//		}
//	}
}
