import java.io.*;
import java.util.PriorityQueue;

public class PancakeFlip
{
	static int intPow(int a, int b)
	{
		int out = 1;
		for (int i = 0; i < b; i++)
		{
			out *= a;
		}
//		System.out.println(a + " " + b + " " + out);
		return out;
	}

	public static class FlipState implements Comparable<FlipState>
	{
		FlipState parent;
		int size;
		// All pancakes flipped is 0
		int representation;
		int generation;

		FlipState(FlipState parent, int generation, int size, int representation)
		{
			this.parent = parent;
			this.generation = generation;
			this.size = size;
			this.representation = representation;
		}

		FlipState[] getChildren(int flipSize)
		{
			FlipState[] children = new FlipState[size - flipSize + 1];

			int toXor = (intPow(2, flipSize) - 1);
			for (int i = 0; i < children.length; i++)
			{
				children[i] = new FlipState(this, generation + 1, size, representation ^ toXor);
				toXor *= 2;
			}

			return children;
		}

		int getDistance()
		{
			int a = 0;
			int temp = representation;
			for (int i = 0; i < size; i++)
			{
				if (temp % 2 == 1) { a++; }
				temp /= 2;
			}
			return a;
		}

		static FlipState parseCase(String s)
		{
			int a = 0;
			for (int i = 0; i < s.length(); i++)
			{
				if (s.charAt(i) == '-')
				{
					a += intPow(2, i);
				}
			}

			return new FlipState(null, 0, s.length(), a);
		}

		@Override
		public String toString()
		{
			String asThing = "";
			int temp = representation;
			for (int i = 0; i < size; i++)
			{
				asThing = asThing + ((temp % 2 == 1) ? "-" : "+");
				temp /= 2;
			}

			return asThing + " " + generation + " " + getDistance() + " " + representation;
		}

		@Override
		public int compareTo(FlipState o)
		{
//			return this.getDistance() - o.getDistance();
			return this.getDistance() + this.generation - o.getDistance() - o.generation;
		}
	}

	public static void main(String[] args) throws IOException
	{
		// File IO sourced from USACO training pages
		BufferedReader f = new BufferedReader(new FileReader("A-small-attempt1.in"));
		PrintWriter out = new PrintWriter(new BufferedWriter(new FileWriter("a-small.out")));

		int cases = Integer.parseInt(f.readLine());

		long start = System.nanoTime();

		for (int caseNo = 1; caseNo <= cases; caseNo++)
		{
			String[] theCase = f.readLine().split("\\s");
//			System.out.println(theCase[0]);

			FlipState init = FlipState.parseCase(theCase[0]);
			int flipSize = Integer.parseInt(theCase[1]);

//			FlipState[] bestTo = new FlipState[intPow(2, init.size)];
//			bestTo[init.representation] = init;
			boolean[] explored = new boolean[intPow(2, init.size)];
			explored[init.representation] = true;
			PriorityQueue<FlipState> queue = new PriorityQueue<FlipState>();
			queue.add(init);

			int flips = -1;
			FlipState solution = null;
			while (!queue.isEmpty())
			{
				FlipState current = queue.remove();
				explored[current.representation] = true;
				if (current.representation == 0)
				{
					flips = current.generation;
					solution = current;
					break;
				}
				else
				{
					FlipState[] children = current.getChildren(flipSize);
					for (FlipState fs : children)
					{
						if (!explored[fs.representation])
						{
							queue.add(fs);
						}
					}
				}
			}

//			while (solution != null)
//			{
//				System.out.println(solution);
//				solution = solution.parent;
//			}
//			System.out.println("Case #" + caseNo + ": " + ((flips == -1) ? "IMPOSSIBLE" : flips));
			out.println("Case #" + caseNo + ": " + ((flips == -1) ? "IMPOSSIBLE" : flips));
		}

		out.close();
	}
}
