import org.apache.commons.io.FileUtils;
import org.apache.commons.io.LineIterator;

import java.io.File;
import java.io.IOException;
import java.util.Collections;
import java.util.List;
import java.util.LinkedList;
import java.util.ArrayList;
import java.util.Hashtable;


public class IHOPV2
{
    // Input Methods

    public static LinkedList<Integer> spaceSeparatedToIntArray(String in)
    {
        char[] source = in.toCharArray();
        LinkedList<Integer> out = new LinkedList<>();
        int temp = 0;
        for (int i = 0; i < source.length; i++)
        {
            if (source[i] != ' ')
            {
                temp = temp * 10 + Integer.parseInt(source[i] + "");
            }
            else
            {
                out.add(temp);
                temp = 0;
            }
        }
        out.add(temp);
        return out;
    }

    // Helpful Stuff

    public static void pseudoSortBackwards(List<Integer> in)
    {
        // This is only useful for finding max of a list
        // One iteration of bubble sorts the largest number to the top
        for (int i = in.size()-2; i >= 0; i--)
        {
            if (in.get(i+1) > in.get(i)) {Collections.swap(in, i, i+1);}
        }
    }

    // Main

    public static void main(String[] args) throws IOException
    {
        LineIterator input = FileUtils.lineIterator(new File("C:\\Users\\Raisins\\Downloads\\B-small-attempt0.in"), "UTF-8");
        File output = new File("C:\\Users\\Raisins\\Downloads\\B-small-attempt0.out");

        LinkedList<String> entireOutput = new LinkedList<>();

        // Loop through every case
        final int cases = Integer.parseInt(input.nextLine());
        for (int currentCase = 1; currentCase <= cases; currentCase++)
        {
            System.out.print("Case #" + currentCase + ": ");

            // Number of people with pancakes
            int peopleWithPancakes = spaceSeparatedToIntArray(input.nextLine()).get(0);
            // Amount each person has
            ArrayList<Integer> source = new ArrayList(spaceSeparatedToIntArray(input.nextLine()));

            // Pancakes should be Robin Hooded, taken from the richest and given to the poorest
            Collections.sort(source);
            Collections.reverse(source);

            // Dijkstra? IMIG
            class Node implements Comparable<Node>
            {
                boolean toTry = false;
                int distanceFromStart;
                List<Integer> distribution;
                int time;

                List<Node> children = new LinkedList<>();

                Node(List<Integer> nDistribution, int nDistanceFromStart, Hashtable<Integer, Node> nRegister)
                {
                    pseudoSortBackwards(nDistribution);
                    this.distribution = nDistribution;
                    this.distanceFromStart = nDistanceFromStart;

//                    System.out.print("New: ");
//                    for (Integer i : distribution)
//                    {
//                        System.out.print(i + " ");
//                    }
//                    System.out.println();

                    this.time = this.distanceFromStart + this.distribution.get(0);

                    if (nRegister.get(distribution.hashCode()) != null)
                    {
                        if (this.time < nRegister.get(distribution.hashCode()).time)
                        {
                            nRegister.put(distribution.hashCode(), this);
                            toTry = true;
                        }
                    }
                    else
                    {
                        nRegister.put(distribution.hashCode(), this);
                        toTry = true;
                    }
                }

                public int compareTo(Node n)
                {
                    // Sort ascending time
                    return (int)(this.time - n.time);
                }

                void getPossible(Hashtable<Integer, Node> nRegister, List<Node> buffer)
                {
                    // i = 0 would be no change which would recurse into infinity
                    // Anything above half maximum would be symmetric, and besides, time is based on max

                    for (int stolenPancakes = 1; stolenPancakes <= (double)(this.distribution.get(0))/2; stolenPancakes++)
                    {
                        LinkedList<Integer> temp = new LinkedList<Integer>(distribution);
                        temp.push(temp.pop() - stolenPancakes);
                        temp.add(stolenPancakes);

//                        System.out.print("Gen " + distanceFromStart + ": Stole " + stolenPancakes + ": ");
//                        for (Integer i : temp)
//                        {
//                            System.out.print(i + " ");
//                        }
//                        System.out.println();

                        Node child = new Node(temp, distanceFromStart + 1, nRegister);
                        if (child.toTry) {buffer.add(child);}
                    }
                }
            }

            List<Node> current = new LinkedList<>();
            List<Node> children = new LinkedList<>();

            Hashtable<Integer, Node> register = new Hashtable<Integer, Node>();

            Node origin = new Node(source, 0, register);
            current.add(origin);
            do
            {
                for (Node n : current)
                {
                    n.getPossible(register, children);
                }
                current = children;
                children = new LinkedList<Node>();
            }
            while (!current.isEmpty());

            List<Node> all = new ArrayList<Node>(register.values());
            Collections.sort(all);

            Node best = all.get(0);

//            System.out.println("Best:");
            System.out.println(best.time);

//            for(Integer i : best.distribution)
//            {
//                System.out.print(i + " ");
//            }
//            System.out.println();

            entireOutput.add("Case #" + currentCase + ": " + best.time);
        }

        FileUtils.writeLines(output, entireOutput);
        LineIterator.closeQuietly(input);
    }
}

