import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;



public class Solution extends Thread {

	// Java entry point
	static public void main(String [] args){ new Solution().start(); }

	
	final static private String 	PROBLEM_NAME = "A-large";

	static private BufferedReader 	reader;
	static private BufferedWriter 	writer;
	
	static private int				numberOfTests;
	
	public void run() {

		try {
			
			initialize();
			
			getNumberOfTestCases();
			
			solveProblem();
			
		} catch(Exception e) {
			
			// CRY HERE :)
			
		} finally {			
			
			// close reader and writer
			if (reader != null){
				try {
					reader.close();
				} catch (IOException e) {}
			}
			
			if (writer != null){
				try {
					writer.close();
				} catch (IOException e) {}
			}
			
		}
	}


	
	//
	// Static Methods
	//
	
	static private void solveProblem() throws Exception {
		
		String[] 	command;
		int 		seconds;
		int 		numberOfCommands;
		int[]		orange;
		int[]		blue;
		
		int currentBlue, currentOrange;
		int indexBlue, indexOrange;
		
		
		for (int testCase = 1; testCase <= numberOfTests; testCase++){			
			command = null;
			command = reader.readLine().trim().split(" ");
			
			numberOfCommands = Integer.parseInt(command[0]);

			orange 	= new int[(numberOfCommands<<1)];
			blue 	= new int[(numberOfCommands<<1)];
			
			currentBlue = 1;
			currentOrange = 1;		
			
			indexBlue = 0;
			indexOrange = 0;
			
			
			for(int i = 1; i < command.length; i++){
				if (command[i++].equals("O")){
					int temp = Integer.parseInt(command[i]);
					orange[indexOrange++] = Math.abs(currentOrange-temp);
					currentOrange = temp;
					orange[indexOrange++] = i>>1;
				}
				else{
					int temp = Integer.parseInt(command[i]);
					blue[indexBlue++] = Math.abs(currentBlue-temp);
					currentBlue = temp;
					blue[indexBlue++] = i>>1;
				}		
			}

			currentBlue = 0;
			currentOrange = 0;
			
			seconds = 0;
			while(currentBlue < indexBlue || currentOrange < indexOrange){
				
				// both have sequence to complete
				if(currentBlue < indexBlue && currentOrange < indexOrange){
					// blue need to push first
					if (blue[currentBlue + 1] < orange[currentOrange + 1]){
						seconds += blue[currentBlue] + 1;
						orange[currentOrange] = (orange[currentOrange]>(blue[currentBlue] + 1))?(orange[currentOrange]-(blue[currentBlue] + 1)):(0);
						currentBlue += 2;
					}
					// orange need to push first
					else{
						seconds += orange[currentOrange] + 1;
						blue[currentBlue] = (blue[currentBlue]>(orange[currentOrange] + 1))?(blue[currentBlue]-(orange[currentOrange] + 1)):(0);
						currentOrange += 2;
					}
				}
				
				// only blue have sequence to complete
				else if (currentBlue < indexBlue){
					seconds += blue[currentBlue] + 1;
					currentBlue += 2;					
				}
				
				// only orange have sequence to complete
				else if (currentOrange < indexOrange){
					seconds += orange[currentOrange] + 1;
					currentOrange += 2;
				}			
				
			}
			
//			System.out.print("Orange: ");
//			for(int i = 0; i < indexOrange; i++){
//				System.out.print("[+"+orange[i++]+"]:P"+orange[i]+", ");
//			}
//			System.out.println();
//			System.out.print("Blue  : ");
//			for(int i = 0; i < indexBlue; i++){
//				System.out.print("[+"+blue  [i++]+"]:P"+blue  [i]+", ");
//			}
//			System.out.println();
			
			//System.out.print("Case #"+testCase+": "+seconds+"\n");
			if (testCase < numberOfTests){
				writer.write("Case #"+testCase+": "+seconds+"\n");
			}
			else{
				writer.write("Case #"+testCase+": "+seconds);
			}
			
		}
	}



	static private void getNumberOfTestCases() throws Exception {
		try {
			numberOfTests = Integer.parseInt(reader.readLine());
		} catch (Exception e) {
			System.out.println("FAILED TO READER NUMBER OF TESTS!");
			throw new Exception();
		}
	}

	static private void initialize() throws Exception {
		try {
			reader = new BufferedReader(new FileReader(PROBLEM_NAME + ".in"));
			writer = new BufferedWriter(new FileWriter(PROBLEM_NAME + ".out"));
		} catch (Exception e) {
			System.out.println("FAILED TO OPEN READER/WRITER!");
			throw new Exception();
		}
	}
	
	
	
}
