import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.BufferedWriter;
import java.io.Writer;
import static java.io.File.separator;

// This class process the logic for each test case, this is the actual implementation of the solution
public class CountingSheep extends ProblemOneLine {
    private static final String ZERO = "INSOMNIA";

    @Override
    public String solution(BufferedReader input) {
        String result;
        
        try {
            String line = input.readLine();
            long n = Long.parseLong(line);
            
            int flag = 0;
            int positive = 0b1111111111;
            
            if (n != 0) {
                long num = 0;
                long last = 0;
                
                for (long j = 1; flag != positive && j > 0; j++) {
                    num = (n * j);
                    last = num;
                    
                    while (num > 0) {
                        int digit = (int) (num % 10);
                        num /= 10;
                        flag |= 1 << digit;
                    }
                }
                
                result = "" + last; 
            } else {
                result = ZERO;
            }
        } catch (Exception ex) {
            ErrorPrinter.println(ex, CountingSheep.class);
            result = "";
        }
        
        return result;
    }
 
    public static void main(String args[]) {
        Problem.execute(new CountingSheep());
    }
}

// This code prints each test case and reads each test case separately
interface FirstLineProcessor {
    public int testCases(String firstLine);
}

class InputLineStream {
    private int testCases;
    private BufferedReader br;
    private OutputLineStream bw;
    
    public InputLineStream(String inName, String outName) {
        this(inName, outName, null);
    }
    
    public InputLineStream(String inName, String outName,
            FirstLineProcessor first) {
        int cases = 0;
        
        try {
            br = new BufferedReader(new FileReader(inName));
            String line = br.readLine();
            
			// Reads the number of test cases, in cases the first input line it's special use a class 
			//  (normally the same which solves each individual test case)
            if(line != null) {
                if(first == null) {
                    cases = Integer.parseInt(line);
                } else {
                    cases = first.testCases(line);
                }
            }
        } catch (IOException | NumberFormatException ex) {
            ErrorPrinter.println(ex, InputLineStream.class);
            cases = 0;
            
            try {
                br.close();
            } catch (IOException e) {}
        } finally {
            testCases = cases;
        }
        
        try {
            File file = new File(outName);
            
            if (file.exists()) {
                file.delete();
            }
            
            file.createNewFile();
            bw = new OutputLineStream(new FileWriter(file));
        } catch (IOException ex) {
            ErrorPrinter.println(ex, InputLineStream.class);
        }
    }
    
    // Process each test cases
    public boolean process(Problem problem) {
        while(testCases > 0) {
            problem.solve(br, bw);
            testCases--;
        }
        
        try {
            bw.close();
        } catch (IOException ex) {
            ErrorPrinter.println(ex, InputLineStream.class);
        }
        
        return testCases <= 0;
    }
}

// It's convenient to handle the counting and formatting of each test case here, i.e: "Case #_: "
class OutputLineStream extends BufferedWriter {
    private int caseN = 0;

    public OutputLineStream(Writer out) {
        super(out);
    }

    public OutputLineStream(Writer out, int sz) {
        super(out, sz);
    }
    
    public void resetCase() {
        this.caseN = 0;
    }
    
    public void newCase() throws IOException {
        caseN++;
        write(Constants.CASES_HEADER + caseN + Constants.CASES_HEADER_RIGHT);
    }
    
    public void endCase() throws IOException {
        newLine();
    }
}

// I use this to avoid rewritting the i/o code, reads and 
interface Problem {
	
    public boolean solve(BufferedReader input, OutputLineStream out);
    
    public static void execute(String input, String output, Problem problem,
            FirstLineProcessor first) {
        InputLineStream ils = new InputLineStream(input, output, first);
        ils.process(problem);
    }
    
    public static void execute(String input, String output, Problem problem) {
        execute(input, output, problem, null);
    }
    
    public static void execute(Problem problem) {
        execute(problem, null);
    }
    
    public static void execute(Problem problem, FirstLineProcessor first) {
        String name = getName(problem);
        String input = Constants.ROOT_PATH + name + separator + "input";
        String output = Constants.ROOT_PATH + name + separator + "output";
        
        execute(input, output, problem, first);
    }
    
	// The place for the input/output
    public static String getName(Problem problem) {
        String clazz = problem.getClass().getSimpleName();
        
        if(clazz.length() <= 0) {
            clazz = Constants.MISSING_NAME + System.currentTimeMillis();
        } else {
            StringBuilder sb = new StringBuilder();
            boolean b = false;
            
            for (char ch : clazz.toCharArray()) {
                if(b && Character.isUpperCase(ch)) 
                    sb = sb.append(" ");
                
                sb = sb.append(ch);
                b = true;
            }
            
            clazz = sb.toString();
        }
        
        return clazz;
    }
}

abstract class ProblemOneLine implements Problem {
    @Override
    public boolean solve(BufferedReader input, OutputLineStream out) {
        boolean solved = true;
        
        try {
			// Prints the solution for on test case
            out.newCase();
            out.write(solution(input));
            out.endCase();
            out.flush();
        } catch (Exception ex) {
            solved = false;
            ErrorPrinter.println(ex, ProblemOneLine.class);
        }
        
        return solved;
    }
    
    public abstract String solution(BufferedReader input);
}

class Constants {
	// This is the place from which I read the input and output the solution
	// The clase has the same name as the problem
	// <Problem Name>/input
	// <Problem Name>/output
    public static final String ROOT_PATH =
            "";
    public static final String CASES_HEADER = "Case #";
    public static final String CASES_HEADER_RIGHT = ": ";
    public static final String MISSING_NAME = "NO_NAME_";
}

class ErrorPrinter {
    public static void println(Exception ex, Class clazz) {
        System.err.println("At " + clazz.getName() + ":");
        System.err.println("\t" + ex.getClass() + ": " + ex.getMessage());
        System.err.println("\tCaused By: " + ex.getCause());
    }
}