package alienLanguage;

import java.util.SortedMap;
import java.util.TreeMap;

class Node {
	static private Node root = new Node();
	char letter;
	SortedMap<Character, Node> children = new TreeMap<Character, Node>();
	SortedMap<String, Integer> solutions =  new TreeMap<String, Integer>();
	
	private Node() {
		letter = ' ';
	}
	
	public Node(char c) {
		letter = c;
	}

	public static Node getRoot() {
		return root;
	}
	
	public void addWord(String word) {
		Node currentNode = root;
		for (char c : word.toCharArray()) {
			currentNode = currentNode.addLetter(c);
		}
	}

	private Node addLetter(char c) {
		// find the son
		Node letterNode = children.get(c);
		if (letterNode == null) {
			letterNode = new Node(c);
			children.put(c, letterNode);
		}
		return letterNode;
	}

	public int matches(String wordStr) {
		Integer alreadyExistSolution = solutions.get(wordStr); 
		if (alreadyExistSolution != null) {
			return alreadyExistSolution; 
		}
		
		int sum = 0;
		if (wordStr.length() > 0) {
			char firstLetter = wordStr.charAt(0);
			String tail = wordStr.substring(1);
			
			if (firstLetter == '(') {
				int tailEnds = tail.indexOf(")");
				String head = tail.substring(0, tailEnds);
				tail = tail.substring(tailEnds + 1);
				
				for (char nextLetter : head.toCharArray()) {
					sum = sum + singleLetterMatch(nextLetter, tail);
				}
			} else {
				sum = singleLetterMatch(firstLetter ,tail);
			}	
		} else {
			sum = 0;
		}
			
		solutions.put(wordStr, sum);
		return sum;
	}

	private int singleLetterMatch(char firstLetter, String tail) {
		Node subNode = children.get(firstLetter);
		if (subNode != null) {
			if (tail.length() > 0) {
				return subNode.matches(tail);	
			} else {
				return 1;
			}
		} else {
			return 0;
		}
	}
}
