package com.google.magicka;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Hashtable;

/**
 * User: akumar
 * Date: 7/5/11
 * Time: 3:19 PM
 */
public abstract class Magicka {
    private StringBuilder elementList;
    private Hashtable<String, Character> combinationList;
    private Hashtable<Character, ArrayList<Character>> oppositePairs;

    public Magicka() {
        combinationList = new Hashtable<String, Character>();
        elementList = new StringBuilder();
        oppositePairs = new Hashtable<Character, ArrayList<Character>>();
    }

    public void invokeElement(char element) {
        elementList.append(element);
        if (elementList.length() >= 2) {
            int start = elementList.length() - 2;
            String lastTwo = elementList.substring(start);
            Character transformTo = combinationList.get(lastTwo);
            if (transformTo != null) {
                elementList.replace(start, elementList.length(), transformTo.toString());
                element = transformTo;
            }
            if (hasOppositePair(element)) {
                elementList.delete(0, elementList.length());
            }
        }
    }

    private boolean hasOppositePair(char element) {
        ArrayList<Character> characters = oppositePairs.get(element);
        if (characters == null) return false;
        for (Character character : characters) {
            if (elementList.indexOf(character.toString()) != -1) return true;
        }
        return false;
    }

    public String getElementList() {
        return elementList.toString();
    }

    public void addCombinationPair(String pair, Character transformTo) {
        StringBuilder stringBuilder = new StringBuilder(pair);
        combinationList.put(stringBuilder.toString(), transformTo);
        combinationList.put(stringBuilder.reverse().toString(), transformTo);
    }

    public void addOppositePair(char first, char second) {
        addOppositeChar(first, second);
        addOppositeChar(second, first);
    }

    private void addOppositeChar(char first, char second) {
        ArrayList<Character> oppositeChars = oppositePairs.get(first);
        if (oppositeChars == null) {
            oppositeChars = new ArrayList<Character>();
            oppositePairs.put(first, oppositeChars);
        }
        oppositeChars.add(second);
    }

    public abstract void processTestCase(String line) throws IOException;

    public static void main(String [] args) throws IOException {
        FileReader in = null;
        try {
            String fileName = "B-small-attempt0.in";
            in = new FileReader(fileName);

            BufferedReader bufferedReader = new BufferedReader(in);

            String line = bufferedReader.readLine();
            int numberOfTestCases = Integer.parseInt(line);

            for (int i = 0; i < numberOfTestCases; i++) {
                final int finalI = i;
                line = bufferedReader.readLine();
                Magicka magicka = new Magicka() {
                    @Override
                    public void processTestCase(String line) throws IOException {
                        new TestCaseProcessor(this).processTestCase(finalI + 1, line);
                    }
                };
                magicka.processTestCase(line);
            }
        } finally {
            if (in != null) {
                in.close();
            }
        }
    }

}
