import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

public class DWar {

    /**
     * @param args
     */
    public static void main(String[] args) {
        // assuming first arg is input and second is output location
        String inputLoc = args[0];
        String outputLoc = args[1];

        try {
            BufferedReader br = new BufferedReader(new FileReader(inputLoc));
            BufferedWriter bw = new BufferedWriter(new FileWriter(outputLoc));

            // number of test cases
            int tcCount = Integer.parseInt(br.readLine());

            for (int i = 1; i < tcCount + 1; i++) {
                int noOfWts = Integer.parseInt(br.readLine());

                // Naomi's weights
                List<Double> nWts = getWeights(br.readLine().split(" "), noOfWts);

                // Ken's weights
                List<Double> kWts = getWeights(br.readLine().split(" "), noOfWts);

                // sort the lists
                Collections.sort(nWts);
                Collections.sort(kWts);

                // print result
                int numberOfWinsDW = calculateDeceitfulWarWins(new ArrayList<>(nWts), new ArrayList<>(kWts));
                int numberOfWinsW = calculateWarWins(nWts, kWts);
                bw.write("Case #" + i + ": " + numberOfWinsDW + " " + numberOfWinsW + "\n");

            }
            bw.close();
            br.close();
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    private static int calculateWarWins(List<Double> nWts, List<Double> kWts) {
        int score = 0;
        Iterator<Double> nItr = nWts.iterator();

        while (nItr.hasNext()) {
            Double nWt = nItr.next();
            Double kWtUsed = findWeightUsedByKen(kWts, nWt);

            if (nWt.compareTo(kWtUsed) > 0) {
                score += 1;
            }

            // remove this record - well this line is not required but I am
            // trying to match the actual game
            nItr.remove();
        }

        return score;
    }
    
    private static Double findWeightUsedByKen(List<Double> kWts, Double nWt) {
        Iterator<Double> itr = kWts.iterator();
        Double weightUsed = null;
        while (itr.hasNext()) {
            Double wt = itr.next();

            if (wt.compareTo(nWt) > 0) {
                weightUsed = wt;
                itr.remove();
                break;
            }
        }
        
        if (weightUsed == null) {
            weightUsed = kWts.get(0);
            kWts.remove(0);
        }

        return weightUsed;
    }

    private static int calculateDeceitfulWarWins(List<Double> nWts, List<Double> kWts) {
        //System.out.println(nWts);
        //System.out.println(kWts);
        
        int score = 0;
        
        Iterator<Double> nItr = nWts.iterator();
        
        List<Double> bluffsUsed = new ArrayList<>();
        
        while (nItr.hasNext()) {
            // find first element of Naomi's array
            Double firstNWt = nItr.next();
    
            // find first element of Ken's array
            Double firstKWt = kWts.get(0);
            
            Double bluffWt = findBluffedWeight(kWts, firstNWt, firstKWt, bluffsUsed);
            
            Double kWtUsed = findWeightUsedByKen(kWts, bluffWt);
            
            //System.out.println("Bluff:" + bluffWt + ", Ken:" + kWtUsed);
            
            if (bluffWt.compareTo(kWtUsed) > 0) {
                score += 1;
            }
    
            // remove this record - well this line is not required but I am
            // trying to match the actual game
            nItr.remove();
        }

        return score;
    }

    /**
     * @param kWts
     * @param firstNWt
     * @param firstKWt
     * @param bluffsUsed 
     * @return
     */
    private static Double findBluffedWeight(List<Double> kWts, Double firstNWt, Double firstKWt, List<Double> bluffsUsed) {
        Double bluffWt = firstNWt;
        Double lastKWt = kWts.get(kWts.size() - 1);
        
        if (firstNWt.compareTo(firstKWt) > 0) {
            // if Naomi's weight is higher than Ken's weight then bluff with
            // weight to win
            bluffWt = (lastKWt + 1.0d) / 2;
        } else {
            // else use another bluff so that Ken uses his largest weight to win
            if (kWts.size() > 1) {
                Double secondLastKWt = kWts.get(kWts.size() - 2);
                bluffWt = (lastKWt + secondLastKWt) / 2;
            }
        }
        // adding some randomness in bluff
        bluffsUsed.add(bluffWt);
        return bluffWt + 0.000001 * bluffsUsed.size();
    }

    private static List<Double> getWeights(String[] weights, int noOfWts) {
        List<Double> wts = new ArrayList<>();

        for (String wt : weights) {
            wts.add(Double.parseDouble(wt));
        }

        return wts;
    }

}
