import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;

import java.util.List;
import java.io.IOException;

import java.util.Collections;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Arrays;
import java.util.TreeSet;
import java.util.Map;
import java.util.HashMap;

import java.text.DecimalFormat;

import java.math.BigInteger;

public class Minesweeper {		

	final static Charset ENCODING = StandardCharsets.UTF_8;
	
	public static void main(String[] args) throws IOException {

		String problem =  args.length > 0 ? args[0] : "A";
		String scale =  args.length > 1 ? args[1] : "small";
		String num =  args.length > 2 ? args[2] : "0";

		String fileName = problem + "-" + scale + "-" + num + ".in";
		String outFileName = problem + "-" + scale + "-" + num + ".out";
		//InputReader r = new InputReader("A-small-practice.in");
		//int numOfCases = r.open().print().numOfCases();
		Reader in = reader(fileName).open();
		Writer out = writer(outFileName).open();
		int n = in.size();

		for (int i=0; i<n; i++) {
			out.write(i, process(in));
		}
		out.dump();
	}

	public static String[] process(Reader r){

		int[] vals = r.nextAsInts();

		int row = vals[0];
		int col = vals[1];
		int bombs = vals[2];
		int blocks = row * col;
		int empty = blocks - bombs;

		boolean ok = row == 1 || col == 1 || empty == 1 || bombs == 0;
		int gt = row < col ? col : row;
		int lt = row < col ? row : col;
		int folds = 0; int till = 0;
		//log ("blocks: " + blocks + ", empty: " + empty + ", gt: " + gt + ", lt: " + lt);
		for (int i=gt; i>1 && !ok; i--){
			if (empty % i == 0){
				folds = empty / i;
				//log ("i: " + i + ", empty: " + empty + ", folds: " + folds + ", lt: " + lt);
				if (folds > 1){
						//&& (folds < lt)){
								//|| (folds + 1) % lt != 0)){
					ok = true;
					till = i;
				}
			}
		}

		if (!ok)
			return new String[] { "Impossible" };

		int n = 0;
		String[][] arr = new String[gt][lt];

		for (int i=0;i<till; i++){
			for (int j=0;j<Math.min(lt, folds); j++){
				//log ("filling dots, i:" + i + ", j: " + j);
				arr[i][j] = ".";
				n++;
			}
		}

		for (int i=0;i<gt; i++){
			for (int j=0;j<lt; j++){
				//log ("filling rest, i:" + i + ", j: " + j);
				if (arr[i][j] != null && arr[i][j].equals(".")) continue;
				if (n < empty){
					n++;
					arr[i][j] = ".";
				}
				else
					arr[i][j] = "*";
			}
		}		

		arr[0][0] = "c";

		if (row < col) {

			String[] out = new String[lt];
			for (int i=0;i<lt; i++){
				String val = "";
				for (int j=0;j<gt; j++){
					val += arr[j][i];
				}
				out[i] = val;
			}
			return out;
		}
		
		String[] out = new String[gt];
		for (int i=0;i<gt; i++){
			String val = "";
			for (int j=0;j<lt; j++){
				val += arr[i][j];
			}
			out[i] = val;
		}
		return out;
	}

	static Integer add(Integer a, Integer b){
		return a + b;
	}

	static Integer sub(Integer a, Integer b){
		return a - b;
	}

	static Integer mul(Integer a, Integer b){
		return a * b;
	}

	static Integer div(Integer a, Integer b){
		return a / b;
	}

	static BigInteger add(BigInteger a, BigInteger b){
		return a.add(b);
	}

	static BigInteger sub(BigInteger a, BigInteger b){
		return a.subtract(b);
	}

	static BigInteger mul(BigInteger a, BigInteger b){
		return a.multiply(b);
	}

	static BigInteger div(BigInteger a, BigInteger b){
		return a.divide(b);
	}

	static <T, K> Map<T, K> hashmap(){
		return new HashMap<T, K>();
	}

	static <T> List<T> list(){
		return new ArrayList<T>();
	}

	static void log(Object l){
		System.out.println(String.valueOf(l));
	}
	static void nlog(Object l){
		System.out.print(String.valueOf(l));
	}
	static Reader reader(String fileName) {

		return new Reader(fileName);
	}
	static Writer writer(String fileName) {

		return new Writer(fileName);
	}
	public static class Reader {

		String fileName = null;
		List<String> lines = null;
		int readIndex = 1;
		public Reader(String fileName){

			this.fileName = fileName;
		}
		public Reader open() throws IOException {

			lines = readInputFile();
			return this;
		}
		public Reader print() {
			for(int i=0;i<this.lines.size();i++){
				System.out.println(this.lines.get(i));
			} 
			return this;
		}
		public int size() {
			return Integer.parseInt(this.lines.get(0));
		}
		public String read(int index) {
			return this.lines.get(index);
		}
		public String next() {
			return this.read(this.readIndex++);
		}
		public int nextAsInt() {
			return Integer.parseInt(this.next());
		}
		public int[] nextAsInts() {
			String[] vals = this.next().split(" ");
			int[] ret = new int[vals.length];

			for (int i=0; i<vals.length; i++) {
				ret[i] = Integer.parseInt(vals[i]);
			}

			return ret;
		}

		public List<String> readInputFile() throws IOException {
			Path path = Paths.get(this.fileName);
	    	return Files.readAllLines(path, ENCODING);
		}
	}
	public static class Writer {

		String fileName = null;
		List<String> lines = null;
		public Writer(String fileName){

			this.fileName = fileName;
			this.lines = new ArrayList<String>();
		}
		public Writer open() throws IOException {

			return this;
		}
		public Writer write(int index, String content) {

			this.lines.add("Case #" + (index + 1) + ": " + content);
			return this;
		}
		public Writer write(int index, String[] contents) {

			this.lines.add("Case #" + (index + 1) + ":");
			for (int i=0; i<contents.length; i++) {
				this.lines.add(contents[i]);
			}
			return this;
		}
		public Writer dump() throws IOException {
			Path path = Paths.get(this.fileName);
		    try (BufferedWriter writer = Files.newBufferedWriter(path, ENCODING)){
		      for(String line : this.lines){
		        writer.write(line);
		        writer.newLine();
		      }
		    }
		    return this;
		}
	}
}