package ch.me;

import org.apache.commons.io.IOUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.tuple.ImmutablePair;
import org.apache.commons.lang3.tuple.Pair;

import java.io.FileOutputStream;
import java.io.InputStream;
import java.math.BigInteger;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.util.stream.IntStream;

/**
 * @author Andrei Socaciu
 */
public class P3 {

    private static final BigInteger TWO = new BigInteger("2");
    private static final BigInteger FOUR = new BigInteger("4");
    private static final BigInteger THREE = new BigInteger("3");

    enum State {
        I("i"), J("j"), K("k"), ONE("1"), MINUS_ONE("-1"), MINUS_I("-i"), MINUS_J("-j"), MINUS_K("-k");

        String value;

        State(String value) {
            this.value = value;
        }

        public static State byValue(String s) {
            for (State state : State.values()) {
                if (state.value.equals(s)) {
                    return state;
                }
            }
            throw new IllegalArgumentException("No state " + s);
        }
    }

    static final Map<Pair<State, State>, State> multiplicationMap = new HashMap<>();

    static {
        multiplicationMap.put(new ImmutablePair<>(State.ONE, State.ONE), State.ONE);
        multiplicationMap.put(new ImmutablePair<>(State.ONE, State.I), State.I);
        multiplicationMap.put(new ImmutablePair<>(State.ONE, State.J), State.J);
        multiplicationMap.put(new ImmutablePair<>(State.ONE, State.K), State.K);

        multiplicationMap.put(new ImmutablePair<>(State.I, State.ONE), State.I);
        multiplicationMap.put(new ImmutablePair<>(State.I, State.I), State.MINUS_ONE);
        multiplicationMap.put(new ImmutablePair<>(State.I, State.J), State.K);
        multiplicationMap.put(new ImmutablePair<>(State.I, State.K), State.MINUS_J);

        multiplicationMap.put(new ImmutablePair<>(State.J, State.ONE), State.J);
        multiplicationMap.put(new ImmutablePair<>(State.J, State.I), State.MINUS_K);
        multiplicationMap.put(new ImmutablePair<>(State.J, State.J), State.MINUS_ONE);
        multiplicationMap.put(new ImmutablePair<>(State.J, State.K), State.I);

        multiplicationMap.put(new ImmutablePair<>(State.K, State.ONE), State.K);
        multiplicationMap.put(new ImmutablePair<>(State.K, State.I), State.J);
        multiplicationMap.put(new ImmutablePair<>(State.K, State.J), State.MINUS_I);
        multiplicationMap.put(new ImmutablePair<>(State.K, State.K), State.MINUS_ONE);
    }


    public static void main(String[] args) throws Exception {
        InputStream inputStream = P1.class.getResourceAsStream("/C-small-attempt1.in");
        List<String> lines = IOUtils.readLines(inputStream);
        lines.remove(0);
        List<String> results = IntStream.range(0, lines.size()).filter(i -> i % 2 == 0)
                .mapToObj(i -> solve(i, lines.get(i), lines.get(i + 1))).collect(Collectors.toList());
        try (FileOutputStream out = new FileOutputStream("C.out.txt")) {
            IOUtils.writeLines(results, "\n", out);
        }


    }

    private static String solve(int caseNo, String line1, String str) {
        boolean result = solveTrueFalse(line1, str);
        return "Case #" +  (caseNo / 2 + 1) + ": " + (result ? "YES" : "NO");
    }

    private static boolean solveTrueFalse(String line1, String str) {
        String[] parts = line1.split(" ");
        BigInteger L = new BigInteger(parts[0]);
        BigInteger X = new BigInteger(parts[1]);

        if (L.multiply(X).compareTo(new BigInteger("3")) < 0) {
            return false;
        }
        if (L.multiply(X).compareTo(new BigInteger("10000")) <= 0) {
            return solveDirect(L, X, str);
        }
        State partResult = evaluate(str);
        State result = pow(partResult, X);
        return result == State.MINUS_ONE;
    }

    private static boolean solveDirect(BigInteger L, BigInteger X, String str) {
        String completeStr = StringUtils.repeat(str, X.intValue());
        State result = evaluate(completeStr);
        if (result != State.MINUS_ONE) {
            return false;
        }
        State left = State.ONE;
        int indexi = 0;
        while (left != State.I && indexi < completeStr.length()) {
            State step = State.byValue(completeStr.substring(indexi, indexi + 1));
            left = multiply(left, step);
            indexi++;
        }
        if (left != State.I) {
            return false;
        }
        State right = State.ONE;
        int indexk = completeStr.length();
        while (right != State.K && indexk > indexi + 1) {
            State step = State.byValue(completeStr.substring(indexk - 1, indexk));
            right = multiply(step, right);
            indexk--;
        }
        if (right == State.K && indexk > indexi) {
            return true;
        }
        return false;
    }

    private static State pow(State base, BigInteger power) {
        if (base == State.ONE) {
            return State.ONE;
        }
        if (base == State.MINUS_ONE) {
            if (power.mod(TWO).equals(BigInteger.ZERO)) {
                return State.ONE;
            } else {
                return State.MINUS_ONE;
            }
        }
        if (base == State.I || base == State.J || base == State.K) {
            if (power.mod(FOUR).equals(BigInteger.ZERO)) {
                return State.ONE;
            } else if (power.mod(TWO).equals(BigInteger.ZERO)) {
                return State.MINUS_ONE;
            } else if (power.mod(THREE).equals(BigInteger.ZERO)) {
                return State.byValue("-" + base.value);
            } else {
                return base;
            }
        }
        if (base == State.MINUS_I || base == State.MINUS_J || base == State.MINUS_K) {
            if (power.mod(FOUR).equals(BigInteger.ZERO)) {
                return State.ONE;
            } else if (power.mod(TWO).equals(BigInteger.ZERO)) {
                return State.MINUS_ONE;
            } else if (power.mod(THREE).equals(BigInteger.ZERO)) {
                return State.byValue(base.value.replaceAll("-", ""));
            } else {
                return base;
            }
        }
        throw new IllegalStateException("Never");
    }

    private static State evaluate(String str) {
        State state = State.ONE;
        for (int i = 0; i < str.length(); i++) {
            state = multiply(state, State.byValue(str.substring(i, i+1)));
        }
        return state;
    }

    private static State multiply(State s1, State s2) {
        State s11 = State.byValue(s1.value.replaceAll("-", ""));
        State s22 = State.byValue(s2.value.replaceAll("-", ""));
        if (!(s1.value.startsWith("-") ^ s2.value.startsWith("-"))) {
            return multiplicationMap.get(new ImmutablePair<>(s11, s22));
        } else {
            State result = multiplicationMap.get(new ImmutablePair<>(s11, s22));
            if (result.value.startsWith("-")) {
                return State.byValue(result.value.replaceAll("-", ""));
            } else {
                return State.byValue("-" + result.value);
            }
        }
    }


}
