/*
// VERSION 2: double only, without additional libraries
// Author: Alejandro Sotelo Arvalo
// Java JDK 6.0
// Compile: javac -encoding ISO-8859-1 -cp . FlySwatter.java
// Execute: java -cp . FlySwatter
import java.io.*;
import java.util.*;
public class FlySwatter {
  static int compDist(double x1, double y1, double d) {
    double d1=x1*x1+y1*y1,d2=d*d;
    return Math.abs(d1-d2)<=1e-12?0:(d1<d2?-1:1);
  }
  static double circularSegmentArea(double R, double d) { // http://mathworld.wolfram.com/CircularSegment.html
    return R*R*Math.acos(d/R)-d*Math.sqrt(R*R-d*d);
  }
  static double integralDefinidaCirculo(double r, double x1, double x2) {
    // integral definida f(x)=sqrt(r*r-x*x) desde x=x1 hasta x=x2
    return (circularSegmentArea(r,x1)-circularSegmentArea(r,x2))/2;
  }
  public static void main(String[] args) throws Exception {
    java.text.DecimalFormat df=new java.text.DecimalFormat("0.000000");
    Scanner sc=new Scanner(System.in);
    for (int c=0,N=sc.nextInt(); c<N; c++) {
      double f=Double.parseDouble(sc.next()),R=Double.parseDouble(sc.next()),t=Double.parseDouble(sc.next()),r=Double.parseDouble(sc.next()),g=Double.parseDouble(sc.next());
      double B=t+f,b=r+f,p=2*b,q=g-2*f,S=R-B,A=0.0,AR=Math.PI*R*R/4;
      for (double x1=b; x1<R-B; x1+=q+p) for (double y1=b; y1<R-B; y1+=q+p) if (compDist(x1,y1,S)<0) {
        double x2=x1+q,y2=y1+q;
        boolean e1=true,e2=compDist(x2,y1,S)<0,e3=compDist(x2,y2,S)<0,e4=compDist(x1,y2,S)<0;
        if (e3) A+=q*q;
        else if (e2&&e4) {
          // x^2+y^2=S^2 cruza con y=y2 y con x=x2
          double xc=Math.sqrt(S*S-y2*y2);
          A+=q*(xc-x1)+integralDefinidaCirculo(S,xc,x2)-y1*(x2-xc);
        }
        else if (!e2&&!e4) {
          // x^2+y^2=S^2 cruza con x=x1 y con y=y1
          double xc=Math.sqrt(S*S-y1*y1);
          A+=integralDefinidaCirculo(S,x1,xc)-y1*(xc-x1);
        }
        else if (e2&&!e4) {
          // x^2+y^2=S^2 cruza con x=x1 y con x=x2
          A+=integralDefinidaCirculo(S,x1,x2)-y1*(x2-x1);
        }
        else if (!e2&&e4) {
          // x^2+y^2=S^2 cruza con y=y1 y con y=y2
          double xc1=Math.sqrt(S*S-y1*y1),xc2=Math.sqrt(S*S-y2*y2); // xc2<=xc1
          A+=q*(xc2-x1)+integralDefinidaCirculo(S,xc2,xc1)-y1*(xc1-xc2);
        }
      }
      System.out.println("Case #"+(c+1)+": "+df.format((AR-A)/AR).replace(',','.'));
    }
  }
}
*/
// VERSION 1: Version that uses the library Apfloat (http://www.apfloat.org/) to manage better precision and special operations.
// Author: Alejandro Sotelo Arvalo
// Java JDK 6.0 + Apfloat Library (http://www.apfloat.org/apfloat_java/lib/apfloat.jar)
// Compile (Linux)  : javac -encoding ISO-8859-1 -cp .:./apfloat.jar FlySwatter.java
// Compile (Windows): javac -encoding ISO-8859-1 -cp .;./apfloat.jar FlySwatter.java
// Execute (Linux)  : java -cp .:./apfloat.jar FlySwatter
// Execute (Windows): java -cp .;./apfloat.jar FlySwatter
import java.io.*;
import java.util.*;
import org.apfloat.*;
public class FlySwatter {
  static final int digits=50;
  static int compDist(Apfloat x1, Apfloat y1, Apfloat d) {
    Apfloat d1=x1.multiply(x1).add(y1.multiply(y1)),d2=d.multiply(d);
    return ApfloatMath.abs(d1.subtract(d2)).compareTo(new Apfloat("0.000000000000001",digits))<0?0:(d1.compareTo(d2)<0?-1:1);
  }
  static Apfloat circularSegmentArea(Apfloat R, Apfloat d) { // http://mathworld.wolfram.com/CircularSegment.html
    return R.multiply(R).multiply(ApfloatMath.acos(d.divide(R))).subtract(d.multiply(ApfloatMath.sqrt(R.multiply(R).subtract(d.multiply(d)))));
  }
  static Apfloat integralDefinidaCirculo(Apfloat r, Apfloat x1, Apfloat x2) {
    // integral definida f(x)=sqrt(r*r-x*x) desde x=x1 hasta x=x2
    return (circularSegmentArea(r,x1).subtract(circularSegmentArea(r,x2))).divide(new Apfloat("2",digits));
  }
  public static void main(String[] args) throws Exception {
    java.text.DecimalFormat df=new java.text.DecimalFormat("0.000000");
    Scanner sc=new Scanner(System.in);
    for (int c=0,N=sc.nextInt(); c<N; c++) {
      Apfloat f=new Apfloat(sc.next(),digits);
      Apfloat R=new Apfloat(sc.next(),digits);
      Apfloat t=new Apfloat(sc.next(),digits);
      Apfloat r=new Apfloat(sc.next(),digits);
      Apfloat g=new Apfloat(sc.next(),digits);
      Apfloat B=t.add(f),b=r.add(f),p=b.multiply(new Apfloat("2",digits)),q=g.subtract(f.multiply(new Apfloat("2",digits))),S=R.subtract(B),A=new Apfloat("0",digits);
      for (Apfloat x1=b; x1.compareTo(R.subtract(B))<0; x1=x1.add(q.add(p))) for (Apfloat y1=b; y1.compareTo(R.subtract(B))<0; y1=y1.add(q.add(p))) {
        if (compDist(x1,y1,S)>=0) continue;
        Apfloat x2=x1.add(q),y2=y1.add(q);
        boolean e1=true,e2=compDist(x2,y1,S)<0,e3=compDist(x2,y2,S)<0,e4=compDist(x1,y2,S)<0;
        if (e3) A=A.add(q.multiply(q));
        else if (e2&&e4) {
          // x^2+y^2=S^2 cruza con y=y2 y con x=x2
          Apfloat xc=ApfloatMath.sqrt(S.multiply(S).subtract(y2.multiply(y2)));
          A=A.add(q.multiply(xc.subtract(x1)).add(integralDefinidaCirculo(S,xc,x2)).subtract(y1.multiply(x2.subtract(xc))));
        }
        else if (!e2&&!e4) {
          // x^2+y^2=S^2 cruza con x=x1 y con y=y1
          Apfloat xc=ApfloatMath.sqrt(S.multiply(S).subtract(y1.multiply(y1)));
          A=A.add(integralDefinidaCirculo(S,x1,xc).subtract(y1.multiply(xc.subtract(x1))));
        }
        else if (e2&&!e4) {
          // x^2+y^2=S^2 cruza con x=x1 y con x=x2
          A=A.add(integralDefinidaCirculo(S,x1,x2).subtract(y1.multiply(x2.subtract(x1))));
        }
        else if (!e2&&e4) {
          // x^2+y^2=S^2 cruza con y=y1 y con y=y2
          Apfloat xc1=ApfloatMath.sqrt(S.multiply(S).subtract(y1.multiply(y1))),xc2=ApfloatMath.sqrt(S.multiply(S).subtract(y2.multiply(y2))); // xc2<=xc1
          A=A.add(q.multiply(xc2.subtract(x1)).add(integralDefinidaCirculo(S,xc2,xc1).subtract(y1.multiply(xc1.subtract(xc2)))));
        }
      }
      Apfloat AR=ApfloatMath.pi(digits).multiply(R).multiply(R).divide(new Apfloat("4",digits));
      Apfloat porcentaje=AR.subtract(A).divide(AR);
      System.out.println("Case #"+(c+1)+": "+df.format(porcentaje.floatValue()).replace(',','.'));
    }
  }
}
