import java.io.*;
import java.util.*;
import java.lang.*;

public class Main {
    final static boolean debug = false;
    final static String fileName = "";
    final static boolean useFiles = false;

    public static void main(String[] args) throws FileNotFoundException {
        long start;
        if (debug)
            start = System.nanoTime();
        InputStream inputStream;
        OutputStream outputStream;
        if (useFiles) {
            inputStream = new FileInputStream(fileName + ".in");
            outputStream = new FileOutputStream(fileName + ".out");
        } else {
            inputStream = System.in;
            outputStream = System.out;
        }
        InputReader in = new InputReader(inputStream);
        PrintWriter out = new PrintWriter(outputStream);
        Task solver = new Task(in, out);
        solver.solve();
        if(debug)
            out.println((System.nanoTime() - start) / 1e+9);
        out.close();
    }
}

class Digit {
    int No;
    boolean HasSign;

    Digit(int no, boolean sign) {
        No = no;
        HasSign = sign;
    }

    static Digit parse(String a) {
        char last = a.charAt(a.length() - 1);
        return new Digit(last == '1' ? 0 : last - 'i' + 1, a.length() == 2);
    }

    static Digit mul(Digit a, Digit b) {
        if (a.No == 0 && b.No == 0)
            return new Digit(0, a.HasSign ^ b.HasSign);
        if (a.No == 0)
            return new Digit(b.No, a.HasSign ^ b.HasSign);
        if (b.No == 0)
            return new Digit(a.No, a.HasSign ^ b.HasSign);
        if (a.No == b.No)
            return new Digit(0, !(a.HasSign ^ b.HasSign));
        return new Digit(6 - (a.No + b.No), (b.No - a.No != 1 && b.No - a.No != -2) ^ a.HasSign ^ b.HasSign);
    }

    @Override
    public String toString() {
        return (HasSign ? "-" : " ") + (No == 0 ? '1' : (char) (No + 'i' - 1));
    }
}

class Task {
    public void solve() {
//        String[] o = new String[]{"1", "i", "j", "k", "-1", "-i", "-j", "-k"};
//        for (int i = 0; i < o.length; i++) {
//            for (int j = 0; j < o.length; j++) {
//                out.print(Digit.mul(Digit.parse(o[i]), Digit.parse(o[j])) + " ");
//            }
//            out.println();
//        }
        int tests = in.nextInt();
        for (int i = 0; i < tests; i++) {
            solveTest(i);
        }
    }

    void answer(int testNumber, String value){
        out.println("Case #" + (testNumber + 1) + ": " + value);
    }

    void solveTest(int testNumber) {
        int n = in.nextInt();
        int x = in.nextInt();
        String s = in.next();
        int m = n * x;
        if (m < 3) {
            answer(testNumber, "NO");
            return;
        }
        Digit[] a = new Digit[m];
        for (int i = 0; i < n; i++) {
            a[i] = new Digit(s.charAt(i) - 'i' + 1, false);
        }

        for (int k = 1; k < x; k++) {
            for (int i = 0; i < n; i++) {
                a[k * n + i] = a[i];
            }
        }

        Digit prefix = null;
        int firstI = 0;
        for (int i = 0; i < m; i++) {
            if (i == 0)
                prefix = a[i];
            else
                prefix = Digit.mul(prefix, a[i]);
            if (prefix.No == 1 && prefix.HasSign == false) {
                firstI = i;
                break;
            }
        }

        Digit suffix = null;
        int firstK = 0;
        for (int i = m - 1; i >= 0; i--) {
            if (i == m - 1)
                suffix = a[i];
            else
                suffix = Digit.mul(suffix, a[i]);
            if (suffix.No == 3 && suffix.HasSign == false) {
                firstK = i;
                break;
            }
        }

        Digit all = a[0];
        for (int i = 1; i < m; i++){
            all = Digit.mul(all, a[i]);
        }
        boolean result = (all.No == 0 && all.HasSign == true && firstI < firstK);
        answer(testNumber, result ? "YES" : "NO");
    }

    private InputReader in;
    private PrintWriter out;

    Task(InputReader in, PrintWriter out) {
        this.in = in;
        this.out = out;
    }
}

class InputReader {
    public BufferedReader reader;
    public StringTokenizer tokenizer;

    public InputReader(InputStream stream) {
        reader = new BufferedReader(new InputStreamReader(stream), 32768);
        tokenizer = null;
    }

    public String next() {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            try {
                tokenizer = new StringTokenizer(reader.readLine());
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        return tokenizer.nextToken();
    }

    public double nextDouble(){
        return Double.parseDouble(next());
    }

    public int nextInt() {
        return Integer.parseInt(next());
    }

    public char[] nextCharArray(){
        return next().toCharArray();
    }

    public int[] nextIntArray(int n){
        int[] result = new int[n];
        for (int i = 0; i < n; i++)
            result[i] = nextInt();
        return result;
    }

    public long[] nextLongArray(int n){
        long[] result = new long[n];
        for (int i = 0; i < n; i++)
            result[i] = nextLong();
        return result;
    }

    public long nextLong(){
        return Long.parseLong(next());
    }

    public byte nextByte(){
        return Byte.parseByte(next());
    }
}
