import java.util.*;
import java.io.*;
import java.math.BigInteger;
public class Main {
  private static final BigInteger ZERO = BigInteger.ZERO;
  private static final BigInteger ONE = BigInteger.ONE;
  private static final BigInteger TWO = new BigInteger("2");
  private static final BigInteger THREE = new BigInteger("3");

  public static boolean isProbablePrime(BigInteger n, int k) {
      if (n.compareTo(THREE) < 0)
        return true;
      int s = 0;
      BigInteger d = n.subtract(ONE);
      while (d.mod(TWO).equals(ZERO)) {
        s++;
        d = d.divide(TWO);
      }
      for (int i = 0; i < k; i++) {
        BigInteger a = uniformRandom(TWO, n.subtract(ONE));
        BigInteger x = a.modPow(d, n);
        if (x.equals(ONE) || x.equals(n.subtract(ONE)))
          continue;
        int r = 1;
        for (; r < s; r++) {
				x = x.modPow(TWO, n);
				if (x.equals(ONE))
					return false;
				if (x.equals(n.subtract(ONE)))
					break;
			}
			if (r == s) // None of the steps made x equal n-1.
				return false;
		}
		return true;
  }
  
    private static BigInteger uniformRandom(BigInteger bottom, BigInteger top) {
		Random rnd = new Random();
		BigInteger res;
		do {
			res = new BigInteger(top.bitLength(), rnd);
		} while (res.compareTo(bottom) < 0 || res.compareTo(top) > 0);
		return res;
	}

    public static BigInteger getNonTriv(BigInteger bi) {
        BigInteger i = ONE;
        while(true) {
            i = i.add(ONE);
            if (bi.mod(i).equals(ZERO)) {
                break;
            }
        }
        return i;
    }

  public static void main(String[] args) {
    Scanner in = new Scanner(new BufferedReader(new InputStreamReader(System.in)));
    int t = in.nextInt();  // Scanner has functions to read ints, longs, strings, chars, etc.
    for (int i = 1; i <= t; ++i) {
      int n = in.nextInt();
      int m = in.nextInt();
      HashSet<String> keyset = new HashSet<String>();
      HashMap<String, ArrayList<String>> map = new HashMap<String, ArrayList<String>>();
      while(map.size() != m) {
          // generate string with n digits.
          String temp = "";
          for (int j = 0; j < n-2; j++) {
              if(Math.random() < 0.5)
                  temp += "0";
              else
                  temp += "1";
          }
          String current = "1" + temp + "1";
          // no duplicate 
          if(keyset.add(current)) {
            ArrayList<String> nontriv = new ArrayList<String>();
            boolean noPrime = true;
            for (int radix = 2; radix <= 10; radix++) {
                BigInteger bi = new BigInteger(current, radix);
                String bi_in_radix = bi.toString(10);
                BigInteger curBi = new BigInteger(bi_in_radix);
                //System.out.println(curBi);
                if(!isProbablePrime(curBi, 40)) {
                    BigInteger curNontriv = getNonTriv(curBi);
                    nontriv.add(curNontriv.toString());
                }
                else {
                    noPrime = false;
                }
            }
            if(noPrime) {
                map.put(current, nontriv);
                //System.out.println(current);
            }
          }
      }
      //System.out.println("Case #" + i + ": " + (n + m) + " " + (n * m));
      // output map
      System.out.println("Case #" + i + ": ");
      Iterator itt = map.keySet().iterator();
      while(itt.hasNext()) {
          String key = itt.next().toString();
          ArrayList<String> value = map.get(key);
          System.out.print(key);
          for(String ts : value) {
              System.out.print(" "+ts);
          }
          System.out.println(" ");
      }
    }
  }
}
