package com.mani.google.codejam.y2017;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.math.BigInteger;
import java.util.Comparator;
import java.util.PriorityQueue;

/**
 * BathroomStalls.java
 * 
 * @author Manikandan Eswaran
 */
public class BathroomStalls {
   void solve() throws IOException {
      BufferedReader reader = new BufferedReader(
         new FileReader("D:\\small.txt"));
      int testCount = Integer.parseInt(reader.readLine());
      for (int i = 0; i < testCount; i++) {
         String[] tokens = reader.readLine().split(" ");
         maxQueue.clear();
         solve((i + 1), tokens[0], tokens[1]);
      }
      reader.close();
   }
   
   // static class MaxWindow {
   // BigInteger low;
   // Node lowNode;
   // BigInteger high;
   // Node highNode;
   //
   // MaxWindow(BigInteger low, Node lowNode, BigInteger high, Node highNode) {
   // this.low = low;
   // this.lowNode = lowNode;
   // this.high = high;
   // this.highNode = highNode;
   // }
   //
   // public String toString() {
   // return "Low: " + low + " High: " + high;
   // }
   // }
   
   static class MaxWindow {
      BigInteger low;
      BigInteger high;
      
      MaxWindow(BigInteger low, BigInteger high) {
         this.low = low;
         this.high = high;
      }
      
      public String toString() {
         return "Low: " + low + " High: " + high;
      }
   }
   
   // static class Node {
   // BigInteger val;
   // Node next;
   //
   // Node(BigInteger val) {
   // this.val = val;
   // }
   // }
   
   PriorityQueue<MaxWindow> maxQueue = new PriorityQueue<>(1000000,
      new Comparator<MaxWindow>() {
         @Override
         public int compare(MaxWindow m1, MaxWindow m2) {
            BigInteger maxWindowSize1 = m1.high.subtract(m1.low);
            BigInteger maxWindowSize2 = m2.high.subtract(m2.low);
            return maxWindowSize2.compareTo(maxWindowSize1);
         }
      });
   
   private MaxWindow getCurMaxWindow() {
      return maxQueue.poll();
   }
   
   // private MaxWindow getCurMaxWindow(Node node) {
   // MaxWindow maxWindow = new MaxWindow(node.val, node, node.next.val,
   // node.next);
   // BigInteger maxWindowSize = maxWindow.high.subtract(maxWindow.low);
   // while (node.next != null) {
   // if (node.next.val.subtract(node.val).compareTo(maxWindowSize) > 0) {
   // maxWindow = new MaxWindow(node.val, node, node.next.val, node.next);
   // maxWindowSize = maxWindow.high.subtract(maxWindow.low);
   // }
   // node = node.next;
   // }
   // return maxWindow;
   // }
   
   // void print(Node n) {
   // while (n != null) {
   // System.out.print(n.val + "->");
   // n = n.next;
   // }
   // System.out.println();
   // }
   
   private void solve(int testNo, String slotCountString,
      String userCountString) {
      
      // Node root = new Node(BigInteger.ZERO);
      // Node tail = new Node(new
      // BigInteger(slotCountString).add(BigInteger.ONE));
      // root.next = tail;
      
      MaxWindow mw = new MaxWindow(BigInteger.ZERO,
         new BigInteger(slotCountString).add(BigInteger.ONE));
      maxQueue.add(mw);
      
      BigInteger userCountInt = new BigInteger(userCountString);
      //System.out.println("Processing testNo " + testNo);
      for (BigInteger i = BigInteger.ONE; i.compareTo(userCountInt) < 0; i = i
         .add(BigInteger.ONE)) {
         
         // MaxWindow maxWindow = getCurMaxWindow(root);
         MaxWindow maxWindow = getCurMaxWindow();
         
         BigInteger left = maxWindow.low.add(BigInteger.ONE);
         BigInteger right = maxWindow.high.subtract(BigInteger.ONE);
         
         BigInteger range = right.subtract(left).add(BigInteger.ONE);
         
         BigInteger[] divAndRem = range.divideAndRemainder(new BigInteger("2"));
         
         BigInteger mid = maxWindow.low.add(divAndRem[0]).add(divAndRem[1]);
         
         // System.out.println("User " + i + " maxWindow[" + maxWindow.low + ","
         // + maxWindow.high + "] left=" + left + " right=" + right + " range="
         // + range + " mid=" + mid);
         
         // Node midNode = new Node(mid);
         // maxWindow.lowNode.next = midNode;
         // midNode.next = maxWindow.highNode;
         
         maxQueue.add(new MaxWindow(maxWindow.low, mid));
         maxQueue.add(new MaxWindow(mid, maxWindow.high));
      }
      // print(root);
      // MaxWindow maxWindow = getCurMaxWindow(root);
      MaxWindow maxWindow = getCurMaxWindow();
      
      BigInteger left = maxWindow.low.add(BigInteger.ONE);
      BigInteger right = maxWindow.high.subtract(BigInteger.ONE);
      
      BigInteger range = right.subtract(left).add(BigInteger.ONE);
      
      BigInteger[] divAndRem = range.divideAndRemainder(new BigInteger("2"));
      
      BigInteger mid = maxWindow.low.add(divAndRem[0]).add(divAndRem[1]);
      
      // System.out.println("User " + userCountInt + " maxWindow[" +
      // maxWindow.low + ","
      // + maxWindow.high + "] left=" + left + " right=" + right + " range="
      // + range + " mid=" + mid);
      
      BigInteger leftSpace = mid.subtract(left);
      BigInteger rightSpace = right.subtract(mid);
      
      System.out.println("Case #" + testNo + ": " + leftSpace.max(rightSpace)
         + " " + leftSpace.min(rightSpace));
      // System.out.println(
      // slotCountString + " " + userCountString + " Case #" + testNo + ": "
      // + leftSpace.max(rightSpace) + " " + leftSpace.min(rightSpace));
   }
   
   public static void main(String[] args) throws IOException {
      new BathroomStalls().solve();
   }
}
