package com.mani.google.codejam.countingsheep;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Random;

/**
 * @author Manikandan Eswaran
 */
public class CountingSheep {
   private int[] visistedInts = new int[] { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
   
   public void runTest(String fileName) throws IOException {
      BufferedReader br = null;
      try {
         br = new BufferedReader(new FileReader(fileName));
         long n;
         int testCount = Integer.parseInt(br.readLine().trim());
         for (int i = 1; i <= testCount; i++) {
            n = Long.parseLong(br.readLine().trim());
            long count = count(n);
            if (count == -1) {
               System.out.println("Case #" + i + ": INSOMNIA");
            }
            else {
               System.out.println("Case #" + i + ": " + count);
            }
            unsetVisited();
         }
      }
      finally {
         if (br != null) {
            br.close();
         }
      }
   }
   
   private long count(long n) {
      if (n == 0) {
         return -1;
      }
      long currentN = n;
      int i = 1;
      while (!allVisisted()) {
         currentN = i * n;
         checkAndSet(currentN);
         i++;
      }
      return currentN;
   }
   
   private void checkAndSet(long n) {
      while (n != 0 && !allVisisted()) {
         int digit = (int) (n % 10);
         // System.out.println("n = " + n);
         // System.out.println("digit = " + digit);
         visistedInts[digit] = 1;
         n = n / 10;
      }
   }
   
   private boolean allVisisted() {
      return visistedInts[0] == 1 && visistedInts[1] == 1
         && visistedInts[2] == 1 && visistedInts[3] == 1 && visistedInts[4] == 1
         && visistedInts[5] == 1 && visistedInts[6] == 1 && visistedInts[7] == 1
         && visistedInts[8] == 1 && visistedInts[9] == 1;
   }
   
   private void unsetVisited() {
      visistedInts[0] = 0;
      visistedInts[1] = 0;
      visistedInts[2] = 0;
      visistedInts[3] = 0;
      visistedInts[4] = 0;
      visistedInts[5] = 0;
      visistedInts[6] = 0;
      visistedInts[7] = 0;
      visistedInts[8] = 0;
      visistedInts[9] = 0;
   }
   
   public static void main(String[] args) throws IOException {
//      PrintWriter pw = null;      
//      try {
//         pw = new PrintWriter(new FileWriter("D:\\Input.txt"));
//         pw.println("100");
//         for (int i = 0; i < 100; i++) {
//            pw.println(new Random().nextInt(1000000));
//         }
//      }
//      finally {
//         if (pw != null) {
//            pw.close();
//         }
//      }
      new CountingSheep().runTest("D:\\Input.txt");      
   }
}
