import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.util.Scanner;

public class BathroomStalls {
    public String resolve(int n, int k) {
        return findSolution(n, k);
    }

    public String findSolution(int n, int k) {
        if (n == k) {
            return "0 0";
        }

        Stall topLeft = new Stall(-1, -1, null, null);
        Stall topRight = new Stall(-1, -1, null, null);
        initStalls(n, topLeft, topRight);
        Stall bestPos;
        for (int i = 0; i < k - 1; i++) {
            bestPos = findBestPosition(topLeft, topRight);
            updateList(topLeft, topRight, bestPos);
        }

        bestPos = findBestPosition(topLeft, topRight);
        return Math.max(bestPos.right, bestPos.left) + " " + Math.min(bestPos.right, bestPos.left);
    }


    private void updateList(Stall topLeft, Stall topRight, Stall bestPos) {
        bestPos.left = -1;
        bestPos.right = -1;
        Stall pointer = bestPos.leftStall;
        int count = 0;
        while (pointer != topLeft) {
            pointer.right = count;
            count++;
            pointer = pointer.leftStall;
        }

        pointer = bestPos.rightStall;
        count = 0;
        while (pointer != topRight) {
            pointer.left = count;
            count++;
            pointer = pointer.rightStall;
        }
    }

    private Stall findBestPosition(Stall topLeft, Stall topRight) {
        Stall best = topLeft.rightStall;
        Stall pointer = topLeft.rightStall;
        long recordMin = 0;
        long recordMax = pointer.right;
        while (pointer != topRight) {
            if (pointer.left != -1 && pointer.right != -1) {
                long min = Math.min(pointer.left, pointer.right);
                long max = Math.max(pointer.left, pointer.right);
                if (recordMin < min || recordMin == min && recordMax < max) {
                    recordMin = min;
                    best = pointer;
                    recordMax = max;
                }
            }
            pointer = pointer.rightStall;
        }
        return best;
    }

    private void initStalls(int n, Stall topLeft, Stall topRight) {
        Stall pointer = topLeft;
        for (int i = 0; i < n; i++) {
            Stall tmp = new Stall(i, n - i - 1, pointer, null);
            pointer.rightStall = tmp;
            pointer = tmp;
        }
        pointer.rightStall = topRight;
        topRight.leftStall = pointer;
    }

    private static class Stall {
        long left;
        long right;
        Stall leftStall;
        Stall rightStall;

        Stall(int left, int right, Stall leftStall, Stall rightStall) {
            this.left = left;
            this.right = right;
            this.leftStall = leftStall;
            this.rightStall = rightStall;
        }
    }
    
	public static void main(String args[]) {

		try {
			FileWriter foutstream = new FileWriter("B-small.out");
			BufferedWriter out = new BufferedWriter(foutstream);

			Scanner sc = new Scanner(new File("input2.txt"));

			int caseNumber = 1;
			int totalCaseNumber = sc.nextInt();

			int N,K;

			while (caseNumber <= totalCaseNumber) {
				out.write("Case #");
				out.write(String.valueOf(caseNumber++));
				out.write(": ");
				
				N = Integer.parseInt(sc.next());
				K = Integer.parseInt(sc.next());
				BathroomStalls bs = new BathroomStalls();
				out.write(""+bs.resolve(N, K));
				out.newLine();
			}
			sc.close();
			out.close();
		} catch (Exception e) {
			e.printStackTrace();
		}

	}
}