import java.io.BufferedReader;
import java.io.FileReader;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;

public class Main {
    static List<PancakeRow> testCases = new ArrayList<PancakeRow>();

    public static void main(String[] args) {
        String path = "input1.txt";
        readInput(path);
        printOutput(path);
    }

    private static void readInput(String file) {
        try {
            BufferedReader bf = new BufferedReader(new FileReader(file));

            int testCasesCount = Integer.parseInt(bf.readLine());
            for (int i = 0; i < testCasesCount; i++) {
                String line = bf.readLine();
                String[] testCase = line.split(" ");

                PancakeRow row = new PancakeRow(testCase[0], Integer.parseInt(testCase[1]));
                testCases.add(row);
            }
            bf.close();
        } catch (Exception e) {
            System.out.println("Cannot read file");
            e.printStackTrace();
        }
    }

    private static void printOutput(String file) {
        StringBuilder sb = new StringBuilder("");

        for (int i = 0; i < testCases.size(); i++) {
            sb.append("Case #").append(i + 1).append(": ");

            PancakeRow row = testCases.get(i);
            String flips = row.getFlipCount();

            sb.append(flips);
            sb.append("\n");
        }

        for (PancakeRow p : testCases) {
            System.out.println(p.getFlipCount());
        }

        try {
            PrintWriter out = new PrintWriter(file + ".out");

            out.write(sb.toString());
            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}

class PancakeRow {
    private String pancakes;
    private int k;

    public PancakeRow(String pancakes, int k) {
        this.pancakes = pancakes;
        this.k = k;
    }

    @Override
    public String toString() {
        return "PancakeRow{" +
                "pancakes='" + pancakes + '\'' +
                ", k=" + k +
                '}';
    }

    public String getFlipCount() {
        int flips = 0;
        char[] ps = this.pancakes.toCharArray();

        for (int i = 0; i < ps.length - k + 1; i++) {
            if (ps[i] == '-') {
                flips++;
                for (int j = i; j < i + k; j++) {
                    char flip = ps[j] == '-' ? '+' : '-';
                    ps[j] = flip;
                }
            }
        }

        return isFacingAllUp(ps) ? "" + flips : "IMPOSSIBLE";
    }

    private boolean isFacingAllUp(char[] row) {
        for (char c : row) {
            if (c == '-') {
                return false;
            }
        }

        return true;
    }
}