package jam.r1b2009;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.PrintStream;
import java.io.FileOutputStream;
import java.util.*;

/**
 * User: looser
 * Date: Sep 12, 2009
 */
public class Animals {
    private FTree tree;
    private List<Animal> animals;

    public Animals(FTree tree, List<Animal> animals) {
        this.tree = tree;
        this.animals = animals;
    }

    public static class Animal {
        private final String name;
        private final Set<String> features = new HashSet<String>();

        public Animal(String f) {
            String[] s = f.split(" ");
            name = s[0];
            features.addAll(Arrays.asList(s).subList(2, s.length));
        }
    }

    public static class FTree {
        private final double weight;
        private final String feature;
        private final FTree yes;
        private final FTree no;
        private final int last;

        public FTree(double weight, String feature, FTree yes, FTree no, int last) {
            this.weight = weight;
            this.feature = feature;
            this.yes = yes;
            this.no = no;
            this.last = last;
        }

        public Double cuteness(Animal a) {
            if (feature == null) {
                return weight;
            }

            if (a.features.contains(feature)) {
                return weight * yes.cuteness(a);
            } else {
                return weight * no.cuteness(a);
            }
        }


        public static FTree build(String str) {
            int last = 0;
            int open = str.indexOf('(');

            str = str.substring(open + 1);
            last += open + 1;

            int whitespace = str.indexOf(' ');
            int br = str.indexOf(')');
            if (whitespace == -1 || (br != -1 && whitespace > br)) {
                whitespace = br;
            }

            double weight = Double.parseDouble(str.substring(0, whitespace));

            str = str.substring(whitespace);
            last += whitespace;

            if (str.charAt(0) == ' ') {
                str = str.substring(1);
                last ++;
            }

            int nOpen = str.indexOf("(");
            int nClose = str.indexOf(")");
            FTree yes = null;
            FTree no = null;
            String feature = null;
            if (nOpen != -1 && nOpen < nClose) {
                whitespace = str.indexOf(" ");
                feature = str.substring(0, whitespace);

                str = str.substring(whitespace + 1);
                last += whitespace + 1;

                yes = build(str);

                str = str.substring(yes.last + 1);
                last += yes.last + 1;

                no = build(str);

                str = str.substring(no.last + 1);
                last += no.last + 1;
            }

            return new FTree(weight, feature, yes, no, last + str.indexOf(')'));
        }

    }
    public static void main(String[] args) throws Exception {
        BufferedReader f = new BufferedReader(new FileReader("input.txt"));
        PrintStream out = new PrintStream("output.txt");//System.out;
        //PrintStream out = System.out;
        int n = Integer.parseInt(f.readLine());
        for (int i = 1; i <= n; i++) {
            int l = Integer.parseInt(f.readLine());
            StringBuilder s = new StringBuilder();
            for (int j = 0; j < l; j++) {
                s.append(" ").append(f.readLine());
            }
            FTree tree = FTree.build(s.toString().replaceAll(" +", " ").replaceAll("\\( ", "("));


            int a = Integer.parseInt(f.readLine());
            List<Animal> animals = new ArrayList<Animal>();
            for (int j = 0; j < a; j++) {
                animals.add(new Animal(f.readLine()));
            }

            Animals solver = new Animals(tree, animals);
            out.println("Case #" + i + ": " + solver.solve());
        }
    }

    private String solve() {
        StringBuilder s = new StringBuilder();
        for (Animal animal : animals) {
            s.append("\n").append(String.format("%1.7f", tree.cuteness(animal)));
        }
        return s.toString();
    }
}
