package jam;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.PrintStream;
import java.util.Map;
import java.util.HashMap;
import static java.lang.System.currentTimeMillis;

/**
 * User: looser
 * Date: 04.09.2009
 */
public class Welcome {
    public static void main(String[] args) throws Exception {
        BufferedReader f = new BufferedReader(new FileReader("input3.txt"));
        //PrintStream out = System.out;
        PrintStream out = new PrintStream("output3.txt");

        long start = currentTimeMillis();
        int n = Integer.parseInt(f.readLine());
        for (int i = 0; i < n; i++) {
            Welcome w = new Welcome(f.readLine());
            out.println("Case #" + (i+1) + ": " + w.count());
        }

        System.out.println("Total time: " + (currentTimeMillis() - start));
    }

    public static final String WELCOME = "welcome to code jam";
    public static final int WELCOME_LENGTH = WELCOME.length();
    private final String input;
    private final int inputLength;
    private final Map<Pair, FourDigitNumber> cache = new HashMap<Pair, FourDigitNumber>();

    public Welcome(String s) {
        input = s;
        inputLength = input.length();
    }

    private FourDigitNumber count() {
        return traverseTree(0, 0);
    }

    private FourDigitNumber traverseTree(final int inputStart, final int strPosition) {
        FourDigitNumber n = new FourDigitNumber();

        if (WELCOME_LENGTH == strPosition) {
            n.inc();
            return n;
        }

        if ((inputLength - inputStart) < (WELCOME_LENGTH - strPosition)) {
            return n;
        }

        Pair currentPair = new Pair(inputStart, strPosition);
        FourDigitNumber cached = cache.get(currentPair);
        if (cached != null) {
            return cached;
        }

        if (input.charAt(inputStart) == WELCOME.charAt(strPosition)) {
            n.add(traverseTree(inputStart + 1, strPosition + 1));
        }

        n.add(traverseTree(inputStart + 1, strPosition));

        cache.put(currentPair, n);

        return n;
    }

    public static class FourDigitNumber {
        private int counter = 0;
        private static final int MAX = 10000;

        public void inc() {
            counter = (counter + 1) % MAX;
        }

        @Override
        public String toString() {
            if (counter == 0) return "0000";

            StringBuilder s = new StringBuilder();
            int c = counter;
            while (c < MAX/10) {
                c *= 10;
                s.append("0");
            }
            s.append(counter);
            return s.toString();
        }

        public void add(FourDigitNumber number) {
            counter = (counter + number.counter) % MAX;
        }
    }

    private class Pair {
        final int i;
        final int j;

        public Pair(int i, int j) {
            this.i = i;
            this.j = j;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Pair pair = (Pair) o;

            if (i != pair.i) return false;
            if (j != pair.j) return false;

            return true;
        }

        @Override
        public int hashCode() {
            int result = i;
            result = 31 * result + j;
            return result;
        }

        @Override
        public String toString() {
            return "Pair{" +
                    "i=" + i +
                    ", j=" + j +
                    '}';
        }
    }
}
