package jam.roundc;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.PrintStream;
import java.util.Collections;
import java.util.Map;
import java.util.TreeMap;

/**
 * User: looser
 * Date: May 23, 2010
 */
public class ChessBoard {
    private boolean[][] board;
    int m, n;
    boolean[][] isBad;
    boolean[][] isBadToR;
    boolean[][] isBadToD;
    boolean[][] alreadyTaken;

    public ChessBoard(boolean[][] board) {
        this.board = board;
        m = board.length;
        n = board[0].length;

        isBad = new boolean[m][n];
        isBadToR = new boolean[m][n];
        isBadToD = new boolean[m][n];
        alreadyTaken = new boolean[m][n];
    }

    public static void main(String[] args) throws Exception {
        String name = "C-small-attempt1";
        BufferedReader f = new BufferedReader(new FileReader(name + ".in"));
        //BufferedReader f = new BufferedReader(new FileReader("inp.txt"));
        //PrintStream out = System.out;
        PrintStream out = new PrintStream(name + ".out");

        Integer T = Integer.parseInt(f.readLine());

        for (int i = 1; i <= T; i++) {
            String[] s = f.readLine().split(" ");
            int M = Integer.parseInt(s[0]);
            int N = Integer.parseInt(s[1]);

            boolean[][] board = new boolean[M][N];

            for (int j = 0; j < M; j++) {
                String l = f.readLine();
                for (int k = 0; k < N / 4; k++) {
                    int bits = Integer.parseInt(l.substring(k, k + 1), 16);
                    for (int b = 0; b < 4; b++) {
                        int value = bits & 1;
                        board[j][(k+1) * 4 -1 - b] = value == 1;
                        bits >>= 1;
                    }
                }
            }

            ChessBoard o = new ChessBoard(board);

            long start = System.currentTimeMillis();

            out.print("Case #" + i + ": " + o.solve());

            long took = System.currentTimeMillis() - start;
            System.err.println("Case #" + i + " took " + took + "ms");
        }
    }

    private String solve() {
        //print(board);

        fillInBad();

        Map<Integer, Integer> sizeToCount = new TreeMap<Integer, Integer>(Collections.reverseOrder());
        int totalTaken = 0;


        boolean doneSomething;
        int maxSize = m < n ? m : n;
        do {
            doneSomething = false;
            int largestSizeFound = 1;
            Pair placeOfLargestOne = null;
            for (int i = 0; i < m; i++) {
                for (int j = 0; j < n; j++) {
                    if (isBad[i][j] || alreadyTaken[i][j]) {
                        continue;
                    }
                    int size;
                    for (size = 2; ; size++) {
                        if (size > maxSize) {
                            break;
                        }
                        if (!isGoodAsInnerLine(i, j, size)) {
                            if (isGoodAsLastLine(i, j, size)) {
                                size++;
                                break;
                            } else {
                                break;
                            }
                        }
                    }

                    int sizeFound = size-1;
                    if (sizeFound > largestSizeFound) {
                        largestSizeFound = sizeFound;
                        placeOfLargestOne = new Pair(i, j);
                        doneSomething = true;
                    }

                }
            }

            if (doneSomething) {
                mark(alreadyTaken, placeOfLargestOne.a, placeOfLargestOne.b, largestSizeFound);
                totalTaken += largestSizeFound * largestSizeFound;
                Integer count = sizeToCount.get(largestSizeFound);
                if (count == null) {
                    sizeToCount.put(largestSizeFound, 1);
                } else {
                    sizeToCount.put(largestSizeFound, count + 1);
                }
            } else {
                break;
            }
        } while (true);

        int numberOfSizeOne = m * n - totalTaken;
        if (numberOfSizeOne > 0) {
            sizeToCount.put(1, numberOfSizeOne);
        }
        
        StringBuilder s = new StringBuilder();
        s.append(sizeToCount.size()).append("\n");
        for (Integer size : sizeToCount.keySet()) {
            s.append(size).append(" ").append(sizeToCount.get(size)).append("\n");
        }

        return s.toString();
    }

    private boolean isGoodAsInnerLine(int a, int b, int size) {
        // most right column
        int maxI = a + size - 1;
        int maxJ = b + size - 1;

        if (maxI >= m || maxJ >= n || isBad[maxI][maxJ] || alreadyTaken[maxI][maxJ]) {
            return false;
        }

        for (int i = a; i < maxI; i++) {
            if (isBad[i][maxJ] || alreadyTaken[i][maxJ]) {
                return false;
            }
        }

        for (int j = b; j < maxJ; j++) {
            if (isBad[maxI][j] || alreadyTaken[maxI][j]) {
                return false;
            }
        }

        return true;
    }

    private boolean isGoodAsLastLine(int a, int b, int size) {
        // most right column
        int maxI = a + size - 1;
        int maxJ = b + size - 1;

        if (maxI >= m || maxJ >= n || alreadyTaken[maxI][maxJ]) {
            return false;
        }

        for (int i = a; i < maxI; i++) {
            if (isBadToD[i][maxJ] || alreadyTaken[i][maxJ]) {
                return false;
            }
        }

        for (int j = b; j < maxJ; j++) {
            if (isBadToR[maxI][j] || alreadyTaken[maxI][j]) {
                return false;
            }
        }

        return true;
    }

    private void mark(boolean[][] alreadyTaken, int a, int b, int size) {
        for (int i = a; i < a + size; i++) {
            for (int j = b; j < b + size; j++) {
                alreadyTaken[i][j] = true;
            }
        }
    }

    @SuppressWarnings({"UnusedDeclaration"})
    private void print(boolean[][] arr) {
        for (int i = 0; i < m; i++) {
            for (int j = 0; j < n; j++) {
                System.out.print(arr[i][j] ? "1" : "0");
            }
            System.out.println("");
        }
    }

    private void fillInBad() {
        for (int i = 0; i < m; i++) {
            for (int j = 0; j < n; j++) {
                isBadToR[i][j] = isBadToR(i,j);
                isBadToD[i][j] = isBadToD(i,j);
                isBad[i][j] = isBadToR[i][j] || isBadToD[i][j];
            }
        }
    }

    @SuppressWarnings({"SimplifiableIfStatement"})
    private boolean isBadToD(int i, int j) {
        if (i == m - 1 && j == n - 1) {
            return false;
        }

        if (i == m - 1) {
            return false;
        }

        return board[i + 1][j] == board[i][j];
    }

    @SuppressWarnings({"SimplifiableIfStatement"})
    private boolean isBadToR(int i, int j) {
        if (i == m - 1 && j == n - 1) {
            return false;
        }

        if (j == n - 1) {
            return false;
        }

        return board[i][j + 1] == board[i][j];
    }

    class Pair {
        int a, b;

        Pair(int a, int b) {
            this.a = a;
            this.b = b;
        }
    }
}
