package jam;

import java.io.*;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;
import static java.lang.System.currentTimeMillis;

/**
 * @author pyatigil
 * @since 03-Sep-2009
 */
public class AlienLanguage {
	private static final String INPUT = "input1.txt";
	private static final String OUTPUT = "output1.txt";

	private final List<String> dict;
	private final List<String> samples;
	private final BufferedWriter out;

	public AlienLanguage(List<String> dict, List<String> samples) throws IOException {
		this.dict = dict;
		this.samples = samples;
		out = new BufferedWriter(new FileWriter(OUTPUT));
		//out = new BufferedWriter(new OutputStreamWriter(System.out));

	}

	private void doWork() throws IOException {
		List<Pattern> patterns = new ArrayList<Pattern>(samples.size());
		for (String sample : samples) {
			Pattern p = Pattern.compile(sample.replace('(', '[').replace(')', ']'));
			patterns.add(p);
		}

		int caseNum = 1;
		long start = currentTimeMillis();
		for (Pattern pattern : patterns) {
			int matches = 0;
			for (String s : dict) {
				if (pattern.matcher(s).matches()) {
					matches++;
				}
			}
			out.write("Case #" + caseNum++ + ": " + matches + "\n");
		}
		System.out.println("total " + (currentTimeMillis() - start));
		out.close();
	}

	public static void main(String[] args) throws Exception {
		BufferedReader f = new BufferedReader(new FileReader(INPUT));
		String[] strings = f.readLine().split(" ");
		int l = Integer.parseInt(strings[0]);
		int d = Integer.parseInt(strings[1]);
		int n = Integer.parseInt(strings[2]);

		List<String> dict = new ArrayList<String>();
		for (int i = 0; i < d; i++) {
			dict.add(f.readLine());
		}

		List<String> samples = new ArrayList<String>();
		for (int i = 0; i < n; i++) {
			samples.add(f.readLine());
		}

		new AlienLanguage(dict, samples).doWork();
	}
}
