package de.jaki.codejam.y2017.r0;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

public class DL {

	private static final String PROBLEM = "D";
	private static final String TYPE = "large";
	private static final String INPUT = String.format("%s-%s.in", PROBLEM, TYPE);
	private static final String OUTPUT = String.format("%s-%s.out", PROBLEM, TYPE);
	private static final String RES_FORMAT = "Case #%d: %s";
	private static final String LINE = System.getProperty("line.separator");

	public static void main(String[] args) throws Exception {
		BufferedReader br = new BufferedReader(new FileReader(INPUT));
		int ttt = Integer.parseInt(br.readLine());
		StringBuilder sb = new StringBuilder();
		for (int i = 1; i <= ttt; i++) {
			String solution = solve(br);
			String formatted = String.format(RES_FORMAT, i, solution);
			sb.append(formatted);
			System.out.println(formatted);
		}
		PrintWriter pw = new PrintWriter(OUTPUT);
		pw.println(sb.toString());
		pw.flush();
		pw.close();
	}

	private static String solve(BufferedReader br) throws IOException {
		String[] in = br.readLine().split(" ");
		int n = Integer.parseInt(in[0]);
		int m = Integer.parseInt(in[1]);
		char[][] field = new char[n + 1][n + 1];
		boolean[][] bishop = new boolean[n + 1][n + 1];
		Set<Integer> rockRows = new HashSet<>();
		Set<Integer> rockCols = new HashSet<>();
		for (int i = 1; i <= n; i++) {
			rockRows.add(i);
			rockCols.add(i);
		}
		for (int i = 0; i < m; i++) {
			in = br.readLine().split(" ");
			char ch = in[0].charAt(0);
			int x = Integer.parseInt(in[1]);
			int y = Integer.parseInt(in[2]);
			field[x][y] = ch;
			if (ch == 'o' || ch == '+') {
				mark(bishop, x, y, n);
			}
			if (ch == 'x' || ch == 'o') {
				rockRows.remove(x);
				rockCols.remove(y);
			}
		}

		for (int i = 1; i <= n; i++) {
			doMark(bishop, field, i, 1, n);
			doMark(bishop, field, 1, i, n);
			doMark(bishop, field, i, n, n);
			doMark(bishop, field, n, i, n);
		}

		Iterator<Integer> cols = rockCols.iterator();
		Iterator<Integer> rows = rockRows.iterator();

		while (cols.hasNext() && rows.hasNext()) {
			int r = rows.next();
			int c = cols.next();

			if (field[r][c] == 'P' || field[r][c] == '+') {
				field[r][c] = 'O';
			} else {
				field[r][c] = 'X';
			}
		}

		StringBuilder sb = new StringBuilder();
		int moveCount = 0;
		int score = 0;
		for (int i = 1; i <= n; i++) {
			for (int j = 1; j <= n; j++) {
				char ch = field[i][j];

				switch (ch) {
					case 'o':
					case 'O':
						score++;
					case '+':
					case 'P':
					case 'X':
					case 'x':
						score++;
				}
				switch (ch) {
					case 'O':
						move(sb, i, j, 'o');
						moveCount++;
						break;
					case 'P':
						move(sb, i, j, '+');
						moveCount++;
						break;
					case 'X':
						move(sb, i, j, 'x');
						moveCount++;
						break;
				}
			}
		}


		return score + " " + moveCount + LINE + sb.toString();
	}

	private static void move(StringBuilder moves, int x, int y, char ch) {
		moves.append(ch);
		moves.append(' ');
		moves.append(x);
		moves.append(' ');
		moves.append(y);
		moves.append(LINE);
	}

	private static void doMark(boolean[][] bishop, char[][] field, int x, int y, int n) {
		if (!bishop[x][y]) {
			if (field[x][y] == 'x') {
				field[x][y] = 'O';
			} else {
				field[x][y] = 'P';
			}
			mark(bishop, x, y, n);
		}
	}

	private static void mark(boolean[][] bishop, int x, int y, int n) {
		int sum = x + y;
		int dif = x - y;
		for (int j = 1; j <= n; j++) {
			int s = sum - j;
			int d = j - dif;
			if (s > 0 && s <= n) bishop[j][s] = true;
			if (d > 0 && d <= n) bishop[j][d] = true;
		}
	}
}
