import java.awt.Point;
import java.io.BufferedInputStream;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.PrintStream;
import java.util.LinkedList;
import java.util.Queue;
import java.util.Scanner;

public class MinesweeperMaster {
	private static final boolean DEBUG = false;
	private static final String FILENAME = "minesweeper_master";

	public static void main(String[] args) throws IOException {
		long startTime = System.nanoTime();

		if(DEBUG) {
			System.setIn(new BufferedInputStream(new FileInputStream(FILENAME + "_example.in")));
		} else {
			System.setIn(new BufferedInputStream(new FileInputStream(FILENAME + ".in")));
			System.setOut(new PrintStream(FILENAME + ".out"));
		}

		Scanner sc = new Scanner(System.in);

		int numTestCases = sc.nextInt();
		for(int caseNum = 1; caseNum <= numTestCases; caseNum++) {
			int numRows = sc.nextInt();
			int numCols = sc.nextInt();
			int numMines = sc.nextInt();
			int emptySpots = numRows * numCols - numMines;
			
			char[][] playingField = new char[numRows][numCols];
			
			Queue<Point> queue = new LinkedList<Point>();
			queue.add(new Point(0, 0));
			
			boolean impossible = false;
			
			while(!queue.isEmpty()) {
				Point currentPos = queue.poll();
				if(playingField[currentPos.x][currentPos.y] == '\0') {
					if(emptySpots > 0) {
						playingField[currentPos.x][currentPos.y] = '.';
						emptySpots--;
					} else {
						playingField[currentPos.x][currentPos.y] = '*';
					}
				}

				int[] rowDiff = new int[]{1, -1, 0, 0, -1, 1, -1, 1};
				int[] colDiff = new int[]{0, 0, 1, -1, 1, 1, -1, -1};
				
				for(int i = 0; i < colDiff.length; i++) {
					int newRow = currentPos.x + rowDiff[i];
					int newCol = currentPos.y + colDiff[i];
					
					if(newRow >= 0 && newRow < numRows && newCol >= 0 && newCol < numCols) {
						if(playingField[newRow][newCol] == '\0') {
							queue.add(new Point(newRow, newCol));
						}
						
						if(newRow == 0 && newCol == 0 && playingField[currentPos.x][currentPos.y] == '*') {
							impossible = true;
						}
					}
				}
			}
			
			playingField[0][0] = 'c';

			System.out.println("Case #" + caseNum + ":");
			if(impossible && numRows * numCols - numMines != 1) {
				System.out.println("Impossible");
			} else {
				StringBuilder sb = new StringBuilder();
				for(int row = 0; row < playingField.length; row++) {
					for(int col = 0; col < playingField[row].length; col++) {
						sb.append(playingField[row][col]);
					}
					sb.append("\n");
				}
				sb.deleteCharAt(sb.length() - 1);
				System.out.println(sb);
			}
		}

		if(DEBUG) System.out.println("Total time: " + ((System.nanoTime() - startTime) / 1000.0 / 1000.0 / 1000.0) + "s");
	}
}