import java.util.StringTokenizer;
import java.io.*;
import java.util.NoSuchElementException;

public class Bot_Trust {
	private int bluePosition = 1;
	private int orangePosition = 1;
	
	private int blueGoal;
	private int orangeGoal;
	
	private int buttonPresses;	// The number of required button presses
	private char[] colour;
	private int[] button;
	private int step = 0;
	
	private int timeTaken = 0;
	
	private final boolean WAITING_FOR_BLUE = true;
	private final boolean WAITING_FOR_ORANGE = false;
	private final char EMPTY_C = 'z';
	private final int EMPTY_I = 0;
	
	private boolean waitingFor;
	private boolean solved = false;
	
	private int caseNo;
	
	public Bot_Trust(String commandString, int caseNo) {
		this.caseNo = caseNo;
		
		readCommands(commandString);
		updateBlueGoal();
		updateOrangeGoal();
		
		while (!solved) {
			performBestFunction();
			timeTaken++;
		}
		
		System.out.println("Case #" + caseNo + ": " + timeTaken);
	}
	
	public void readCommands(String commandString) {
		StringTokenizer commandList = new StringTokenizer(commandString," ");
		
		buttonPresses = Integer.parseInt(commandList.nextToken());
		
		colour = new char[buttonPresses+1];
		button = new int[buttonPresses+1];
		
		for (int i = 0; i < buttonPresses; i++) {
			if (commandList.hasMoreTokens()) {
				colour[i] = (commandList.nextToken().charAt(0));
			} else {
				colour[i] = EMPTY_C;
				button[i] = EMPTY_I;
				continue;
			}
			if (commandList.hasMoreTokens()) {
				button[i] = Integer.parseInt(commandList.nextToken());	
			} else {
				//System.out.println("ERROR 02");
			}
		}
	}
	
	public void performBestFunction() {
		if (bluePosition < blueGoal && blueGoal != EMPTY_I) {
			bluePosition++;
		} else if (bluePosition > blueGoal && blueGoal != EMPTY_I) {
			bluePosition--;
		} else if (bluePosition == blueGoal && waitingFor == WAITING_FOR_BLUE && blueGoal != EMPTY_I) {
			// Push the button, update the goal
			step++;
			updateBlueGoal();
		}
		
		if (orangePosition < orangeGoal && orangeGoal != EMPTY_I) {
			orangePosition++;
		} else if (orangePosition > orangeGoal && orangeGoal != EMPTY_I) {
			orangePosition--;
		} else if (orangePosition == orangeGoal && waitingFor == WAITING_FOR_ORANGE && orangeGoal != EMPTY_I) {
			// Push the button, update the goal
			step++;
			updateOrangeGoal();
		}
		updateWaitingFor();
	}
	
	public void updateBlueGoal() {
		// Blue pushed the appropriate button
		for (int i = step; i < buttonPresses; i++) {
			// Scan through and look for the next goal
			if (colour[i] == 'B') {
				blueGoal = button[i];
				break;
			} else if (step >= buttonPresses-1) {
				// There are no more commands in the array
				blueGoal = 0;
			}
		}
	}
	
	public void updateOrangeGoal() {
		// Orange pushed the appropriate button
		for (int i = step; i < buttonPresses; i++) {
			// Scan through and look for the next goal
			if (colour[i] == 'O') {
				orangeGoal = button[i];
				break;
			} else if (step >= buttonPresses-1) {
				// There are no more commands in the array
				orangeGoal = 0;
			}
		}
	}
	
	public void updateWaitingFor() {
		// Update the waitingFor boolean
		if (colour[step] == 'B') {
			waitingFor = WAITING_FOR_BLUE;
		} else if (colour[step] == 'O') {
			waitingFor = WAITING_FOR_ORANGE;
		} else {
			solved = true;
		}
	}
	
	public static void main(String[] args) throws IOException, FileNotFoundException {
		int caseNo = 1;
		BufferedReader br = new BufferedReader(new FileReader("input.txt"));
		Bot_Trust bt;
		while (br.ready()) {
			bt = new Bot_Trust(br.readLine(), caseNo);
			caseNo++;
		}
	}
}