import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;

/**
 * 
 * @author AVadas
 * 
 */
public class Language {
	/**
	 * The number of tokens (L)
	 */
	private int tokenNumber;

	/**
	 * The number of words in the language (D)
	 */
	private int wordNumber;

	/**
	 * The words of the language
	 */
	private List<String> dictionary;

	/**
	 * Constructs a language object with empty dictionary
	 * 
	 * @param tokeNumber
	 *            the number of tokens
	 * @param wordNumber
	 *            the number of words in the language
	 */
	public Language(final int tokeNumber, final int wordNumber) {
		this.tokenNumber = tokeNumber;
		this.wordNumber = wordNumber;
		this.dictionary = new ArrayList<String>();
	}

	/**
	 * Adds a word to the dictionary
	 * 
	 * @param word
	 *            the word to add
	 */
	public void addWordToDictionary(final String word) {
		if (this.dictionary.size() + 1 <= this.wordNumber) {
			if (word.length() <= this.tokenNumber) {
				this.dictionary.add(word);
			}
		}
	}

	/**
	 * 
	 * @param pattern
	 *            the pattern
	 * @return the results of the search
	 */
	public List<String> searchForPattern(final String pattern) {

		List<String> results = new ArrayList<String>();

		StringBuffer buffer = new StringBuffer();
		char[] tokens = pattern.toCharArray();
		boolean flag = false;
		for (int i = 0; i < tokens.length - 1; i++) {
			if (flag) {
				if (tokens[i + 1] == ')') {
					flag = false;
					buffer.append(tokens[i]);
				} else {
					buffer.append(tokens[i]).append("|");
				}
			} else {
				if (tokens[i] == '(') {
					flag = true;
				}
				buffer.append(tokens[i]);
			}
		}
		buffer.append(tokens[tokens.length - 1]);

		String regExp = buffer.toString();
		for (String word : this.dictionary) {
			if (Pattern.matches(regExp, word)) {
				results.add(word);
			}
		}
		return results;
	}

	@Override
	public String toString() {
		StringBuffer buffer = new StringBuffer();
		buffer.append("Token number: ").append(this.tokenNumber).append("\n");
		buffer.append("Dictionary size: ").append(this.wordNumber).append("\n");
		for (String word : this.dictionary) {
			buffer.append(word).append("\n");
		}
		return buffer.toString();
	}
}
