import java.util.ArrayList;
import java.util.SortedSet;
import java.util.TreeSet;
import java.lang.Exception;

public class Primes {

	// primes below 1e6
	private TreeSet<Long> primes_1e6;
	public long[] p1e6;
	
	private long[] witness = {2L,3L,5L,7L,11L,13L,17L,19L,23L,29L,31L,37L};
	private long[] A014233 = {2047L, 
							  1373653L, 
							  25326001L, 
							  3215031751L, 
							  2152302898747L, 
							  3474749660383L, 
							  341550071728321L, 
							  341550071728321L, 
							  3825123056546413051L, 
							  3825123056546413051L, 
							  3825123056546413051L}; 
							  //318665857834031151167461L, 
							  //3317044064679887385961981L};
	
	public Primes()
	{	
		compute_primes_upto_1e6();
	}
	
	private void compute_primes_upto_1e6()
	{
		primes_1e6 = new TreeSet<Long>();
		ArrayList<Long> p1e6t = new ArrayList<Long>();
		
		long prime = 2L;
		while (prime <= 1000000L)
		{
			primes_1e6.add(prime);
			p1e6t.add(prime);
			prime = nextNaivePrime(prime);
		}
		p1e6 = new long[p1e6t.size()];
		for (int i = 0; i < p1e6.length; ++i)
			p1e6[i] = p1e6t.get(i);
	}
	
	private long nextNaivePrime(long n)
	{
		if (n < 2L)
			return 2L;
		
		if (n == 2L)
			return 3L;
		
		if (n % 2L == 0L)
			n--;
		
		while(true)
		{	
			n += 2L;
			if (isPrime(n))
				return n;
		}
	}
	
	public boolean isPrime(long n)
	{
		if (n < 0L)
			return isPrime(-n);
		
		if (n == 1L)
			return false;
		
		if (n == 2L)
			return true;
		
		if (n > 5 && (n % 2 == 0 || n % 3 == 0 || n % 5 == 0))
			return false;
		
		return isProbPrime_Miller_Rabin(n);
	}
	
	private boolean isProbPrime_Miller_Rabin(long n)
	{
		int max_i = witness.length;
		for (int k = 0; k < witness.length; ++k)
			if (n < A014233[k])
			{
				max_i = k;
				break;
			}
		
		long s, d;
		d = n-1;
		s = 0L;
		while (d % 2 == 0)
		{
			s++;
			d = d / 2;
		}
		
		for (int i = 0; i <= max_i; ++i)
		{	
			if (witness_Miller_Rabin(witness[i],n, s, d))
				return false;
		}
		return true;
	}
	
	private boolean witness_Miller_Rabin(long a, long n, long s, long d)
	{
		long x = pow_mod(a,d,n);
		
		if (x == 1 || x == n - 1L)
			return false;
		
		while(s > 1L)
		{
			x = (x*x) % n;
			if (x == n - 1)
				return false;
			s--;
		}
		
		return true;
	}
	
	private long pow_mod(long n, long e, long m)
	{
		if (e == 0L)
			return 1L;
		if (e == 1L)
			return n;
			
		long buf = pow_mod(n,e/2L,m);
		if (e % 2L == 0L)	
			return (buf * buf) % m ;
		else
			return (((buf * buf) % m) * n) % m;
	}
	
	public long approximate_number_primes(long n)
	{
		if (n < 2L)
			return 0L;
		
		return (long)(n/((Math.log(n) - 1)));
	}
	
	public long nextPrime(long n)
	{
		if (n < 2L)
			return 2L;
		
		if (n == 2L)
			return 3L;
		
		if (n < primes_1e6.last()) // last prime in the set
			return primes_1e6.ceiling(n+1L);
					
		if (n % 2L == 0)
			n++;
		else 
			n += 2;
		
		while (!isProbPrime_Miller_Rabin(n))
			n += 2;
		
		if (!primes_1e6.contains(n))
			primes_1e6.add(n);
		
		return n;
	}
	
	public long previousPrime(long n)
	{
		if (n <= 2L)
			return -1L;
			//throw new Exception("No prime number below 2");
		
		if (n == 3L)
			return 2L;
		
		if (n < 999863L) // last prime before 1000000
			return primes_1e6.floor(n-1L);
					
		if (n % 2L == 0)
			n--;
		else 
			n -= 2;
		
		while (!isProbPrime_Miller_Rabin(n))
			n -= 2;
		
		return n;
	}
	
}
