package watersheds;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;

public class Watersheds
{
	private enum FlowDirection 
		{ NORTH, WEST, EAST, SOUTH, SINK };
		
	private static void solve(List<String> lines)
	{
		int lnum = 0;
		int n = Integer.parseInt(lines.get(lnum++));
		for (int problem = 0; problem < n; problem++)
		{
			System.out.println("Case #" + (problem+1) + ":");
			String[] dims = lines.get(lnum++).split(" ");
			int rows = Integer.parseInt(dims[0]);
			int cols = Integer.parseInt(dims[1]);
			int[][] map = new int[rows][cols];
			for (int i = 0; i < rows; i++) {
				String[] alts = lines.get(lnum++).split(" ");
				for (int j = 0; j < cols; j++)
					map[i][j] = Integer.parseInt(alts[j]);
			}
			
			solveProblem(map);
		}
	}
	
	private static void solveProblem(int[][] map)
	{
		int rows = map.length;
		int cols = map[0].length;
		// get flow directions
		FlowDirection[][] flows = new FlowDirection[rows][cols];
		for (int y = 0; y < rows; y++) {
			for (int x = 0; x < cols; x++) {
				int lowestAltitude = map[y][x];
				flows[y][x] = FlowDirection.SINK;
				
				// check north
				if (y > 0) {
					if (map[y-1][x] < lowestAltitude) {
						lowestAltitude = map[y-1][x];
						flows[y][x] = FlowDirection.NORTH;
					}
				}
				
				// check west
				if (x > 0) {
					if (map[y][x-1] < lowestAltitude) {
						lowestAltitude = map[y][x-1];
						flows[y][x] = FlowDirection.WEST;
					}
				}
				
				// check east
				if (x+1 < cols) {
					if (map[y][x+1] < lowestAltitude) {
						lowestAltitude = map[y][x+1];
						flows[y][x] = FlowDirection.EAST;
					}
				}
								
				// check south
				if (y+1 < rows) {
					if (map[y+1][x] < lowestAltitude) {
						lowestAltitude = map[y+1][x];
						flows[y][x] = FlowDirection.SOUTH;
					}
				}
			}
		}
		
//		for (int y = 0; y < rows; y++) {
//			for (int x = 0; x < cols; x++) {
//				System.out.print(flows[y][x] + " ");
//			}
//			System.out.println();
//		}
		
		
		String[][] sinkNames = new String[rows][cols];
		char curSinkName = 'a'-1;
		for (int y = 0; y < rows; y++) {
			for (int x = 0; x < cols; x++) {
				if (sinkNames[y][x] == null) {
					// System.out.printf("followFlows(%d, %d)\n", x, y);
					List<int[]> way = followFlows(flows, x, y);
					int[] sink = way.get(way.size()-1);
					// System.out.printf("sink x=%d y=%d\n", sink[0], sink[1]);
					String mySink;
					if (sinkNames[sink[1]][sink[0]] == null) {
						curSinkName++;
					//	System.out.println("inc sink: " + curSinkName);
						mySink = "" + curSinkName;
					} else mySink = sinkNames[sink[1]][sink[0]];
					// System.out.print("way: ");
					for (int[] pos : way) { 
						// System.out.printf("x=%d,y=%d ", pos[0],pos[1]);
						sinkNames[pos[1]][pos[0]] = mySink;
					}
					// System.out.println();
				}
			}
		}
		
		for (int y = 0; y < rows; y++) {
			for (int x = 0; x < cols; x++) {
				if (x > 0) System.out.print(" ");
				System.out.print(sinkNames[y][x]);
			}
			System.out.println();
		}
	}
	
	private static List<int[]> followFlows(FlowDirection[][] flows, int x, int y)
	{
		List<int[]> way = new ArrayList<int[]>();
		while (flows[y][x] != FlowDirection.SINK)
		{
			int[] pos = new int[2];
			pos[0] = x;
			pos[1] = y;
			way.add(pos);
			if (flows[y][x] == FlowDirection.NORTH) 		y--;
			else if (flows[y][x] == FlowDirection.WEST)		x--;
			else if (flows[y][x] == FlowDirection.EAST) 	x++;
			else if (flows[y][x] == FlowDirection.SOUTH)	y++;
			else throw new RuntimeException("flow direction is SINK which doesn't make sense");
		}
		int[] pos = new int[2];
		pos[0] = x;
		pos[1] = y;
		way.add(pos);
		return way;
	}
	
	public static void main(String[] args) throws Exception
	{
		BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
		ArrayList<String> lines = new ArrayList<String>();
		String l;
		while ((l = in.readLine()) != null)	lines.add(l);
		solve(lines);
	}
}
