import java.io.*;
import java.text.MessageFormat;

/**
 * @author Aleksey Lagoshin
 */
public class BotTrust {

    long moves = 0;
    long currPosO = 1, currPosB = 1, nextPosO = 0, nextPosB = 0;
    char shouldPress;

    public BotTrust() {
    }

    private long readNextNumber(BufferedReader reader) throws IOException {
        StringBuffer numberStr = new StringBuffer();
        char ch = (char) reader.read();
        while (ch == ' ')
            ch = (char) reader.read();
        while (ch != ' ' && ch != '\n') {
            numberStr.append(ch);
            ch = (char) reader.read();
        }
        return Long.parseLong(numberStr.toString());
    }

    private char readNextRobot(BufferedReader reader) throws IOException {
        char result = (char) reader.read();
        reader.read(); // space
        return result;
    }

    private long calculateMoves(long extraMoves) {
        long moves = extraMoves;
        switch (shouldPress) {
            case 'O':
                moves += Math.abs(nextPosO - currPosO) + 1;
                currPosO = nextPosO;
                nextPosO = 0;
                currPosB = moveTo(currPosB, nextPosB, moves);
                shouldPress = 'B';
                break;
            case 'B':
                moves += Math.abs(nextPosB - currPosB) + 1;
                currPosB = nextPosB;
                nextPosB = 0;
                currPosO = moveTo(currPosO, nextPosO, moves);
                shouldPress = 'O';
                break;
        }

        return moves;
    }

    private long moveTo(long curr, long to, long moves) {
        long delta = to - curr;
        if (moves >= Math.abs(delta))
            return to;

        return delta > 0 ? curr + moves : curr - moves;
    }

    private void solve(File inputFile) throws Exception {
        BufferedReader reader = new BufferedReader(new FileReader(inputFile));
        BufferedWriter writer = new BufferedWriter(new FileWriter("/home/ayzen/out.txt"));
        long count = Long.parseLong(reader.readLine());

        // Main cycle
        for (int i = 1; i <= count; i++) {
            moves = 0;
            currPosO = 1;
            currPosB = 1;
            long buttons = readNextNumber(reader);

            if (buttons > 0) {
                shouldPress = readNextRobot(reader);
                if (shouldPress == 'O')
                    nextPosO = readNextNumber(reader);
                else
                    nextPosB = readNextNumber(reader);

                while (buttons-- > 0) {
                    boolean nextPosFound = false;
                    int extraMoves = 0;

                    while (buttons > 0 && !nextPosFound) {
                        char robot = readNextRobot(reader);
                        long nextPos = readNextNumber(reader);
                        if (robot == shouldPress) {
                            if (robot == 'O') {
                                extraMoves += Math.abs(nextPosO - currPosO);
                                currPosO = nextPosO;
                                nextPosO = nextPos;
                            }
                            else {
                                extraMoves += Math.abs(nextPosB - currPosB);
                                currPosB = nextPosB;
                                nextPosB = nextPos;
                            }
                            extraMoves++;
                            buttons--;
                        }
                        else {
                            nextPosFound = true;
                            if (robot == 'O')
                                nextPosO = nextPos;
                            else
                                nextPosB = nextPos;
                        }
                    }

                    if (nextPosFound)
                        moves += calculateMoves(extraMoves);
                    else
                        moves += extraMoves;
                }
                // And the last button
                moves += (shouldPress == 'O' ? Math.abs(nextPosO - currPosO) : Math.abs(nextPosB - currPosB)) + 1;
            }

            writer.write(MessageFormat.format("Case #{0}: {1}", i, moves) + '\n');
        }
        reader.close();
        writer.close();
    }

    public static void main(String[] args) {
        try {
            new BotTrust().solve(new File("/home/ayzen/input.txt"));
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

}
