import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Scanner;

public class Pancakes {
	
	private static void printStack(boolean[] stack) {
		if(true) { //True for testing
			int i;
			
			for(i = 0; i < stack.length; i++) {
				if(stack[i]) {
					System.out.print("+");
				} else {
					System.out.print("-");
				}
			}
			
			System.out.print("\n");
			
		}
	}
	
	/* Flip the stack at (and including) the given index. */
	private static void flipAt(boolean[] stack, int index) {
		
		int i; 
		
		for(i = 0; i < (index+1)/2; i++) {
			
			boolean temp = stack[i];
			stack[i] = !stack[index-i];
			stack[index-i] = !temp;
			
		}
		
		//If there were an odd number of pancakes flipped, also invert (index+1)/2
		if(index%2 == 0) {
			stack[(index+1)/2] = !stack[(index+1)/2];
		}
		
	}
	
	/* Returns the index of the lowest unsorted pancake
	 * if all sorted, returns -1 */
	private static int lowestUnsorted(boolean[] stack) {
		
		int lowest = stack.length-1;
		
		while(lowest >= 0 && stack[lowest]) {
			
			lowest--;
			
		}
		
		return lowest;
		
	}
	
	public static void main(String[] args) {
		
		if(args.length == 0) {
			
			System.out.println("No arguments provided");
			return;
			
		}
		
		try {
			
			File file = new File(args[0]);
			Scanner input = new Scanner(file);
			FileWriter fileOut = new FileWriter("output.txt");
			BufferedWriter writer = new BufferedWriter(fileOut);
						
			int numTestCases = input.nextInt();
			String dummy = input.nextLine(); //Clear the newline char
			
			int i; 
			
			for(i = 0; i < numTestCases; i++) {
				
				String nextLine = input.nextLine();
				
				//Put the string into a boolean array, true == + and false == -
				
				boolean[] stack = new boolean[nextLine.length()];
				
				int j;
				
				for(j = 0; j < nextLine.length(); j++) {
					
					if(nextLine.charAt(j) == '+') {
						
						stack[j] = true;
						
					} else {
						
						stack[j] = false;
						
					}
					
				}
				
				int numManeuvers = 0;
				printStack(stack);
				
				//Start at the bottom and work your way up the stack sorting
				
				while(lowestUnsorted(stack) != -1) {
					
					//Flip all the happy pancakes at the top of the stack
					int numTopHappy = 0;
					
					while(stack[numTopHappy]) {
						
						stack[numTopHappy] = false;
						numTopHappy++;
						
					}
					
					if(numTopHappy != 0) {
						printStack(stack);
						numManeuvers++;
					}
					
					//Check that still unsorted
					if(lowestUnsorted(stack) != -1) {

						//Now flip at the lowest unsorted
						flipAt(stack, lowestUnsorted(stack));
						printStack(stack);
						numManeuvers++;
						
					}
					
				}
				
				writer.write("Case #" + (i+1) + ": " + numManeuvers + "\n");
				
			}
			
			writer.close();
			fileOut.close();
			input.close();
			
		} catch(FileNotFoundException e) {
			
			System.out.println("Error reading input file");
			
		} catch(IOException e) {
			
			System.out.println("Error writing output");
			
		}
		
	}

}
