package org.google.qualif3;

import java.util.ArrayList;
import java.util.Collections;
import java.util.GregorianCalendar;

public class Case {

	public ArrayList<Train> trains = new ArrayList<Train>();
	public TimeTable table = new TimeTable();

	public int fromA = 0;
	public int fromB = 0;
	public int rotatingTime;

	public void process() {

		TimeTableEntry ent;
		while ((ent = table.getNext()) != null) {

			if (ent.isA) {

				boolean found = false;

				for (int i = 0; i < trains.size() && !found; i++) {

					ArrayList<Train> availableTrains = new ArrayList<Train>();

					if (trains.get(i).isAtA && trains.get(i).isAvailableAt(ent.depart)) availableTrains.add(trains.get(i));

					if (availableTrains.size() > 0) {

						Collections.sort(availableTrains);

						availableTrains.get(0).depart = ent.depart;
						availableTrains.get(0).arrivee = ent.arrivee;
						availableTrains.get(0).isAtA = false;

						availableTrains.get(0).arrivee.add(GregorianCalendar.MINUTE, rotatingTime);

						found = true;
					}
				}

				if (!found) {
					Train train = new Train();
					train.isAtA = false;
					train.depart = ent.depart;
					train.arrivee = ent.arrivee;
					train.arrivee.add(GregorianCalendar.MINUTE, rotatingTime);
					trains.add(train);
					fromA++;
				}
			} else {

				boolean found = false;
				for (int i = 0; i < trains.size() && !found; i++) {

					ArrayList<Train> availableTrains = new ArrayList<Train>();

					if (!trains.get(i).isAtA && trains.get(i).isAvailableAt(ent.depart)) availableTrains.add(trains.get(i));

					if (availableTrains.size() > 0) {

						Collections.sort(availableTrains);

						availableTrains.get(0).depart = ent.depart;
						availableTrains.get(0).arrivee = ent.arrivee;
						availableTrains.get(0).isAtA = true;
						availableTrains.get(0).arrivee.add(GregorianCalendar.MINUTE, rotatingTime);
						found = true;
					}
				}
				if (!found) {
					Train train = new Train();
					train.isAtA = true;
					train.depart = ent.depart;
					train.arrivee = ent.arrivee;
					train.arrivee.add(GregorianCalendar.MINUTE, rotatingTime);
					trains.add(train);
					fromB++;
				}
			}
		}
	}

	public String toString() {
		return fromA + " " + fromB;
	}

	public class TimeTable {

		public ArrayList<TimeTableEntry> list = new ArrayList<TimeTableEntry>();
		public int pos = -1;

		public void addEntry(boolean isA, GregorianCalendar depart, GregorianCalendar arrivee) {
			TimeTableEntry entry = new TimeTableEntry();
			entry.isA = isA;
			entry.depart = depart;
			entry.arrivee = arrivee;
			list.add(entry);
			Collections.sort(list);
		}

		public TimeTableEntry getNext() {
			if (++pos == list.size()) return null;
			return list.get(pos);
		}
	}

	public class TimeTableEntry implements Comparable<TimeTableEntry> {

		boolean isA;
		GregorianCalendar depart;
		GregorianCalendar arrivee;

		public int compareTo(TimeTableEntry date) {
			return depart.compareTo(date.depart);
		}

	}
}
