package codejam2016.qr;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.math.BigInteger;
import java.util.*;

/**
 * Created by b4dt0bi on 02.05.15.
 */
public class C {
    public static void main(String[] args) throws IOException {
        BufferedReader bufferedReader = new BufferedReader(new FileReader(args[0]));
        C c = new C();
        String line = bufferedReader.readLine();
        int tcs = Integer.parseInt(line);
        for (int tc = 0; tc < tcs; tc++) {
            String data[] = bufferedReader.readLine().split(" ");
            int n = Integer.parseInt(data[0]);
            int j = Integer.parseInt(data[1]);
            System.out.println("Case #" + (tc + 1) + ":\n" + c.getCoins(n, j).trim());
        }
        bufferedReader.close();
    }

    private String getFirstCoin(int n) {
        String coin = "1";
        for (int i = 0; i < n - 2; i++) {
            coin += "0";
        }
        return coin + "1";
    }

    List<String> coins = Collections.synchronizedList(new ArrayList<String>());
    List<String> results = Collections.synchronizedList(new ArrayList<String>());

    private boolean coinCreatorRunning = true;

    public String getCoins(final int n, final int j) {
        coins.clear();
        results.clear();
        testedCoin.clear();

        final Thread coinCreator = new Thread(new Runnable() {
            public void run() {
                coinCreatorRunning = true;
                String coin = getFirstCoin(n);
                while (coinCreatorRunning) {
                    while (!isValidCoin(coin)) {
                        coin = getNextRandomCoin(n);
                    }
                    coins.add(coin);
                    coin = getNextRandomCoin(n);
                }
            }
        });
        coinCreator.start();

        List<CoinProcessor> coinProcessors = new ArrayList<CoinProcessor>();
        int maxThreads = 20;
        long maxTimeout = 2000;
        while (results.size() < j) {
            while (coinProcessors.size() < maxThreads && !coins.isEmpty()) {
                CoinProcessor coinProcessor = new CoinProcessor(coins.remove(0));
                coinProcessor.start();
                coinProcessors.add(coinProcessor);
            }
            try {
                Thread.sleep(250);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            Iterator<CoinProcessor> itC = coinProcessors.iterator();
            while (itC.hasNext()) {
                CoinProcessor coinProcessor = itC.next();
                if (!coinProcessor.isAlive() && coinProcessor.isDone() && results.size() < j && !coins.isEmpty()) {
                    itC.remove();
                } else {
                    if (System.currentTimeMillis() - coinProcessor.getTime() > maxTimeout && results.size() < j && !coins.isEmpty()) {
                        coinProcessor.stop();
                        itC.remove();
                    }
                }
            }
        }
        coinCreatorRunning = false;
        coinCreator.stop();
        String result = "";

        for (int i = 0; i < j; i++) {
            result += results.get(i) + "\n";
        }
        return result;
    }

    class CoinProcessor extends Thread implements Runnable {
        private String coin;
        private long time;
        private boolean done;

        public CoinProcessor(String coin) {
            setCoin(coin);
        }

        public long getTime() {
            return time;
        }

        public boolean isDone() {
            return done;
        }

        public void setCoin(String coin) {
            this.coin = coin;
            time = System.currentTimeMillis();
            done = false;
        }

        public void run() {
            testedCoin.add(new BigInteger(coin, 2));
            String trivNrs = "";
            for (int base = 2; base < 11; base++) {
                trivNrs += factor(new BigInteger(coin, base)) + " ";
            }
            results.add(coin + " " + trivNrs.trim());
            //System.out.println("Found coin (" + results.size() + ") : " + coin);
            done = true;
        }
    }

    private String getNextRandomCoin(int n) {
        BigInteger result = getNextCoin(n);
        while (testedCoin.contains(result)) {
            result = getNextCoin(n);
        }
        testedCoin.add(result);
        return result.toString(2);
    }

    public BigInteger factor(BigInteger n) {
        for (BigInteger i = BigIntegerTWO; i.intValue() < 10000; i = i.nextProbablePrime()) {
            if (n.remainder(i).equals(BigInteger.ZERO)) return i;
        }

        return smallestPrimeFactor(n);
    }

    private boolean isValidCoin(String coin) {
        if (coin.charAt(0) != '1' || coin.charAt(coin.length() - 1) != '1') return false;
        for (int base = 2; base < 11; base++) {
            if (new BigInteger(coin, base).isProbablePrime(1)) {
                return false;
            }
        }
        return true;
    }

    private Set<BigInteger> testedCoin = Collections.synchronizedSet(new HashSet<BigInteger>());

    private Random random = new Random();

    private BigInteger getNextCoin(int bits) {
        return new BigInteger(bits, random).setBit(0).setBit(bits - 1);
    }

    private static final BigInteger MAXLONG = BigInteger.valueOf(Long.MAX_VALUE);
    private static final BigInteger BIGTWO = BigInteger.valueOf(2);

    private BigInteger smallestPrimeFactor(BigInteger n) {
        if (n.compareTo(BigInteger.ONE) <= 0) {
            return BigInteger.ZERO;
        }
        if (n.mod(BIGTWO).equals(BigInteger.ZERO)) {
            return BIGTWO;
        }
        if (n.compareTo(MAXLONG) <= 0) {
            // for 'small' n's use a simple long-based prime-factor.
            return BigInteger.valueOf(smallestPrimeFactor(n.longValue()));
        }
        // use special BigInteger code for this...
        return internalPrimeFactor(n);
    }

    private long smallestPrimeFactor(long n) {
        if (n < 1) {
            return 0;
        }
        if (n % 2 == 0) {
            return 2;
        }
        // only need aproximate end-point... even if n is larger than 48 bits
        // (the largest accurate integer number in double),
        // the sqrt will be only off by 1 at most.
        long root = (long) (Math.sqrt(n)) + 1;
        for (long i = 3; i <= root; i += 2) {
            if (n % i == 0) {
                return i;
            }
        }
        // it's prime!
        return n;
    }

    /**
     * From http://faruk.akgul.org/blog/javas-missing-algorithm-biginteger-sqrt/
     */
    public BigInteger sqrt(BigInteger n) {
        BigInteger a = BigInteger.ONE;
        BigInteger b = new BigInteger(n.shiftRight(5).add(new BigInteger("8")).toString());
        while (b.compareTo(a) >= 0) {
            BigInteger mid = new BigInteger(a.add(b).shiftRight(1).toString());
            if (mid.multiply(mid).compareTo(n) > 0) b = mid.subtract(BigInteger.ONE);
            else a = mid.add(BigInteger.ONE);
        }
        return a.subtract(BigInteger.ONE);
    }

    private BigInteger internalPrimeFactor(BigInteger n) {
        BigInteger root = sqrt(n);
        BigInteger maxlimit = new BigInteger("" + (root.compareTo(MAXLONG) > 0 ? Long.MAX_VALUE : root.longValue()));

        for (BigInteger i = new BigInteger("3"); i.compareTo(maxlimit) < 0; i = i.add(BigIntegerTWO)) {
            if (n.mod(i).equals(BigInteger.ZERO)) {
                return i;
            }
        }

        // OK, no prime factor found less than Long.
        // resort to using BigInteger arithmatic in the loop.
        // MAXLONG is odd, we can go from there.
        for (BigInteger i = MAXLONG; root.compareTo(i) >= 0; i = i.add(BIGTWO)) {
            if (n.mod(i).equals(BigInteger.ZERO)) {
                return i;
            }
        }
        // it's prime!
        return n;
    }

    protected static BigInteger BigIntegerTWO = BigInteger.valueOf(2);


}