package gcj.b4sh.y2009.r1c;

import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.PrintWriter;
import java.math.BigDecimal;
import java.text.NumberFormat;
import java.util.Scanner;

/**
 * <p>
 * Google Code Jam 2009 - Round 1C - Problem B<br />
 * Center of Mass
 * </p>
 *
 * @see http://code.google.com/codejam/contest/dashboard?c=189252#s=p1
 * @author Carlos Vara
 */
public class ProblemB {
    
    NumberFormat nf = NumberFormat.getInstance();
    
    public static BigDecimal round(double d, int decimalPlace){
        BigDecimal bd = new BigDecimal(Double.toString(d));
        bd = bd.setScale(decimalPlace,BigDecimal.ROUND_HALF_UP);
        return bd;
      }
    
    /**
     * Calculates the distance d[t]*d[t]
     */
    public double distance(double[][] swarm, double t) {
        
        double[] cm = new double[3];
        for ( int i=0; i<swarm.length; ++i ) {
            cm[0] += swarm[i][0] + t*swarm[i][3];
            cm[1] += swarm[i][1] + t*swarm[i][4];
            cm[2] += swarm[i][2] + t*swarm[i][5];
        }
        cm[0] /= swarm.length;
        cm[1] /= swarm.length;
        cm[2] /= swarm.length;
        
        return Math.sqrt(cm[0]*cm[0] + cm[1]*cm[1] + cm[2]*cm[2]);
    }
    
    /**
     * Solves the proposed problem.
     * 
     * @param inName Name of the input file.
     * @param outName Name of the output file (will be overwritten if exists).
     */
    public void solve(String inName, String outName) throws Exception {

        nf.setMaximumFractionDigits(8);
        nf.setMinimumFractionDigits(8);
        
        // Open input and output files
        Scanner inSc = new Scanner(new FileInputStream(inName));
        PrintWriter outPw = new PrintWriter(new FileWriter(outName));

        // Solve all the cases
        int T = inSc.nextInt();
        for (int i = 1; i <= T; ++i) {

            // Read N
            int N = inSc.nextInt();
            
            // Read the swarm
            double[][] swarm = new double[N][6];
            for ( int n=0; n<N; ++n ) {
                for ( int d=0; d<6; ++d ) {
                    swarm[n][d] = inSc.nextDouble();
                }
            }
            
            // Search for the minimum
            double l_low = 0.0d;
            double l_hig = 9000000000000.0d;
            double e = 0.00000000001d;
            double d_low, d_hig;
            
            do {
                d_low = distance(swarm, l_low);
                double d_med = distance(swarm, (l_hig+l_low)/2.0d);
                d_hig = distance(swarm, l_hig);
                if ( Math.abs(d_hig-d_low) < e && Math.abs(l_hig-l_low) < e) {
                    break;
                }
                else {
                    // Choose what half to keep
                    if ( Math.abs(d_hig-d_med) < Math.abs(d_med-d_low) ) {
                        l_low = (l_hig+l_low)/2.0d;
                    }
                    else {
                        l_hig = (l_hig+l_low)/2.0d;
                    }
                }
            } while ( true );
            
           outPw.println("Case #"+i+": " + round(d_low,6) + " " + round(l_low,6));
//            outPw.println("Case #"+i+": " + nf.format(round(d_low,6)) + " " + nf.format(round(l_low,6)));
            
            
        }

        // Close files
        outPw.flush();
        outPw.close();
        inSc.close();
    }


    public static void main(String... args) {
        try {
            new ProblemB().solve("r1c/B-small.in", "r1c/B-small.out");
        } catch (Exception e) {
            System.err.println("Oops, something went wrong");
            e.printStackTrace(System.err);
        }
    }


}
