package gcj.b4sh.q2009;

import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.PrintWriter;
import java.util.Scanner;
import java.util.Stack;

/**
 * <p>
 * Google Code Jam 2009 - Qualification Round - Problem B<br />
 * Watersheds
 * </p>
 *
 * @see http://code.google.com/codejam/contest/dashboard?c=90101#s=p1
 * @author Carlos Vara
 */
public class ProblemB {

    
    /**
     * Data of a cell in the area.
     */
    public class Cell {
        
        public Cell(int x, int y, int h) {
            this.x = x;
            this.y = y;
            this.h = h;
        }
        
        // Cell coordinates and height
        int x;
        int y;
        int h;
        
        // Cell's basin name
        char basinName = ' ';
        
    }
    
    
    /**
     * An elevation map. The name of a cell's basin can be obtained with the
     * function <code>getCellBasin</code>.
     */
    public class Area {
        
        // Direction priorities: N W E S
        int[][] directions = { { 0, -1 }, { -1, 0 }, { 1, 0 }, { 0, 1 } };
        
        // Grid of cells and dimensions
        public Cell[][] cells;
        public int h;
        public int w;
        
        // Next name to assign to an unnamed sink
        public char nextSinkName = 'a';
        
        public Area( int h, int w ) {
            cells = new Cell[w][h];
            this.h = h;
            this.w = w;
        }
        
        public boolean inRange(int x, int y) {
            return ((x>=0) && (x<w) &&( y>=0) && (y<h));
        }
        
        public char getCellBasin( Cell c ) {
            
            // If this has already been visited, name will be set
            if (c.basinName != ' ') {
                return c.basinName;
            }
            
            // Follow the flow, and fill the stack with the path
            Stack<Cell> cellsInPath = new Stack<Cell>();
            cellsInPath.push(c);
            c = getNextCell(c);
            while ( c != null && c.basinName == ' ' ) {
                cellsInPath.push(c);
                c = getNextCell(c);
            }
            
            // New sink?
            if ( c == null ) {
                c = cellsInPath.pop();
                c.basinName = nextSinkName++;
            } 
            
            // Name all remaining cells in the stack with c.name
            while ( !cellsInPath.empty() ) {
                cellsInPath.pop().basinName = c.basinName;
            }
            
            return c.basinName;
        }
        
        public Cell getNextCell(Cell c) {
            
            Cell nextC = null;
            int lowestH = c.h;
            
            // Gets the cell to wich c's water will flow, null if c is a sink
            for ( int i=0; i<directions.length; ++i ) {
                if ( inRange(c.x+directions[i][0], c.y+directions[i][1]) && cells[c.x+directions[i][0]][c.y+directions[i][1]].h < lowestH ) {
                    nextC = cells[c.x+directions[i][0]][c.y+directions[i][1]];
                    lowestH = nextC.h;
                }
            }
            
            return nextC;
        }
        
    }

    /**
     * Solves the proposed problem.
     * 
     * @param inName Name of the input file.
     * @param outName Name of the output file (will be overwritten if exists).
     */
    public void solve(String inName, String outName) throws Exception {

        // Open input and output files
        Scanner inSc = new Scanner(new FileInputStream(inName));
        PrintWriter outPw = new PrintWriter(new FileWriter(outName));

        // Solve all the cases
        int totCases = inSc.nextInt();
        for (int i = 1; i <= totCases; ++i) {

            // Read the case
            Area area = new Area( inSc.nextInt(), inSc.nextInt() );
            for ( int y=0; y<area.h; ++y ) {
                for ( int x=0; x<area.w; ++x ) {
                    area.cells[x][y] = new Cell(x, y, inSc.nextInt());
                }
            }
            
            // Output the result
            outPw.println("Case #" + i +":");
            for ( int y=0; y<area.h; ++y ) {
                for ( int x=0; x<area.w-1; ++x ) {
                    outPw.print(area.getCellBasin(area.cells[x][y]) + " ");
                }
                outPw.print(area.getCellBasin(area.cells[area.w-1][y]));
                outPw.println();
            }

        }

        // Close files
        outPw.flush();
        outPw.close();
        inSc.close();
    }


    public static void main(String... args) {
        try {
            new ProblemB().solve("q2009/B-small-attempt2.in", "q2009/B-small2.out");
        } catch (Exception e) {
            System.err.println("Oops, something went wrong");
            e.printStackTrace(System.err);
        }
    }


}
