package com.google.jam14.qualification.cookie;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.util.Locale;

import static com.google.jam14.qualification.cookie.JamUtils.*;

/**
 * Created with IntelliJ IDEA.
 * User: Alisa
 * Date: 12.04.14
 * Time: 14:26
 * To change this template use File | Settings | File Templates.
 */
public class CookieClicker extends JamTask {

    private final int startCookiesPerSec;

    public CookieClicker(int cookiesPerSec) {
        this.startCookiesPerSec = cookiesPerSec;
    }

    public static void main(String ... args) {

        CookieClicker taskA = new CookieClicker(2);
        taskA.start();
    }

    @Override
    public void solve(int testCaseNum, BufferedReader bufferedReader, BufferedWriter bufferedWriter) throws IOException {
        String[] lines = getNextString(bufferedReader).split(" ");
        double farmCostInCookies = parseDouble(lines[0]);
        double farmSalaryInCookies = parseDouble(lines[1]);
        double winCookies = parseDouble(lines[2]);
        System.out.println(String.format(" testCase = %d; c = %f; f = %f;  x = %f", testCaseNum, farmCostInCookies, farmSalaryInCookies, winCookies));
        boolean useFormulaSolution = true;
        //first solution with "how people think approach"
        if (!useFormulaSolution) {
            Game game = new Game(startCookiesPerSec, farmCostInCookies, farmSalaryInCookies, winCookies);

            processAnotherStep(testCaseNum, game, 0, bufferedWriter);

        }  else {
            // second solution using formulas
            int numOfFarmBuys = 0;
            if (winCookies / startCookiesPerSec <= farmCostInCookies / startCookiesPerSec) {
                format(bufferedWriter, testCaseNum, winCookies / startCookiesPerSec);
                return;
            }
            double secWithNBuys = getSecondsOfGameWithNBuys(numOfFarmBuys, farmSalaryInCookies, farmCostInCookies, winCookies, startCookiesPerSec);
            double secWithOneMoreBuy = getSecondsOfGameWithNBuys(numOfFarmBuys + 1, farmSalaryInCookies, farmCostInCookies, winCookies, startCookiesPerSec);
            double err = Math.pow(10, -7);
            while (secWithOneMoreBuy < secWithNBuys && Math.abs(secWithNBuys - secWithOneMoreBuy) > err) {
                numOfFarmBuys++;
                secWithNBuys = getSecondsOfGameWithNBuys(numOfFarmBuys, farmSalaryInCookies, farmCostInCookies, winCookies, startCookiesPerSec);
                secWithOneMoreBuy = getSecondsOfGameWithNBuys(numOfFarmBuys + 1, farmSalaryInCookies, farmCostInCookies, winCookies, startCookiesPerSec);

            }
            format(bufferedWriter, testCaseNum, secWithNBuys);
        }

    }

    /**
     *
     * @param numberOfBuys - amount of buys of farm during whole game
     * @param f - cookies farm earn for u
     * @param c - cost of farm in cookies
     * @param w - cookies to win and finish game
     * @param x - start amount of cookies u earn per second
     * @return
     */
    private double getSecondsOfGameWithNBuys(int numberOfBuys, double f, double c, double w, double x) {
        double sum = 0;
        for(int i = 0; i <= numberOfBuys - 1; i++) {
            sum += 1.0 / (x + i * f);
        }
        return c * sum + w / (x + (numberOfBuys * f));
    }

    private void processAnotherStep(int testCaseNum, Game game, int iteration, BufferedWriter bufferedWriter) throws IOException {
         if (game.getSecondsElapsed() > game.getStartSecondsToWin()) {
             format(bufferedWriter, testCaseNum, game.getStartSecondsToWin());
             return;
         }

        // if it's obvious to win without buying a farm
        if (game.weCanFinish()) {
            game.finish();
            format(bufferedWriter, testCaseNum, game.getSecondsElapsed());
        } else {
            //else we buy a farm and repeat iteration
            game.buyNewFarm();

            Game gameWithOneMoreBuy = game.clone();
            gameWithOneMoreBuy.buyNewFarm();


            System.out.println(String.format("        timeToWin=%f (%f) ; timeToWinWithOneBuy=%f (%f)",
                    game.getCurrentSecondsToWinWithoutBuyingFarm(),
                    game.getSecondsElapsed() + game.getCurrentSecondsToWinWithoutBuyingFarm(),
                    gameWithOneMoreBuy.getCurrentSecondsToWinWithoutBuyingFarm(),
                    gameWithOneMoreBuy.getSecondsElapsed() + gameWithOneMoreBuy.getCurrentSecondsToWinWithoutBuyingFarm()));

            if (gameWithOneMoreBuy.getSecondsElapsed() + gameWithOneMoreBuy.getCurrentSecondsToWinWithoutBuyingFarm() < game.getSecondsElapsed() + game.getCurrentSecondsToWinWithoutBuyingFarm()) {
                System.out.println(String.format("        the game is on....."));
                processAnotherStep(testCaseNum, game, iteration + 1, bufferedWriter);
            } else {
                format(bufferedWriter, testCaseNum, game.getSecondsElapsed() + game.getCurrentSecondsToWinWithoutBuyingFarm());
                return;
            }

        }

    }

    private void format(BufferedWriter bufferedWriter, int testCaseNum, double value) throws IOException {
        formatOutput(bufferedWriter, testCaseNum, String.format(Locale.US, "%.6f", value));

    }

    public class Game {
        private double secondsElapsed;
        private final double startCookiesWeEarnPerSec;
        private int farmsWeOwn;
        private final double farmSalaryPerSec;
        private final double farmCostInCookies;
        private double cookiesWeOwn;
        private double cookiesToWin;

        public Game clone() {
            Game g = new Game(startCookiesPerSec, farmCostInCookies, farmSalaryPerSec, cookiesToWin);
            g.cookiesWeOwn = cookiesWeOwn;
            g.secondsElapsed = secondsElapsed;
            g.farmsWeOwn = farmsWeOwn;
            return g;
        }


        @Override
        public String toString() {
            return "Game{" +
                    "secondsElapsed=" + secondsElapsed +
                    ", startCookiesWeEarnPerSec=" + startCookiesWeEarnPerSec +
                    ", cookiesWeEarnPerSec=" + getCookiesWeEarnPerSec() +
                    ", farmsWeOwn=" + farmsWeOwn +
                    ", farmSalaryPerSec=" + farmSalaryPerSec +
                    ", farmCostInCookies=" + farmCostInCookies +
                    ", cookiesWeOwn=" + cookiesWeOwn +
                    ", cookiesToWin=" + cookiesToWin +
                    '}';
        }

        public Game(double startCookiesWeEarnPerSec, double farmCostInCookies , double farmSalaryPerSec, double cookiesToWin) {
            this.startCookiesWeEarnPerSec = startCookiesWeEarnPerSec;
            this.farmCostInCookies = farmCostInCookies;
            this.farmSalaryPerSec = farmSalaryPerSec;
            this.cookiesToWin = cookiesToWin;
        }

        public double getSecondsElapsed() {
            return secondsElapsed;
        }

        public double getCookiesWeEarnPerSec() {
            return startCookiesPerSec + farmsWeOwn * farmSalaryPerSec;
        }

        public int getFarmsWeOwn() {
            return farmsWeOwn;
        }
        public double getCookiesWeOwn() {
            return cookiesWeOwn;
        }

        public void setCookiesWeOwn(double cookiesWeOwn) {
            this.cookiesWeOwn = cookiesWeOwn;
        }

        public double getCookiesToWin() {
            return cookiesToWin;
        }

        public double getCurrentSecondsToWinWithoutBuyingFarm() {
            return cookiesWeOwn >= cookiesToWin ? 0 : cookiesToWin  / getCookiesWeEarnPerSec();
        }

        public double getStartSecondsToWin() {
            return cookiesToWin  / startCookiesWeEarnPerSec;
        }

        public double getCurrentSecondsToGetNewFarm() {
            return (farmCostInCookies <= getCookiesWeOwn()) ? 0 : (farmCostInCookies - getCookiesWeOwn()) /getCookiesWeEarnPerSec() ;
        }

        public boolean weCanFinish() {
            return getCurrentSecondsToWinWithoutBuyingFarm() <= getCurrentSecondsToGetNewFarm();
        }

        public void finish() {
            secondsElapsed += getCurrentSecondsToWinWithoutBuyingFarm();
        }

        public void buyNewFarm() {
            double timeToBuy = getCurrentSecondsToGetNewFarm();
            secondsElapsed += timeToBuy;
            cookiesWeOwn += timeToBuy * getCookiesWeEarnPerSec() - farmCostInCookies;
            farmsWeOwn++;
        }
    }


    @Override
    public String getInputFileName() {
        return "B-large.in";
    }
}
