package com.baconcutter;

import java.io.IOException;
import java.math.BigInteger;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.*;
import java.util.stream.Stream;

/**
 * Created by Auke on 4/9/2016.
 */
public class ProblemSolver {

    private int problems = 0;
    private int lineIndex = 0;
    private int requestedJamCoins = 0;
    private List<String> answers = new ArrayList<>();

    private static final String ONE = "1";
    private static final String ZERO = "0";
    private Map<String, Long> divisorCache = new HashMap<>();

    public ProblemSolver(String filenameInput, String filenameOutput) throws IOException {
        long start = System.currentTimeMillis();
        try (Stream<String> lines = Files.lines(Paths.get(filenameInput), Charset.defaultCharset())) {
            lines.forEachOrdered(line -> process(line));
            Files.write(Paths.get(filenameOutput), answers);
        }
        long end = System.currentTimeMillis();
        System.out.println("it took " + ((end-start) / 1000) + " seconds");
    }

    private void process(String line) {
        if (lineIndex == 0) {
            problems = Integer.parseInt(line);
        } else {
            answers.add("Case #" + lineIndex + ":");
            solveProblem(line);
        }
        lineIndex++;
    }

    private void solveProblem(String input) {
        String[] request = input.split("\\s");
        int jamcoinLength = Integer.valueOf(request[0]);
        requestedJamCoins = Integer.valueOf(request[1]);

        List<Boolean> prefixList = new ArrayList<>();
        prefixList.add(true);

        renderPossiblities(jamcoinLength, prefixList);
    }

    private void checkPossibility(List<Boolean> possibility){
        if (requestedJamCoins == 0) {
            //Finished
            return;
        }
        StringBuilder answerBuilder = new StringBuilder();

        for (boolean b : possibility) {
            answerBuilder.append(b? ONE: ZERO);
        }

        Collections.reverse(possibility);

        for (long base = 2; base <= 10; base++) {
            BigInteger acc = new BigInteger("0");

            for (int i = 0; i < possibility.size(); i++) {
                if(possibility.get(i)){
                    long result = (long) Math.pow(base, (long) i);
                    acc = acc.add(BigInteger.valueOf(result));
                }
            }

            if (acc.isProbablePrime(1)) {
                return;
            }

            long nonTrivialDivisor = getNonTrivialDivisor(acc);
            if(nonTrivialDivisor > 0){
                answerBuilder.append(" ").append(nonTrivialDivisor);
            } else{
                System.out.println("no divisor found for: " + acc);
                return;
            }
        }

        String answer = answerBuilder.toString();
        answers.add(answer);
        System.out.println("Found " + (answers.size() -1) + " answers");
        requestedJamCoins--;
    }

    private long getNonTrivialDivisor(BigInteger number){
        String numberString = number.toString();
        Long cachedDivisor = divisorCache.get(numberString);
        if(cachedDivisor != null){
            return cachedDivisor;
        }

        long start = System.currentTimeMillis();
        long timeLimit = start + 5*1000;
        long step = 1;
        for(long i = 3; i < Long.MAX_VALUE / 2; i+=step){
            if(number.compareTo(BigInteger.valueOf(i)) == 1) {
                BigInteger[] bigIntegers = number.divideAndRemainder(BigInteger.valueOf(i));
                if (bigIntegers[1].compareTo(BigInteger.ZERO) == 0) {
                    long divider = bigIntegers[0].longValue();
                    if(divider <= 0){
                        divider = i;
                    }
                    divisorCache.put(numberString, divider);

                    return divider;
                }
            } else{
                return 0;
            }

            if(System.currentTimeMillis() > timeLimit){
                System.out.println("Time limit exceeded trying to find divisor for: " + numberString);
                return 0;
            }
        }
        return 0;
    }


    private void renderPossiblities(int requiredLength, List<Boolean> prefixList) {
        if(requestedJamCoins == 0){
            return;
        }

        if (prefixList.size() + 1 == requiredLength) {
            prefixList.add(true);
            checkPossibility(prefixList);
        } else {
            //start with the 0 tree, because of efficiency
            List<Boolean> newPrefixListWithFalseBool = new ArrayList<>();
            newPrefixListWithFalseBool.addAll(prefixList);
            newPrefixListWithFalseBool.add(false);
            renderPossiblities(requiredLength, newPrefixListWithFalseBool);

            List<Boolean> newPrefixListWithTrueBool = new ArrayList<>();
            newPrefixListWithTrueBool.addAll(prefixList);
            newPrefixListWithTrueBool.add(true);
            renderPossiblities(requiredLength, newPrefixListWithTrueBool);
        }
    }


}
