package com.baconcutter;

import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;
import java.util.stream.Stream;

/**
 * Created by Auke on 4/9/2016.
 */
public class ProblemSolver {

    private int problems = 0;
    private int lineIndex = 0;
    private List<String> answers = new ArrayList<>();

    public ProblemSolver(String filenameInput, String filenameOutput) throws IOException {
        try (Stream<String> lines = Files.lines(Paths.get(filenameInput), Charset.defaultCharset())) {
            lines.forEachOrdered(line -> process(line));
            Files.write(Paths.get(filenameOutput), answers);
        }
    }

    private void process(String line) {
        if (lineIndex == 0) {
            problems = Integer.parseInt(line);
        } else {
            answers.add("Case #" + lineIndex + ": " + solveProblem(line));
        }
        lineIndex++;
    }

    private int solveProblem(String input) {
        if(input == null || input.length() == 0){
            return 0;
        }
        List<Boolean> booleanList = convertStringToBooleanList(input);

        int attempt1 = flipBooleansToTrue(booleanList, 0);
        int attempt2 = flipBooleansToTrue(flipReverse(booleanList), 1);

        return attempt1 > attempt2 ? attempt2 : attempt1;
    }

    private int flipBooleansToTrue(List<Boolean> booleanList, int attempts) {
        boolean firstBoolean = false;
        for (int i = 0; i < booleanList.size(); i++) {
            boolean b = booleanList.get(i);
            if (i == 0) {
                firstBoolean = b;
                continue;
            }

            if (b != firstBoolean) {
                //flipReverse all booleans before this one
                List<Boolean> flipReversedSubList = flipReverse(booleanList.subList(0, i));
                flipReversedSubList.addAll(booleanList.subList(i, booleanList.size()));
                return flipBooleansToTrue(flipReversedSubList, attempts + 1);
            }
        }

        if(!firstBoolean){
            attempts++;
        }

        return attempts;
    }

    /**
     * flip all booleans in given list and reverse list.
     * @param listToBeReverseFlipped
     * @return
     */
    private List<Boolean> flipReverse(List<Boolean> listToBeReverseFlipped) {
        List<Boolean> reversedList = new LinkedList<>();
        listToBeReverseFlipped.forEach(b -> reversedList.add(!b));
        Collections.reverse(reversedList);
        return reversedList;
    }

    private List<Boolean> convertStringToBooleanList(String input) {
        List<Boolean> booleanList = new LinkedList<>();

        for (int i = 0; i < input.length(); i++) {
            boolean b = "+".equals(String.valueOf(input.charAt(i)));
            booleanList.add(b);
        }
        return booleanList;
    }
}
