package com.badal;

import static com.badal.util.InputUtility.getInt;
import static com.badal.util.InputUtility.getIntArray;

import java.io.BufferedReader;

import com.badal.util.AbstractProblem;

public class MinesweeperMaster extends AbstractProblem {

	public static void main(String[] args) throws Exception {
		MinesweeperMaster problem = new MinesweeperMaster();
		problem.generateOutputForInput("C:\\Users\\badal\\Downloads\\C-small-attempt0.in");
	}

	@Override
	public void solve(BufferedReader br) throws Exception {
		int t = getInt(br);
		for (int i = 0; i < t; i++) {
			int[] inp = getIntArray(br);
			int r = inp[0];
			int c = inp[1];
			int m = inp[2];

			int[][] opt = new int[r][c];
			fillOptimumSolution(opt, 0, r - 1, 0, c - 1, m);
			String out = "Case #" + (i + 1) + ":";
			System.out.println(out);
			output.add(out);
			if (checkPossible(opt, r, c, m)) {
				printOutput(opt);
			} else {
				output.add("Impossible");
				System.out.println("Impossible");
			}
		}

	}

	private boolean checkPossible(int[][] opt, int r, int c, int m) {
		int row = r / 2 + 1;
		int col = c / 2 + 1;
		if (opt[row - 1][col - 1] == -1) {
			return false;
		} else {
			if (startSolving(opt, r, c, row - 1, col - 1)){
				opt[row - 1][col - 1] = -2;
				return true;
			}else if(startSolving(opt, r, c, row, col)){
				opt[row][col] = -2;
				return true;
			}else if(startSolving(opt, r, c, row-1, col)){
				opt[row - 1][col] = -2;
				return true;
			}else if(startSolving(opt, r, c, row, col-1)){
				opt[row][col - 1] = -2;
				return true;
			}
			
		}
		return false;
	}

	private boolean startSolving(int[][] opt, int r, int c, int row, int col) {
		if (row >= r || col >= c || row < 0 || col < 0) {
			return false;
		}
		if(opt[row][col] == 1 || opt[row][col] == -1){
			return false;
		}
		boolean bomb1 = isBomb(opt, r, c, row - 1, col - 1);
		boolean bomb2 = isBomb(opt, r, c, row - 1, col);
		boolean bomb3 = isBomb(opt, r, c, row - 1, col + 1);
		boolean bomb4 = isBomb(opt, r, c, row, col - 1);
		boolean bomb5 = isBomb(opt, r, c, row, col + 1);
		boolean bomb6 = isBomb(opt, r, c, row + 1, col - 1);
		boolean bomb7 = isBomb(opt, r, c, row + 1, col);
		boolean bomb8 = isBomb(opt, r, c, row + 1, col + 1);
		if (!bomb1 && !bomb2 && !bomb3 && !bomb4 && !bomb5 && !bomb6 && !bomb7 && !bomb8) {
			opt[row][col] = 1;
			startSolving(opt, r, c, row - 1, col - 1);
			startSolving(opt, r, c, row - 1, col);
			startSolving(opt, r, c, row - 1, col + 1);
			startSolving(opt, r, c, row, col - 1);
			startSolving(opt, r, c, row, col + 1);
			startSolving(opt, r, c, row + 1, col - 1);
			startSolving(opt, r, c, row + 1, col);
			startSolving(opt, r, c, row + 1, col + 1);
			return true;
		}else{
			opt[row][col] = 2;
			return false;
		}
	}

	private boolean isBomb(int[][] opt, int r, int c, int row, int col) {
		if (row >= r || col >= c || row < 0 || col < 0) {
			return false;
		}
		if (opt[row][col] == -1)
			return true;
		return false;
	}

	private void printOutput(int[][] opt) {
		for (int i = 0; i < opt.length; i++) {
			StringBuilder sb = new StringBuilder();
			for (int j = 0; j < opt[i].length; j++) {
				if (opt[i][j] == -1) {
					sb.append("*");
				}else if (opt[i][j] == -2) {
					sb.append("c");
				} else if (opt[i][j] == 1) {
					sb.append(".");
				} else if (opt[i][j] == 2) {
					sb.append(".");
				}else
					sb.append(".");
			}
			output.add(sb.toString());
			System.out.println(sb.toString());
		}
	}

	private int fillOptimumSolution(int[][] opt, int i, int row, int j, int col, int m) {
		if (m == 0)
			return m;

		int fill = fillCol(opt, j, i, row, m);
		if (fill != 0) {
			m -= fill;
			j++;
		}
		fill = fillCol(opt, col, i, row, m);
		if (fill != 0) {
			m -= fill;
			col--;
		}
		fill = fillRow(opt, i, j, col, m);
		if (fill != 0) {
			m -= fill;
			i++;
		}
		fill = fillRow(opt, row, j, col, m);
		if (fill != 0) {
			m -= fill;
			row--;
		}
		if (m < row - i + 1 && m < col - j + 1) {
			m = fillRest(opt, i, row, j, col, m);
		} else {
			m = fillOptimumSolution(opt, i, row, j, col, m);
		}
		return m;
	}

	private int fillRest(int[][] opt, int i, int row, int j, int col, int m) {
		int x = 0;
		int y = 0;
		while (m != 0) {
			for (int z = 0; z <= x; z++) {
				if (m != 0) {
					opt[i + z][j + x - z] = -1;
					m--;
				}
				if (m != 0) {
					opt[row - z][col - x + z] = -1;
					m--;
				}
			}
			x++;
		}
		return m;
	}

	private int fillRow(int[][] opt, int rowNo, int j, int col, int m) {
		if (col - j + 1 <= m && m != 0) {
			for (int k = j; k <= col; k++) {
				opt[rowNo][k] = -1;
			}
			return col - j + 1;
		} else
			return 0;
	}

	private int fillCol(int[][] opt, int colNo, int i, int row, int m) {
		if (row - i + 1 <= m && m != 0) {
			for (int k = i; k <= row; k++) {
				opt[k][colNo] = -1;
			}
			return row - i + 1;
		} else
			return 0;
	}

}
