package rq2017.c;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.HashMap;
import java.util.Map.Entry;

import util.RawInput;
import util.Util;

/**
 * Solver class template, intended to be used for a specific Google Code Jam problem.
 * The class solves exactly one case at a time and returns the result in String format, ready to be appended into the submission file for the given case number
 *
 */
public class ProblemSolver implements util.CaseSolver {

	private int runmode;
	
	private long N;
	private long K;
	
	public static HashMap<Long, Node> nodes;
	public static boolean nodesCreated = false;
	
	/**
	 * constructor. The expected size of the problem might require different approaches, therefore runmode is required as a parameter   
	 * @param inRunMode expected RUNMODE_SMALL or RUNMODE_LARGE (see ProblemSolution)
	 */
	public ProblemSolver(int inRunMode){
		runmode = inRunMode;
	}
	
	
	@Override
	public String solveCase(RawInput inCase) {
		init(inCase);
		// TODO Auto-generated method stub
		return solveBF(inCase);
	}
	
	public String solveBF(RawInput inCase) {
		//binary tree, but only path from root to leaf representing the Kth person
		//construct path from leaf to root
		//upper or lower child?
		ArrayList<Integer> path = new ArrayList<Integer>();
		Node tmp = nodes.get(K);
		 
		while(tmp != null){
			path.add(0, tmp.type);
			tmp = tmp.parent;
		}
		path.remove(0);
		//System.out.println("path=" + Util.iterableToString(path, ","));
		
		//head (max, min) pair of the first person entering the bathroom
		LongPair first = null;
		if(N % 2==0){
			first = new LongPair(N/2, N/2-1);
		} else {
			first = new LongPair(N/2, N/2);
		}
		//System.out.println("first=" + first);
		
		//go down the path and choose the child as indicated
		LongPair prev = first;
		for(int i=0; i<path.size(); i++){
			long parentValue = prev.getValue(path.get(i));
			if(parentValue % 2==0){
				prev = new LongPair(parentValue/2, parentValue/2-1);
			} else {
				prev = new LongPair(parentValue/2, parentValue/2);
			}
			//System.out.println("i=" + i + ", parentValue=" + parentValue + " --> prev=" + prev);
		}
		
		return Long.toString(prev.max) + " " + Long.toString((prev.min<0L ? 0 : prev.min));
	}
	
	/**
	 * initializer code, called immediately by solveCase
	 * @param inCase case to be solved
	 */
	private void init(RawInput inCase){
		//store raw data
		//ArrayList<Integer> xx = Util.splitStringToInt(inCase.getData()[0], null);
		String[] xx = inCase.getData()[0].split(" ");
		N = Long.parseLong(xx[0]);
		K = Long.parseLong(xx[1]);
		genTree();
		System.out.println("init :: N=" + N + ", K=" + K);
	}

	private void genTree(){
		if(nodesCreated) return;
		
		nodes = new HashMap<Long, Node>();
		
		Node root = new Node(1L, null, -1);
		nodes.put(1L, root);
		
		ArrayList<Node> toProcess = new ArrayList<Node>();
		toProcess.add(root);
		int added = 1;
		
		for(int i=1; i<20; i++){
			ArrayList<Node> tmp = new ArrayList<Node>();
			int distance = toProcess.size();
			int cnt = 0;
			for(Node nd : toProcess){
				cnt++;
				//uppers
				long key = (long)added + (long)cnt;
				Node un = new Node( key, nd, 0 );
				nd.upperChild = un;
				nodes.put(key, un);
				//lowers
				key += (long)distance;
				Node ln = new Node( key, nd, 1 );
				nd.lowerChild = ln;
				nodes.put(key, ln);
				tmp.add(un);
				tmp.add(ln);
			}
			added += (2*distance);
			toProcess = new ArrayList<Node>();
			for(Node nd : tmp){
				toProcess.add(nd);
			}
		}
		nodesCreated = true;
	}
}
