package rq2017.b;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.HashMap;
import java.util.Map.Entry;

import util.RawInput;
import util.Util;

/**
 * Solver class template, intended to be used for a specific Google Code Jam problem.
 * The class solves exactly one case at a time and returns the result in String format, ready to be appended into the submission file for the given case number
 *
 */
public class ProblemSolver implements util.CaseSolver {

	private int runmode;
	
	private long N;
	private String strN;
	
	/**
	 * constructor. The expected size of the problem might require different approaches, therefore runmode is required as a parameter   
	 * @param inRunMode expected RUNMODE_SMALL or RUNMODE_LARGE (see ProblemSolution)
	 */
	public ProblemSolver(int inRunMode){
		runmode = inRunMode;
	}
	
	
	@Override
	public String solveCase(RawInput inCase) {
		init(inCase);
		//trivia
		if(strN.length()==1) return strN;
		if(isTidy(strN)) return strN;
		// TODO Auto-generated method stub
		//return solveBF(inCase);
		return solveLarge(inCase);
	}
	
	public String solveBF(RawInput inCase){
		init(inCase);
		boolean tidy = isTidy(N);
		while(!tidy){
			N--;
			tidy = isTidy(N);
		}
		return Long.toString(N);
	}
	
	public String solveLarge(RawInput inCase){
		init(inCase);
		
		String ret = "";
		String cop = strN;
		while(!isTidy(cop)){
			cop = transform(cop);
		}
		
		if(cop.substring(0, 1).equalsIgnoreCase("0"))
			return cop.substring(1);
		else return cop; 
	}
	
	public String transform(String inStrNum){
		char[] a = inStrNum.toCharArray();
		String ret = "";
		
		for(int i=1; i<a.length; i++){
			int prv = Integer.parseInt(Character.toString(a[i-1]));
			int act = Integer.parseInt(Character.toString(a[i]));
			if(prv > act){
				for(int j=0; j<i-1; j++){
					ret += a[j];
				}
				ret += Integer.toString(prv-1);
				for(int j=i; j<a.length; j++){
					ret += "9";
				}
				break;
			}
		}
		
		return ret;
	}
	
	public boolean isTidy(long inNum){
		return isTidy(Long.toString(inNum));
	}
	
	public boolean isTidy(String inNumStr){
		boolean ret = true;
		
		char[] a = inNumStr.toCharArray();
		for(int i=1; i<inNumStr.length(); i++){
			int prv = Integer.parseInt(Character.toString(a[i-1]));
			int act = Integer.parseInt(Character.toString(a[i]));
			if(prv > act){
				ret = false;
				break;
			}
		}
		
		return ret;
	}
	
	/**
	 * initializer code, called immediately by solveCase
	 * @param inCase case to be solved
	 */
	private void init(RawInput inCase){
		//store raw data
		//ArrayList<Integer> xx = Util.splitStringToInt(inCase.getData()[0], null);
		strN = inCase.getData()[0];
		N = Long.parseLong(strN);
	}

}
