package rq2017.a;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.HashMap;
import java.util.Map.Entry;

import util.RawInput;
import util.Util;

/**
 * Solver class template, intended to be used for a specific Google Code Jam problem.
 * The class solves exactly one case at a time and returns the result in String format, ready to be appended into the submission file for the given case number
 *
 */
public class ProblemSolver implements util.CaseSolver {

	private int runmode;
	
	private String origS;
	private String[] S;
	private int K;
	
	/**
	 * constructor. The expected size of the problem might require different approaches, therefore runmode is required as a parameter   
	 * @param inRunMode expected RUNMODE_SMALL or RUNMODE_LARGE (see ProblemSolution)
	 */
	public ProblemSolver(int inRunMode){
		runmode = inRunMode;
	}
	
	
	@Override
	public String solveCase(RawInput inCase) {
		init(inCase);
		// TODO Auto-generated method stub
		return solveBF(inCase);
	}
	
	public String solveBF(RawInput inCase) {
		PKRow p = new PKRow(origS);
		if(p.isOK()) return "0";
		
		int ptr = -1;
		while((ptr <= origS.length()-K) && (!p.isOK()) ){
			ptr = p.firstNeg();
			p.flip(ptr, K);
			//System.out.println("after flip: " + p.toString());
		}
		
		if(p.isOK())
			return Integer.toString(p.getFlipNum());
		else return "IMPOSSIBLE";
	}
	
	/**
	 * initializer code, called immediately by solveCase
	 * @param inCase case to be solved
	 */
	private void init(RawInput inCase){
		//store raw data
		//ArrayList<Integer> xx = Util.splitStringToInt(inCase.getData()[0], null);
		String[] x = inCase.getData()[0].split(" ");
		origS = x[0];
		K = Integer.parseInt(x[1]);
		S = new String[origS.length()];
		for(int i=0; i<origS.length(); i++){
			S[i] = origS.substring(i, i+1);
		}
		//System.out.println("init :: K=" + K + ", origS=" + origS + ", S=" + tostr(S));
	}
	
	public String tostr(String[] inArr){
		String ret = inArr[0];
		for(int i=1; i<inArr.length; i++){
			ret += (","+inArr[i]);
		}
		return ret;
	}

}
