package com.google.codejam.ka.tic;

import java.io.*;
import java.util.Scanner;

public class TicTacToeTomek {

    private enum Status {

        X_WON("X won"), O_WON("O won"), DRAW("Draw"), GAME_HAS_NOT_COMPLETED("Game has not completed");

        private String msg;

        private Status(String msg) {
            this.msg = msg;
        }

        @Override
        public String toString() {
            return msg;
        }
    }

    private class StatusHolder {
        Status status;
        boolean hasFreeCell;

        private StatusHolder(Status status, boolean hasFreeCell) {
            this.status = status;
            this.hasFreeCell = hasFreeCell;
        }
    }

    private String readInput(Scanner scanner) {
        StringBuilder result = new StringBuilder();
        int caseCnt = Integer.parseInt(scanner.nextLine().trim());
        for (int i = 0; i < caseCnt; i++) {
            Status statusForCase = getStatusForCase(scanner);
            result.append(String.format("Case #%d: %s\n", i+1, statusForCase));
            scanner.nextLine();
        }

        return result.toString();
    }

    private Status getStatusForCase(Scanner scanner) {
        char[][] board = new char[4][4];
        for (int x = 0; x < 4; ++x) {
            String line = scanner.nextLine().trim();
            for (int y = 0; y < 4; ++y) {
                board[x][y] = line.charAt(y);
            }
            StatusHolder lineStatus = getStatus(board[x]);
            if (lineStatus.status != null) {
                for (int j = x + 1; j < 4; ++j) {
                    line = scanner.nextLine();
                }
                return lineStatus.status;
            }
        }
        StatusHolder rowAndDiagonalStatus = getRowAndDiagonalStatus(board);
        return rowAndDiagonalStatus.status;
    }

    private StatusHolder getRowAndDiagonalStatus(char[][] board) {
        boolean canContinue = false;
        Evaluator evaluator = new Evaluator();
        for (int y = 0; y < 4; ++y) {
            evaluator.reset();
            for (int x = 0; x < 4; ++x) {
                evaluator.addChar(board[x][y]);
            }
            StatusHolder statusHolder = evaluator.eval();
            if (statusHolder.status != null) {
                return statusHolder;
            } else if (statusHolder.hasFreeCell) {
                canContinue = true;
            }
        }

        evaluator.reset();
        for (int x = 0; x < 4; ++x) {
            evaluator.addChar(board[x][x]);
        }
        StatusHolder statusHolder = evaluator.eval();
        if (statusHolder.status != null) {
            return statusHolder;
        }

        evaluator.reset();
        for (int x = 0; x < 4; ++x) {
            evaluator.addChar(board[3-x][x]);
        }
        statusHolder = evaluator.eval();
        if (statusHolder.status != null) {
            return statusHolder;
        }

        if (!canContinue) {
            return new StatusHolder(Status.DRAW, false);
        } else {
            return new StatusHolder(Status.GAME_HAS_NOT_COMPLETED, true);
        }
    }

    private StatusHolder getStatus(char[] chars) {
        Evaluator evaluator = new Evaluator();
        for (int i = 0; i < chars.length; i++) {
            evaluator.addChar(chars[i]);
        }
        return evaluator.eval();
    }

    public static void main(String[] args) throws IOException {
        TicTacToeTomek ttt = new TicTacToeTomek();
        String result = ttt.readInput(new Scanner(new File(args[0])));
        FileWriter fileWriter = new FileWriter("c:/work/codejam/out.txt");
        fileWriter.write(result);
        fileWriter.close();
    }

    private class Evaluator {
        private boolean hasX = false;
        private boolean hasO = false;
        private boolean hasFreeCell = false;

        void addChar(char c) {
            switch (c) {
                case 'X':
                    hasX = true;
                    break;
                case 'O':
                    hasO = true;
                    break;
                case 'T':
                    break;
                case '.':
                    hasFreeCell = true;
                    break;
                default:
                    throw new IllegalArgumentException("Invalid char: " + c);
            }
        }

        void reset() {
            hasX = false;
            hasO = false;
            hasFreeCell = false;
        }

        StatusHolder eval() {
            if (!hasFreeCell) {
                if (hasX && !hasO) {
                    return new StatusHolder(Status.X_WON, false);
                } else if (hasO && !hasX) {
                    return new StatusHolder(Status.O_WON, false);
                } else {
                    return new StatusHolder(null, false);
                }
            } else {
                return new StatusHolder(null, true);
            }
        }
    }
}
