package com.google.codejam.ka.fairandsquare;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.util.Date;
import java.util.Scanner;

public class FairAndSquare {

    public static void main(String args[]) throws IOException {
        StringBuilder result = new StringBuilder();
        Scanner scanner = new Scanner(new File(args[0]));
        int caseCnt = scanner.nextInt();
        for (int i = 0; i < caseCnt; i++) {
            BigInteger min = scanner.nextBigInteger();
            BigInteger max = scanner.nextBigInteger();
            BigInteger currentPalindromSqrt = getFirstPalindromSqrt(min);
            int fairAndSquareCnt = 0;
            boolean inInterval = true;
            while (inInterval) {
                BigInteger square = currentPalindromSqrt.pow(2);
                if (square.compareTo(min) >= 0 && square.compareTo(max) <= 0 && isPalindrome(square)) {
                    ++fairAndSquareCnt;
                } else if (square.compareTo(max) > 0) {
                    inInterval = false;
                }
                currentPalindromSqrt = nextPalindrome(currentPalindromSqrt);
            }
            result.append(String.format("Case #%d: %d\n", i + 1, fairAndSquareCnt));
        }
        FileWriter fileWriter = new FileWriter(new File("fas_out.txt"));
        fileWriter.append(result.toString());
        fileWriter.close();
    }

    private static boolean isPalindrome(BigInteger square) {
        StringBuilder str = new StringBuilder(square.toString());
        return str.toString().equalsIgnoreCase(str.reverse().toString());
    }

    private static BigInteger getFirstPalindromSqrt(BigInteger min) {
        BigInteger sqrt = sqrt(min);
        if (isPalindrome(sqrt)) {
            return sqrt;
        } else {
            return nextPalindrome(sqrt);
        }
    }

    // http://faruk.akgul.org/blog/javas-missing-algorithm-biginteger-sqrt/
    private static BigInteger sqrt(BigInteger n) {
        BigInteger a = BigInteger.ONE;
        BigInteger b = new BigInteger(n.shiftRight(5).add(new BigInteger("8")).toString());
        while(b.compareTo(a) >= 0) {
            BigInteger mid = new BigInteger(a.add(b).shiftRight(1).toString());
            if(mid.multiply(mid).compareTo(n) > 0) b = mid.subtract(BigInteger.ONE);
            else a = mid.add(BigInteger.ONE);
        }
        return a.subtract(BigInteger.ONE);
    }

    private static BigInteger nextPalindrome(BigInteger num) {
        String s = num.toString();
        int length = s.length();
        if (s.matches("^9+$")) {
            return num.add(new BigInteger("2"));
        } else {
            String firstPart = s.substring(0, (length + 1) / 2);
            StringBuilder forReverse = new StringBuilder(s.substring(0, length / 2)).reverse();
            BigInteger candidate = new BigInteger(firstPart + forReverse.toString());
            if (candidate.compareTo(num) > 0) {
                return candidate;
            } else {
                BigInteger incrFirstPart = new BigInteger(firstPart).add(BigInteger.ONE);
                forReverse = new StringBuilder(incrFirstPart.toString().substring(0, length / 2)).reverse();
                return new BigInteger(incrFirstPart.toString() + forReverse);
            }
        }
    }
}
