

import java.util.*;
import java.math.*;

public class JamC {public class Combination {

	  private int[] a;
	  private int n;
	  private int r;
	  private BigInteger numLeft;
	  private BigInteger total;

	  //------------
	  // Constructor
	  //------------

	  public Combination (int n, int r) {
	    if (r > n) {
	      throw new IllegalArgumentException ();
	    }
	    if (n < 1) {
	      throw new IllegalArgumentException ();
	    }
	    this.n = n;
	    this.r = r;
	    a = new int[r];
	    BigInteger nFact = getFactorial (n);
	    BigInteger rFact = getFactorial (r);
	    BigInteger nminusrFact = getFactorial (n - r);
	    total = nFact.divide (rFact.multiply (nminusrFact));
	    reset ();
	  }

	  //------
	  // Reset
	  //------

	  public void reset () {
	    for (int i = 0; i < a.length; i++) {
	      a[i] = i;
	    }
	    numLeft = new BigInteger (total.toString ());
	  }

	  //------------------------------------------------
	  // Return number of combinations not yet generated
	  //------------------------------------------------

	  public BigInteger getNumLeft () {
	    return numLeft;
	  }

	  //-----------------------------
	  // Are there more combinations?
	  //-----------------------------

	  public boolean hasMore () {
	    return numLeft.compareTo (BigInteger.ZERO) == 1;
	  }

	  //------------------------------------
	  // Return total number of combinations
	  //------------------------------------

	  public BigInteger getTotal () {
	    return total;
	  }

	

	  //--------------------------------------------------------
	  // Generate next combination (algorithm from Rosen p. 286)
	  //--------------------------------------------------------

	  public int[] getNext () {

	    if (numLeft.equals (total)) {
	      numLeft = numLeft.subtract (BigInteger.ONE);
	      return a;
	    }

	    int i = r - 1;
	    while (a[i] == n - r + i) {
	      i--;
	    }
	    a[i] = a[i] + 1;
	    for (int j = i + 1; j < r; j++) {
	      a[j] = a[i] + j - i;
	    }

	    numLeft = numLeft.subtract (BigInteger.ONE);
	    return a;

	  }
	}

  private static int getSum (Vector v) {
    int sum = 0;
    Integer n;
    for (int i = 0; i < v.size (); i++) {
      n = (Integer) v.elementAt (i);
      sum += n.intValue ();
    }
    return sum;
  }

  public Vector compute (int[] array, int atATime) {
    int[] indices;
    Combination gen = new Combination (array.length, atATime);
    Vector results = new Vector ();
    Vector combination;
    BigInteger numCombinations = gen.getTotal ();
    //System.out.println ("Num combinations to test " + numCombinations.toString ());
   
    Integer intObj;
    while (gen.hasMore ()) {
      combination = new Vector ();
      indices = gen.getNext ();
      for (int i = 0; i < indices.length; i++) {
        intObj = new Integer (array[indices[i]]);
        combination.addElement (intObj);
      }
 
   
        Collections.sort (combination);
        if (!results.contains (combination)) {
         // System.out.println (combination.toString ());
          results.addElement (combination);
        }
     
    }
    return results;
  }

  public static String test(int array[]){
	  JamC arc = new JamC();
	    int output = 0;
	    
	    for(int l = array.length - 1;l>0;l--)
	    {
	    	Vector results = arc.compute(array, l);
	    	//System.out.println(results);
		    for(int i=0;i<results.size();i++){
		    	Vector v = (Vector)results.get(i);
		    	int b[] = new int[array.length];
		    	for(int k=0;k<b.length;k++){
		    		b[k] = array[k];
		    	}
		    	int xor1 = 0;
		    	int sum = 0;
		    	for(int j = 0; j < v.size(); j++){
		    		Integer val = (Integer)v.get(j);
		    		for(int k = 0; k < b.length; k++){
		    			if(b[k] == val.intValue()){
		    				b[k] = 0;
		    				break;
		    			}
		    		}
		    		
		    		xor1 = xor1 ^ val.intValue();
		    		sum += val.intValue();
		    	}
		    	int xor2 = 0;
		    
		    	for(int k = 0; k < b.length; k++){
		    		xor2 = xor2 + b[k];
		    		
		    	}
		    	
		    	if(xor1 == xor2 && xor1!=0){
		    		//System.out.println(v);
		    		for(int k = 0; k < b.length; k++){
		        		//System.out.println(array[k]);
		        	}
		    		//output = sum;
		    		if(sum>output)
		    			output = sum;
		    	}
		    }
		    if(output>0)
		    	break;
	    }
	    
	    if(output==0)
	    	return "NO";
	    else
	    	return ""+output;
  }
  
  public static void main (String[] args) {
    Scanner scn = new Scanner(System.in);
    int T = scn.nextInt();
    int arr[];
    int N;
    for(int i=1;i<=T;i++){
    	N = scn.nextInt();
    	arr = new int[N];
    	for(int j=0;j<N;j++)
    		arr[j] = scn.nextInt();
    	System.out.println("Case #"+i+": "+test(arr));
    }
  }
  
  //------------------
  // Compute factorial
  //------------------

  private static BigInteger getFactorial (int n) {
    BigInteger fact = BigInteger.ONE;
    for (int i = n; i > 1; i--) {
      fact = fact.multiply (new BigInteger (Integer.toString (i)));
    }
    return fact;
  }

}