package c;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.InputStreamReader;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.Comparator;
import java.util.PriorityQueue;
import java.util.Scanner;

public class ProblemCRunner {

  private static Comparator<Score> comp = (s1, s2) -> {
    if (s1.min() > s2.min()) return -1;
    if (s1.min() < s2.min()) return 1;


    if (s1.max() > s2.max()) return -1;
    if (s1.max() < s2.max()) return 1;

    if (s1.pos < s2.pos) return -1;
    return 1;
  };

  public static Score solve(int n, int k) {
    boolean[] stalls = new boolean[n + 2];
    stalls[0] = true;
    stalls[stalls.length - 1] = true;
    Score last = null;
    for (int i = 0; i < k; i++) {
      PriorityQueue<Score> scores = new PriorityQueue<>(comp);
      for (int j = 1; j <= n; j++) {
        if (stalls[j]) continue;
        Score score = score(j, stalls);
        scores.add(score);
      }
      last = scores.peek();
      stalls[last.pos] = true;
    }
    return last;
  }

  private static Score score(int pos, boolean[] stalls) {
    Score score = new Score();
    score.pos = pos;

    int left = pos;
    int right = pos;

    while (!stalls[left]) left--;
    while (!stalls[right]) right++;

    score.left = pos - left - 1;
    score.right = right - pos - 1;
    return score;
  }

  public static void main(String[] args) throws Exception {
    String name = "C-small-1-attempt0.in";
    String out = name.replace(".in", ".out");
    Scanner in = new Scanner(new BufferedReader(
        new InputStreamReader(ProblemCRunner.class.getResourceAsStream(name))));
    int t = in.nextInt();
    in.nextLine();
    try (BufferedWriter writer = Files.newBufferedWriter(Paths.get(out))) {
      for (int i = 1; i <= t; ++i) {
        int n = in.nextInt();
        int k = in.nextInt();
        Score score = solve(n, k);
        System.out.println(score);
        writer.write(String.format("Case #%d: %d %d%n", i, score.max(), score.min()));
      }
    }
  }

  private static long min(long[] lr) {
    return Math.min(lr[0], lr[1]);
  }

  private static long max(long[] lr) {
    return Math.max(lr[0], lr[1]);
  }

  private static class Score implements Comparable<Score> {
    int pos;
    int left;
    int right;

    @Override public String toString() {
      final StringBuilder sb = new StringBuilder("Score{");
      sb.append("pos=").append(pos);
      sb.append(", left=").append(left);
      sb.append(", right=").append(right);
      sb.append('}');
      return sb.toString();
    }

    int min() {
      return Math.min(left, right);
    }

    int max() {
      return Math.max(left, right);
    }

    @Override public int compareTo(Score o) {
      return comp.compare(this, o);
    }
  }
}
