import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import java.util.Queue;
import java.util.Scanner;

/**
 * 
 * @author Gregory M Chen
 *
 */
public class Minesweeper {

	/**
	 * Main method.
	 * @param args
	 * @throws FileNotFoundException 
	 * @throws UnsupportedEncodingException 
	 */
	public static void main(String[] args) throws FileNotFoundException, UnsupportedEncodingException {
		Scanner scanner = new Scanner(new File("C-small-attempt0.in"));
		PrintWriter pw = new PrintWriter("Output3.txt", "UTF-8");
		int T = scanner.nextInt();
		for(int x = 1; x <= T; x++) {
			int R = scanner.nextInt();
			int C = scanner.nextInt();
			int M = scanner.nextInt();
			String answer = getAnswer(R,C,M);
			pw.write("Case #" + x + ":\n" + answer);
		}
		pw.close();
	}

	static String getAnswer(int R, int C, int M) {
		// Brute force. 
		String answer = null;
		Queue<boolean[][]> q = new LinkedList<boolean[][]>();
		for(int i = 0; i < R/2+1; i++) {
			for(int j = 0; j < C/2+1; j++) {
				boolean[][] grid = new boolean[R][C];
				grid[i][j] = true;
				q.add(grid);
			}
		}
		boolean[][] answerGrid = null;
		ArrayList<Integer> visitedCodes = new ArrayList<Integer>();
		while(!q.isEmpty()) {
			boolean[][] currentGrid = q.poll();
			int code = getCode(currentGrid);
			
			if(visitedCodes.contains(code)) {
				continue;
			}
			visitedCodes.add(code);
			
			//System.out.println(numMines(currentGrid));
			if(numMines(currentGrid) == M) {
				answerGrid = currentGrid;
				break;
			}
			
			// Add new possibilities!
			for(int i = 0; i < currentGrid.length; i++) {
				for(int j = 0; j < currentGrid[0].length; j++) {
					if(currentGrid[i][j] == true) {
						for(int idiff = -1; idiff <= 1; idiff++) {
							for(int jdiff = -1; jdiff <= 1; jdiff++) {
								if(i + idiff < 0 || j + jdiff < 0 || i + idiff >= currentGrid.length || j + jdiff >= currentGrid[0].length) {
									continue;
								}
								if(currentGrid[i+idiff][j+jdiff] == false) {
									boolean[][] newGrid = currentGrid.clone();
									newGrid[i+idiff][j+jdiff] = true;
									//System.out.println(getOutput(newGrid));
									q.add(newGrid);
								}
							}
						}
					}
				}
			}
			
		}
		
		if(answerGrid != null) {
			answer = getOutput(answerGrid);
		}
		else {
			answer = "Impossible\n";
		}
		
		return answer;
	}
	
	static void printGrid(boolean[][] grid) {
		for(int i = 0; i < grid.length; i++) {
			for(int j = 0; j < grid[0].length; j++) {
				if(grid[i][j]) {
					System.out.print("o");
				}
				else{
					System.out.print("n");
				}
			}
			System.out.println();
		}
		System.out.println();
	}
	
	static String getOutput(boolean[][] grid) {
		boolean[][] visited = new boolean[grid.length][grid[0].length];
		int x = 0;
		int y = 0;
		for(int i = 0; i < grid.length; i++) {
			for(int j = 0; j < grid[0].length; j++) {
				if(grid[i][j] == true) {
					x = i;
					y = j;
					for(int idiff = -1; idiff <= 1; idiff++) {
						for(int jdiff = -1; jdiff <= 1; jdiff++) {
							if(i + idiff < 0 || j + jdiff < 0 || i + idiff >= grid.length || j + jdiff >= grid[0].length) {
								continue;
							}
							if(!visited[i+idiff][j+jdiff]) {
								visited[i+idiff][j+jdiff] = true;
							}
						}
					}
				}
			}
		}
		String output = "";
		for(int i = 0; i < visited.length; i++) {
			for(int j = 0; j < visited[0].length; j++) {
				if(!visited[i][j]) {
					output += "*";
				}
				else if(i == x && j == y) {
					output += "c";
				}
				else {
					output += ".";
				}
			}
			output += "\n";
		}
		return output;
	}
	
	static int numMines(boolean[][] grid) {
		int count = 0;
		boolean[][] visited = new boolean[grid.length][grid[0].length];
		for(int i = 0; i < grid.length; i++) {
			for(int j = 0; j < grid[0].length; j++) {
				if(grid[i][j] == true) {
					for(int idiff = -1; idiff <= 1; idiff++) {
						for(int jdiff = -1; jdiff <= 1; jdiff++) {
							if(i + idiff < 0 || j + jdiff < 0 || i + idiff >= grid.length || j + jdiff >= grid[0].length) {
								continue;
							}
							if(!visited[i+idiff][j+jdiff]) {
								visited[i+idiff][j+jdiff] = true;
								count++;
							}
						}
					}
				}
			}
		}
		return (grid.length * grid[0].length) - count;
	}
	
	// The max grid size has 25 things, so this should suffice with a 32 bit integer...
	static int getCode(boolean[][] grid) {
		int code = 0;
		for(int i = 0; i < grid.length; i++) {
			for(int j = 0; j < grid[0].length; j++) {
				if(grid[i][j] == true) {
					int pow = 1;
					for(int k = 0; k < i * grid[0].length + j; k++) {
						pow *= 2;
					}
					code += pow;
				}
			}
		}
		return code;
	}
}
