package round1c;

import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class P3Enclosure
{
	private final int id;
	private final int n;
	private final int m;
	private final int k;

	public P3Enclosure(int id, int n, int m, int k)
	{
		this.id = id;
		this.n = n;
		this.m = m;
		this.k = k;
	}

	public void solve()
	{
		int bestMinStones = m * n;
		for(int attempt = 0; attempt < 10; attempt++)
		{

			int minStones = 0;
			boolean[][] board = new boolean[n][m];
			double ellipseA = 0;
			double ellipseB = 0;
			double step = 0.5d;
			double centerX = (m - 1) / 2d + Math.random() - 0.5d;
			double centerY = (n - 1) / 2d + Math.random() - 0.5d;

			if(k == 1)
			{
				System.out.println("Case #" + (id + 1) + ": " + 1);
				return;
			}

			int count = 0;

			while(true)
			{
				ellipseA += step;
				for(int row = 0; row < n; row++)
				{
					for(int col = 0; col < m; col++)
					{
						if(pointInsideEllipse((double)col - centerX, (double)row - centerY, ellipseA, ellipseB))
							board[row][col] = true;
						else
							board[row][col] = false;
					}
				}
				if(countEnclosedIntersections(board, m, n) >= k)
					break;
				else
					ellipseA -= step;

				ellipseB += step;
				for(int row = 0; row < n; row++)
				{
					for(int col = 0; col < m; col++)
					{
						if(pointInsideEllipse(col - centerX, row - centerY, ellipseA, ellipseB))
							board[row][col] = true;
						else
							board[row][col] = false;
					}
				}
				if(countEnclosedIntersections(board, m, n) >= k)
					break;
				else
					ellipseB -= step;

				ellipseA += step;
				ellipseB += step;
				for(int row = 0; row < n; row++)
				{
					for(int col = 0; col < m; col++)
					{
						if(pointInsideEllipse(col - centerX, row - centerY, ellipseA, ellipseB))
							board[row][col] = true;
						else
							board[row][col] = false;
					}
				}

				count = countEnclosedIntersections(board, m, n);

				if(count >= k)
					break;
			}

			minStones = count;
			for(int row = 1; row < n - 1; row++)
			{
				for(int col = 1; col < m - 1; col++)
				{
					if(board[row - 1][col] && board[row + 1][col] && board[row][col - 1] && board[row][col + 1])
						minStones--;
				}
			}

			if(minStones < bestMinStones)
				bestMinStones = minStones;
		}

		System.out.println("Case #" + (id + 1) + ": " + bestMinStones);
	}

	private boolean pointInsideEllipse(double pointX, double pointY, double ellipseA, double ellipseB)
	{
		if(ellipseA == 0d && pointX != 0d)
			return false;
		else if(ellipseB == 0d && pointY != 0d)
			return false;
		else if(Math.pow((pointX / ellipseA), 2d) + Math.pow((pointY / ellipseB), 2d) <= 1d)
			return true;
		else
			return false;
	}

	private int countEnclosedIntersections(final boolean[][] board, int m, int n)
	{
		int enclosedIntersections = 0;

		for(int row = 0; row < n; row++)
		{
			for(int col = 0; col < m; col++)
			{
				if(board[row][col])
					enclosedIntersections++;
			}
		}

		return enclosedIntersections;
	}

	public static void main(String[] args)
	{
		Scanner in = new Scanner(System.in);

		int numberOfTestCases = in.nextInt();
		List<P3Enclosure> problemList = new ArrayList<P3Enclosure>();

		for(int i = 0; i < numberOfTestCases; i++)
		{
			int n = in.nextInt();
			int m = in.nextInt();
			int k = in.nextInt();

			problemList.add(new P3Enclosure(i, n, m, k));
		}

		int i = 0;
		for(P3Enclosure problem : problemList)
		{
			problem.solve();
		}
	}
}
