
/**
 ** @description Clase de java para manejar algunas caracter?sticas y manipulaci?n
 ** sobre archivos
 ** @author Byron Barquero Chave
 ** @date 24 de abril del 2008
 */

import java.io.BufferedReader;
import java.io.File;
import java.io.FileWriter;
import java.io.PrintWriter;
import java.util.Scanner;
import javax.swing.JOptionPane;

public class ManejadorArchivos {

    Scanner scanner;
    BufferedReader reader;

    public ManejadorArchivos() {
        this.scanner = null;
    }//Fin del constructor de la clase

    /**
     **<b>EFECTUA:</b> determina si el archivo o directorio que se introduce como par?metro existe en
     ***el sistema de archivos actual<br/ >
     **<b>REQUIERE:</b> recibir como par?metro la ruta relativa o absoluta del archivo o directorio
     ***y que sea v?lida<br/ >
     **<b>MODIFICA:</b> N/A<br/ >
     **@returns true si el archivo o directorio de la ruta que entra como par?metro existe en el sistema
     **de archivos actual
     **@returns false si el archivo o directorio de la ruta que entra como par?metro no existe en el sistema
     **de archivos actual
     **@param nombreArchivo la ruta relativa o absoluta del archivo o directorio
     **/
    public boolean existeArchivo(String nombreArchivo) {
        boolean existeArchivo = true;
        File archivoNuevo = new File(nombreArchivo);

        if (!archivoNuevo.exists()) {
            existeArchivo = false;
        }//Fin del if
        return existeArchivo;
    }//Fin del m?todo existeArchivo

    /**
     **<b>EFECTUA:</b> crea un archivo con el nombre del archivo que recibe como par?metro<br />
     **<b>REQUIERE:</b> recibir como par?metro un nombre de archivo v?lido para poder crearlo<br/ >
     **<b>MODIFICA:</b> N/A<br/ >
     **@param nombreArchivo el nombre del archivo que se desea crear
     **/
    public void crearArchivo(String nombreArchivo) {
        if (nombreArchivo.length() > 0) {
            try {
                PrintWriter salida = new PrintWriter(new FileWriter(nombreArchivo));
                salida.close();
            }//Fin del try
            catch (Exception e) {
                System.out.println("" + e);
            }//Fin del catch
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "Debe ingresar un nombre de archivo", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
    }//Fin del m?todo crearArchivo

    /**
     **<b>EFECTUA:</b> agrega una hilera de texto a un archivo existente en el sistema de archivos<br />
     **<b>REQUIERE:</b> recibir como p?rametro una hilera de texto cuya longitud sea mayor a un caracter
     * **y nombre de archivo v?lido y que exista, en caso contrario no agregar? la hilera de texto<br />
     **<b>MODIFICA:</b> rl archivo que se recibe como par?metro<br />
     **@param nombreArchivo el archivo al cual se le va a agregar la hilera de texto
     **/
    public void agregarPalabraArchivo(String palabra, String nombreArchivo) {

        if (nombreArchivo.length() > 0 && palabra.length() > 0) {
            if (this.existeArchivo(nombreArchivo)) {
                try {
                    PrintWriter salida = new PrintWriter(new FileWriter(nombreArchivo, true));
                    salida.println(palabra);
                    salida.close();
                }//Fin del try
                catch (Exception e) {
                    System.out.println("" + e);
                }//Fin del catch
            }//Fin del if
            else {
                JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del else
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "Debe ingresar un nombre de archivo", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
    }//Fin del m?todo agregarPalabraArchivo

    /**
     **<b>EFECTUA:</b> recupera el primer token completo que se encuentre dentro del nombre de archivo
     **que se pasa como par?metro<br />
     **<b>REQUIERE:</b> recibir como par?metro un nombre de archivo v?lido para poder obtener el token
     **correspondiente<br/ >
     **<b>MODIFICA:</b> N/A<br/ >
     **@param nombreArchivo el nombre del archivo del cual se desea obtener el primer token
     **@return token Un string que contiene el primer token del archivo recibido como par?metro
     **@return null En caso de que el archivo recibido no exista o no contenga tokens
     **/
    public String obtenerPrimeraPalabraArchivo(String nombreArchivo) {
        String token = null;
        if (this.existeArchivo(nombreArchivo) == true) {
            try {
                this.scanner = null;
                File archivoRecibido = new File(nombreArchivo);
                this.scanner = new Scanner(archivoRecibido);
                if (this.scanner.hasNext() == true) {
                    token = this.scanner.nextLine();
                }//Fin del if
            }//Fin del try
            catch (Exception e) {
                JOptionPane.showMessageDialog(null, "El archivo no existe " + e, "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del catch
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
        return token;
    }//Fin del m?todo obtenerPalabraArchivo

    /**
     **<b>EFECTUA:</b> recupera el siguiente token completo que se encuentre dentro del nombre de archivo
     **con el cual se configuro el manejador de archivos en el m?todo obtenerPalabraArchivo<br />
     **<b>REQUIERE:</b> recibir como par?metro un nombre de archivo v?lido para poder obtener el token
     **correspondiente, as? como la ejecuci?n anterior del m?todo obtenerSiguientePalabraArchivo<br/ >
     **<b>MODIFICA:</b> N/A<br/ >
     **@return token Un string que contiene el siguiente token del archivo configurado
     **en el manejador de archivos
     **@return null En caso de que el archivo recibido no exista, no se haya ejecutado el m?todo
     **obtenerPalabraArchivo primero o no contenga m?s tokens que recuperar
     **/
    public String obtenerSiguientePalabraArchivo() {
        String token = null;
        if (this.scanner != null) {
            try {
                if (this.scanner.hasNext() == true) {
                    token = this.scanner.nextLine();
                }//Fin del if
            }//Fin del try
            catch (Exception e) {
                JOptionPane.showMessageDialog(null, "El archivo no existe " + e, "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del catch
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
        return token;
    }//Fin del m?todo obtenerSiguientePalabraArchivo

    public String obtenerLineaArchivo(BufferedReader reader) {
        String linea = "";
    	try {
            linea = reader.readLine();
        }//Fin del try
        catch (Exception e) {
            JOptionPane.showMessageDialog(null, "El archivo no existe " + e, "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del catch
        return linea;
    }//Fin del mtodo parsearArchivoMinusculas
}//Fin de la clase ManejadorArchivos
