package themepark;

/**
 ** @description Clase de java para manejar algunas caracter?sticas y manipulaci?n
 ** sobre archivos
 ** @author Byron Barquero Chave
 ** @date 24 de abril del 2008
 */

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.PrintWriter;
import java.util.LinkedList;
import java.util.Scanner;
import javax.swing.JOptionPane;

public class ManejadorArchivos {

    Scanner scanner;
    BufferedReader reader;

    public ManejadorArchivos() {
        this.scanner = null;
    }//Fin del constructor de la clase

    /**
     **<b>EFECTUA:</b> determina si el archivo o directorio que se introduce como par?metro existe en
     ***el sistema de archivos actual<br/ >
     **<b>REQUIERE:</b> recibir como par?metro la ruta relativa o absoluta del archivo o directorio
     ***y que sea v?lida<br/ >
     **<b>MODIFICA:</b> N/A<br/ >
     **@returns true si el archivo o directorio de la ruta que entra como par?metro existe en el sistema
     **de archivos actual
     **@returns false si el archivo o directorio de la ruta que entra como par?metro no existe en el sistema
     **de archivos actual
     **@param nombreArchivo la ruta relativa o absoluta del archivo o directorio
     **/
    public boolean existeArchivo(String nombreArchivo) {
        boolean existeArchivo = true;
        File archivoNuevo = new File(nombreArchivo);

        if (!archivoNuevo.exists()) {
            existeArchivo = false;
        }//Fin del if
        return existeArchivo;
    }//Fin del m?todo existeArchivo

    /**
     **<b>EFECTUA:</b> crea un archivo con el nombre del archivo que recibe como par?metro<br />
     **<b>REQUIERE:</b> recibir como par?metro un nombre de archivo v?lido para poder crearlo<br/ >
     **<b>MODIFICA:</b> N/A<br/ >
     **@param nombreArchivo el nombre del archivo que se desea crear
     **/
    public void crearArchivo(String nombreArchivo) {
        if (nombreArchivo.length() > 0) {
            try {
                PrintWriter salida = new PrintWriter(new FileWriter(nombreArchivo));
                salida.close();
            }//Fin del try
            catch (Exception e) {
                System.out.println("" + e);
            }//Fin del catch
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "Debe ingresar un nombre de archivo", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
    }//Fin del m?todo crearArchivo

    /**
     **<b>EFECTUA:</b> agrega una hilera de texto a un archivo existente en el sistema de archivos<br />
     **<b>REQUIERE:</b> recibir como p?rametro una hilera de texto cuya longitud sea mayor a un caracter
     * **y nombre de archivo v?lido y que exista, en caso contrario no agregar? la hilera de texto<br />
     **<b>MODIFICA:</b> rl archivo que se recibe como par?metro<br />
     **@param nombreArchivo el archivo al cual se le va a agregar la hilera de texto
     **/
    public void agregarPalabraArchivo(String palabra, String nombreArchivo) {

        if (nombreArchivo.length() > 0 && palabra.length() > 0) {
            if (this.existeArchivo(nombreArchivo)) {
                try {
                    PrintWriter salida = new PrintWriter(new FileWriter(nombreArchivo, true));
                    salida.println(palabra);
                    salida.close();
                }//Fin del try
                catch (Exception e) {
                    System.out.println("" + e);
                }//Fin del catch
            }//Fin del if
            else {
                JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del else
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "Debe ingresar un nombre de archivo", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
    }//Fin del m?todo agregarPalabraArchivo

    /**
     **<b>EFECTUA:</b> recupera el primer token completo que se encuentre dentro del nombre de archivo
     **que se pasa como par?metro<br />
     **<b>REQUIERE:</b> recibir como par?metro un nombre de archivo v?lido para poder obtener el token
     **correspondiente<br/ >
     **<b>MODIFICA:</b> N/A<br/ >
     **@param nombreArchivo el nombre del archivo del cual se desea obtener el primer token
     **@return token Un string que contiene el primer token del archivo recibido como par?metro
     **@return null En caso de que el archivo recibido no exista o no contenga tokens
     **/
    public String obtenerPrimeraPalabraArchivo(String nombreArchivo) {
        String token = null;
        if (this.existeArchivo(nombreArchivo) == true) {
            try {
                this.scanner = null;
                File archivoRecibido = new File(nombreArchivo);
                this.scanner = new Scanner(archivoRecibido);
                if (this.scanner.hasNext() == true) {
                    token = this.scanner.nextLine();
                }//Fin del if
            }//Fin del try
            catch (Exception e) {
                JOptionPane.showMessageDialog(null, "El archivo no existe " + e, "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del catch
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
        return token;
    }//Fin del m?todo obtenerPalabraArchivo

    /**
     **<b>EFECTUA:</b> recupera el siguiente token completo que se encuentre dentro del nombre de archivo
     **con el cual se configuro el manejador de archivos en el m?todo obtenerPalabraArchivo<br />
     **<b>REQUIERE:</b> recibir como par?metro un nombre de archivo v?lido para poder obtener el token
     **correspondiente, as? como la ejecuci?n anterior del m?todo obtenerSiguientePalabraArchivo<br/ >
     **<b>MODIFICA:</b> N/A<br/ >
     **@return token Un string que contiene el siguiente token del archivo configurado
     **en el manejador de archivos
     **@return null En caso de que el archivo recibido no exista, no se haya ejecutado el m?todo
     **obtenerPalabraArchivo primero o no contenga m?s tokens que recuperar
     **/
    public String obtenerSiguientePalabraArchivo() {
        String token = null;
        if (this.scanner != null) {
            try {
                if (this.scanner.hasNext() == true) {
                    token = this.scanner.nextLine();
                }//Fin del if
            }//Fin del try
            catch (Exception e) {
                JOptionPane.showMessageDialog(null, "El archivo no existe " + e, "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del catch
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
        return token;
    }//Fin del m?todo obtenerSiguientePalabraArchivo

    /**
     **<b>EFECTUA:</b> escribe en un el archivo que recibe como par?metro una registro para el archivo
     **.tok de los documentos<br />
     **<b>REQUIERE:</b> recibir como par?metro un nombre de archivo v?lido y creado previamente,
     **un palabra, un frecuencia y una frecuencia normalizada<br/ >
     **<b>MODIFICA:</b> el archivo que se recibe como par?metro<br/ >
     **@param palabra la palabra que se guarda en el registro del archivo .tok
     **@param frecuencia el int que indica cuantas veces aparace la palabra en el archivo
     **@param frecuenciaNormalizada el double con la frecuencia normalizada de la palabra en el archivo
     **@param nombreArchivo con el nombre de archivo donde se va a guardar el registro
     **/
    public void escribirRegistroEnArchivo(String palabra, int frecuencia, double frecuenciaNormalizada, String nombreArchivo) {
        if (nombreArchivo.length() > 0 && palabra.length() > 0 && (String.valueOf(frecuencia)).length() > 0 && (String.valueOf(frecuenciaNormalizada)).length() > 0) {
            if (this.existeArchivo(nombreArchivo)) {
                try {
                    PrintWriter salida = new PrintWriter(new FileWriter(nombreArchivo, true));
                    String registro = this.registroDeString(palabra, 30) + " " + this.registroDeEntero(frecuencia, 12) + " " + this.registroDeDouble(frecuenciaNormalizada, 20);
                    salida.println(registro);
                    salida.close();
                }//Fin del try
                catch (Exception e) {
                    System.out.println("" + e);
                }//Fin del catch
            }//Fin del if
            else {
                JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del else
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "Debe ingresar un nombre de archivo", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
    }//Fin del m?todo escribirRegistroEnArchivo

    public void escribirRegistroPosting(String termino, String aliasURL, String pesoTermino, String nombreArchivo) {
        if (nombreArchivo.length() > 0 && termino.length() > 0 && (aliasURL.length() > 0 && pesoTermino.length() > 0)) {
            if (this.existeArchivo(nombreArchivo)) {
                try {
                    PrintWriter salida = new PrintWriter(new FileWriter(nombreArchivo, true));
                    String registro = this.registroDeString(termino, 30) + " " + this.registroDeString(aliasURL, 30) + " " + this.registroDeDouble(Double.parseDouble(pesoTermino), 20);
                    salida.println(registro);
                    salida.close();
                }//Fin del try
                catch (Exception e) {
                    System.out.println("" + e);
                }//Fin del catch
            }//Fin del if
            else {
                JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del else
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "Debe ingresar un nombre de archivo", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
    }//Fin del m?todo escribirRegistroEnArchivo

    public void escribirRegistroIndice(String termino, int posicionInicial, int cantidadEntradas, String nombreArchivo) {
        if (nombreArchivo.length() > 0 && termino.length() > 0 && (String.valueOf(posicionInicial).length() > 0 && String.valueOf(cantidadEntradas).length() > 0)) {
            if (this.existeArchivo(nombreArchivo)) {
                try {
                    PrintWriter salida = new PrintWriter(new FileWriter(nombreArchivo, true));
                    String registro = this.registroDeString(termino, 30) + " " + this.registroDeEntero(posicionInicial, 12) + " " + this.registroDeEntero(cantidadEntradas, 12);
                    salida.println(registro);
                    salida.close();
                }//Fin del try
                catch (Exception e) {
                    System.out.println("" + e);
                }//Fin del catch
            }//Fin del if
            else {
                JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del else
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "Debe ingresar un nombre de archivo", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
    }//Fin del m?todo escribirRegistroEnArchivo

    public void escribirRegistroPesosEnArchivo(String palabra, double peso, String nombreArchivo) {
        if (nombreArchivo.length() > 0 && palabra.length() > 0 && (String.valueOf(peso)).length() > 0) {
            if (this.existeArchivo(nombreArchivo)) {
                try {
                    PrintWriter salida = new PrintWriter(new FileWriter(nombreArchivo, true));
                    String registro = this.registroDeString(palabra, 30) + " " + this.registroDeDouble(peso, 20);
                    salida.println(registro);
                    salida.close();
                }//Fin del try
                catch (Exception e) {
                    System.out.println("" + e);
                }//Fin del catch
            }//Fin del if
            else {
                JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del else
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "Debe ingresar un nombre de archivo", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
    }//Fin del m?todo escribirRegistroEnArchivo

    /**
     **<b>EFECTUA:</b> formatea un string para que tenga una longitud de 30 caracteres
     **incluyendo espacios en blanco al final del string<br />
     **<b>REQUIERE:</b> recibir como par?metro el string que se desea formatear<br/ >
     **<b>MODIFICA:</b> el par?metro recibido<br/ >
     **@return palabra la palabra que fue formateada
     **@param palabra la palabra que se desea formatear
     **/
    public String registroDeString(String palabra, int longitudEspacio) {
        while (palabra.length() <= longitudEspacio) {
            palabra += " ";
        }//Fin del while
        return palabra;
    }//Fin del m?todo registroDeString

    /**
     **<b>EFECTUA:</b> formatea un int para que tenga una longitud de tamaniooDeString
     **caracteres incluyendo espacios en blanco al final del int convertido a String<br />
     **<b>REQUIERE:</b> recibir como par?metro el int que se desea formatear<br/ >
     **<b>MODIFICA:</b> el par?metro recibido<br/ >
     **@return respuesta el int que fue formateado
     **@param entero el entero que se desea formatear
     **@param tamanioDeString el tama?o que se desea asignar al string del entero
     **/
    public String registroDeEntero(int entero, int tamanioDeString) {
        String respuesta = String.valueOf(entero);
        while (respuesta.length() <= tamanioDeString) {
            respuesta += " ";
        }//Fin del while
        return respuesta;
    }//Fin del m?todo registroDeEntero

    /**
     **<b>EFECTUA:</b> formatea un double para que tenga una longitud de tamaniooDeString
     **caracteres incluyendo espacios en blanco al final del double convertido a String<br />
     **<b>REQUIERE:</b> recibir como par?metro el double que se desea formatear<br/ >
     **<b>MODIFICA:</b> el par?metro recibido<br/ >
     **@return respuesta el double que fue formateado
     **@param numero el double que se desea formatear
     **@param tamanioDeString el tama?o que se desea asignar al string del entero
     **/
    public String registroDeDouble(double numero, int tamanioDeString) {
        String respuesta = String.valueOf(numero);
        while (respuesta.length() <= tamanioDeString) {
            respuesta += " ";
        }//Fin del while
        return respuesta;
    }//Fin del m?todo registroDeDouble

    /**
     **<b>EFECTUA:</b> crea un archivo nuevo con la extensi?n .lowercase
     **que contiene el contenido del archivo original pero con todos sus
     **caracteres en min?scula<br/ >
     **<b>REQUIERE:</b> recibir la ruta del archivo que se quiere procesar<br/ >
     **<b>MODIFICA:</b> N/A <br/ >
     **@param nombreArchivo la ruta del archivo que se quiere procesar
     **/
    public void parsearArchivoMinusculas(String nombreArchivo) {
        String linea = "";
        if (this.existeArchivo(nombreArchivo) == true) {
            try {
                BufferedReader reader = new BufferedReader(new FileReader(nombreArchivo));
                PrintWriter salida = new PrintWriter(new FileWriter(nombreArchivo + ".lowercase"));
                linea = reader.readLine();
                while (linea != null) {
                    salida.println(linea.toLowerCase());
                    linea = reader.readLine();
                }//Fin del while
                reader.close();
                salida.close();
            }//Fin del try
            catch (Exception e) {
                JOptionPane.showMessageDialog(null, "El archivo no existe " + e, "ERROR", JOptionPane.ERROR_MESSAGE);
            }//Fin del catch
        }//Fin del if
        else {
            JOptionPane.showMessageDialog(null, "El archivo no existe", "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del else
    }//Fin del m?todo parsearArchivoMinusculas

    /**
     **<b>EFECTUA:</b> crear una arreglo de String con los nombre de archivos
     **que se encuentran el archivoURLs y les agrega la extensi?n donde se
     **encuentran f?sicamente dichos archivos<br/ >
     **<b>REQUIERE:</b> recibir la ruta donde se encuentra el archivo de URLs<br/ >
     **<b>MODIFICA:</b> N/A <br/ >
     **@return pathArchivos con las rutas de todos los archivos contenidos dentro de archivoURLs
     **@param archivoURLs el archivo que contiene el nombre de los archivos de la colecci?n
     **/
    public String[] pathArchivos(String archivoURLs) {

        String linea = "";
        String[] pathArchivos = null;
        String[] partesDeLinea;
        LinkedList<String> listaDeArchivos = new LinkedList<String>();
        try {
            BufferedReader reader = new BufferedReader(new FileReader(archivoURLs));
            linea = reader.readLine();
            while (linea != null) {
                partesDeLinea = linea.split("\t");
                listaDeArchivos.add("./Coleccion/Coleccion/" + partesDeLinea[0]);
                linea = reader.readLine();

            }//Fin del while
            reader.close();
            Object objetoPathArchivos[] = listaDeArchivos.toArray();
            pathArchivos = new String[listaDeArchivos.size()];

            for (int i = 0; i < listaDeArchivos.size(); i++) {
                pathArchivos[i] = (String) objetoPathArchivos[i];
            }//Fin del for
        }//Fin del try
        catch (Exception e) {
            JOptionPane.showMessageDialog(null, "El archivo no existe " + e, "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del catch
        return pathArchivos;
    }//Fin del m?todo rutaArchivosDirectorio

    public LinkedList<String> obtenerPalabrasArchivo(String nombreArchivo) {
        String linea = "";
        String[] pathArchivos = null;
        String[] partesDeLinea;
        LinkedList<String> palabras = new LinkedList<String>();
        try {
            BufferedReader reader = new BufferedReader(new FileReader(nombreArchivo));
            linea = reader.readLine();
            while (linea != null) {
                partesDeLinea = linea.split(" ");
                palabras.add(partesDeLinea[0]);
                linea = reader.readLine();
            }//Fin del while
            reader.close();
        }//Fin del try
        catch (Exception e) {
            JOptionPane.showMessageDialog(null, "El archivo no existe " + e, "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del catch
        return palabras;
    }//Fin del m?todo parsearArchivoMinusculas
   
    public String getUrlDeAlias(String aliasArchivo, String archivoURLs){
        String linea = "";
        String urlArchivo = "";
        String[] partesDeLinea;
        boolean continuar = true;
        
        try {
            BufferedReader reader = new BufferedReader(new FileReader(archivoURLs));
            linea = reader.readLine();
            while (linea != null && continuar) {
                partesDeLinea = linea.split("\\s+"); 
                if(partesDeLinea[0].compareToIgnoreCase(aliasArchivo) == 0){
                    urlArchivo = partesDeLinea[1];
                    continuar = false;
                }//Fin del if
                linea = reader.readLine();
            }//Fin del while
            reader.close();
        }//Fin del try
        catch (Exception e) {
            JOptionPane.showMessageDialog(null, "El archivo no existe " + e, "ERROR", JOptionPane.ERROR_MESSAGE);
        }//Fin del catch
        return urlArchivo;
    }//Fin del m?todo getUrlAlias
}//Fin de la clase ManejadorArchivos
