package codejam;

import codejam.util.AbstractSolution;
import java.math.BigDecimal;
import java.math.MathContext;

/**
 *
 * @author fwallenius
 */
public class CookieClickerAlpha extends AbstractSolution {

    private static final Double BASETICK = 2.0;
    private static final MathContext PRECISION = MathContext.DECIMAL64;

    @Override
    public void run() {
        Integer amount = Integer.parseInt(this.readLine(), 10);
        for (int i = 0; i < amount; i++) {

            String[] numbers = this.readLine().split(" ");

            BigDecimal pricePerFactory = new BigDecimal(numbers[0]);
            BigDecimal increaseByFactory = new BigDecimal(numbers[1]);
            BigDecimal goalAmount = new BigDecimal(numbers[2]);

            BigDecimal secsNeeded = this.solve(pricePerFactory, increaseByFactory, goalAmount);

            System.out.println("Case #" + (i + 1) + ": " + secsNeeded.toPlainString());
        }
    }

    private BigDecimal solve(BigDecimal pricePerFactory, BigDecimal increaseByFactory, BigDecimal goalAmount) {
        BigDecimal tickPerSecond = new BigDecimal(BASETICK);
        BigDecimal elapsedTime = new BigDecimal(0);

        while (true) {
            BigDecimal secsUntilGoal = secsUntil(goalAmount, tickPerSecond);
            BigDecimal secsUntilNextFactory = secsUntil(pricePerFactory, tickPerSecond);

            if (secsUntilGoal.compareTo(secsUntilNextFactory) <= 0) {
                // Goal is before next factory
                return elapsedTime.add(secsUntilGoal);
            } else {
                // Next factory is before goal
                // Check if buying factory will get us quicker to goal or if waiting for ticks is still better

                BigDecimal tickIfWeBuy = tickPerSecond.add(increaseByFactory);
                BigDecimal elapsedTimeIfWeBuy = elapsedTime.add(pricePerFactory.divide(tickPerSecond, PRECISION));
                BigDecimal totalTimeIfWeBuy = elapsedTimeIfWeBuy.add(goalAmount.divide(tickIfWeBuy, PRECISION));
                Boolean makesSense = totalTimeIfWeBuy.compareTo(elapsedTime.add(secsUntilGoal)) <= 0;

                if (makesSense) {
                    // Buy one
                    elapsedTime = elapsedTime.add(pricePerFactory.divide(tickPerSecond, PRECISION));
                    tickPerSecond = tickPerSecond.add(increaseByFactory);
                } else {
                    // Wait instead
                    return elapsedTime.add(secsUntilGoal);
                }
            }
        }
    }

    private BigDecimal secsUntil(BigDecimal goalAmount, BigDecimal tickPerSecond) {
        BigDecimal secsUntilGoal = goalAmount.divide(tickPerSecond, PRECISION);
        return secsUntilGoal;
    }

}
