import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.Random;
import java.util.Set;
import java.util.TreeSet;

public class CoinJamLarge {
	
	private static final PrintWriter out = new PrintWriter(System.out);
	
	private static final int J = 500;
	private static Set<Integer> primes = new TreeSet<Integer>();
	
	private static final BigInteger ZERO = BigInteger.ZERO;
	private static final BigInteger ONE = BigInteger.ONE;
	private static final BigInteger TWO = new BigInteger("2");
	private static final BigInteger THREE = new BigInteger("3");
	
	private static Random random = new Random();
	
	static {
		final boolean[] isPrime = new boolean[300_000_000];
		for (int i = 2; i < isPrime.length; i++) isPrime[i] = true;
		for (int i = 2; i < isPrime.length; i++) {
			if (!isPrime[i]) continue;
			int j = 2;
			int k = i * j;
			while (k < isPrime.length) {
				isPrime[k] = false;
				j++;
				k = i * j;
			}
		}
		for (int i = 2; i < isPrime.length; i++) {
			if (isPrime[i]) primes.add(i);
		}
	}

	public static void main(String[] args) {
		out.println("Case #1:");
		int jj = 0;
		for (long i = 0; i < 1 << 30; i++) {
			final String s = "1" + String.format("%30s", Long.toBinaryString(i)).replace(' ', '0') + "1";
			boolean isValid = true;
			for (int base = 2; base <= 10; base++) {
				if (checkPrime(s, base)) {
					isValid = false;
					break;
				}
			}
			if (!isValid) continue;
			
			final int[] dividers = new int[11];
			for (int base = 2; base <= 10; base++) {
				final int divider = findDivider(s, base);
				if (divider == -1) {
					isValid = false;
					break;
				}
				dividers[base] = divider;
			}
			if (!isValid) continue;
			
			out.print(s + " ");
			for (int base = 2; base <= 10; base++) {
				out.print(dividers[base] + " ");
			}
			out.println();
			out.flush();
			if (++jj == J) break;
		}
		out.close();
	}
	
	private static boolean checkPrime(String s, int base) {
		final BigInteger n = new BigInteger(s, base);
		for (int i : primes) {
			if (n.mod(BigInteger.valueOf(i)) == ZERO) return false;
		}
		return isProbablePrime(n, 1000);
	}
	
	private static int findDivider(String s, int base) {
		final BigInteger n = new BigInteger(s, base);
		for (int i : primes) {
			if (n.mod(BigInteger.valueOf(i)) == ZERO) return i;
		}
		return -1;
	}
	
	private static boolean isProbablePrime(BigInteger n, int k) {
		if (n.compareTo(THREE) < 0)
			return true;
		int s = 0;
		BigInteger d = n.subtract(ONE);
		while (d.mod(TWO).equals(ZERO)) {
			s++;
			d = d.divide(TWO);
		}
		for (int i = 0; i < k; i++) {
			BigInteger a = uniformRandom(TWO, n.subtract(ONE));
			BigInteger x = a.modPow(d, n);
			if (x.equals(ONE) || x.equals(n.subtract(ONE)))
				continue;
			int r = 1;
			for (; r < s; r++) {
				x = x.modPow(TWO, n);
				if (x.equals(ONE))
					return false;
				if (x.equals(n.subtract(ONE)))
					break;
			}
			if (r == s) // None of the steps made x equal n-1.
				return false;
		}
		return true;
	}

	private static BigInteger uniformRandom(BigInteger bottom, BigInteger top) {
		BigInteger res;
		do {
			res = new BigInteger(top.bitLength(), random);
		} while (res.compareTo(bottom) < 0 || res.compareTo(top) > 0);
		return res;
	}

}
