package round1;

import java.io.PrintWriter;
import java.util.PriorityQueue;
import java.util.Scanner;

public class SenateEvacuation {
	
	private static final Scanner in = new Scanner(System.in);
	private static final PrintWriter out = new PrintWriter(System.out);
	
	private static final class Party implements Comparable<Party> {
		private final char letter;
		private final int members;
		
		public Party(char letter, int members) {
			this.letter = letter;
			this.members = members;
		}

		@Override
		public int compareTo(Party o) {
			return Integer.compare(o.members, members);
		}
		
	}
	
	public static void main(String[] args) {
		final int t = in.nextInt();
		for (int tt = 1; tt <= t; tt++) {
			final int n = in.nextInt();
			int allMembersCount = 0;
			PriorityQueue<Party> parties = new PriorityQueue<>();
			for (int i = 0; i < n; i++) {
				final char letter = (char) ('A' + i);
				final int members = in.nextInt();
				allMembersCount += members;
				parties.add(new Party(letter, members));
			}
			out.print("Case #" + tt + ":");
			while (!parties.isEmpty()) {
				PriorityQueue<Party> newParties = evacuateTwoMembersOfLargestParty(parties);
				final Party largestParty = parties.peek();
				if (largestParty.members >= 2 && isStable(newParties, allMembersCount - 2)) {
					out.print(" " + largestParty.letter + "" + largestParty.letter);
					parties = newParties;
					allMembersCount -= 2;
				} else {
					newParties = evacuateOneMemberOfTwoLargestParties(parties);
					if (isStable(newParties, allMembersCount - 2)) {
						parties.poll();
						final Party secondLargestParty = parties.poll();
						out.print(" " + largestParty.letter + "" + secondLargestParty.letter);
						parties = newParties;
						allMembersCount -= 2;
					} else {
						newParties = evacuateOneMemberLargestParty(parties);
						out.print(" " + largestParty.letter);
						parties = newParties;
						allMembersCount -= 1;
					}
				}
			}
			out.println();
		}
		in.close();
		out.close();
	}
	
	private static PriorityQueue<Party> evacuateTwoMembersOfLargestParty(PriorityQueue<Party> parties) {
		final PriorityQueue<Party> newParties = new PriorityQueue<Party>(parties);
		final Party largestParty = newParties.poll();
		if (largestParty.members > 2) {
			newParties.add(new Party(largestParty.letter, largestParty.members - 2));
		}
		return newParties;
	}
	
	private static PriorityQueue<Party> evacuateOneMemberOfTwoLargestParties(PriorityQueue<Party> parties) {
		final PriorityQueue<Party> newParties = new PriorityQueue<Party>(parties);
		final Party largestParty = newParties.poll();
		final Party secondLargestParty = newParties.poll();
		if (largestParty.members > 1) {
			newParties.add(new Party(largestParty.letter, largestParty.members - 1));
		}
		if (secondLargestParty.members > 1) {
			newParties.add(new Party(secondLargestParty.letter, secondLargestParty.members - 1));
		}
		return newParties;
	}
	
	private static PriorityQueue<Party> evacuateOneMemberLargestParty(PriorityQueue<Party> parties) {
		final PriorityQueue<Party> newParties = new PriorityQueue<Party>(parties);
		final Party largestParty = newParties.poll();
		if (largestParty.members > 1) {
			newParties.add(new Party(largestParty.letter, largestParty.members - 1));
		}
		return newParties;
	}
	
	private static boolean isStable(PriorityQueue<Party> parties, int allMembersCount) {
		if (parties.isEmpty()) {
			return true;
		}
		final Party largestParty = parties.peek();
		return largestParty.members <= allMembersCount / 2;
	}

}
