/* PancakeFlipper.java
 * Version 1.0
 * Robert Piechota
 * 4/8/2017
 */
import java.util.*;
import java.io.*;
/**Reads an input file of T test cases.
 * For each string s of '+' and '-'s and corresponding number n,
 * calculate how many moves it takes to make all of them +'s.
 * A move flips the state of exactly n adjacent characters.
 * If it is impossible to reach a state of all +'s, print "IMPOSSIBLE".
 */
public class PancakeFlipper
{
    public static void setupInput() throws Exception{
        try{
            System.setIn(new FileInputStream("A-small-attempt0.in"));
        }catch(IOException e){
            e.printStackTrace();
            return;
        }
        System.out.print("\f");
        main();
    }
    public static void main(){
        Scanner in = new Scanner(new BufferedReader(new InputStreamReader(System.in)));
        int t = in.nextInt();
        for (int i=1; i<=t; i++){
            String s = in.next();
            int n = in.nextInt();
            System.out.println("Case #" + i + ": " +answer(s,n));
        }
    }
    public static String answer(String s, int n){
        int count=0;//increments every time a flip occurs
        while(s.length()!=n){
            /* The string is continuously shortened to smaller cases.
             * When its size is the flip length, the base case has been reached.
             */
            
            if(s.charAt(0)=='-'){
                count++;
                s=flip(s.substring(0,n))+s.substring(n);
                /* Only the leftmost possible flip affects the leftmost character.
                 * If that character is -, perform that flip. The first character
                 * is now guaranteed to be +.
                 */
            }
            s=s.substring(1);
            /* Now that the first character is +, it just needs to be proved that
             * the rest of the string can be turned into only +'s.
             */
            if(s.length()==n){
                break;
            }
            if(s.charAt(s.length()-1)=='-'){
                count++;
                s=s.substring(0,s.length()-n)+flip(s.substring(s.length()-n));
                /* Only the rightmost possible flip affects the rightmost character.
                 * If that character is -, perform that flip. The last character
                 * is now guaranteed to be +.
                 */
            }
            s=s.substring(0,s.length()-1);
            /* Now that the last character is +, it just needs to be proved that
             * the rest of the string can be turned into only +'s.
             */
        }
        if(s.charAt(0)=='-'){
            count++;
            s=flip(s);
        }//In case the string is all -'s, flipping will make it valid.
        for(int i=0; i<s.length(); i++){
            if(s.charAt(i)=='-'){
                return "IMPOSSIBLE";
            }
        }//If the string at its base case of length()==n isn't all +'s, it is an impossible state.
        return Integer.toString(count);
    }
    public static String flip(String s){
        String ans = "";
        for(int i=0; i<s.length(); i++){
            if(s.charAt(i)=='-'){
                ans+="+";
            }else{
                ans+="-";
            }
        }
        //returns a string with -'s and +'s swapped
        return ans;
    }
}
