package stalls;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Optional;

public class BathroomStalls {

    static final String input = "inputs/stalls/" + "C-large.in";
    static final String output = input.replaceAll(".in$", ".out");
    static BufferedWriter writer;

    public static void main(String[] args) throws FileNotFoundException, IOException {

        try (BufferedReader reader = new BufferedReader(new FileReader(input));
                BufferedWriter writer = new BufferedWriter(new FileWriter(output))) {
            BathroomStalls.writer = writer;
            reader.readLine();
            String line = null;
            int i = 1;
            while ((line = reader.readLine()) != null) {
                compute(i++, line);
            }
        }
    }

    static void compute(int _i, String _line) {

        BigInteger numberOfStalls = new BigInteger(_line.split(" ")[0]);
        BigInteger peoples = new BigInteger(_line.split(" ")[1]);

        BigInteger current = BigInteger.ZERO;
        List<LR> lrs = Arrays.asList(LR.startingWith(numberOfStalls));

        Optional<LR> solution = Optional.empty();
        while (!solution.isPresent()) {
            debug(current + ": " + lrs);
            solution = find(current, peoples, lrs);
            for (LR lr : lrs) {
                current = current.add(lr.factor);
            }
            lrs = nextOf(lrs);
        }
        log("Case #" + _i + ": " + solution.get().max() + " " + solution.get().min());

    }

    private static Optional<LR> find(BigInteger _current, BigInteger _peoples, List<LR> _lrs) {
        BigInteger soFar = _current;

        for (LR candidate : _lrs) {
            if (soFar.add(candidate.factor).compareTo(_peoples) >= 0) {
                return Optional.of(candidate);
            }
            soFar = soFar.add(candidate.factor);
        }

        return Optional.empty();
    }

    static List<LR> nextOf(List<LR> _list) {
        List<LR> nextList = new ArrayList<>();
        for (LR lr : _list) {
            LR[] next = lr.next();
            addTo(nextList, next[0]);
            addTo(nextList, next[1]);
        }
        return nextList;
    }

    static void addTo(List<LR> _nextList, LR _lr) {
        if (_nextList.contains(_lr)) {
            _nextList.stream().filter(l -> l.equals(_lr)).findAny().ifPresent(l -> l.add(_lr));
        } else {
            _nextList.add(_lr);
        }
    }

    static void log(String _msg) {
        System.out.println(_msg);
        try {
            writer.write(_msg);
            writer.write("\n");
        } catch (IOException _e) {
            _e.printStackTrace();
        }
    }

    static void debug(String _msg) {
        System.err.println(_msg);
    }

    static class LR implements Comparable<LR> {
        final BigInteger l;
        final BigInteger r;
        BigInteger factor;

        LR(BigInteger _l, BigInteger _r, BigInteger _f) {
            l = _l;
            r = _r;
            factor = _f;
        }

        public void add(LR _lr) {
            factor = factor.add(_lr.factor);
        }

        static LR startingWith(BigInteger _start) {
            return nextOf(_start, BigInteger.ONE);
        }

        BigInteger min() {
            return (l.compareTo(r) < 0) ? l : r;
        }

        BigInteger max() {
            return (l.compareTo(r) > 0) ? l : r;
        }

        LR[] next() {
            return new LR[] { nextOf(l, factor), nextOf(r, factor) };
        }

        static LR nextOf(BigInteger _n, BigInteger _f) {
            BigInteger[] divideAndRemainder = _n.divideAndRemainder(BigInteger.valueOf(2));
            BigInteger divisor = divideAndRemainder[0];
            BigInteger remainder = divideAndRemainder[1];
            if (remainder.equals(BigInteger.ZERO)) {
                return new LR(divisor, divisor.subtract(BigInteger.ONE), _f);
            } else {
                return new LR(divisor, divisor, _f);
            }
        }

        @Override
        public int compareTo(LR _o) {
            return _o.max().compareTo(max());
        }

        @Override
        public boolean equals(Object _obj) {
            LR other = (LR) _obj;
            return min().equals(other.min()) && max().equals(other.max());
        }

        @Override
        public String toString() {
            return factor + "*(" + max() + "," + min() + ")";
        }

    }

}
