package jam.coin;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;
import java.math.BigInteger;
import java.time.Duration;
import java.time.Instant;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;
import java.util.Set;
import java.util.concurrent.ConcurrentSkipListSet;
import java.util.concurrent.TimeoutException;
import java.util.stream.Collectors;

public class JamCoins {

    public static void main(String[] args) throws FileNotFoundException, IOException {

        disableDebug();

        int n = 32;
        int j = 500;

        Set<JamCoinCandidate> found = new ConcurrentSkipListSet<JamCoins.JamCoinCandidate>();

        System.out.println("Case #1:");

        new Thread(() -> doFind(n, j, found)).start();
        new Thread(() -> doFind(n, j, found)).start();
        new Thread(() -> doFind(n, j, found)).start();

        doFind(n, j, found);
    }

    private static void doFind(int n, int j, Set<JamCoinCandidate> found) {
        while (found.size() < j) {
            JamCoinCandidate candidate = JamCoinCandidate.random(n);
            System.err.println("checking " + candidate);
            if (candidate.isJamCoin) {
                System.err.println("found " + candidate);
                if (!found.contains(candidate)) {
                    System.out.println(candidate);
                    found.add(candidate);
                }
            }
        }
    }

    static class JamCoinCandidate implements Comparable<JamCoinCandidate> {
        private static final Duration TIMEOUT = Duration.ofSeconds(2);
        private static final Random RND = new Random();
        final String presentation;
        final boolean isJamCoin;
        final List<BigInteger> nonTrivialDivisors = new ArrayList<>();

        JamCoinCandidate(String _presentation) {
            presentation = _presentation;

            if (!presentation.startsWith("1") || !presentation.endsWith("1")) {
                isJamCoin = false;
            } else {
                for (int radix = 2; radix <= 10; radix++) {
                    Number number = new Number(new BigInteger(presentation, radix));
                    if (!number.isDefinetlyComposite()) {
                        isJamCoin = false;
                        return;
                    }
                    try {
                        nonTrivialDivisors.add(number.nonTrivialDivisor(TIMEOUT));
                    } catch (TimeoutException e) {
                        isJamCoin = false;
                        return;
                    }
                }
                isJamCoin = true;
            }
        }

        static JamCoinCandidate random(int _size) {
            String randomNumber = new BigInteger(_size - 2, RND).toString(2);
            while (randomNumber.length() < _size - 2) {
                randomNumber = "0" + randomNumber;
            }
            return new JamCoinCandidate("1" + randomNumber + "1");
        }

        @Override
        public String toString() {
            if (!isJamCoin) {
                return presentation + " (no jamcoin)";
            }
            return presentation + " "
                    + nonTrivialDivisors.stream().map(d -> d.toString()).collect(Collectors.joining(" "));
        }

        @Override
        public int compareTo(JamCoinCandidate _o) {
            return presentation.compareTo(_o.presentation);
        }

        @Override
        public int hashCode() {
            return presentation.hashCode();
        }

        @Override
        public boolean equals(Object obj) {
            if (obj == null || !(obj instanceof JamCoinCandidate)) {
                return false;
            }

            return presentation.equals(((JamCoinCandidate) obj).presentation);
        }
    }

    static class Number {
        final BigInteger number;

        public Number(BigInteger _number) {
            number = _number;
        }

        boolean isDefinetlyComposite() {
            return !number.isProbablePrime(1);
        }

        BigInteger nonTrivialDivisor(Duration _timeout) throws TimeoutException {
            System.err.println("searching for divisor of " + number);
            Instant start = Instant.now();
            for (BigInteger n = new BigInteger("2"); n.compareTo(number) < 0; n = n.add(BigInteger.ONE)) {
                if (number.mod(n).equals(BigInteger.ZERO)) {
                    return n;
                }
                if (Instant.now().isAfter(start.plus(_timeout))) {
                    throw new TimeoutException();
                }
            }

            return BigInteger.ZERO;
        }
    }

    private static void disableDebug() {
        System.setErr(new PrintStream(new OutputStream() {
            @Override
            public void write(int _b) throws IOException {
            }
        }));
    }
}
