package getting.the.digits;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

public class GettingTheDigits {

    static final List<NumberDetection> detections = new ArrayList<GettingTheDigits.NumberDetection>();

    static {
        detections.add(new NumberDetection("ZERO", 'Z', 0));
        detections.add(new NumberDetection("TWO", 'W', 2));
        detections.add(new NumberDetection("SIX", 'X', 6));
        detections.add(new NumberDetection("EIGHT", 'G', 8));
        detections.add(new NumberDetection("FOUR", 'U', 4));
        detections.add(new NumberDetection("THREE", 'T', 3));
        detections.add(new NumberDetection("ONE", 'O', 1));
        detections.add(new NumberDetection("FIVE", 'F', 5));
        detections.add(new NumberDetection("SEVEN", 'V', 7));
        detections.add(new NumberDetection("NINE", 'N', 9));
    }

    public static void main(String[] _args) throws FileNotFoundException, IOException {

        try (BufferedReader reader = new BufferedReader(new FileReader("inputs/gettingdigits/A-large.in"))) {
            skipOneLine(reader);
            String line = null;
            int i = 1;
            while ((line = reader.readLine()) != null) {
                compute(i, line);
                i++;
            }
        }

    }

    private static void compute(int _testCase, String _line) {

        List<Character> remaining = _line.chars().sorted().mapToObj(i -> (char) i).collect(Collectors.toList());

        List<Integer> phoneNumber = new ArrayList<Integer>();

        for (NumberDetection detection : detections) {
            while (remaining.contains(detection.detect)) {
                remove(detection.numberString, remaining);
                phoneNumber.add(detection.number);
            }
        }

        System.out.format("Case #%s: ", _testCase);
        phoneNumber.stream().sorted().forEach(System.out::print);

        if (!remaining.isEmpty()) {
            System.out.println("NOPE!" + remaining);
        } else {
            System.out.println();
        }

    }

    private static void remove(String _string, List<Character> _remaining) {
        _string.chars().mapToObj(c -> (char) c).forEach(c -> _remaining.remove(c));
    }

    private static void skipOneLine(BufferedReader _reader) throws IOException {
        _reader.readLine();
    }

    private static class NumberDetection {
        final String numberString;
        final Character detect;
        final Integer number;

        public NumberDetection(String _numberString, Character _detect, Integer _number) {
            numberString = _numberString;
            detect = _detect;
            number = _number;
        }

    }

}
