// package QR2017;

/**
 * Project: google-code-jam
 * Author:  Brian Dang
 * Date:    4/7/2017
 */

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;

/**
 * Problem:
 *      - Tatiana likes to keep things tidy.
 *      - Her toys are sorted from smallest to largest.
 *      - Her pencils are sorted from shortest to longest.
 *      - Her computers are sorted from oldest to newest.
 *
 *      - One day when practicing her counting skills, she noticed that some integers, when written in base 10 with
 *      no leading zeros, have their digits sorted in non-decreasing order.
 *      - Some examples of this are: 8, 123, 555, 224488.
 *      - She decided to call these numbers "tidy".
 *      - Numbers that don't have this property are like: 20, 321, 495, 999990 - are not tidy.
 *
 *      - She just finished counting *all* positive integers in ascending order from 1 to N.
 *      - What was the last "tidy" number she counted?
 *
 * Input:
 *      - The first line of the input gives the number of test cases, T.
 *      - T lines follow.
 *      - Each line describes a test case with a single integer N, the last number counted by Tatiana.
 *
 *  Output:
 *      - For each test case, output one line containing Case #x: y, where x is the test case number (starting from
 *      1) and y is the last tidy number counted by Tatiana.
 *
 *  Limits:
 *      1 <= T <= 100
 *
 *  Small data set:
 *      1 <= N <= 1000
 *
 *  Large data set:
 *      1 <= N <= 10^18
 *      10^18 = 1 000 000 000 000 000 000
 *
 *  Solution:
 *      - API to see if a number has increasing digits
 *      - Convert number to String
 *      - Use a 'long' data type to handle up to 10^18
 */
public class TidyNumbers {

    /**
     * Outputs a file with a list of last tidy numbers.
     * @param filePath Input file with test cases (list of last counting numbers).
     */
    public void input(String filePath) {
        try {
            PrintWriter pw = new PrintWriter(new File("solution-" + filePath));
            File input = new File(filePath);
            Scanner scan = new Scanner(input);

            int testCases = Integer.valueOf(scan.nextLine());
            for(int i=1; i <= testCases; i++) {
                int lastCountingNumber = scan.nextInt();
                long lastTidyNumber = getLastTidyNumber(lastCountingNumber);
                System.out.println("Last Counting Number '" + lastCountingNumber + "' => " + lastTidyNumber);
                pw.write("Case #" + i + ": " + lastTidyNumber + "\n");
            }

            scan.close();
            pw.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    /**
     * Given the last number to count, determine the last tidy number.
     * @param lastNumber the last counting number
     * @return the last tidy number
     */
    public long getLastTidyNumber(long lastNumber) {
        if(lastNumber < 1)
            throw new IllegalArgumentException("lastNumber must be greater or equal to 1!");

        long lastTidyNum = 1;
        for(long i=1; i <= lastNumber; i++) {
            boolean isTidyNum = isTidyNumber(i);
            if(isTidyNum)
                lastTidyNum = i;
        }

        return lastTidyNum;
    }

    /**
     * Given a number (long), determine if it is a tidy number. A tidy number should have non-decreasing digits.
     * @param num the number to test
     * @return true if it is a tidy number. otherwise, false.
     */
    public boolean isTidyNumber(long num) {
        if(num < 1)
            throw new IllegalArgumentException("Number cannot be less than 0!");

        String numString = String.valueOf(num);
        int numDigits = numString.length();
        byte prevDigit = Byte.valueOf(String.valueOf(numString.charAt(0)));
        for(int i=0; i < numDigits; i++) {
            char c = numString.charAt(i);
            byte currDigit = Byte.valueOf(String.valueOf(c));
            if(currDigit >= prevDigit) {
                prevDigit = currDigit;
            } else {
                return false;
            }
        }

        return true;
    }
}
