package ROUND1B2017;

import org.junit.Test;
import static org.junit.Assert.*;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.*;

/**
 * Project: google-code-jam
 * Author:  Brian Dang
 * Date:    4/22/2017
 */

/**
 * Problem:
 *      - Annie is a bus driver w/ high stress job. She tried to unwind by going on a cruise but that was stressful.
 *      She's going to try horse back riding. Annie is riding a horse to the east along a long,
 *      narrow one-way road that runs west to east. She is at kilometer 0 of the road and her destination is kilometer D.
 *
 *      - There are N other horses traveling east on the same road; all of them will go on traveling forever and all
 *      of them are currently between Annie's horse and her destination.
 *      - The ith of these horses is initially at kilometer Ki and is traveling at max speed Si kilometers per hour
 *
 *      - Horses are polite and a horse H1 will not pass another horse H2 that started off ahead of H1.
 *      - Two or more horses can share the same position for any amount of time; you may consider the horses to be
 *      single points.
 *      - Horses (other than Annie's) travel at max speeds except whenever a horse H1 catches up to another slower horse
 *      H2, H1 reduces its speed to match speed H2.
 *
 *      - Annie's horse does not have a max speed and can travel at any speed that Annie chooses, as long as it
 *      does not pass another horse.
 *      - To ensure a smooth ride for her and her horse, Annie wants to choose a single constant "cruise control"
 *      speed for her horse for the ENTIRE trip from current position to destination such that her horse will not PASS
 *      any other horses.
 *
 *      - What is the max such speed that Annie can choose?
 *
 *  Input:
 *      - The first line of the input gives the number of test cases, T.
 *      - T lines follow.
 *      - Each test case begins with integers D and N: the destination position of all the horses (in kilometers)
 *      and the number of other horses on the road.
 *      - Then N lines follow.
 *      - The ith of those lines has two integers: Ki and Si: the initial position (in kilometers) and max
 *      speed (in kilometers per hour) of the ith of the other horses on the road.
 *
 *  Output:
 *      - For each test case, output one line containing Case #x: y
 *      - x is the test case number.
 *      - y is the max constant speed (kph) that Annie can use without colliding with other horses.
 *      - y will be considered correct if it is within an abssolute or relative error of 10^-6 of the correct answer.
 *
 *  Limits:
 *      1 <= T <= 100
 *      0 < K < D < 10^9
 *      Ki != Mj for all i != j (no 2 horses start at same position)
 *      1 <= Si <= 10000
 *
 *  Small Data Set:
 *      1 <= N <= 2
 *
 *  Large Data Set:
 *      1 <= N <= 1000
 *
 *  Solution:
 *      - Need to calculate time for each horse to get to Destination
 *      - Annie's travel time can't be less than anyone else
 *      - For a given Horse, the time it takes for it to reach Destination can't be less than a Horse in front of it.
 *      - Given a distance, calculate how long it takes
 *      - Need to sort the horses in order from left to right
 */
public class CruiseControl {
    public static class Horse implements Comparable<Horse>{
        private int startingPosition;
        private int maxKPH;

        public Horse(int startingPosition, int maxKPH) {
            this.startingPosition = startingPosition;
            this.maxKPH = maxKPH;
        }

        public int getStartingPosition() {
            return startingPosition;
        }

        public int getMaxKPH() {
            return maxKPH;
        }

        public int compareTo(Horse o) {
            if(getStartingPosition() < o.getStartingPosition())
                return 1;
            if(getStartingPosition() == o.getStartingPosition())
                return 0;
            return -1;
        }

        @Override
        public String toString() {
            return "Horse{" +
                    "startingPosition=" + startingPosition +
                    ", maxKPH=" + maxKPH +
                    '}';
        }
    }

    private double getTravelTimeInHours(double startingPosition, double destination, double speed) {
        double distance = destination - startingPosition;
        double hours = distance / speed;
        return hours;
    }

    private double getMaxSpeed(double distance, double hours) {
        System.out.println("getMaxSpeed(" + distance + ", " + hours + ")");
        double result = distance / hours;
        System.out.println("Result: " + result);
        return result;
    }

    public double getAnnieMaxConstantSpeed(int destination, List<Horse> horses) {
        System.out.println("Destination: " + destination + ", Horses: " + horses);

        // Sort the horses in order from RIGHT to LEFT
        Collections.sort(horses);
        int size = horses.size();
        Horse prevHorse = horses.get(0);

        double prevHorseHours = getTravelTimeInHours(prevHorse.getStartingPosition(), destination, prevHorse.getMaxKPH());
        double prevHorseSpeed = prevHorse.getMaxKPH();

        for(int h=1; h < size; h++) {
            Horse myHorse = horses.get(h);
            double myHours = getTravelTimeInHours(myHorse.getStartingPosition(), destination, myHorse.getMaxKPH());
            double mySpeed = myHorse.getMaxKPH();

            if(myHours < prevHorseHours) {
                System.out.println("Rear Horse can potentially pass Front Horse");
                System.out.println("\tRear Horse Hours [" + myHours + "] , Front Horse Hours [" + prevHorseHours + "]");
                System.out.println("\tRear Horse Speed [" + mySpeed + "] , Front Horse Speed [" + prevHorseSpeed + "]");

                myHours = prevHorseHours;
                double distance = destination - myHorse.getStartingPosition();
                mySpeed = getMaxSpeed(distance, myHours);

                System.out.println("\tUpdated Rear Horse Hours [" + myHours + "] and Speed [" + mySpeed + "]");
            }

            // Update
            prevHorse = myHorse;
            prevHorseHours = myHours;
            prevHorseSpeed = mySpeed;
        }

        // Calculate Annie's Max Constant Speed
        double anniesMaxConstantSpeed = getMaxSpeed(destination, prevHorseHours);
        return anniesMaxConstantSpeed;
    }

    /**
     * Parses the input of test cases and generates an output file with solutions to each test case.
     * @param filePath the file path to the input file
     */
    public void runTestCases(String filePath) {
        try {
            PrintWriter pw = new PrintWriter(new File("solution-" + filePath));
            File input = new File(filePath);
            Scanner scan = new Scanner(input);

            int testCases = Integer.valueOf(scan.nextLine());
            for(int i=1; i <= testCases; i++) {
                int totalDistance = scan.nextInt();
                int numHorses = scan.nextInt();
                System.out.println(totalDistance + " " + numHorses);
                List<Horse> horses = new ArrayList<Horse>();
                for(int h=0; h < numHorses; h++) {
                    int startingPos = scan.nextInt();
                    int maxKPH = scan.nextInt();
                    System.out.println(startingPos + " " + maxKPH);

                    Horse horse = new Horse(startingPos, maxKPH);
                    horses.add(horse);
                }

                double annieMaxConstantSpeed = getAnnieMaxConstantSpeed(totalDistance, horses);
                System.out.println("annie max constant speed: " + annieMaxConstantSpeed);
                pw.write("Case #" + i + ": " + String.valueOf(annieMaxConstantSpeed) + "\n");
            }

            scan.close();
            pw.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    @Test
    public void testHorseSort() {
        List<Horse> horses = new ArrayList<Horse>();
        horses.add(new Horse(5, 10));
        horses.add(new Horse(3, 10));
        horses.add(new Horse(7, 10));
        horses.add(new Horse(4, 10));

        System.out.println(horses);
        Collections.sort(horses);
        System.out.println(horses);
    }

    @Test
    public void test() {
        CruiseControl f = new CruiseControl();

        Horse h = new Horse(2400, 5);
        assertEquals(101, f.getAnnieMaxConstantSpeed(2525, Arrays.asList(h)), Math.pow(10, -6));
    }

    @Test
    public void input() {
        CruiseControl f = new CruiseControl();
//        f.runTestCases("1sample.in");
//        f.runTestCases("1-small.in");
        f.runTestCases("1-large.in");
    }
}
