package ROUND1C2017;

import org.junit.Test;

import java.io.*;
import java.util.*;

/**
 * Project: google-code-jam
 * Author:  Brian Dang
 * Date:    4/30/2017
 */

/**
 * Problem:
 *      - Stack of K pancakes
 *      - Chef has N pancakes available where N >= K
 *      - Each pancake is a cylinder and different pancakes may have different radii and heights
 *
 *      - You must choose K out of N available pancakes, discard the others, and arrange those K pancakes in a stack on
 *      a plate.
 *          1) Take the pancake w/ largest radius and lay it down on the plate on one of its circular faces
 *          (if multiple pancakes have same radius, you can use any of them)
 *          2) Take remaining pancake w/ the next largest radius and lay it on top of that pancake, and so on until
 *          all K pancakes are in the stack and the centers of the circular faces are aligned in a line perpendicular
 *          to the plate
 *
 *      - Your diners love syrup
 *      - It's best to maximize the total amount of exposed pancake surface area in the stack since more
 *      exposed pancake surface area means more places to pour syrup
 *      - Any part of a pancake that isn't touching part of another pancake OR the plate is considered to be exposed
 *
 *      - If you choose K pancakes optimally, what's the largest total exposed pancake surface area you can achieve?
 *
 *
 *  Input:
 *      - The first line of the input gives the number of test cases, T.
 *      - T lines follow.
 *      - Each has 2 integers N and K
 *      - Then N lines follow
 *          Each has 2 integers Ri and Hi
 *
 *  Output:
 *      - For each test case, output one line containing Case #x: y
 *      - x is the test case number.
 *      - y is max total exposed pancake surface area in millimeters
 *      - y is correct if relative error of 10^-6
 *
 *  Limits:
 *
 *
 *  Small Data Set:
 *
 *
 *  Large Data Set:
 *
 *
 *  Solution:
 *      -
 */
public class AmpleSyrup {
    public class NormalPancakeComparator implements Comparator<Pancake> {
        public int compare(Pancake o1, Pancake o2) {
            if(o1.getRadius() > o2.getRadius()) {
                return -1;
            } else if(o1.getRadius() < o2.getRadius()) {
                return 1;
            }

            if(o1.getHeight() > o2.getHeight()) {
                return -1;
            } else if(o1.getHeight() < o2.getHeight()) {
                return 1;
            }

            return 0;
        }
    }

    public static class Pancake implements Comparable<Pancake> {
        private double radius;
        private double height;

        public Pancake(double radius, double height) {
            this.radius = radius;
            this.height = height;
        }

        public double getRadius() {
            return radius;
        }

        public double getHeight() {
            return height;
        }

        public double getTotalSurfaceArea() {
            // Don't calculate bottom part of pancake
            double result = 2 * Math.PI * radius * height + Math.PI * radius * radius;
            return result;
        }

        public double getBottomArea() {
            double result = Math.PI * radius * radius;
            return result;
        }

//        // sort by radius then height
//        public int compareTo(Pancake o) {
//            if(this.getRadius() > o.getRadius()) {
//                return -1;
//            } else if(this.getRadius() < o.getRadius()) {
//                return 1;
//            }
//
//            if(this.getHeight() > o.getHeight()) {
//                return -1;
//            } else if(this.getHeight() < o.getHeight()) {
//                return 1;
//            }
//
//            return 0;
//        }

        // sort by surface area then radius
        public int compareTo(Pancake o) {
            double mySurfaceArea = getTotalSurfaceArea();
            double otherSurfaceArea = o.getTotalSurfaceArea();

            if(mySurfaceArea > otherSurfaceArea) {
                return -1;
            } else if (mySurfaceArea < otherSurfaceArea){
                return 1;
            }

            if(this.getRadius() > o.getRadius()) {
                return -1;
            } else if(this.getRadius() < o.getRadius()) {
                return 1;
            }

            if(this.getHeight() > o.getHeight()) {
                return -1;
            } else if(this.getHeight() < o.getHeight()) {
                return 1;
            }

            return 0;
        }

        @Override
        public String toString() {
            return "Pancake{" +
                    "radius=" + radius +
                    ", height=" + height +
                    ", totalSurfaceArea=" + getTotalSurfaceArea() +
                    '}';
        }
    }

    private double getTotalExposedSurfaceArea(List<Pancake> kPancakes) {

        double totalArea = kPancakes.get(0).getTotalSurfaceArea();
        int numPancakes = kPancakes.size();
        for(int i=1; i < numPancakes; i++) {
            Pancake myPancake = kPancakes.get(i);
            totalArea = totalArea - myPancake.getBottomArea();
            totalArea = totalArea + myPancake.getTotalSurfaceArea();
        }

        return totalArea;
    }

    private Set<List<Pancake>> getAllCombinations(List<Pancake> pancakes) {
        Set<List<Pancake>> combinations = new HashSet<List<Pancake>>();
        combinations.add(new ArrayList<Pancake>());
        int numPancakes = pancakes.size();
        for(int i=0; i < numPancakes; i++) {
            Pancake myPancake = pancakes.get(i);

            List<List<Pancake>> toAddToCombination = new ArrayList<List<Pancake>>();
            for(List<Pancake> myList : combinations) {
                List<Pancake> newList = new ArrayList<Pancake>();
                newList.add(myPancake);
                for (Pancake p : myList) {
                    newList.add(p);
                }
                toAddToCombination.add(newList);
            }

            combinations.addAll(toAddToCombination);
        }

        return combinations;
    }

    private double getLargestTotalExposedPancakeSurfaceArea(List<Pancake> pancakes, int k) {
        System.out.println("Pancakes: " + pancakes + ", K: " + k);

        // Sort pancakes by surface area?
        Collections.sort(pancakes);
        System.out.println("Sorted Pancakes: " + pancakes);

        // Get top K pancakes
        List<Pancake> topK = new ArrayList<Pancake>();
//        for(int i=0; i < k; i++) {
//            topK.add(pancakes.get(i));
//        }
//        int count = 0;
//        int numPancakes = pancakes.size();
//        for(int i=0; i < numPancakes; i++) {
//            Pancake prev = pancakes.get(i);
//            topK.add(prev);
//            count++;
//            if(count == k)
//                break;
//
//            for(int j=i+1; j < numPancakes; j++) {
//                Pancake p2 = pancakes.get(j);
//                if(p2.getRadius() <= prev.getRadius()) {
//                    topK.add(p2);
//                    count++;
//                    prev = p2;
//                }
//
//                if(count == k)
//                    break;
//            }
//
//            if(count == k)
//                break;
//
//            topK.clear();
//            count = 0;
//        }
//
//        System.out.println("Top K: " + topK);
//        if(count != k) {
//            Collections.sort(pancakes, new NormalPancakeComparator());
//            for(int i=0; i < k; i++) {
//                topK.add(pancakes.get(i));
//            }
//            System.out.println("Top K: " + topK);
//        }

        // Create combinations
        Set<List<Pancake>> combinations = getAllCombinations(pancakes);

        // Only use combinations with length K
        List<List<Pancake>> combosLengthK = new ArrayList<List<Pancake>>();
        for(List<Pancake> myList : combinations) {
            if(myList.size() == k)
                combosLengthK.add(myList);
        }

        // Get the max exposed surface area of these combinations
        double maxTotalSurfaceArea = 0.0;
        List<Pancake> bestStack = null;
        for(List<Pancake> myList : combosLengthK) {
            // Sort
            Collections.sort(myList, new NormalPancakeComparator());

            // Calculate
            double getTotalSA = getTotalExposedSurfaceArea(myList);
            if(getTotalSA > maxTotalSurfaceArea) {
                maxTotalSurfaceArea = getTotalSA;
                bestStack = myList;
                System.out.println("### BEST STACK : " + bestStack);
            }
        }

        // Calculate the total exposed surface area
        return maxTotalSurfaceArea;
    }

    /**
     * Parses the input of test cases and generates an output file with solutions to each test case.
     * @param filePath the file path to the input file
     */
    public void runTestCases(String filePath) {
        try {
            PrintWriter pw = new PrintWriter(new File("solution-" + filePath));
            File input = new File(filePath);
            Scanner scan = new Scanner(input);

            int testCases = Integer.valueOf(scan.nextLine());
            for(int i=1; i <= testCases; i++) {
                int N = scan.nextInt();
                int K = scan.nextInt();

                List<Pancake> pancakes = new ArrayList<Pancake>();
                for(int j=1; j <= N; j++) {
                    int radius = scan.nextInt();
                    int height = scan.nextInt();
                    Pancake p = new Pancake(radius, height);
                    pancakes.add(p);
                }

                double totalArea = getLargestTotalExposedPancakeSurfaceArea(pancakes, K);
                System.out.println("Total Area: " + totalArea);
                pw.write("Case #" + i + ": " +  totalArea + "\n");
            }

            scan.close();
            pw.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

//    public List<Integer> processSet(List<Integer> orig, int k) {
//        List<Integer> allSets = new ArrayList<Integer>();
//
//        for(int i=0 ; i < orig.size(); i++) {
//            List<Integer> desiredSet = new ArrayList<Integer>();
//            desiredSet.add(orig.get(i));
//
//        }
//
//        return allSets;
//    }
//
//    public List<Integer> processSet2(List<Integer>)

    @Test
    public void test() {
        Pancake p1 = new Pancake(1, 100);
        Pancake p2 = new Pancake(2, 200);
        Pancake p3 = new Pancake(3, 300);
        Pancake p4 = new Pancake(4, 400);
        Pancake p5 = new Pancake(5, 500);
        List<Pancake> pancakes = new ArrayList<Pancake>();
        pancakes.add(p1);
        pancakes.add(p2);
        pancakes.add(p3);
        pancakes.add(p4);
        pancakes.add(p5);

        System.out.println("Pancakes: " + pancakes);
        Set<List<Pancake>> allCombinations = getAllCombinations(pancakes);
        for(List<Pancake> myList : allCombinations) {
            String combo = "";
            for(Pancake p : myList) {
                combo = combo + p.getRadius() + ", ";
            }
            System.out.println("Combo: " + combo);
        }

    }

    @Test
    public void input() {
        AmpleSyrup app = new AmpleSyrup();
        app.runTestCases("1-sample.in");
        app.runTestCases("1-small.in");
//        app.runTestCases("1-large.in");
    }
}