import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.*;

public class ProblemC {

    public static BufferedReader br = new BufferedReader(new InputStreamReader(System.in));

    class Node{
        ArrayList<Edge> adj;
        Horse h;
        Horse horses[];
        double arrivalTime[];
        Node(Horse h, int N){
            arrivalTime = new double[N];
            for(int i = 0; i<N; i++){
                arrivalTime[i] = Double.MAX_VALUE;
            }
            adj = new ArrayList();
            horses = new Horse[N];
            this.h = h;
        }
    }

    class Horse{
        int index;
        double E;
        double S;
        Horse(int i, int E, int S){
            this.index = i;
            this.E = E;
            this.S = S;
        }
        Horse(Horse h){
            this.index = h.index;
            this.E = h.E;
            this.S = h.S;
        }
    }

    class Edge{
        int target;
        double weight;
        Edge(int t, int w){
            this.target = t;
            this.weight = w;
        }
    }

    class Pair{
        int start;
        int end;
        Pair(int s, int e){
            this.start = s;
            this.end = e;
        }
    }

    class Search{
        int index;
        double time;
        Search(int i, double t){
            this.index = i;
            this.time = t;
        }
    }

    Node V[];
    Pair pairs[];

    public void run(int caseNum) throws IOException{
        String output = "Case #" + caseNum + ": ";
        readInput();
        for(Pair p: pairs){
            resetGraph();
            output += search(p.start, p.end)+" ";
        }
        output.trim();
        System.out.println(output);

    }

    public void readInput() throws IOException{
        String input[] = br.readLine().split("\\s+");
        int N = pint(input[0]);
        V = new Node[N];
        int Q = pint(input[1]);
        pairs = new Pair[Q];
        for(int i = 0; i<N; i++){
            input = br.readLine().split("\\s+");
            int e = pint(input[0]);
            int s = pint(input[1]);
            Horse h = new Horse(i, e, s);
            V[i] = new Node(h, N);
        }
        for(int i = 0; i<N; i++){
            input = br.readLine().split("\\s+");
            for(int j = 0; j<N; j++){
                int dist = pint(input[j]);
                if(dist == -1)continue;
                V[i].adj.add(new Edge(j, dist));
            }
        }
        for(int i = 0; i<Q; i++){
            input = br.readLine().split("\\s+");
            int s = pint(input[0]) - 1;
            int e = pint(input[1]) - 1;
            pairs[i] = new Pair(s, e);
        }
    }

    public void resetGraph(){
        for(int i = 0; i<V.length; i++){
            V[i].horses = new Horse[V.length];
            for(int j = 0; j<V.length; j++){
                V[i].arrivalTime[j] = Double.MAX_VALUE;
            }
        }
    }

    public double search(int source, int end){
        ArrayList<Search> nodes = new ArrayList<>();
        nodes.add(new Search(source, 0));
        while(!nodes.isEmpty()){
            Search s = nodes.get(0);
            nodes.remove(0);
            int curr = s.index;
            double time = s.time;

            for(Edge e: V[curr].adj){
                //node's own horse
                if(e.weight <= V[curr].h.E) {
                    double newTime = time + (e.weight / V[curr].h.S);
                    if(V[e.target].arrivalTime[curr] > newTime) {
                        V[e.target].arrivalTime[curr] = newTime;
                        Horse h = new Horse(V[curr].h);
                        h.E -= e.weight;
                        V[e.target].horses[curr] = h;
                        nodes.add(new Search(e.target, newTime));
                    }
                }
                //all arrived horses
                for(Horse parent : V[curr].horses) {
                    if(parent == null) continue;
                    if (time < V[curr].arrivalTime[parent.index]) continue;
                    if (e.weight > parent.E) continue;

                    double newTime = time + (e.weight / parent.S);
                    if(V[e.target].arrivalTime[parent.index] > newTime) {
                        V[e.target].arrivalTime[parent.index] = newTime;
                        Horse h = new Horse(parent);
                        h.E -= e.weight;
                        V[e.target].horses[parent.index] = h;
                        nodes.add(new Search(e.target, newTime));
                    }
                }

            }
        }
        double bestTime = Double.MAX_VALUE;
        for(int i = 0; i<V.length; i++){
            bestTime = Math.min(bestTime, V[end].arrivalTime[i]);
        }
        return bestTime;
    }


    public static void main(String[] args) throws IOException{
        int testcases = pint(br.readLine());
        for(int i = 0; i<testcases; i++){
            new ProblemC().run(i+1);
        }
    }

    public static int pint(String input){
        return Integer.parseInt(input);
    }

    public static long plong(String input){
        return Long.parseLong(input);
    }

    public static double pdouble(String input){
        return Double.parseDouble(input);
    }

}
