package org.bds.contest;

import org.junit.Test;
import org.bds.contest.common.IOReader;
import org.bds.contest.common.ResultChecker;
import org.bds.contest.common.ResultWriter;

import java.io.InputStream;
import java.io.ByteArrayInputStream;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.List;
import java.util.ArrayList;
import java.util.Set;
import java.util.HashSet;

/**
 * Created by IntelliJ IDEA.
 * User: bds
 * Date: Sep 3, 2009
 * Time: 5:00:26 PM
 */
public class AlienLanguageTest {
    @Test
    public void testFistExample() throws Exception {
        String input = "3 5 4\n" +
                "abc\n" +
                "bca\n" +
                "dac\n" +
                "dbc\n" +
                "cba\n" +
                "(ab)(bc)(ca)\n" +
                "abc\n" +
                "(abc)(abc)(abc)\n" +
                "(zyx)bc\n";
        String expected = "Case #1: 2\n" +
                "Case #2: 1\n" +
                "Case #3: 3\n" +
                "Case #4: 0\n";

        InputStream is = new ByteArrayInputStream(input.getBytes());
        IOReader reader = new IOReader();
        reader.setReader(new BufferedReader(new InputStreamReader(is)));
        ResultChecker checker = new ResultChecker(new ByteArrayInputStream(expected.getBytes()));
        List<Integer> paramList = reader.nextLineAsIntList();
        reader.setNumCases(paramList.get(2));

        int L = paramList.get(0);
        int D = paramList.get(1);

        List<String> dict = new ArrayList<String>();
        for (int i = 0; i < D; i++) {
            dict.add(i, reader.nextLineAsString());
        }

        int numCase = reader.getNumCases();
        for (int i = 0; i < numCase; i++) {
            AlienLanguage alienLanguage = new AlienLanguage(dict, createPattern(L, reader.nextLineAsString()));
            alienLanguage.setResultWriter(checker);
            alienLanguage.setResultHeader("Case #" + (i + 1) + ": ");
            alienLanguage.process();
        }

        checker.verify();
    }

    @Test
    public void testSmall() throws Exception {
        doTest("/alienlanguage/alien-input.txt", "/alienlanguage/alien-expected.txt");
    }

    @Test
    public void testWriteSmall() throws Exception {
        doWrite("/alienlanguage/A-small-attempt0.in", "A-small.out");
    }
    @Test
    public void testWriteLarge() throws Exception {
        doWrite("/alienlanguage/A-large.in", "A-large.out");
    }


    public void doTest(String inputFileName, String expectedFileName) throws Exception {
        InputStream is = getClass().getResourceAsStream(inputFileName);
        InputStream expectedOutput = getClass().getResourceAsStream(expectedFileName);

        IOReader reader = new IOReader();
        reader.setReader(new BufferedReader(new InputStreamReader(is)));
        ResultChecker checker = new ResultChecker(expectedOutput);
        List<Integer> paramList = reader.nextLineAsIntList();
        reader.setNumCases(paramList.get(2));

        int L = paramList.get(0);
        int D = paramList.get(1);

        List<String> dict = new ArrayList<String>();
        for (int i = 0; i < D; i++) {
            dict.add(i, reader.nextLineAsString());
        }

        int numCase = reader.getNumCases();
        for (int i = 0; i < numCase; i++) {
            AlienLanguage alienLanguage = new AlienLanguage(dict, createPattern(L, reader.nextLineAsString()));
            alienLanguage.setResultWriter(checker);
            alienLanguage.setResultHeader("Case #" + (i + 1) + ": ");
            alienLanguage.process();
        }

        checker.verify();
    }

    public void doWrite(String inputFileName, String resultFileName) throws Exception {
        InputStream is = getClass().getResourceAsStream(inputFileName);

        IOReader reader = new IOReader();
        reader.setReader(new BufferedReader(new InputStreamReader(is)));
        ResultWriter writer = new ResultWriter(resultFileName);
        List<Integer> paramList = reader.nextLineAsIntList();
        reader.setNumCases(paramList.get(2));

        int L = paramList.get(0);
        int D = paramList.get(1);

        List<String> dict = new ArrayList<String>();
        for (int i = 0; i < D; i++) {
            dict.add(i, reader.nextLineAsString());
        }

        int numCase = reader.getNumCases();
        for (int i = 0; i < numCase; i++) {
            AlienLanguage alienLanguage = new AlienLanguage(dict, createPattern(L, reader.nextLineAsString()));
            alienLanguage.setResultWriter(writer);
            alienLanguage.setResultHeader("Case #" + (i + 1) + ": ");
            alienLanguage.process();
        }

        writer.close();
    }


    private List<Set<Character>> createPattern(int len, String pattern) {
        List<Set<Character>> processed = new ArrayList<Set<Character>>();
        int curr = 0;
        for (int i = 0; i < len; i++) {
            Set currSet = new HashSet<Character>();
            if (pattern.charAt(curr) == '(') {
                curr++;
                while (pattern.charAt(curr) != ')') {
                    currSet.add(pattern.charAt(curr++));
                }
                curr++;
            } else {
                currSet.add(pattern.charAt(curr++));
            }
            processed.add(i, currSet);
        }
        return processed;
    }
}
