
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Arrays;
import java.util.Collections;

public class HousePancakes
{
    // private static String FILENAME = "sample.in";
    private static String FILENAME = "B-small-attempt0.in";
    // private static String FILENAME = "A-large.in";
    
    public static void main(String[] args)
    {
        BufferedReader br = null;
        String outFileName;
        if (FILENAME.contains("small"))
        {
            outFileName = "small.out";
        }
        else if (FILENAME.contains("large"))
        {
            outFileName = "large.out";
        }
        else
        {
            outFileName = "sample.out";
        }

        try
        {
            FileWriter fstream = new FileWriter(outFileName);
            BufferedWriter out = new BufferedWriter(fstream);

            br = new BufferedReader(new FileReader(FILENAME));
            int numberTestCases = Integer.parseInt(br.readLine());

            System.out.println("Number of Cases: " + numberTestCases);
            
            for (int i = 1; i <= numberTestCases; i++)
            {
                System.out.println("TestCase #" + i);
                
                // get number of diners
                int numDiners = Integer.parseInt(br.readLine());
                System.out.println("Number of diners: " + numDiners);
                
                // get diner pancake stacks
                String[] inputVar = br.readLine().split(" ");
                ArrayList<Integer> stacks = new ArrayList<Integer>();
                
                int totalPancakes = 0;
                int maxPlate = 0;
                for (String s : inputVar)
                {
                    // add up total pancakes and load arraylist
                    int numPancakes = Integer.parseInt(s);
                    stacks.add(numPancakes);
                    totalPancakes += numPancakes;
                    
                    if (numPancakes > maxPlate)
                    {
                        maxPlate = numPancakes;
                    }
                    
                    System.out.println("Stack height: " + s);
                    System.out.println("Total Pancakes: " + totalPancakes);
                    
                }
                System.out.println("Biggest Plate: " + maxPlate);
                System.out.println("Diner's plates: " + stacks);
                
                int minutes = 0;
                int doNothingTime = maxPlate;
                
                // simulate each minute until pancakes are gone
                while (totalPancakes > 0)
                {
                    // tick the minute and reset special minute flag
                    minutes++;
                    boolean special = false;
                    
                    // remove the diners with empty plates
                    stacks.removeAll(Arrays.asList(Integer.valueOf(0)));
                    
                    // find number of diners with pancakes
                    numDiners = stacks.size();
                    
                    // re-sort diners and find biggest plate
                    Collections.sort(stacks);
                    maxPlate = stacks.get(stacks.size() - 1);
                    System.out.println("Current Biggest Plate: " + maxPlate);
                    System.out.println("Current Diner's plates: " + stacks);
                    
                    // decide if it should be a special minute
                    if ((maxPlate / (numDiners + 1)) >= 1)
                    {
                        special = true;
                        System.out.println("*** Special Minute ***");
                    }
                    
                    if (special)
                    {
                        // remove pancakes from top plate and add another diner
                        int halfPlate = maxPlate / 2;
                        int newPlate = maxPlate - halfPlate;
                        int oldPlate = maxPlate - newPlate;
                        
                        stacks.set(stacks.size() - 1, oldPlate);
                        stacks.add(newPlate);
                        
                        System.out.println("Special Minute: " + stacks);
                    }
                    else
                    {
                        System.out.println("Number of Diners: " + numDiners);
                        for (int p = 0; p < stacks.size(); p++)
                        {
                            System.out.println("Diner #: " + p);
                            int numStacks = Integer.valueOf(stacks.get(p));
                            System.out.println("Stacks on the plate: " + numStacks);
                            
                            stacks.set(p, (numStacks - 1));
                            System.out.println("Eat one!!!!!");
                        }
                        
                        totalPancakes -= numDiners;
                        System.out.println("Non-Special minute: " + stacks);
                        System.out.println("New Total Pancakes: " + totalPancakes);
                    }
                    
                    // if minutes become greater than maxPlate break
                    // could have had no special minutes by now
                    if (minutes >= doNothingTime)
                    {
                        break;
                    }
                }
                
                System.out.println("====================================");
                System.out.println("Minutes needed: " + minutes);
                out.write("Case #" + i + ": " + minutes + "\r\n");
                System.out.println("====================================");
                
            } // next test case
            
            
            out.close();
        }
        catch (Exception e)
        {
            System.out.println(e);
        }
        finally
        {
            try
            {
                br.close();
            }
            catch (IOException e)
            {
                System.out.println(e);
            }
        }
          
    }
}
