import java.math.BigInteger;

import edu.princeton.cs.algs4.In;
import edu.princeton.cs.algs4.Out;
import edu.princeton.cs.algs4.MinPQ;

public class BathRoomStalls {

  public String[] solver(String n, String k) {
    String[] res = new String[2];

    BigInteger limit = new BigInteger(k);
    BigInteger i = BigInteger.ZERO;
    MinPQ<Segment> pq = new MinPQ<Segment>();
    pq.insert(new Segment(new BigInteger("1"), new BigInteger(n)));
    Segment current = null;

    while (pq.size() != 0 && i.compareTo(limit) == -1) {
      current = pq.delMin();
      if (current.distance().compareTo(BigInteger.ZERO) == 0) {
        res[0] = "0";
        res[1] = "0";
      } else if (current.distance().compareTo(BigInteger.ONE) == 0) {
        pq.insert(new Segment(current.max, current.max));
        res[0] = "1";
        res[1] = "0";
      } else {
        BigInteger middle = current.middle();
        pq.insert(new Segment(current.min, middle.subtract(BigInteger.ONE)));
        pq.insert(new Segment(middle.add(BigInteger.ONE), current.max));
        BigInteger val1 = middle.subtract(current.min);
        BigInteger val2 = current.max.subtract(middle);
        if (val1.compareTo(val2) < 0) {
          res[0] = val2.toString();
          res[1] = val1.toString();
        } else {
          res[0] = val1.toString();
          res[1] = val2.toString();
        }
      }
      i = i.add(BigInteger.ONE);
    }

    return res;
  }

  private class Segment implements Comparable<Segment> {
    private BigInteger min;
    private BigInteger max;

    public Segment(BigInteger _min, BigInteger _max) {
      min = _min;
      max = _max;
    }

    public BigInteger distance() {
      return max.subtract(min);
    }

    public BigInteger middle() {

      BigInteger d = this.distance().divide(new BigInteger("2"));
      return min.add(d);
    }

    public int compareTo(Segment that) {
      // BigInteger d = this.distance().divide(new BigInteger("2")).subtract(that.distance().divide(new BigInteger("2")));
      BigInteger d = that.distance().subtract(this.distance());
      if (d.signum() == 0) {
        return this.min.subtract(that.min).signum();
      } else {
        return d.signum();
      }
    }
  }

  private static String extractFileName(String file) {
    String[] tab = file.split("\\.");
    return tab[0];
  }

  public static void main(String[] args) {
    String filename = args[0];
    In in = new In(filename);
    int nb = in.readInt();
    BathRoomStalls brs = new BathRoomStalls();
    String[][] testCases = new String[nb][2];
    for (int i = 0; i < nb; i++) {
      String n = in.readString();
      String k = in.readString();
      testCases[i] = brs.solver(n, k);
    }

    Out out = new Out(extractFileName(filename) + "-sol.txt");
    for (int i = 0; i < nb; i++) {
      out.println(String.format("Case #%d: %s %s", i + 1, testCases[i][0], testCases[i][1]));
    }
    out.close();

  }
}