package r2;

import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;
import java.util.Map.Entry;
import java.util.Queue;
import java.util.Scanner;
import java.util.Set;

public class C {
	public static void main(String[] args) throws IOException {
		Scanner sc = new Scanner(new FileReader("C-small.in"));
		sc.useLocale(Locale.US);
		PrintWriter out = new PrintWriter(new FileWriter(
				new File("c-small.out")));
		int n = sc.nextInt();

		for (int T = 1; n-- > 0; T++) {
			int N = sc.nextInt();
			sc.nextLine();
			HashMap<String, Integer[]> map = new HashMap<String, Integer[]>();
			for(int i = 0;i<N;i++) {
				String line = sc.nextLine();
				String[] split = line.split(" ");
				for(String s : split) {
					if(map.containsKey(s)) {
						Integer[] l = map.get(s);
						l[i] = 1;
					} else {
						Integer[] l = new Integer[N];
						Arrays.fill(l, 0);
						l[i] = 1;
						map.put(s, l);
					}
				}
			}
			
//			Set<Entry<String, Integer[]>> entries = map.entrySet();
//			for(Entry<String, Integer[]> e : entries) {
//				System.out.print("Entry: "+e.getKey()+" Value: ");
//				Integer[] l = e.getValue();
//				for(int i = 0;i<l.length;i++) {
//					System.out.print(l[i]+" ");
//				}
//				System.out.println();
//			}
			
			List<Pair> pairs = new LinkedList<Pair>();
			
			int bilingual = 0;
			
			Collection<Integer[]> values = map.values();
			for(Integer[] a : values) {
				boolean first = true;
				for(int i = 0;i<N;i++) {
					if(a[i] == 0)
						continue;
					for(int j = i+1;j<N;j++) {
						if(a[j]==0)
							continue;
						else {
							if(first) {
								first = false;
								bilingual++;
							}
							pairs.add(new Pair(i,N+bilingual));
							pairs.add(new Pair(j,N+bilingual));
						}
					}
				}
			}
			
			int[][] grid = new int[N+bilingual+1][N+bilingual+1];
			for(Pair l : pairs) {
				grid[l.source][l.destination] = 1;
				grid[l.destination][l.source] = 1;
			}
			
			int result = MaxFlowMinCut.run(grid);

			out.println("Case #" + T + ": "+result);
			System.out.println("Case #" + T + ": "+result);
		}
		out.flush();
	}
}
class MaxFlowMinCut
{
    private int[] parent;
    private Queue<Integer> queue;
    private int numberOfVertices;
    private boolean[] visited;
    private Set<Pair> cutSet;
    private ArrayList<Integer> reachable;
    private ArrayList<Integer> unreachable;
 
    public MaxFlowMinCut (int numberOfVertices)
    {
        this.numberOfVertices = numberOfVertices;
        this.queue = new LinkedList<Integer>();
        parent = new int[numberOfVertices + 1];
        visited = new boolean[numberOfVertices + 1];
        cutSet = new HashSet<Pair>();
        reachable = new ArrayList<Integer>();
        unreachable = new ArrayList<Integer>();
    }
 
    public boolean bfs (int source, int goal, int graph[][])
    {
        boolean pathFound = false;
        int destination, element;
        for (int vertex = 1; vertex <= numberOfVertices; vertex++)
        {
            parent[vertex] = -1;
            visited[vertex] = false;
        }
        queue.add(source);
        parent[source] = -1;
        visited[source] = true;
 
        while (!queue.isEmpty())
        {
            element = queue.remove();
            destination = 1;
            while (destination <= numberOfVertices)
            {
                if (graph[element][destination] > 0 &&  !visited[destination])
                {
                    parent[destination] = element;
                    queue.add(destination);
                    visited[destination] = true;
                }
                destination++;
            }
        }
 
        if (visited[goal])
        {
            pathFound = true;
        }
        return pathFound;
    }
 
    public int  maxFlowMinCut (int graph[][], int source, int destination)
    {
        int u, v;
        int maxFlow = 0;
        int pathFlow;
        int[][] residualGraph = new int[numberOfVertices + 1][numberOfVertices + 1];
 
        for (int sourceVertex = 1; sourceVertex <= numberOfVertices; sourceVertex++)
        {
            for (int destinationVertex = 1; destinationVertex <= numberOfVertices; destinationVertex++)
            {
                residualGraph[sourceVertex][destinationVertex] = graph[sourceVertex][destinationVertex];
            }
        }
 
        /*max flow*/
        while (bfs(source, destination, residualGraph))
        {
            pathFlow = Integer.MAX_VALUE;
            for (v = destination; v != source; v = parent[v])
            {
                u = parent[v];
                pathFlow = Math.min(pathFlow,residualGraph[u][v]);
            }
            for (v = destination; v != source; v = parent[v])
            {
                u = parent[v];
                residualGraph[u][v] -= pathFlow;
                residualGraph[v][u] += pathFlow;
            }
            maxFlow += pathFlow;	
        }
 
        /*calculate the cut set*/		
        for (int vertex = 1; vertex <= numberOfVertices; vertex++)
        {
            if (bfs(source, vertex, residualGraph))
            {
                reachable.add(vertex);
            }
            else
            {
                unreachable.add(vertex);
            }
        }
        for (int i = 0; i < reachable.size(); i++)
        {
            for (int j = 0; j < unreachable.size(); j++)
            {
                if (graph[reachable.get(i)][unreachable.get(j)] > 0)
                {
                    cutSet.add(new Pair(reachable.get(i), unreachable.get(j)));
                }
            }
        }
        return maxFlow;
    }
 
    public void printCutSet ()
    {
        Iterator<Pair> iterator = cutSet.iterator();
        while (iterator.hasNext())
        {
            Pair pair = iterator.next();
            System.out.println(pair.source + "-" + pair.destination);
        }
    }
 
    public static int run (int[][] grid)
    {
        int[][] graph;
        int numberOfNodes;
        int source;
        int sink;
        int maxFlow;
        
        numberOfNodes = grid.length;
        graph = new int[numberOfNodes + 1][numberOfNodes + 1];
        for (int sourceVertex = 1; sourceVertex <= numberOfNodes; sourceVertex++)
        {
            for (int destinationVertex = 1; destinationVertex <= numberOfNodes ; destinationVertex++)
            {
                graph[sourceVertex][destinationVertex] = grid[sourceVertex-1][destinationVertex-1];
            }
        }
        source = 1;
        sink = 2;
        
        MaxFlowMinCut maxFlowMinCut = new MaxFlowMinCut(numberOfNodes);
        maxFlow = maxFlowMinCut.maxFlowMinCut(graph, source, sink);
        
        return maxFlow;
 
//        System.out.println("The Cut Set is ");
//        maxFlowMinCut.printCutSet();
    }
}
 
class Pair
{
    public int source;
    public int destination;
 
    public Pair (int source, int destination)
    {
        this.source = source;
        this.destination = destination;
    }
 
    public Pair()
    {
    }
}