import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

/**
 * A class to solve the Bot Trust Problem at the Google Code Jam
 * @author Ben McCormick
 *
 */
public class BotTrust {

	/**
	 * 
	 * A method for the Bot Trust Problem on Google code jam 2011
	 * Moves the output for each test case into 2 arrays, one for color and one for position,
	 * then sends it to the computeMinTime method
	 * It then prints the results in the specified format
	 * @param args
	 * @throws IOException 
	 * @throws NumberFormatException 
	 */
	public static void main(String[] args) throws NumberFormatException, IOException {
		BufferedReader br = new BufferedReader(new FileReader(new File("test.txt")));
		int numtests = Integer.parseInt(br.readLine());
		String line,tok;
		String[] tokens;
		char[] colors;
		int[] positions;
		int numtoks,minimumtime;
		for(int i=1; i<=numtests; i++)
		{
			line = br.readLine();
			tokens=line.split(" ");
			numtoks =Integer.parseInt(tokens[0]);
			colors = new char[numtoks];
			positions=new int[numtoks];
			for(int h=1; h<numtoks*2;h+=2)
			{
				colors[(h-1)/2]=tokens[h].charAt(0);
				positions[(h-1)/2]=Integer.parseInt(tokens[h+1]);
			}
			minimumtime = computeMinTime(colors,positions);
			System.out.println("Case #"+i+": "+minimumtime);
			
		}
		
		
		
	}
	/**
	 * Computes the minimum time for making the travel by comparing the time it would take the robot 
	 * to travel from its last button location, and the time since the last required event was completed
	 * and choosing the maximum time between the two for each decision
	 * @param color
	 * @param pos
	 * @return
	 */
	public static int computeMinTime(char[] color,int[] pos)
	{
		int lastbpos=1;
		int lastbtime=0;
		int lastopos =1;
		int lastotime =0;
		int currenttime=0;
		int traveltime,completetime;
		for(int i=0; i<color.length; i++)
		{
			if(color[i]=='B')
			{
				traveltime =Math.abs(pos[i]-lastbpos);
				completetime=lastbtime+traveltime ;
				if(completetime> currenttime)
				{
					currenttime=completetime+1;
				}
				else
				{
					currenttime++;
				}
				lastbpos=pos[i];
				lastbtime=currenttime;
			}
			else
			{
				traveltime = Math.abs(pos[i]-lastopos);
				completetime=lastotime+traveltime ;
				if(completetime> currenttime)
				{
					currenttime=completetime+1;
				}
				else
				{
					currenttime++;
				}
				lastopos=pos[i];
				lastotime=currenttime;
			}
		}
		
		return currenttime;
	}
}
