package org.inexorable.codejam.year2013.qr;

import org.inexorable.codejam.util.FileHelper;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>org.inexorable.codejam.year2013.qr.A_TicTacToeTomek, created on 13/04/13 9:05 AM </p>
 *
 * @author ben
 */
public class A_TicTacToeTomek {

    public static void main(String[] args) throws Exception {
        new A_TicTacToeTomek().run("/home/ben/inexorable/modules/codejam/res/year2013/QRA-example");
        new A_TicTacToeTomek().run("/home/ben/inexorable/modules/codejam/res/year2013/A-small-attempt0");
    }

    private void run(String filename) throws Exception {
        // load the tasks to run into a list of task objects
        BufferedReader reader = new BufferedReader(new FileReader(filename + ".in"));
        int n = Integer.parseInt(reader.readLine().trim());
        List<Task> tasks = new ArrayList<Task>(n);
        for (int i = 1; i <= n; i++) {
            Task task = new Task();
            task.number = i;
            task.array = new char[4][];
            task.array[0] = FileHelper.readCharArray(reader, 4);
            task.array[1] = FileHelper.readCharArray(reader, 4);
            task.array[2] = FileHelper.readCharArray(reader, 4);
            task.array[3] = FileHelper.readCharArray(reader, 4);
            reader.readLine();
            tasks.add(task);
        }
        reader.close();
        // now execute each task, writing the result to a file as we process it
        BufferedWriter writer = new BufferedWriter(new FileWriter(filename + ".out"));
        for (Task task : tasks) {
            writer.write(task.run());
            writer.newLine();
        }
        writer.flush();
        writer.close();
        System.out.println("--");
    }

    private class Task {
        private static final int SIZE = 4;

        int number;
        char[][] array;

        public String run() {
            // better way would have been to lay it out in a line and process the line
            boolean dot = false;

            boolean rowO = true;
            boolean rowX = true;
            boolean colO = true;
            boolean colX = true;
            for (int i = 0; i < SIZE; i++) {
                char[] row = array[i];
                // check for all in a row
                for (int j = 0; j < SIZE; j++) {
                    rowO &= (row[j] == 'O' || row[j] == 'T');
                    rowX &= (row[j] == 'X' || row[j] == 'T');
                    // keep track if we've found a dot
                    dot |= row[j] == '.';
                }
                // check for all in a column
                for (int j = 0; j < SIZE; j++) {
                    char c = array[j][i];
                    colO &= (c == 'O' || c == 'T');
                    colX &= (c == 'X' || c == 'T');
                }
                // check for completion
                if (rowO || colO) {
                    return finish("O won");
                }
                if (rowX || colX) {
                    return finish("X won");
                }
                // reset for the next pass
                rowO = true;
                rowX = true;
                colO = true;
                colX = true;
            }

            // check diagonals
            boolean ldiagO = true;
            boolean ldiagX = true;
            boolean rdiagO = true;
            boolean rdiagX = true;
            for (int i = 0; i < SIZE; i++) {
                char lc = array[i][i];
                ldiagO &= (lc == 'O' || lc == 'T');
                ldiagX &= (lc == 'X' || lc == 'T');
                char rc = array[i][SIZE - i - 1];
                rdiagO &= (rc == 'O' || rc == 'T');
                rdiagX &= (rc == 'X' || rc == 'T');
            }

            // check for completion
            if (ldiagO || rdiagO) {
                return finish("O won");
            }

            if (ldiagX || rdiagX) {
                return finish("X won");
            }

            return finish(dot ? "Game has not completed" : "Draw");
        }

        private String finish(String s) {
            String result = "Case #" + number + ": " + s;
            System.out.println(result);
            return result;
        }
    }

}
