package org.inexorable.codejam.year2013.qr;

import org.inexorable.codejam.util.FileHelper;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.*;
import java.util.concurrent.Callable;

/**
 * <p>org.inexorable.codejam.year2013.qr.D_Treasure, created on 13/04/13 3:17 PM </p>
 *
 * @author ben
 */
public class D_Treasure {

    public static void main(String[] args) throws Exception {
//        new D_Treasure().run("/home/ben/inexorable/modules/codejam/res/year2013/QRD-example");
//        new D_Treasure().run("/home/ben/inexorable/modules/codejam/res/year2013/QRD-temp");
//        new D_Treasure().run("/home/ben/inexorable/modules/codejam/res/year2013/D-small-attempt0");
//        new D_Treasure().run("/home/ben/inexorable/modules/codejam/res/year2013/D-small-attempt1");
        new D_Treasure().run("/home/ben/inexorable/modules/codejam/res/year2013/D-small-attempt2");
//        new D_Treasure().run("/home/ben/inexorable/modules/codejam/res/year2013/D-large");
    }

    private void run(String filename) throws Exception {
        // load the tasks to run into a list of task objects
        BufferedReader reader = new BufferedReader(new FileReader(filename + ".in"));
        int n = Integer.parseInt(reader.readLine().trim());
        List<Task> tasks = new ArrayList<Task>(n);
        for (int i = 1; i <= n; i++) {
            Task task = new Task();
            task.number = i;
            int[] ia = FileHelper.readIntArray(reader, 2);
            task.k = ia[0];
            task.n = ia[1];
            task.keys = FileHelper.readIntArray(reader, task.k);
            task.chests = new int[task.n][];
            for (int ni = 0; ni < task.n; ni++) {
                task.chests[ni] = FileHelper.readIntArray(reader);
            }
            tasks.add(task);
        }
        reader.close();
        // now execute each task, writing the result to a file as we process it
        BufferedWriter writer = new BufferedWriter(new FileWriter(filename + ".out"));
        for (Task task : tasks) {
            writer.write(task.run());
            writer.newLine();
        }
        writer.flush();
        writer.close();
        System.out.println("--");
    }

    private class Task implements Callable<String> {
        int number;
        int k;
        int n;
        int[] keys;
        int[][] chests;

        public String call() throws Exception {
            return run();
        }

        public String run() throws Exception {
            // determine the current keys we are holding
            List<Integer> keys = new ArrayList<Integer>();
            for (int i = 0; i < this.keys.length; i++) {
                keys.add(this.keys[i]);
            }
            // create a set of chests to search
            List<Chest> chests = new ArrayList<Chest>(this.chests.length);
            for (int i = 0; i < this.chests.length; i++) {
                int[] data = this.chests[i];
                Chest chest = new Chest(i + 1, data);
                chests.add(chest);
            }
            // before we start do some easy checks
            int keyCount = keys.size();
            Map<Integer, Integer> chestCounts = new HashMap<Integer, Integer>();
            Map<Integer, Integer> keyCounts = new HashMap<Integer, Integer>();
            for (Chest chest : chests) {
                keyCount += chest.contents.size();
                // increment the chest count required for that key
                if (!chestCounts.containsKey(chest.key)) {
                    chestCounts.put(chest.key, 0);
                }
                chestCounts.put(chest.key, chestCounts.get(chest.key) + 1);
                // increment the number we have of each key
                for (Integer key : chest.contents) {
                    if (!keyCounts.containsKey(key)) {
                        keyCounts.put(key, 0);
                    }
                    keyCounts.put(key, keyCounts.get(key) + 1);
                }
            }
            for (Integer key : keys) {
                if (!keyCounts.containsKey(key)) {
                    keyCounts.put(key, 0);
                }
                keyCounts.put(key, keyCounts.get(key) + 1);
            }
            // make sure we have more keys than chests
            if (keyCount < chests.size()) {
                System.out.println("noKeys = " + keyCount + ", noChests = " + chests.size());
                return finish("IMPOSSIBLE");
            }
            // now make sure we have the right number of keys for chests
            for (Map.Entry<Integer, Integer> entry : chestCounts.entrySet()) {
                int noChests = entry.getValue();
                int noKeys = keyCounts.containsKey(entry.getKey()) ? keyCounts.get(entry.getKey()) : 0;
                if (noKeys < noChests) {
                    System.out.println("key = " + entry.getKey() + ", noKeys = " + noKeys + ", noChests = " + noChests);
                    return finish("IMPOSSIBLE");
                }
            }

            // now search the chests
            List<Chest> opened = new ArrayList<Chest>();
            boolean ok = search(keys, chests, opened);
            return finish(ok ? asString(opened) : "IMPOSSIBLE");
        }

        private boolean search(List<Integer> keys, List<Chest> closed, List<Chest> opened) {
            if (closed.isEmpty()) return true;
            if (keys.isEmpty()) return false;

            Set<Chest> used = new HashSet<Chest>();
            while (!keys.isEmpty()) {
                // find the lowest chest number for the keys we currently have
                int cIdx = Integer.MAX_VALUE;
                Chest c = null;
                for (int key : keys) {
                    for (Chest chest : closed) {
                        if (chest.key == key && !noWayOut(keys, key, chest, closed)) {
                            int idx = closed.indexOf(chest);
                            if (cIdx > idx && !used.contains(chest)) {
                                cIdx = idx;
                                c = chest;
                            }
                        }
                        if (cIdx == 0) break;
                    }
                }

                if (c == null) return false;

                List<Integer> newKeys = new ArrayList<Integer>(keys);
                newKeys.remove((Integer) c.key);
                newKeys.addAll(c.contents);
                closed.remove(c);
                opened.add(c);
                if (search(newKeys, closed, opened)) {
                    return true;
                }
                closed.add(cIdx, c);
                opened.remove(c);
                used.add(c);
            }
            return false;
        }

        private boolean noWayOut(List<Integer> keys, int key, Chest chest, List<Chest> chests) {
            if (chest.contents.size() == 0 && chests.size() > 1) {
                List<Integer> keysToCheck = new ArrayList<Integer>(keys);
                keysToCheck.remove((Integer) key);
                if (keysToCheck.contains(key)) return false;
                // check if we need this key again
                int keysRequired = 0;
                // check if the key is available
                int keysAvailable = 0;
                int otherCount = 0;
                for (Chest c : chests) {
                    if (c != chest) {
                        if (c.key == key) {
                            keysRequired++;
                        }
                        if (c.contents.contains(key) && c.key != key) {
                            keysAvailable++;
                            otherCount += c.contents.size();
                        } else if (c.contents.contains(key)) {
                            otherCount += c.contents.size();
                        }
                    }
                }
                return keysAvailable < keysRequired && otherCount <= keysRequired;
            }
            return false;
        }

        private String asString(List<Chest> chests) {
            StringBuffer sb = new StringBuffer();
            for (Chest chest : chests) {
                sb.append(sb.length() > 0 ? " " : "").append(chest.number);
            }
            return sb.toString();
        }

        private String finish(String s) {
            String result = "Case #" + number + ": " + s;
            System.out.println(result);
            return result;
        }

        private class Chest {
            int number;
            int key;
            Collection<Integer> contents = new ArrayList<Integer>();

            private Chest(int number, int[] chest) {
                this.number = number;
                this.key = chest[0];
                int keys = chest[1];
                if (keys > 0) {
                    for (int i = 2; i < 2 + keys; i++) {
                        contents.add(chest[i]);
                    }
                }
            }

            @Override
            public String toString() {
                return "C" + number;
            }
        }

        public void print() {
            System.out.println(k + " " + n);
            for (int i = 0; i < keys.length; i++) {
                int key = keys[i];
                System.out.print(key + " ");
            }
            System.out.println();
            for (int i = 0; i < chests.length; i++) {
                int[] chest = chests[i];
                for (int j = 0; j < chest.length; j++) {
                    System.out.print(chest[j] + " ");
                }
                System.out.println();
            }
        }
    }

}
