package GCJ2016.qualiticationRound.problemC;

import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.util.*;

public class Main {

    public static void main(String[] args) throws Exception {
        new Main();
    }

    public Main() throws Exception {
        solve();
    }

    Random rng = new Random();
    List<Integer> primes;

    private void solve() throws Exception {
        primes = getPrimeNumbers(Integer.MAX_VALUE - 1);

        System.out.println(">>> Input: ");
        Scanner sc = new Scanner(System.in);
        BufferedWriter out = new BufferedWriter(new FileWriter("output.txt"));
        out.write("Case #1:");

        int test_cases = sc.nextInt();

        for (int test_case = 1; test_case <= test_cases; test_case++) {
            int n = sc.nextInt();
            int j = sc.nextInt();

            HashSet<BitSet> numbers = getResult(n, j);

            for (BitSet number : numbers) {
                writeResult(out, number, n);
            }
        }

        out.flush();
        out.close();
        sc.close();
    }

    private HashSet<BitSet> getResult(int n, int j) {
        BitSet set = new BitSet(n);
        set.set(0, n);

        HashSet<BitSet> numbers = new HashSet<>();
        while (numbers.size() < j) {
            while (!isJamcoin(set, n)) {
                flipRandom(set, n);
            }
            System.out.println(bitSetToString(set, n));
            numbers.add((BitSet) set.clone());
            System.out.println(numbers.size());
            flipRandom(set, n);
        }

        return numbers;
    }

    private boolean isJamcoin(BitSet set, int length) {
        if (!(set.get(0) && set.get(length-1))) {
            return false;
        }
        for (int i = 2; i <= 10; i ++) {
            BigInteger number = bitSetToBigInteger(set, length, i);
            if (number.isProbablePrime(Integer.MAX_VALUE)
                    || getDivisor(number) == -1) {
                return false;
            }
        }
        return true;
    }

    private BigInteger bitSetToBigInteger(BitSet set, int length, int radix) {
        return new BigInteger(bitSetToString(set, length), radix);
    }

    private String bitSetToString(BitSet set, int length) {
        StringBuilder builder = new StringBuilder(length);
        for (int i = 0; i < length; i++) {
            if (set.get(i)) {
                builder.append("1");
            } else {
                builder.append("0");
            }
        }
        return builder.toString();
    }

    private void flipRandom(BitSet set, int length) {
        int index = rng.nextInt(length - 1) + 1;
        set.flip(index);
    }

    private void writeResult(BufferedWriter out, BitSet number, int length) throws IOException {
        StringBuilder result = new StringBuilder();
        result.append(bitSetToString(number, length));

        for (int i = 2; i <= 10; i++) {
            result.append(" ");
            result.append(getDivisor(bitSetToBigInteger(number, length, i)));
        }

        result.append("\n");
        out.write(result.toString());
    }

    private int getDivisor(BigInteger number) {
        for (int prime : primes) {
            if (number.remainder(BigInteger.valueOf(prime)).compareTo(BigInteger.ZERO) == 0) {
                return prime;
            }
        }
        return -1;
    }

    private List<Integer> getPrimeNumbers(int N) {
        BitSet isPrime = new BitSet(N + 1);
        for (int i = 2; i <= N; i++) {
            isPrime.set(i);
        }

        for (long i = 2; i*i <= N; i++) {
            if (isPrime.get((int) i)) {
                for (long j = i; i*j <= N; j++) {
                    isPrime.clear((int) (i*j));
                }
            }
        }

        List<Integer> primes = new ArrayList<>();
        int prev = 0;
        while (isPrime.nextSetBit(prev+1) != -1) {
            prev = isPrime.nextSetBit(prev+1);
            primes.add(prev);
        }

        return primes;
    }
}