package codeJam;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Stack;

public class Watersheds {

	public static boolean shouldMove(int h, int w, int H, int W, int alt, int minAlt, int [][] map) {
		if(h < 0 || h >= H)
			return false;
		
		if(w < 0 || w >= W)
			return false;
		
		if(map[h][w] >= alt)
			return false;
		
		if(minAlt == -1 || map[h][w] < minAlt)
			return true;
		
		return false;
	}
	
	protected static int [][] validMoves = new int[][] {
		{-1, 0}, 	// North
		{0, -1},	// West
		{0, 1},		// East
		{1, 0}		// South
	};
	
	public static char [][] solveBasins(int H, int W, int [][] map) {
		int [][] retVal = new int[H][W];
		for(int h = 0; h < H; h++) {
			for(int w = 0; w < W; w++) {
				retVal[h][w] = -1;
			}
		}
		
		int letter = 0;
		// Solve via depth search
		for(int h = 0; h < H; h++) {
			for(int w = 0; w < W; w++) {
				if(retVal[h][w] != -1)
					continue;
				
				Stack<Integer> pathStackH = new Stack<Integer>();
				Stack<Integer> pathStackW = new Stack<Integer>();
				
				int [] location = new int[] {h, w};
				int useLabel = -1;
				
				while(true) {
					
					final int alt = map[location[0]][location[1]];
					
					// Determine a move
					int minAlt = -1;
					int [] connected = null;
					for(int j = 0; j < validMoves.length; j++) {
						if(shouldMove(location[0] + validMoves[j][0], location[1] + validMoves[j][1], 
								H, W, alt, minAlt, map)) {
							connected = new int[]{location[0] + validMoves[j][0], location[1] + validMoves[j][1]};
							minAlt = map[connected[0]][connected[1]];
						}
					}
					pathStackH.push(location[0]);
					pathStackW.push(location[1]);
					
					if(connected == null) {
						// We are a sink
						useLabel = letter++;
						break;
					} else {
						if(retVal[connected[0]][connected[1]] != -1) {
							// We are connected to a sink
							useLabel = retVal[connected[0]][connected[1]];
							break;
						} else {
							location = new int[] { connected[0], connected[1] };
						}
					}
				}
				while(!pathStackH.isEmpty()) {
					location = new int[] {pathStackH.pop(), pathStackW.pop()};
					retVal[location[0]][location[1]] = useLabel;
				}
			}
		}
		char [][] retValChar = new char[H][W];
		for(int h = 0; h < H; h++) {
			for(int w = 0; w < W; w++) {
				retValChar[h][w] = (char)((int)'a' + retVal[h][w]);
			}
		}
		return retValChar;
	}
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		BufferedReader input;
		BufferedWriter output;
		try {
			input = new BufferedReader(new FileReader(args[0]));
			output = new BufferedWriter(new FileWriter(args[1]));
			int T = Integer.parseInt(input.readLine());
			
			for(int t = 0; t < T; t++) {
				String [] dimArg = input.readLine().split(" ");			
				int H = Integer.parseInt(dimArg[0]);
				int W = Integer.parseInt(dimArg[1]);
				int [][] map = new int[H][W];
				for(int i = 0; i < H; i++) {
					String [] intParts = input.readLine().split(" ");
					for(int j = 0; j < W; j++) {
						map[i][j] = Integer.parseInt(intParts[j]);
					}
				}
				char [][] sol = solveBasins(H, W, map);
				output.write("Case #" + (t+1) + ":");
				output.newLine();
				for(int h = 0; h < H; h++) {
					for(int w = 0; w < W; w++) {
						output.write(sol[h][w] + " ");
					}
					output.newLine();
				}
			}
			output.flush();
			output.close();
		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

}
