package codeJam;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.Date;
import java.util.List;

public class TrainTimetable {

	public static class Event implements Comparable<Event> {
		public Event(Date inTime, boolean inaEvent, boolean arrivalEvent) {
			eventTime = inTime;
			aEvent = inaEvent;
			isReady = arrivalEvent;
		}
		
		Date eventTime;
		boolean aEvent;
		boolean isReady;
		
		@Override
		public int compareTo(Event arg0) {
			if(arg0.eventTime != eventTime) {
				return eventTime.compareTo(arg0.eventTime);
			}
			if(isReady)
				return -1;
			else if(arg0.isReady)
				return 1;
			
			return 0;
		}
	}
	
	public static int [] getNumberOfTrains(List<Date> aArr, List<Date> aDept,
			List<Date> bArr, List<Date> bDept, int turnaround) {
		
		int [] result = new int [2];
		List<Event> eventList = new ArrayList<Event>(aArr.size() + aDept.size() + bArr.size() + bDept.size());
		
		Calendar calendar = Calendar.getInstance();
		
		// Add the delay time onto arrivals and put into list as events
		for(Date d : aArr) {
			calendar.setTime(d);
			calendar.add(Calendar.MINUTE, turnaround);
			
			eventList.add(new Event(calendar.getTime(), false, true));
		}
		for(Date d : bArr) {
			calendar.setTime(d);
			calendar.add(Calendar.MINUTE, turnaround);
			
			eventList.add(new Event(calendar.getTime(), true, true));
		}
		for(Date d : aDept) {
			eventList.add(new Event(d, true, false));
		}
		for(Date d : bDept) {
			eventList.add(new Event(d, false, false));
		}

		Collections.sort(eventList);

		int aTrains = 0;
		int bTrains = 0;
		
		for(Event e : eventList) {
			if(e.isReady) { // Arrivals
				if(e.aEvent) {
					aTrains++;
				} else {
					bTrains++;
				}
			} else { // Departures
				if(e.aEvent) {
					if(aTrains > 0) {
						aTrains--;
					} else {
						result[0] ++;
					}
				} else {
					if(bTrains > 0) {
						bTrains--;
					} else {
						result[1] ++;
					}
				}
			}
		}
		
		if((bTrains + aTrains) != (result[0] + result[1])) {
			int qu = 0;
			qu++;
		}
		return result;
	}
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		try {
	        BufferedReader in = new BufferedReader(new FileReader(args[0]));
	        BufferedWriter out = new BufferedWriter(new FileWriter(args[1]));
	        int testCases = Integer.parseInt(in.readLine());
	        for(int i = 0; i < testCases; i++) {
	        	int turnaround = Integer.parseInt(in.readLine());
	        	
	        	String [] schedEntries = in.readLine().split(" ");
	        	int nA = Integer.parseInt(schedEntries[0]);
	        	int nB = Integer.parseInt(schedEntries[1]);
	        	
	        	List<Date> aArr = new ArrayList<Date>(nA);
	        	List<Date> aDept = new ArrayList<Date>(nA);
	        	
	        	List<Date> bArr= new ArrayList<Date>(nB);
	        	List<Date> bDept = new ArrayList<Date>(nB);
	        	try {
//	        		DateFormat timeFormat = DateFormat.getDateInstance(DateFormat.SHORT, Locale.CANADA);
	        		DateFormat timeFormat = new SimpleDateFormat("HH:mm");

		        	for(int j = 0; j < nA; j++) {
		        		String [] entry = in.readLine().split(" ");
						aDept.add(timeFormat.parse(entry[0]));
		        		aArr.add(timeFormat.parse(entry[1]));
		        	}
	
		        	for(int j = 0; j < nB; j++) {
		        		String [] entry = in.readLine().split(" ");
		        		bDept.add(timeFormat.parse(entry[0]));
		        		bArr.add(timeFormat.parse(entry[1]));
		        	}

	        	} catch (ParseException e) {
	        		e.printStackTrace();
	        	}
	        	
	        	int[] trains = getNumberOfTrains(aArr, aDept, bArr, bDept, turnaround);
	        	
	        	out.write("Case #" + Integer.toString(i+1) + ": " + trains[0] + " " + trains[1]);
	        	
	        	if((i+1) < testCases)
	        		out.newLine();
	        }
	        out.flush();
	        out.close();
	        in.close();
	    } catch (IOException e) {
	    }
	}

}
