package codeJam;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.DecimalFormat;
import java.util.Stack;

public class ProblemA {

	public static class Animal {
		public String name;
		public String [] features;
	}
	
	public static class Tree {
		public String feature;
		public float weight;
		public Tree left;
		public Tree right;
		public boolean isLeaf;
	}
	
	public static float computeCute(Tree tree, Animal animal) {
		Tree currentNode = tree;
		float retVal = 1.0f;
		retVal *= currentNode.weight;
		while(currentNode.left != null) {
			Tree nextNode = currentNode.right;
			for(int i = 0; i < animal.features.length; i++) {
				if(currentNode.feature.equals(animal.features[i])) {
					nextNode = currentNode.left;
					break;
				}				
			}
			currentNode = nextNode;
			retVal *= currentNode.weight;
		}
		
		return retVal;
	}
	
	public static class InputObject {
		public InputObject(BufferedReader input) {
			this.input  = input;
			buffered = "";
		}
		
		public String getToken() {
			String retToken = null;
			try {
				while(buffered.isEmpty())
					buffered = input.readLine().trim();
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			
			if(buffered.charAt(0) == '(' || buffered.charAt(0) == ')') {
				retToken = buffered.substring(0, 1);
//				buffered = buffered.substring(1).trim();
				
			} else {			
				String [] tokens = buffered.split(" ");
				retToken = tokens[0];
				int bracketPos = retToken.indexOf(')');
				if(bracketPos != -1) {
					retToken = retToken.substring(0, bracketPos);
				}
			}
			
			buffered = buffered.substring(retToken.length()).trim();
			return retToken;
		}
		
		String buffered;
		BufferedReader input;
	}
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		DecimalFormat outputFormat = new DecimalFormat("0.0000000");
		BufferedReader input;
		BufferedWriter output;
		try {
			input = new BufferedReader(new FileReader(args[0]));
			output = new BufferedWriter(new FileWriter(args[1]));

			int N = Integer.parseInt(input.readLine());
			
			for(int i = 0; i < N; i++) {
				// Read decision tree
				int L = Integer.parseInt(input.readLine());
				Tree root = null;
				Tree currNode = null;
				
				Stack<Tree> treeStack = new Stack<Tree>();
				
				InputObject inputObject  = new InputObject(input); 
				while(true) {
					String token = inputObject.getToken();
					if(token.equals("(")) {
						// New node
						Tree newNode = new Tree();
						if(currNode != null) {							
							if(currNode.left == null) {
								currNode.left = newNode;								
							} else
								currNode.right = newNode;
						}
						currNode = newNode;
						
						if(root == null)
							root = currNode;
						
						treeStack.push(currNode);
					} else if(token.equals(")")) {
						// End node
						treeStack.pop();
						if(treeStack.isEmpty())
							break;
						currNode = treeStack.peek();
					} else {
						// Node def
						float weight = Float.parseFloat(token);
						currNode.weight = weight;
						
						String nextToken = inputObject.getToken();
						if(nextToken.equals(")")) {
							// def ends
							treeStack.pop();
							if(treeStack.isEmpty())
								break;
							currNode = treeStack.peek();
						} else {
							// feature name
							currNode.feature = nextToken;
						}
					}
				}
				
				
				output.write("Case #" + (i+1) + ": ");
				output.newLine();
				
				int A = Integer.parseInt(input.readLine());
				for(int j = 0; j < A; j++) {
					Animal animal = new Animal();
					String [] animalDef = input.readLine().split(" ");
					animal.name = animalDef[0];
					int animalFeatures = Integer.parseInt(animalDef[1]);
					animal.features = new String[animalFeatures];
					for(int k = 0; k < animalFeatures; k++) {
						animal.features[k] = animalDef[2+k];
					}
					float cuteVal = computeCute(root, animal);
					output.write(outputFormat.format(cuteVal));
					
					output.newLine();
				}
			}
			output.flush();
			output.close();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
