package nl.bertje.googlecodejam;

import java.io.BufferedReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.stream.LongStream;

public class ProblemC extends Problem {

  public ProblemC(String problemFile) {
	super(problemFile);
  }

  @Override
  public String solveNextCase(BufferedReader br) throws IOException {
	final String[] input = br.readLine().split(" ");
	assert input.length == 2;
	final int jamcoinLength = Integer.parseInt(input[0]);
	final int expectedJamcoins = Integer.parseInt(input[1]);

	final List<JamCoin> possibleJamCoins = Collections.synchronizedList(new ArrayList<>());
	final Map<JamCoin, String> results = new HashMap<>();
	final long start = getStart(jamcoinLength);
	final long end = getEnd(jamcoinLength);
	final LongStream stream = LongStream.range(start, end).unordered().parallel()
	    .filter(x -> (x - start) % 2 == 0)
	    .filter(x -> new JamCoin(x).getDivisors().isPresent())
	    .peek(x -> possibleJamCoins.add(new JamCoin(x)));
	final Thread thread = new Thread(new Runnable() {

	  @Override
	  public void run() {
		stream.forEach(x -> System.out.println(x));
	  }
	});
	thread.start();
	while (possibleJamCoins.size() < expectedJamcoins) {
	  try {
		Thread.sleep(1000);
	  } catch (final InterruptedException e) {
		// TODO Auto-generated catch block
		e.printStackTrace();
	  }
	}
	stream.close();
	possibleJamCoins.subList(0, expectedJamcoins)
	    .forEach(x -> results.put(x, x.getDigits() + " " + x.getDivisors().get()));
	return System.lineSeparator() + String.join(System.lineSeparator(), results.values());
  }

  private long getStart(int length) {
	final StringBuilder builder = new StringBuilder("1");
	for (int i = 1; i < length - 1; i++) {
	  builder.append("0");
	}
	builder.append("1");
	return Long.parseLong(builder.toString(), 2);
  }

  private long getEnd(int length) {
	final StringBuilder builder = new StringBuilder("1");
	for (int i = 1; i < length - 1; i++) {
	  builder.append("1");
	}
	builder.append("1");
	return Long.parseLong(builder.toString(), 2);
  }

  private static class JamCoin {

	private final long digits;
	private Optional<String> result = Optional.empty();

	JamCoin(long base2Rep) {
	  digits = Long.parseLong(Long.toBinaryString(base2Rep));
	}

	long getDigits() {
	  return digits;
	}

	Optional<String> getDivisors() {
	  if (!result.isPresent()) {
		final List<String> divisors = new ArrayList<>();
		for (int base = 2; base <= 10; base++) {
		  final Long divisor = getDivisor(base);
		  if (divisor == null) {
			break;
		  } else {
			divisors.add("" + divisor);
		  }
		}
		if (divisors.size() == 9) {
		  result = Optional.of(String.join(" ", divisors));
		  System.out.println("Found one: " + digits);
		} else {
		  result = Optional.empty();
		}
	  }
	  return result;
	}

	Long getDivisor(int base) {
	  final long digitsInBase = Long.parseLong("" + digits, base);
	  Long divisor = null;
	  if (digitsInBase % 2 == 0) {
		divisor = digitsInBase / 2L;
	  } else {
		for (long i = 3; i * i <= digitsInBase; i += 2) {
		  if (digitsInBase % i == 0) {
			divisor = digitsInBase / i;
			break;
		  }
		}
	  }

	  return divisor;
	}

	@Override
	public int hashCode() {
	  return (int) digits;
	}

	@Override
	public boolean equals(Object obj) {
	  return obj instanceof JamCoin && digits == ((JamCoin) obj).digits;
	}

  }

}
