package nl.bertje.googlecodejam;

import java.io.BufferedReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

public class ProblemC extends Problem {

  public ProblemC(String problemFile) {
	super(problemFile);
  }

  @Override
  public String solveNextCase(BufferedReader br) throws IOException {
	final String input = br.readLine();
	final String[] split = input.split(" ");
	final int nrOfStalls = Integer.parseInt(split[0]);
	final int people = Integer.parseInt(split[1]);

	final List<Stall> stalls = init(nrOfStalls);

	String output = "";
	for (int i = 0; i < people; i++) {
	  final int maximumMin = stalls.stream()
		  .filter(x -> !x.occupied)
		  .mapToInt(x -> x.getMin()).max().getAsInt();

	  final List<Stall> minStalls = stalls.stream()
	      .filter(x -> !x.occupied)
	      .filter(x -> x.getMin() == maximumMin)
	      .collect(Collectors.toList());

	  if (minStalls.size() == 0) {
		System.out.println("problem!");
	  }
	  final int maximumMax = minStalls.stream()
		  .filter(x -> !x.occupied)
		  .mapToInt(x -> x.getMax()).max().getAsInt();

	  final List<Stall> maxStalls = minStalls.stream()
	      .filter(x -> x.getMax() == maximumMax)
	      .collect(Collectors.toList());

	  Collections.sort(maxStalls, (x1, x2) -> Integer.compare(x1.stallIndex, x2.stallIndex));

	  final Stall intoStall = maxStalls.get(0);
	  occupyStall(stalls, intoStall);

	  output = maximumMax + " " + maximumMin;
	}

	return output;
  }

  private List<Stall> init(int nrOfStalls) {
	final List<Stall> stalls = new ArrayList<>();
	for (int i = 0; i <= nrOfStalls; i++) {
	  stalls.add(new Stall(i, i, nrOfStalls - i - 1));
	}
	return stalls;
  }

  private void occupyStall(final List<Stall> stalls, Stall occupyStall) {
	occupyStall.occupied = true;
	// update left of occupied
	for (int i = occupyStall.stallIndex - 1; i >= 0; i--) {
	  final Stall stallToLeft = stalls.get(i);
	  if (stallToLeft.occupied) {
		break;
	  }
	  stallToLeft.right = occupyStall.stallIndex - i - 1;
	}
	// update right of occupied
	for (int i = occupyStall.stallIndex + 1; i < stalls.size(); i++) {
	  final Stall stallToRight = stalls.get(i);
	  if (stallToRight.occupied) {
		break;
	  }
	  stallToRight.left = i - occupyStall.stallIndex - 1;
	}
  }

  private class Stall {

	private final int stallIndex;
	private int left;
	private int right;
	private boolean occupied = false;

	Stall(int stallIndex, int left, int right) {
	  this.stallIndex = stallIndex;
	  this.left = left;
	  this.right = right;
	}

	public int getMin() {
	  return Math.min(left, right);
	}

	public int getMax() {
	  return Math.max(left, right);
	}

	@Override
	public String toString() {
	  return "[stallIndex=" + stallIndex + ", left=" + left + ", right=" + right + "]";
	}

  }

}
