package nl.bertje.googlecodejam;

import java.io.BufferedReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class ProblemC extends Problem {

  private final Map<String, String> convertMap = new HashMap<>();

  private enum IjkChar {
    i, j, k;

    static IjkChar fromChar(char someChar) {
      if (someChar == 'i') {
        return IjkChar.i;
      } else if (someChar == 'j') {
        return IjkChar.j;
      } else if (someChar == 'k') {
        return IjkChar.k;
      } else {
        return null;
      }
    }

  }

  public ProblemC(String problemFile) {
    super(problemFile);
  }

  @Override
  public String solveNextCase(BufferedReader br) throws IOException {
    // first line holds nr of chars and times repeated:
    final String[] parts = br.readLine().split(" ");
    final int nrChars = Integer.parseInt(parts[0]);
    final int repeats = Integer.parseInt(parts[1]);
    // next holds the actual characters
    final String pattern = br.readLine();
    final StringBuilder actualLine = new StringBuilder();
    for (int i = 1; i <= repeats; i++) {
      actualLine.append(pattern);
    }

    return isPossible(actualLine.toString()) ? "YES" : "NO";
  }

  private boolean isPossible(String line) {
    final List<Integer> possibleIndexesI = getPossibleIs(line);
    final List<Integer> possibleIndexesK = getPossibleKs(line);
    possibleIndexesK.sort(null);
    for (final int indexI : possibleIndexesI) {
      String uptillNow = "1";
      int doneKIndex = indexI;
      for (final int indexK : possibleIndexesK) {
        if (indexI < indexK) {
          uptillNow = resolveThis(uptillNow, line.substring(doneKIndex, indexK));
          doneKIndex = indexK;
          if (IjkChar.fromChar(uptillNow.charAt(0)) == IjkChar.j) {
            return true;
          }
        }
      }
    }
    return false;
  }

  private List<Integer> getPossibleIs(final String line) {
    final List<Integer> indexes = new ArrayList<>();
    String currentChar = "" + line.charAt(0);
    if (IjkChar.fromChar(line.charAt(0)) == IjkChar.i) {
      indexes.add(1);
    }
    for (int i = 1; i < line.length(); i++) {
      currentChar = (currentChar.length() > 1 ? currentChar.substring(0, currentChar.length() - 1) : "")
          + multiply(currentChar.charAt(currentChar.length() - 1), line.charAt(i));
      currentChar = minimize(currentChar);
      if (IjkChar.fromChar(currentChar.charAt(0)) == IjkChar.i) {
        indexes.add(i + 1);
      }
    }
    return indexes;
  }

  private List<Integer> getPossibleKs(final String line) {
    final List<Integer> indexes = new ArrayList<>();
    String currentChar = "" + line.charAt(line.length() - 1);
    if (IjkChar.fromChar(currentChar.charAt(0)) == IjkChar.k) {
      indexes.add(line.length() - 1);
    }
    for (int i = line.length() - 2; i >= 0; i--) {
      currentChar = (currentChar.length() > 1 ? currentChar.substring(0, currentChar.length() - 1) : "")
          + multiply(line.charAt(i), currentChar.charAt(currentChar.length() - 1));
      currentChar = minimize(currentChar);
      if (IjkChar.fromChar(currentChar.charAt(0)) == IjkChar.k) {
        indexes.add(i);
      }
    }
    return indexes;
  }

  private String resolveThis(String current, final String line) {
    String currentChar = current;
    for (int i = 0; i < line.length(); i++) {
      currentChar = (currentChar.length() > 1 ? currentChar.substring(0, currentChar.length() - 1) : "")
          + multiply(currentChar.charAt(currentChar.length() - 1), line.charAt(i));
      currentChar = minimize(currentChar);
    }
    return currentChar;
  }

  protected String minimize(String smallBit) {
    final String correct = smallBit.replaceAll("--", "");
    if (correct.length() == 0) {
      return "1";
    } else if (correct.length() == 1) {
      return correct;
    } else {
      return correct.replace("1", "");
    }
  }

  protected String multiply(final char before, final char next) {
    if (before == next) {
      return "-1";
    } else if (before == '1') {
      return "" + next;
    } else if (next == '1') {
      return "" + before;
    } else if (before == '-') {
      if (next == '-') {
        return "1";
      } else {
        return "-" + next;
      }
    } else if (next == '-') {
      return "-" + before;
    } else if (before == 'i') {
      if (next == 'j') {
        return "k";
      } else if (next == 'k') {
        return "-j";
      } else {
        throw new RuntimeException("");
      }
    } else if (before == 'j') {
      if (next == 'i') {
        return "-k";
      } else if (next == 'k') {
        return "i";
      } else {
        throw new RuntimeException("");
      }
    } else if (before == 'k') {
      if (next == 'j') {
        return "-i";
      } else if (next == 'i') {
        return "j";
      } else {
        throw new RuntimeException("");
      }
    } else {
      throw new RuntimeException("");
    }
  }

}
