package nl.bertje.googlecodejam;

import java.io.BufferedReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class ProblemA extends Problem {

  private final Set<String> seenSets = new HashSet<>();

  public ProblemA(String problemFile) {
	super(problemFile);
  }

  @Override
  public String solveNextCase(BufferedReader br) throws IOException {
	final String input = br.readLine();
	seenSets.clear();
	final String[] split = input.split(" ");
	final List<Boolean> startingPancakes = new ArrayList<>();
	for (int i = 0; i < split[0].length(); i++) {
	  startingPancakes.add(split[0].charAt(i) == '+');
	}
	final int flipper = Integer.parseInt(split[1]);
	seenSets.add(toString(startingPancakes));

	final String output;
	final int badPancakes = countBadPancakes(startingPancakes);
	if (badPancakes == 0) {
	  output = "0";
	} else if (badPancakes == 1) {
	  output = "IMPOSSIBLE";
	} else {
	  final int flipRestNormal = flipNormal(startingPancakes, flipper);
	  final int flipRestReverse = flipReverse(startingPancakes, flipper);
	  final int minimum = determineMinumum(flipRestNormal, flipRestReverse);
	  output = (minimum == 0 ? "IMPOSSIBLE" : ("" + minimum));
	}
	return output;
  }

  private int countBadPancakes(List<Boolean> pancakes) {
	return pancakes.stream().mapToInt(i -> i ? 0 : 1).sum();
  }

  private int flipNormal(List<Boolean> pancakes, int flipper) {
	final int output;
	final int firstBadOne = pancakes.indexOf(Boolean.FALSE);
	if (firstBadOne > pancakes.size() - flipper) {
	  output = 0;
	} else {
	  final List<Boolean> flipped = flipBadPancakes(pancakes, flipper, firstBadOne);
	  final int badPancakes = countBadPancakes(flipped);
	  final String asString = toString(flipped);
	  if (badPancakes == 0) {
		output = 1;
	  } else if (badPancakes == 1 || seenSets.contains(asString)) {
		output = 0;
	  } else {
		seenSets.add(asString);
		final int flipRestNormal = flipNormal(flipped, flipper);
		final int flipRestReverse = flipReverse(flipped, flipper);
		final int minimum = determineMinumum(flipRestNormal, flipRestReverse);
		output = (minimum == 0 ? 0 : (1 + minimum));
	  }
	}
	return output;
  }

  private int flipReverse(List<Boolean> pancakes, int flipper) {
	final int output;
	final int lastBadOne = pancakes.lastIndexOf(Boolean.FALSE);
	if (lastBadOne < flipper) {
	  output = 0;
	} else {
	  final List<Boolean> flipped = flipBadPancakes(pancakes, flipper, lastBadOne - flipper + 1);
	  final int badPancakes = countBadPancakes(flipped);
	  final String asString = toString(flipped);
	  if (badPancakes == 0) {
		output = 1;
	  } else if (badPancakes == 1 || seenSets.contains(asString)) {
		output = 0;
	  } else {
		seenSets.add(asString);
		final int flipRestNormal = flipNormal(flipped, flipper);
		final int flipRestReverse = flipReverse(flipped, flipper);
		final int minimum = determineMinumum(flipRestNormal, flipRestReverse);
		output = (minimum == 0 ? 0 : (1 + minimum));
	  }
	}
	return output;
  }

  private int determineMinumum(int restNormal, int restReverse) {
	final int output;
	if (restNormal == 0 && restReverse == 0) {
	  output = 0;
	} else if (restNormal == 0) {
	  output = restReverse;
	} else if (restReverse == 0) {
	  output = restNormal;
	} else {
	  output = Math.min(restNormal, restReverse);
	}
	return output;
  }

  private List<Boolean> flipBadPancakes(List<Boolean> pancakes, int flipper, int index) {
	final List<Boolean> flipped = new ArrayList<>(pancakes);
	for (int i = index; i < index + flipper; i++) {
	  flipped.set(i, !flipped.get(i));
	}
	return flipped;
  }

  private String toString(List<Boolean> pancakes) {
	final StringBuilder builder = new StringBuilder();
	for (final Boolean value : pancakes) {
	  builder.append(value ? "1" : 0);
	}
	return builder.toString();
  }

}
