package nl.bertje.googlecodejam;

import java.io.BufferedReader;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;

public abstract class Problem {

  private static final String PROBLEM_FILE_EXTENSION = ".in";
  private static final String SOLUTION_FILE_EXTENSION = ".out";

  private final String problemFile;

  public Problem(String problemFile) {
    this.problemFile = problemFile;
  }

  public void solve() throws IOException {
    final Path path = Paths.get(problemFile + PROBLEM_FILE_EXTENSION);
    try (BufferedReader br = Files.newBufferedReader(path)) {
      final int nrOfCases = Integer.parseInt(br.readLine());
      solveCases(br);
    }
  }

  public void solveCases(BufferedReader br) throws IOException {
    int currentCase = 1;
    String currentLine;
    final List<String> solutions = new ArrayList<>();
    while ((currentLine = br.readLine()) != null) {
      final String solved = "Case #" + currentCase++ + ": " + solveCase(currentLine);
      System.out.println(solved);
      solutions.add(solved);
    }
    Files.write(Paths.get(problemFile + SOLUTION_FILE_EXTENSION), solutions);
  }

  public abstract String solveCase(String line);

}
