package nl.bertje.googlecodejam;

import java.io.BufferedReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class ProblemB extends Problem {

  public ProblemB(String problemFile) {
    super(problemFile);
  }

  @Override
  public String solveNextCase(BufferedReader br) throws IOException {
    // first line is nr of current stacks
    final int nrOfStacks = Integer.parseInt(br.readLine());
    // second line is stacks, space separated.
    // convert it to int list
    final List<Integer> stacks = getStacks(br.readLine());
    assert stacks.size() == nrOfStacks;
    // Just letting everyone eat their plate, time would be the max of the
    // stacks.
    return Integer.toString(minutesNeeded(stacks));
  }

  private List<Integer> getStacks(String line) {
    final String[] stacksAsStrings = line.split(" ");

    final List<Integer> stacks = new ArrayList<>();
    for (final String stack : stacksAsStrings) {
      stacks.add(Integer.parseInt(stack));
    }
    return stacks;
  }

  private int maxStack(List<Integer> stacks) {
    return stacks.stream().mapToInt(i -> i).max().getAsInt();
  }

  private List<Integer> eat(List<Integer> stacks) {
    final List<Integer> afterEat = new ArrayList<>();
    for (final int stack : stacks) {
      afterEat.add(stack - 1);
    }
    return afterEat;
  }

  private List<Integer> split(List<Integer> stacks) {
    final List<Integer> afterSplit = new ArrayList<>(stacks);
    final int currentMax = maxStack(stacks);
    // replace first occurrence of max with half the stack (rounding up)
    afterSplit.set(stacks.indexOf(currentMax), currentMax / 2 + currentMax % 2);
    // add the other stack as well (that's always the rounded down one.
    afterSplit.add(currentMax / 2);
    return afterSplit;
  }

  private List<Integer> splitThree(List<Integer> stacks) {
    final List<Integer> afterSplit = new ArrayList<>(stacks);
    final int currentMax = maxStack(stacks);
    // replace first occurrence of max with a third of the stack (rounding down)
    afterSplit.set(stacks.indexOf(currentMax), 2 * currentMax / 3);
    // add the other stack as well (rounded up this time).
    afterSplit.add(currentMax / 3 + currentMax % 3);
    return afterSplit;
  }

  private int minutesNeeded(List<Integer> stacks) {
    int minutesNeeded = maxStack(stacks);
    if (minutesNeeded > 2) {
      final List<Integer> afterEating = eat(stacks);
      final List<Integer> afterSplitting;
      if (minutesNeeded % 9 == 0) {
        afterSplitting = splitThree(stacks);
      } else {
        afterSplitting = split(stacks);
      }
      minutesNeeded = 1 + Math.min(minutesNeeded(afterSplitting), minutesNeeded(afterEating));
    }
    return minutesNeeded;

  }

}
