import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.DecimalFormat;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;

public class CookieClickerAlphaBig {

	static final String inputPath = "/home/bertrand/Desktop/B-large.in";
	static final String outputPath = "/home/bertrand/Desktop/B-large.out";

	static final Map<Integer, String> answers = new ConcurrentHashMap<>();

	public static void main(String[] args) throws IOException, InterruptedException {
		long beginning = System.currentTimeMillis();

		FileReader fr = new FileReader(inputPath);
		final BufferedReader br = new BufferedReader(fr);

		FileWriter fw = new FileWriter(outputPath);
		BufferedWriter bw = new BufferedWriter(fw);

		String nbCaseString = br.readLine();
		int nbCase = Integer.parseInt(nbCaseString);

		ExecutorService newCachedThreadPool = Executors.newCachedThreadPool();

		for (int i = 1; i <= nbCase; i++) {
			String readLine = br.readLine();
			newCachedThreadPool.submit(new Task(i, readLine));
		}

		newCachedThreadPool.shutdown();
		newCachedThreadPool.awaitTermination(1, TimeUnit.MINUTES);

		for (int i = 1; i <= nbCase; i++) {
			System.out.println("Case " + i);
			bw.write(String.format("Case #%s: ", i));

			String answer = answers.get(i);
			bw.write(answer);

			bw.write("\n");
		}

		bw.close();
		br.close();

		long end = System.currentTimeMillis();
		System.out.println((end - beginning) / 1000 + " s");
	}

	static class Task implements Callable<Object> {

		int indice;
		String line;

		public Task(int i, String line) {
			this.indice = i;
			this.line = line;
		}

		@Override
		public Object call() throws Exception {
			System.out.println("Run du cas " + indice);
			try {
				String answer = solve(line);
				answers.put(indice, answer);
				System.out.println("Fin du cas " + indice);
			} catch (IOException e) {
				e.printStackTrace();
			}
			return null;
		}

	}

	static final double initialCookiesPerSecond = 2;
	static final DecimalFormat df = new DecimalFormat("#.0000000");

	private static String solve(String line) throws IOException {
		String[] args = line.split(" ");
		double costForFarmC = Double.parseDouble(args[0]);
		double extraCookiesPerSecondF = Double.parseDouble(args[1]);
		double cookiesGoalX = Double.parseDouble(args[2]);

		double bestcostWithoutFarm = costWithNbFarm(0, costForFarmC, extraCookiesPerSecondF, cookiesGoalX);
		for (int nbFarm = 1; true; nbFarm++) {
			double cost = costWithNbFarm(nbFarm, costForFarmC, extraCookiesPerSecondF, cookiesGoalX);
			if (cost > bestcostWithoutFarm) {
				break;
			} else {
				bestcostWithoutFarm = cost;
			}
		}

		return df.format(bestcostWithoutFarm);
	}

	static double costWithNbFarm(int nbFarm, double costForFarmC, double extraCookiesPerSecondF, double cookiesGoalX) {
		if (nbFarm == 0) {
			return cookiesGoalX / initialCookiesPerSecond;
		}
		double time = 0;

		for (int i = 0; i < nbFarm; i++) {
			time += costForFarmC / (initialCookiesPerSecond + i * extraCookiesPerSecondF);
		}

		time += cookiesGoalX / (initialCookiesPerSecond + nbFarm * extraCookiesPerSecondF);

		return time;
	}

}
