package fr.pabeke.round1;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;

public class A {

	static final String INPUT_PATH = "/home/bertrand/Desktop/A-small-attempt1.in";
	static final String OUTPUT_PATH = "/home/bertrand/Desktop/A-small-attempt1.out";

	static final ExecutorService POOL = Executors.newSingleThreadExecutor();

	public static void main(String[] args) throws IOException, InterruptedException, ExecutionException {
		try (final BufferedReader br = new BufferedReader(new FileReader(INPUT_PATH)); final BufferedWriter bw = new BufferedWriter(new FileWriter(OUTPUT_PATH));) {
			long beginningTime = System.currentTimeMillis();
			int nbCase = Integer.parseInt(br.readLine());
			Map<Integer, Future<String>> answers = new HashMap<>();

			for (int i = 1; i <= nbCase; i++) {
				int nbLines = Integer.parseInt(br.readLine());
				List<String> lines = new ArrayList<>();
				for (int j = 0; j < nbLines; j++) {
					lines.add(br.readLine());
				}
				TestCase task = new TestCase(i, lines);
				Future<String> future = POOL.submit(task);
				answers.put(i, future);
			}

			POOL.shutdown();
			POOL.awaitTermination(1, TimeUnit.DAYS);

			for (int i = 1; i <= nbCase; i++) {
				System.out.print(String.format("Case #%s: ", i));
				bw.write(String.format("Case #%s: ", i));

				Future<String> future = answers.get(i);
				String answer = future.get();
				System.out.println(answer);
				bw.write(answer);
				bw.write("\n");
			}

			long end = System.currentTimeMillis();
			System.out.println("Solved everything in " + (end - beginningTime) / 1000 + " s");
		}
	}

	static class TestCase implements Callable<String> {

		int indice;
		List<String> lines;

		public TestCase(int i, List<String> lines) {
			this.indice = i;
			this.lines = lines;
		}

		@Override
		public String call() throws Exception {
			long beginningTime = System.currentTimeMillis();
			System.out.println("Beginning solving of test case " + indice);
			String answer = solve(lines);
			long end = System.currentTimeMillis();
			System.out.println("Finished solving of test case " + indice + " in " + (end - beginningTime) / 1000 + " s");
			return answer;
		}

		private String solve(List<String> lines) {
			// Get a map: char->nbchar of the lines
			List<List<ElementAndNb>> all = new ArrayList<>();
			for (String line : lines) {
				char[] charArray = line.toCharArray();
				List<ElementAndNb> charAndNb = new ArrayList<>();
				for (char c : charArray) {
					if (charAndNb.isEmpty()) {
						ElementAndNb el = new ElementAndNb(c, 1);
						charAndNb.add(el);
					} else {
						ElementAndNb last = charAndNb.get(charAndNb.size() - 1);
						if (last.character == c) {
							charAndNb.remove(charAndNb.size() - 1);
							ElementAndNb el = new ElementAndNb(c, last.nb + 1);
							charAndNb.add(el);
						} else {
							ElementAndNb el = new ElementAndNb(c, 1);
							charAndNb.add(el);
						}
					}
				}
				all.add(charAndNb);
			}

			// Verify possible to win
			Set<List<Character>> setCharacters = new HashSet<>();
			for (List<ElementAndNb> one : all) {
				List<Character> chars = new ArrayList<>();
				for (ElementAndNb elementAndNb : one) {
					chars.add(elementAndNb.character);
				}
				setCharacters.add(chars);
			}
			if (setCharacters.size() != 1) {
				return "Fegla Won";
			}

			// Find the max for each
			List<Character> charactersUnique = setCharacters.iterator().next();
			List<ElementAndNb> maxs = new ArrayList<>();
			for (Character character : charactersUnique) {
				ElementAndNb e = new ElementAndNb(character, 1);
				maxs.add(e);
			}
			for (List<ElementAndNb> list : all) {
				for (int i = 0; i < charactersUnique.size(); i++) {
					ElementAndNb elementAndNb = list.get(i);
					ElementAndNb max = maxs.get(i);
					if (elementAndNb.nb > max.nb) {
						maxs.remove(i);
						maxs.add(i, new ElementAndNb(elementAndNb.character, elementAndNb.nb));
					}
				}
			}

			// Find the mean
			List<ElementAndNb> mins = new ArrayList<>();
			for (Character character : charactersUnique) {
				ElementAndNb e = new ElementAndNb(character, Integer.MAX_VALUE);
				mins.add(e);
			}
			for (List<ElementAndNb> list : all) {
				for (int i = 0; i < charactersUnique.size(); i++) {
					ElementAndNb elementAndNb = list.get(i);
					ElementAndNb min = mins.get(i);
					if (elementAndNb.nb < min.nb) {
						mins.remove(i);
						mins.add(i, new ElementAndNb(elementAndNb.character, elementAndNb.nb));
					}
				}
			}

			// Get the objectif
			List<ElementAndNb> obj = new ArrayList<>();
			for (int i = 0; i < mins.size(); i++) {
				ElementAndNb max = maxs.get(i);
				ElementAndNb min = mins.get(i);

				int delta = max.nb - min.nb;
				if (delta == 0) {
					delta = 1;
				}
				ElementAndNb e = new ElementAndNb(max.character, delta);
				obj.add(e);
			}

			System.out.println(obj);

			// Compute the distance
			int distance = 0;
			for (List<ElementAndNb> list : all) {
				for (int i = 0; i < list.size(); i++) {
					ElementAndNb elementAndNb = list.get(i);
					ElementAndNb moy = obj.get(i);
					distance += Math.abs(elementAndNb.nb - moy.nb);
				}
			}
			return "" + distance;
		}
	}

	static class ElementAndNb {

		char character;
		int nb;

		public ElementAndNb(char character, int nb) {
			super();
			this.character = character;
			this.nb = nb;
		}

		@Override
		public String toString() {
			return "[" + character + "->" + nb + "]";
		}

		@Override
		public int hashCode() {
			final int prime = 31;
			int result = 1;
			result = prime * result + character;
			result = prime * result + nb;
			return result;
		}

		@Override
		public boolean equals(Object obj) {
			if (this == obj)
				return true;
			if (obj == null)
				return false;
			if (getClass() != obj.getClass())
				return false;
			ElementAndNb other = (ElementAndNb) obj;
			if (character != other.character)
				return false;
			if (nb != other.nb)
				return false;
			return true;
		}

	}

}
