import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.InputStreamReader;
import java.io.Reader;



public class RPI {

	public static void main( String[] args ) throws Exception {
		final Reader READER;
		final File FILE; // "betlista=etc/problem.in"
		final boolean DEBUG;
		long start = 0L;
		if ( args.length > 0 && args[ 0 ].startsWith( "betlista=" ) ) {
			FILE = new File( args[ 0 ].substring( "betlista=".length() ) );
		} else {
			FILE = null;
		}
		if ( FILE != null && FILE.exists() ) {
			READER = new FileReader( FILE );
			DEBUG = true;
		} else {
			READER = new InputStreamReader( System.in );
			DEBUG = false;
		}
		BufferedReader br = new BufferedReader( READER );

		if ( DEBUG )
			start = System.currentTimeMillis();

		final int T = Integer.parseInt( br.readLine() ); // CONTINUE HERE
		int n;
		String line;
		Boolean[][] m;
		for ( int i = 0; i < T; ++i ) {
			n = Integer.parseInt( br.readLine() );
			m = new Boolean[n][n];
			for ( int j = 0; j < n; ++j ) {
				line = br.readLine();
				for ( int k = 0; k < n; ++k ) {
					switch ( line.charAt( k ) ) {
						case '1': m[j][k] = true; break;
						case '0': m[j][k] = false; break;
						default: m[j][k] = null;
					}
				}
			}
			System.out.printf( "Case #%d:\n%s", i+1, solve(m) );
		}

		if ( DEBUG )
			System.out.println( System.currentTimeMillis() - start );
	}

	private static String solve( Boolean[][] m ) {
		StringBuilder buff = new StringBuilder();

		double[] wp = new double[m.length];
		for ( int i = 0; i < m.length; ++i ) {
			wp[i] = wp( m[i], null );
		}

		double[] owp = new double[m.length];
		int cnt;
		double tmp;
		for ( int i = 0; i < m.length; ++i ) {
			cnt = 0;
			for ( int j = 0; j < m.length; ++j ) {
				if ( m[i][j] != null ) {
					tmp = wp( m[j], i );
					owp[i] += tmp;
					++cnt;
				}
			}
			owp[i] /= cnt;
		}
		
		double[] oowp = new double[m.length];
		for ( int i = 0; i < m.length; ++i ) {
			cnt = 0;
			for ( int j = 0; j < m.length; ++j ) {
				if ( m[i][j] != null ) {
					tmp = owp[j];
					oowp[i] += tmp;
					++cnt;
				}
			}
			oowp[i] /= cnt;
		}
		
		for ( int i = 0; i < m.length; ++i ) {
			buff.append( rpi( wp[i], owp[i], oowp[i], m.length ) ).append( "\n" );
		}
		return buff.toString();
	}

	private static double rpi( double wpi, double owpi, double oowp, int n ) {
		return 0.25*wpi + 0.5*owpi + 0.25*oowp;
	}

	private static double wp( Boolean[] mi, Integer skip ) {
		int wpi = 0;
		double cnt = 0;
		int act = -1;
		for ( Boolean b : mi ) {
			++act;
			if ( b == null ) continue;
			if ( skip != null && skip == act ) continue;
			if ( b ) {
				++wpi;
			}			
			++cnt;
		}
		return wpi/cnt;
	}
	
	
}
