import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;
import java.util.HashSet;
import java.util.PriorityQueue;
import java.util.Set;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class RevengeOfThePancakesQuick {

	static InputStreamReader isr = new InputStreamReader(System.in, StandardCharsets.US_ASCII);
	static BufferedReader br = new BufferedReader(isr, 20 << 20);

	public static void main(String[] args) throws Exception {
		final ExecutorService es = Executors.newFixedThreadPool(5);

		Result[] res = parseInputAndCreateSolvers(es);
		
		printResults(es, res);
	}
	
	private static Result[] parseInputAndCreateSolvers(ExecutorService es) throws Exception {
		int T = Integer.parseInt(br.readLine());
		Result[] res = new Result[T];
		for (int i = 0; i < res.length; i++) {
			char[] in = br.readLine().toCharArray();
			res[i] = new Result();
			es.submit(new Solver(res[i], in));
		}
		
		return res;
	}

	private static void printResults(ExecutorService es, Result[] res) {
		es.shutdown();
		while (!es.isTerminated()) {
			try {
				Thread.sleep(1000);
			} catch (InterruptedException ie) {
				ie.printStackTrace();
			}
		}
		final StringBuilder sb = new StringBuilder();
		for (int ii = 0; ii < res.length; ii++) {
			sb.append("Case #").append(ii+1).append(": ").append(res[ii]).append('\n');
		}
		System.out.print(sb);
	}

	static class Solver extends ResultHolder {
		
		char[] in;
		
		Solver(Result res, char[] in) {
			super(res);
			this.in = in;
		}
		
		Set<String> set = new HashSet<>();
		
		@Override
		public void run() {
			set.add(new String(in));
			
			PriorityQueue<RevengeOfThePancakesQuick.State> pq = new PriorityQueue<>();
			pq.add(new RevengeOfThePancakesQuick.State(in, 0));
			while (true) {
				RevengeOfThePancakesQuick.State act = pq.poll();
				if (act.isFinal()) {
					res.steps = act.step;
					return;
				}
				addNextPossibility(pq, act);
			}
		}

		private void addNextPossibility(PriorityQueue<RevengeOfThePancakesQuick.State> pq, RevengeOfThePancakesQuick.State act) {
			char[] copy = Arrays.copyOf(act.pan, act.pan.length);
			int to = 0;
			if (act.pan[0] == '-') {
				to = copy.length - 1;
				while (to - 1 >= 0 && copy[to] == '+') --to;				
			} else {
				while (to + 1 < copy.length && copy[to+1] == '+') ++to;
			}
			pq.add(new RevengeOfThePancakesQuick.State( getNewAndFlipTo(act.pan, to), act.step + 1));
		}

		private char[] getNewAndFlipTo(char[] pan, int toIncluding) {
			char[] copy = Arrays.copyOf(pan, pan.length);
			for (int from = 0, to = toIncluding; from <= to; ++from, --to) {
				char tmp = copy[from];
				copy[from] = flip(copy[to]);
				copy[to] = flip(tmp);
			}
			return copy;
		}

		private char flip(char c) {
			return c == '+' ? '-' : '+';
		}
	}
	
	static class State implements Comparable<State> {

		char[] pan;
		int step;
		
		public State(char[] pan, int step) {
			this.pan = pan;
			this.step = step;
		}
		
		boolean isFinal() {
			for (int i = 0; i < pan.length; i++) {
				if (pan[i] == '-') {
					return false;
				}
			}
			return true;
		}
		
		@Override
		public int compareTo(State o) {
			return Integer.compare(step, o.step);
		}
	}
	
	static class ResultHolder extends Thread {
		Result res;

		public ResultHolder(Result res) {
			this.res = res;
		}
		
	}

	static class Result {
		
		int steps;
		
		@Override
		public String toString() {
			return Integer.toString(steps);
		}
	}

}
