import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class CoinJam {

	static InputStreamReader isr = new InputStreamReader(System.in, StandardCharsets.US_ASCII);
	static BufferedReader br = new BufferedReader(isr, 20 << 20);

	public static void main(String[] args) throws Exception {
		final ExecutorService es = Executors.newFixedThreadPool(5);

		Result[] res = parseInputAndCreateSolvers(es);
		
		printResults(es, res);
	}
	
	private static Result[] parseInputAndCreateSolvers(ExecutorService es) throws Exception {
		
		int T = Integer.parseInt(br.readLine());
		Result[] res = new Result[T];
		for (int i = 0; i < res.length; i++) {
			StringTokenizer st = new StringTokenizer(br.readLine());
			int N = Integer.parseInt(st.nextToken());
			int J = Integer.parseInt(st.nextToken());

			res[i] = new Result();
			es.submit(new Solver(res[i], N, J));
		}
		
		return res;
	}

	private static void printResults(ExecutorService es, Result[] res) {
		es.shutdown();
		while (!es.isTerminated()) {
			try {
				Thread.sleep(1000);
			} catch (InterruptedException ie) {
				ie.printStackTrace();
			}
		}
		final StringBuilder sb = new StringBuilder();
		for (int ii = 0; ii < res.length; ii++) {
			sb.append("Case #").append(ii+1).append(":\n").append(res[ii]);
		}
		System.out.print(sb);
	}

	static class Solver extends ResultHolder {
		
		final int N, J;
		
		Solver(Result res, int N, int J) {
			super(res);
			this.N = N;
			this.J = J;
		}
		
		@Override
		public void run() {
			int count = 0;
			long act = 1;
			for (int i = 0; i < N - 1; i++) {
				act *= 10;
			}
			do {
				act = inc(act);
				JamCoin jc = convertToJamCoin(act);
				if (jc != null) {
					res.list.add(jc);
					++count;
				}
			} while (count < J);
		}

		private long inc(long act) {
			long actBase2 = Long.parseLong(Long.toString(act), 2);
			++actBase2;
			String newActString = Long.toString(actBase2, 2);
			return Long.parseLong(newActString);
		}

		private JamCoin convertToJamCoin(long act) {
			if (act % 10 == 0) return null;
			JamCoin res = new JamCoin();
			for (int base = 2; base <= 10; base++) {
				long val = Long.parseLong(Long.toString(act), base);
				long div = isPrime(val);
				if (div != 1) {
					res.divs[base] = div; 
				} else {
					return null;
				}
			}
			res.val = act;
			return res;
		}

		private long isPrime(long val) {
			if ((val & 1) == 0) return 2;
			for (long i = 3; i * i <= val; i += 2) {
				if (val % i == 0) {
					return i;
				}
			}
			return 1;
		}
	}

	static class JamCoin {
		long val;
		long[] divs = new long[11];
	}
	
	static class ResultHolder extends Thread {
		Result res;

		public ResultHolder(Result res) {
			this.res = res;
		}
		
	}

	static class Result {
		
		List<JamCoin> list = new LinkedList<>();
		
		@Override
		public String toString() {
			StringBuilder sb = new StringBuilder();
			for (JamCoin jamCoin : list) {
				sb.append(jamCoin.val);
				for (int i = 2; i <= 10; ++i) {
					sb.append(' ').append(jamCoin.divs[i]);
				}
				sb.append('\n');
			}

			return sb.toString();
		}
	}

}
