import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.LinkedList;



public class BotTrust {

	private static final boolean DEBUG = false;

	public static void main( String[] args ) throws Exception {
		final Reader READER;
		final File FILE; // "betlista=etc/problem.in"
		final boolean DEBUG;
		long start = 0L;
		if ( args.length > 0 && args[ 0 ].startsWith( "betlista=" ) ) {
			FILE = new File( args[ 0 ].substring( "betlista=".length() ) );
		} else {
			FILE = null;
		}
		if ( FILE != null && FILE.exists() ) {
			READER = new FileReader( FILE );
			DEBUG = true;
		} else {
			READER = new InputStreamReader( System.in );
			DEBUG = false;
		}
		BufferedReader br = new BufferedReader( READER );

		if ( DEBUG )
			start = System.currentTimeMillis();

		int T = Integer.parseInt( br.readLine() );
		for ( int i = 0; i < T; ++i ) {
			System.out.printf( "Case #%d: %d\n", i+1, solve( br.readLine() ) );
		}

		if ( DEBUG )
			System.out.println( System.currentTimeMillis() - start );
	}
	
	public static int solve( String commands ) {
		Command[] commandi = parse( commands );
		
		LinkedList<Command> alist = new LinkedList<BotTrust.Command>(), olist = new LinkedList<BotTrust.Command>(), blist = new LinkedList<BotTrust.Command>();
		for ( Command command : commandi ) {
			alist.add( command );
			switch( command.robot ) {
				case 'O': olist.add( command ); break;
				case 'B': blist.add( command ); break;
				default: assert (false) : "wrong robot: " + command.robot;
			}
		}
		
		boolean orf = false, brf = false; /* Orange Robot Finished, Blue Robot Finished */
		int orp = 1, brp = 1; /* Orange Robot Position, Blue Robot Position */
		Integer ort = null, brt = null; /* Orange Robot Target, Blue Robot Target */
		if ( olist.isEmpty() ) {
			orf = true;
		} else {
			ort = olist.poll().button;
		}
		if ( blist.isEmpty() ) {
			brf = true;
		} else {
			brt = blist.poll().button;
		}
		Command ac = alist.poll();
		int res = 0;
		if (DEBUG) System.out.printf( "%d: %s %d %b %d | %d %b %d\n", res, ac, orp, orf, ort, brp, brf, brt );
		boolean pushed;
		while ( !(orf && brf) ) {
			pushed = false;
			++res;
			if ( !orf ) {
				if ( !pushed && ac.robot == 'O' && ac.button == orp ) {
					if ( DEBUG ) System.out.printf( "%s at %d\n", ac, res );
					if ( olist.isEmpty() ) {
						orf = true;
					} else {
						ort = olist.poll().button;
					}
					if ( !alist.isEmpty() ) ac = alist.poll();
					pushed = true;
				} else {
					if ( ort < orp ) {
						--orp;
					} else if (ort > orp) {
						++orp;
					}
				}
			}
			if ( !brf ) {
				if ( !pushed && ac.robot == 'B' && ac.button == brp ) {
					if ( DEBUG ) System.out.printf( "%s at %d\n", ac, res );
					if ( blist.isEmpty() ) {
						brf = true;
					} else {
						brt = blist.poll().button;
					}
					if ( !alist.isEmpty() ) ac = alist.poll(); 
				} else {
					if ( brt < brp ) {
						--brp;
					} else if (brt > brp) {
						++brp;
					}
				}
			}
			if (DEBUG) System.out.printf( "%d: %s %d %b %d | %d %b %d\n", res, ac, orp, orf, ort, brp, brf, brt );
		}
		return res;
	}
	
	private static Command[] parse( String commands ) {
		String[] parti = commands .split( " " );
		int n = Integer.parseInt( parti[0] );
		Command[] res = new Command[ n ];
		for ( int i = 0; i < n; ++i ) {
			res[i] = new Command();
			assert ( parti[2*i + 1].length() == 1 ) : "wrong command: " + parti[2*i + 1];
			res[i].robot = parti[2*i + 1].charAt( 0 );
			assert ( res[i].robot == 'B' || res[i].robot == 'O' ) : "wrong robot: " + res[i].robot ;
			res[i].button = Integer.parseInt( parti[2*i + 2] );
		}
		return res;
	}

	static class Command {
		char robot;
		int button;

		@Override
		public int hashCode() {
			final int prime = 31;
			int result = 1;
			result = prime * result + button;
			result = prime * result + robot;
			return result;
		}
		@Override
		public boolean equals( Object obj ) {
			if ( this == obj )
				return true;
			if ( obj == null )
				return false;
			if ( getClass() != obj.getClass() )
				return false;
			Command other = (Command)obj;
			if ( button != other.button )
				return false;
			if ( robot != other.robot )
				return false;
			return true;
		}
		@Override
		public String toString() {
			return String.format( "[%c, %d]", robot, button );
		}
		
	}
}
