import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.Map;



public class Magicka {

	private static boolean DEBUG = false;

	public static void main( String[] args ) throws Exception {
		final Reader READER;
		final File FILE; // "betlista=etc/problem.in"
		final boolean DEBUG;
		long start = 0L;
		if ( args.length > 0 && args[ 0 ].startsWith( "betlista=" ) ) {
			FILE = new File( args[ 0 ].substring( "betlista=".length() ) );
		} else {
			FILE = null;
		}
		if ( FILE != null && FILE.exists() ) {
			READER = new FileReader( FILE );
			DEBUG = true;
		} else {
			READER = new InputStreamReader( System.in );
			DEBUG = false;
		}
		BufferedReader br = new BufferedReader( READER );

		if ( DEBUG )
			start = System.currentTimeMillis();

		final int T = Integer.parseInt( br.readLine() );
		for ( int i = 0; i < T; ++i ) {
			System.out.printf( "Case #%d: %s\n", i+1, solve( br.readLine() ) );
		}

		if ( DEBUG )
			System.out.println( System.currentTimeMillis() - start );
	}

	static enum BE { // Base Elements
		Q,W,E,R,A,S,D,F
	}

	private static class WizardStack {

		LinkedList<Character> stack = new LinkedList<Character>();
		Map<Character, Integer> map = new HashMap<Character, Integer>();
		Character[][] comb = new Character[BE.F.ordinal() + 1][BE.F.ordinal() + 1];
		Map<Character, Character> opp = new HashMap<Character, Character>();
		
		void addCombination( char[] c ) {
			assert (c.length == 3 ) : "incorect combination " + new String(c);
			BE axis1 = mapCharToElement( c[0] );
			BE axis2 = mapCharToElement( c[1] );
			comb[ axis1.ordinal() ][ axis2.ordinal() ] = c[2];
			comb[ axis2.ordinal() ][ axis1.ordinal() ] = c[2];
		}
		
		void addOpposite( char[] o ) {
			assert (o.length == 2 ) : "incorect opposite " + new String(o);
			opp.put( o[0], o[1] );
			opp.put( o[1], o[0] );
		}

		public void invoke( char element ) {
			  if (DEBUG) System.out.printf( "invoke before: %s\n", this.toString() );
			// check combinations
			if ( isCombination( element ) ) {
				combine( element );
			} else {
				// check opposites
				if ( isOpposite( element ) ) {
					stack.clear();
					map.clear();
				} else {
					// just add
					Integer cnt = map.get( element );
					if ( cnt == null ) {
						cnt = 0;
					}
					map.put( element, cnt + 1 );
					stack.addFirst( element );
				}
			}
			  if (DEBUG) System.out.printf( "invoke after : %s\n", this.toString() );
		}
		
		boolean isCombination( char element ) {
			if ( stack.isEmpty() ) return false;
			BE i = mapCharToElement( stack.getFirst() );
			BE j = mapCharToElement( element );
			if ( i == null || j == null ) return false;
			return comb[i.ordinal()][j.ordinal()] != null;
		}

		void combine( char ec /* element character */ ) {
			char sc = stack.removeFirst(); // Stack Character

			int scc = map.get( sc );
			if ( scc == 1 ) {
				map.remove( sc );
			} else {
				map.put( sc, scc - 1 );
			}

			BE se = mapCharToElement( sc );
			BE e = mapCharToElement( ec );
			char res = comb[ se.ordinal() ][ e.ordinal() ];
			stack.addFirst( res );
		}

		boolean isOpposite( char e ) {
			Character c = opp.get( e );
			if ( c == null ) return false;
			Integer o = map.get( c );
			return o != null;
		}

		BE mapCharToElement( char c ) {
			switch ( c ) {
				case 'Q': return BE.Q;
				case 'W': return BE.W;
				case 'E': return BE.E;
				case 'R': return BE.R;
				case 'A': return BE.A;
				case 'S': return BE.S;
				case 'D': return BE.D;
				case 'F': return BE.F;
				default:
					return null;
			}
		}
		
		@Override
		public String toString() {
			StringBuilder buff = new StringBuilder( "[" );

			Iterator<Character> iter = stack.descendingIterator();
			if ( iter.hasNext() ) {
				buff.append( iter.next() );
			}
			while ( iter.hasNext() ) {
				buff.append( ", " ).append( iter.next() );
			}
			buff.append( ']' );
			return buff.toString();
		}
	}
	
	
	public static String solve( String input ) {
		WizardStack ws = new WizardStack();

		String[] pi = input.split( " " );
		int index = 0;
		int cc = Integer.parseInt( pi[index++] ); /* Combinations Count */
		for ( int i = 0; i < cc; ++i ) {
			ws.addCombination( pi[index++].toCharArray() );
		}
		int oc = Integer.parseInt( pi[index++] ); /* Opposites Count */
		for ( int i = 0; i < oc; ++i ) {
			ws.addOpposite( pi[index++].toCharArray() );
		}
		char[] elements = pi[++index].toCharArray();
		for ( char element : elements ) {
			ws.invoke( element );
		}
		
		return ws.toString();
	}
}
