import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.LinkedList;



public class CandySplitting {

	private static final int MAX_BINARY_LENGTH = 20;
	private static final boolean DEBUG = false;

	public static void main( String[] args ) throws Exception {
		final Reader READER;
		final File FILE; // "betlista=etc/problem.in"
		final boolean DEBUG;
		long start = 0L;
		if ( args.length > 0 && args[ 0 ].startsWith( "betlista=" ) ) {
			FILE = new File( args[ 0 ].substring( "betlista=".length() ) );
		} else {
			FILE = null;
		}
		if ( FILE != null && FILE.exists() ) {
			READER = new FileReader( FILE );
			DEBUG = true;
		} else {
			READER = new InputStreamReader( System.in );
			DEBUG = false;
		}
		BufferedReader br = new BufferedReader( READER );

		if ( DEBUG )
			start = System.currentTimeMillis();

		int T = Integer.parseInt( br.readLine() );
		for ( int i = 0; i < T; ++i ) {
			br.readLine(); // ignore line
			System.out.printf( "Case #%d: %s\n", i + 1, solve( conv( br.readLine().split( " " ) ) ) );
		}

		if ( DEBUG )
			System.out.println( System.currentTimeMillis() - start );
	}
	
	public static String solve( int[] conv ) {
		final int n = conv.length;

		Integer res = null;
		final LinkedList<Integer> p = new LinkedList<Integer>(), s = new LinkedList<Integer>();
		for ( int i = 1; i < 1<<n; ++i ) {
			p.clear();
			s.clear();
			for ( int j = 0; j < n; ++j ) {
				if ( (i & (1<<j)) > 0 ) {
					p.add( conv[j] );
				} else {
					s.add( conv[j] );
				}
			}
			if (DEBUG) System.out.printf( "p=%s\ns=%s\n", p, s );
			if ( patrickSum( p ) == patrickSum( s ) ) {
				int sum = sum( s );
				if ( res == null || res < sum ) res = sum;
			}
		}
		if ( res == null ) return "NO";
		return res.toString();
	}

	private static int patrickSum( LinkedList<Integer> p ) {
		int res = 0;
		for ( Integer x : p ) {
			res = patrickSum( res, x );
		}
		if (DEBUG) System.out.printf( "psum(%s)=%d\n", p, res );
		return res;
	}

	static int patrickSum( int a, int b ) {
		char[] sa = addZeros(Integer.toString( a, 2 )).toCharArray();
		char[] sb = addZeros(Integer.toString( b, 2 )).toCharArray();
		char[] sum = new  char[MAX_BINARY_LENGTH];
		for ( int i = 0; i < MAX_BINARY_LENGTH; ++i ) {
			if ( sa[i] == '0' && sb[i] == '0' ) sum[i] = '0';
			if ( sa[i] == '0' && sb[i] == '1' ) sum[i] = '1';
			if ( sa[i] == '1' && sb[i] == '0' ) sum[i] = '1';
			if ( sa[i] == '1' && sb[i] == '1' ) sum[i] = '0';
		}
		int res = toInt(sum);
		if (DEBUG) System.out.printf( "psum(%d, %d)=%d\n", a, b, res );
		return res;
	}

	private static int toInt( char[] sum ) {
		assert( sum[0] == '0' || sum[0] == '1' ) : "wrong binary digit: " + sum[0] ;
		int res = sum[0] - '0';
		for ( int i = 1; i < sum.length; ++i ) {
			assert( sum[i] == '0' || sum[i] == '1' ) : "wrong binary digit: " + sum[i] ;
			res = 2*res + sum[i] - '0';
		}
		return res;
	}

	private static String addZeros( String string ) {
		StringBuilder buff = new StringBuilder( string );
		while ( buff.length() < MAX_BINARY_LENGTH ) { // 2^20 < 1000000
			buff.insert( 0, '0' );
		}
		return buff.toString();
	}

	private static int sum( LinkedList<Integer> s ) {
		int res = 0;
		for ( Integer x : s ) {
			res += x;
		}
		return res;
	}

	private static int[] conv( String[] si ) {
		int[] res = new int[ si.length ];
		for ( int i = 0; i < si.length; ++i ) {
			res[ i ] = Integer.parseInt( si[i] );
		}
		return res;
	}
}
