import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;
import java.util.StringTokenizer;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class C_BFF {

	static InputStreamReader isr = new InputStreamReader(System.in, StandardCharsets.US_ASCII);
	static BufferedReader br = new BufferedReader(isr, 20 << 20);

	public static void main(String[] args) throws Exception {
		final ExecutorService es = Executors.newFixedThreadPool(5);

		Result[] res = parseInputAndCreateSolvers(es);
		
		printResults(es, res);
	}
	
	private static Result[] parseInputAndCreateSolvers(ExecutorService es) throws Exception {
		
		int T = Integer.parseInt(br.readLine());
		Result[] res = new Result[T];
		for (int i = 0; i < res.length; i++) {
			int N = Integer.parseInt(br.readLine());
			
			StringTokenizer st = new StringTokenizer(br.readLine());
			int[] bff = new int[N];
			for (int j = 0; j < N; j++) {
				bff[j] = Integer.parseInt(st.nextToken()) - 1;
			}
			
			res[i] = new Result();
			es.submit(new Solver(res[i], N, bff));
		}
		
		return res;
	}

	private static void printResults(ExecutorService es, Result[] res) {
		es.shutdown();
		while (!es.isTerminated()) {
			try {
				Thread.sleep(1000);
			} catch (InterruptedException ie) {
				ie.printStackTrace();
			}
		}
		final StringBuilder sb = new StringBuilder();
		for (int ii = 0; ii < res.length; ii++) {
			sb.append("Case #").append(ii+1).append(": ").append(res[ii]).append('\n');
		}
		System.out.print(sb);
	}

	static class Solver extends ResultHolder {
		
		int N;
		int[] bff;
		
		Solver(Result res, int N, int[] bff) {
			super(res);
			this.N = N;
			this.bff = bff;
		}
		
		@Override
		public void run() {
			for (int length = N; length > 0; --length) {
				int[] stud = tryAllWithLength(length);
				if (stud != null) {
					res.max = length;
					return;
				}
			}
		}

		private int[] tryAllWithLength(int length) {
			for (int mask = 0; mask < 1 << N; mask++) {
				if (Integer.bitCount(mask) == length) {
					int[] stud = new int[length];
					int si = 0;
					for (int i = 0; i < N; i++) {
						if ( (mask & (1 << i)) > 0) {
							stud[si++] = i;
						}
					}
					if (isOk(stud)) {
						return stud;
					}
				}
			}
			return null;
		}

		private boolean isOk(int[] stud) {
			// bff next to each student?
			int[] p = Arrays.copyOf(stud, stud.length);
			if (bffsOk(p)) {
				return true;
			}
			while (next_permutation(p)) {
				if (bffsOk(p)) {
					return true;
				}
			}
			return false;
		}

		private boolean bffsOk(int[] p) {
			// I have student indexes and their position
			for (int i = 0; i < p.length; i++) {
				int l = pos(p, i - 1);
				int r = pos(p, i + 1);
				if (bff[p[i]] != l && bff[p[i]] != r) {
					return false;
				}
			}
			return true;
		}

		private int pos(int[] p, int idx) {
			int nidx = (idx + p.length)%p.length;
			return p[nidx];
		}
	}
	
	// C++ next_permutation() analog in Java
	static boolean next_permutation(int[] p) {
		for (int a = p.length - 2; a >= 0; --a)
			if (p[a] < p[a + 1])
				for (int b = p.length - 1;; --b)
					if (p[b] > p[a]) {
						int t = p[a];
						p[a] = p[b];
						p[b] = t;
						for (++a, b = p.length - 1; a < b; ++a, --b) {
							t = p[a];
							p[a] = p[b];
							p[b] = t;
						}
						return true;
					}
		return false;
	}
	
	static class ResultHolder extends Thread {
		Result res;

		public ResultHolder(Result res) {
			this.res = res;
		}
		
	}

	static class Result {
		
		int max;
		
		@Override
		public String toString() {
			return Integer.toString(max);
		}
	}
}
