import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;
import java.util.StringTokenizer;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class A_SenateEvacuation {

	static InputStreamReader isr = new InputStreamReader(System.in, StandardCharsets.US_ASCII);
	static BufferedReader br = new BufferedReader(isr, 20 << 20);

	public static void main(String[] args) throws Exception {
		final ExecutorService es = Executors.newFixedThreadPool(5);

		Result[] res = parseInputAndCreateSolvers(es);
		
		printResults(es, res);
	}
	
	private static Result[] parseInputAndCreateSolvers(ExecutorService es) throws Exception {
		
		int T = Integer.parseInt(br.readLine());
		Result[] res = new Result[T];
		for (int i = 0; i < res.length; i++) {
			
			int N = Integer.parseInt(br.readLine());
			
			StringTokenizer st = new StringTokenizer(br.readLine());
			int cnts[] = new int[N];
			for (int j = 0; j < N; j++) {
				cnts[j] = Integer.parseInt(st.nextToken());
			}
			
			res[i] = new Result();
			es.submit(new Solver(res[i], N, cnts));
		}
		
		return res;
	}

	private static void printResults(ExecutorService es, Result[] res) {
		es.shutdown();
		while (!es.isTerminated()) {
			try {
				Thread.sleep(1000);
			} catch (InterruptedException ie) {
				ie.printStackTrace();
			}
		}
		final StringBuilder sb = new StringBuilder();
		for (int ii = 0; ii < res.length; ii++) {
			sb.append("Case #").append(ii+1).append(":").append(res[ii]).append('\n');
		}
		System.out.print(sb);
	}

	static class Solver extends ResultHolder {
		
		int N;
		int[] cnts;
		
		Solver(Result res, int N, int[] cnts) {
			super(res);
			this.N = N;
			this.cnts = cnts;
		}
		
		@Override
		public void run() {
			check();
			int allCnt = getAllCount();
			while (allCnt > 0) {
				if (allCnt == 2) {
					check2();
					addLastTwo();
					return;
				} else if (allCnt == 3) {
					check3();
					addOne();
					addLastTwo();
					return;
				} else {
					removeMaxTwo();
					allCnt -= 2;
					check();
				}
			}
		}

		private void removeMaxTwo() {
			int[] copy = Arrays.copyOf(cnts, N);
			Arrays.sort(copy);
			int max1 = copy[N-1];
			int max2 = copy[N-2];
			
			int i1 = -1, i2 = -1;
			for (int i = 0; i < N; i++) {
				if (cnts[i] == max1) {
					if (i1 == -1) i1 = i;
					else i2 = i; // same max
				} else if (cnts[i] == max2) {
					i2 = i;
				}
			}
			res.add(i1, i2);
			cnts[i1] -= 1;
			cnts[i2] -= 1;
		}

		private void addOne() {
			for (int i = 0; i < N; i++) {
				if (cnts[i] > 0) {
					res.add(i);
					cnts[i] -= 1;
					return;
				}
			}
		}

		private void addLastTwo() {
			int i1 = - 1, i2 = -1;
			for (int i = 0; i < N; i++) {
				if (cnts[i] > 0) {
					if (i1 == -1) i1 = i;
					else if (i2 == -1) i2 = i;
					else throw new IllegalStateException(i1 + " " + i2 + " " + i + ": " + Arrays.toString(cnts));
				}
			}
			res.add(i1, i2);
		}

		private void check() {
			int max = cnts[0];
			int cnt = 0;
			
			for (int i = 0; i < N; i++) {
				cnt += cnts[i];
				if (cnts[i] > max) {
					max = cnts[i];
				}
			}
			
			if (max > cnt/2.0) {
				throw new IllegalStateException(Arrays.toString(cnts));
			}
		}

		private void check2() {
			int cnt = 0;
			for (int i = 0; i < N; i++) {
				if (cnts[i] == 2) {
					throw new IllegalStateException(Arrays.toString(cnts));
				}
				cnt += cnts[i];
			}
			if (cnt != 2) {
				throw new IllegalStateException(Integer.toString(cnt));
			}
		}

		private void check3() {
			int cnt = 0;
			for (int i = 0; i < N; i++) {
				if (cnts[i] == 2) {
					throw new IllegalStateException(Arrays.toString(cnts));
				}
				if (cnts[i] == 3) {
					throw new IllegalStateException(Arrays.toString(cnts));
				}
				cnt += cnts[i];
			}
			if (cnt != 3) {
				throw new IllegalStateException(Integer.toString(cnt));
			}
		}

		private int getAllCount() {
			int res = 0;
			for (int i = 0; i < N; i++) {
				res += cnts[i];
			}
			return res;
		}
	}
	
	static class ResultHolder extends Thread {
		Result res;

		public ResultHolder(Result res) {
			this.res = res;
		}
		
	}

	static class Result {
		
		StringBuilder sb = new StringBuilder();
		
		@Override
		public String toString() {
			return sb.toString();
		}

		public void add(int i1) {
			sb.append(' ');
			sb.append((char)('A' + i1));
		}
		
		public void add(int i1, int i2) {
			sb.append(' ');
			sb.append((char)('A' + i1));
			sb.append((char)('A' + i2));
		}
	}
}
