import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class B_RankAndFile {

	static InputStreamReader isr = new InputStreamReader(System.in, StandardCharsets.US_ASCII);
	static BufferedReader br = new BufferedReader(isr, 20 << 20);

	public static void main(String[] args) throws Exception {
		final ExecutorService es = Executors.newFixedThreadPool(5);

		Result[] res = parseInputAndCreateSolvers(es);
		
		printResults(es, res);
	}
	
	private static Result[] parseInputAndCreateSolvers(ExecutorService es) throws Exception {
		
		int T = Integer.parseInt(br.readLine());
		Result[] res = new Result[T];
		for (int i = 0; i < res.length; i++) {
			int N = Integer.parseInt(br.readLine());
			int[][] lists = new int[2*N-1][N];
			for (int j = 0; j < 2*N - 1; j++) {
				StringTokenizer st = new StringTokenizer(br.readLine());
				for (int c = 0; c < N; c++) {
					lists[j][c] = Integer.parseInt(st.nextToken());
				}
			}
			res[i] = new Result();
			es.submit(new Solver(res[i], N, lists));
		}
		
		return res;
	}

	private static void printResults(ExecutorService es, Result[] res) {
		es.shutdown();
		while (!es.isTerminated()) {
			try {
				Thread.sleep(1000);
			} catch (InterruptedException ie) {
				ie.printStackTrace();
			}
		}
		final StringBuilder sb = new StringBuilder();
		for (int ii = 0; ii < res.length; ii++) {
			sb.append("Case #").append(ii+1).append(": ").append(res[ii]).append('\n');
		}
		System.out.print(sb);
	}

	static class Solver extends ResultHolder {
		
		int N;
		int[][] lists;
		
		Solver(Result res, int N, int[][] lists) {
			super(res);
			this.N = N;
			this.lists = lists;
		}
		
		@Override
		public void run() {
			for (int mask = 0; mask < 1 << (2*N - 1); mask++) {
				// select columns
				if (Integer.bitCount(mask) == N) {
					int[][] mat = new int[N][N];
					int ac = 0;
					int pos = 0;
					while (ac < N) {
						if ((mask & (1 << pos)) > 0) {
							setColumn(N, mat, ac++, lists[pos]);
						}
						pos++;
					}
					//sort columns
					sort(N, mat);
					if (isOk(N, mat)) {
//						System.out.println(mat);
						String missing = findMissing(lists, mat);
						if (missing != null) {
							res.s = missing;
						} else {
							// skip
						}
					}
				}
			}
		}

		Comparator<int[]> arrayComparator = new Comparator<int[]>() {
			@Override
			public int compare(int[] arr1, int[] arr2) {
				return Integer.compare(arr1[0], arr2[0]);
			}
		};
		
		private void sort(int N, int[][] mat) {
			ArrayList<int[]> cols = new ArrayList<>(N);
			for (int ci = 0; ci < mat.length; ci++) {
				int[] col = new int[N];
				for (int ri = 0; ri < N; ri++) {
					col[ri] = mat[ri][ci];
				}
				cols.add(col);
			}
			cols.sort(arrayComparator);
			setBack(mat, cols);
		}

		private void setBack(int[][] mat, ArrayList<int[]> cols) {
			for (int ci = 0; ci < cols.size(); ci++) {
				int[] col = cols.get(ci);
				for (int ri = 0; ri < mat.length; ri++) {
					mat[ri][ci] = col[ri];
				}
			}
		}

		private boolean isOk(int N, int[][] mat) {
			for (int ri = 0; ri < N; ri++) {
				for (int ci = 1; ci < mat.length; ci++) {
					if (mat[ri][ci] <= mat[ri][ci-1]) {
						return false;
					}
				}
			}
			for (int ci = 0; ci < N; ci++) {
				for (int ri = 1; ri < mat.length; ri++) {
					if (mat[ri][ci] <= mat[ri-1][ci]) {
						return false;
					}
				}
			}
			return true;
		}

		private String findMissing(int[][] lists, int[][] mat) {
			List<String> weHave = new LinkedList<>();
			for (int ri = 0; ri < mat.length; ri++) {
				weHave.add(toString(mat[ri]));
			}
			for (int ci = 0; ci < mat.length; ci++) {
				weHave.add(colToString(N, mat, ci));
			}
			int miss = 0;
			for (int[] list : lists) {
				String s = toString(list);
				if (weHave.contains(s)) {
					weHave.remove(s);
				} else {
					if (miss == 1) {
//						System.out.println("ERROR 1");
					} else {
//						System.out.println(s);
					}
					++miss;
				}
			}
			if (weHave.size() != 1) {
//				System.out.println("ERROR 2");
				return null;
			}
			return weHave.iterator().next();
		}

		private String colToString(int N, int[][] mat, int ci) {
			int[] col = new int[N];
			for (int ri = 0; ri < N; ri++) {
				col[ri] = mat[ri][ci];
			}
			return toString(col);
		}

		private String toString(int[] list) {
			StringBuilder sb = new StringBuilder();
			sb.append(list[0]);
			for (int i = 1; i < list.length; i++) {
				sb.append(' ').append(list[i]);
			}
			return sb.toString();
		}

		private void setColumn(int N, int[][] mat, int coli, int[] arr) {
			for (int i = 0; i < N; i++) {
				mat[i][coli] = arr[i];
			}
		}
	}
	
	static class ResultHolder extends Thread {
		Result res;

		public ResultHolder(Result res) {
			this.res = res;
		}
		
	}

	static class Result {
		
		String s;
		
		@Override
		public String toString() {
			return s;
		}
	}
}
