import java.io.PrintWriter;
import java.util.Scanner;
import java.util.Set;
import java.util.StringTokenizer;
import java.util.TreeSet;

public class Solution {

	public void process(Scanner scan) {
		int i, j, k;
		int T, featureCount;
		int L, N;
		DecisionTree solver = new DecisionTree();
		String featureString;
		StringTokenizer tokenizer;
		StringBuilder tree = null;
		Set<String> features = new TreeSet<String>();
		PrintWriter writer = new PrintWriter(System.out);

		T = Integer.parseInt(scan.nextLine());
		for (i = 0; i < T; ++i) {
			writer.format("Case #%d:\n", i + 1);
			L = Integer.parseInt(scan.nextLine());
			tree = new StringBuilder();
			for (j = 0; j < L; ++j) {
				tree.append(scan.nextLine());
			}
			solver.initTree(tree.toString().trim());
			N = Integer.parseInt(scan.nextLine());

			for (j = 0; j < N; ++j) {
				features.clear();
				featureString = scan.nextLine();
				tokenizer = new StringTokenizer(featureString);
				tokenizer.nextToken();
				featureCount = Integer.parseInt(tokenizer.nextToken());
				for (k = 0; k < featureCount; ++k) {
					features.add(tokenizer.nextToken());
				}
				writer.format("%s\n", String.format("%.6f",
						solver.getProbability(features)).replace(',', '.'));
				writer.flush();
			}
		}
		writer.flush();
		writer.close();
	}

	public static void main(String args[]) {

		Scanner scan = new Scanner(System.in);
		Solution solution = new Solution();
		solution.process(scan);
	}
}

class Node {
	public double probability;
	public String name;
	public Node left, right;

	public Node(double probability, String name) {
		this.name = name;
		this.probability = probability;
		this.name = name;
	}
}

class DecisionTree {

	private Node parseNode(String text) {
		int i, j, count, k;
		Node currentNode = null;
		StringTokenizer tokenizer;
		double probability;
		String name;

		for (i = 1; i < text.length(); ++i) {
			if (text.charAt(i) == '(') {
				tokenizer = new StringTokenizer(text.substring(1, i));
				probability = Double.parseDouble(tokenizer.nextToken());
				name = tokenizer.hasMoreTokens() ? tokenizer.nextToken() : "";
				currentNode = new Node(probability, name);
				count = 1;
				for (j = i + 1; count > 0; ++j) {
					if (text.charAt(j) == '(') {
						++count;
					}
					if (text.charAt(j) == ')') {
						--count;
					}
				}
				currentNode.left = parseNode(text.substring(i, j));

				for (; text.charAt(j) != '('; ++j)
					;
				k = j;

				count = 1;
				for (j = k + 1; count > 0; ++j) {
					if (text.charAt(j) == '(') {
						++count;
					}
					if (text.charAt(j) == ')') {
						--count;
					}
				}
				currentNode.right = parseNode(text.substring(k, j));
				return currentNode;
			}
			if (text.charAt(i) == ')') {
				break;
			}
		}
		if (currentNode == null) {
			tokenizer = new StringTokenizer(text
					.substring(1, text.length() - 1));
			probability = Double.parseDouble(tokenizer.nextToken());
			name = tokenizer.hasMoreTokens() ? tokenizer.nextToken() : "";
			currentNode = new Node(probability, name);
		}
		return currentNode;
	}

	public void initTree(String tree) {
		root = parseNode(tree);
	}

	public double getProbability(Set<String> featureSet) {
		double probability = 1;
		Node ptr = root;
		while (ptr != null) {
			probability *= ptr.probability;
			if ((ptr.left != null) && (ptr.right != null)) {
				if (featureSet.contains(ptr.name)) {
					ptr = ptr.left;
				}
				else {
					ptr = ptr.right;
				}
			}
			else {
				break;
			}
		}
		return probability;
	}

	private Node root;
}