import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.io.StreamTokenizer;
import java.util.ArrayDeque;
import java.util.ArrayList;

import javax.swing.plaf.SliderUI;

public class Solution {

	public void prepare(StreamTokenizer tokenizer) {
		tokenizer.ordinaryChars('0', '9');
		tokenizer.wordChars('0', '9');
	}

	public void process(StreamTokenizer tokenizer) {
		int testCount, i, j;
		int T, H, W;
		WaterShedsSolver problemSolver = new WaterShedsSolver();
		PrintWriter writer = new PrintWriter(System.out);
		int[][] altitudeMatrix;
		char[][] drainageBasinMathrix;

		try {
			tokenizer.nextToken();
			if (tokenizer.ttype == StreamTokenizer.TT_WORD) {
				T = Integer.parseInt(tokenizer.sval);

				for (testCount = 1; testCount <= T; ++testCount) {

					tokenizer.nextToken();
					if (tokenizer.ttype == StreamTokenizer.TT_WORD) {
						H = Integer.parseInt(tokenizer.sval);

						tokenizer.nextToken();
						if (tokenizer.ttype == StreamTokenizer.TT_WORD) {
							W = Integer.parseInt(tokenizer.sval);

							altitudeMatrix = new int[H][W];
							for (i = 0; i < H; ++i) {
								for (j = 0; j < W; ++j) {
									tokenizer.nextToken();
									if (tokenizer.ttype == StreamTokenizer.TT_WORD) {
										altitudeMatrix[i][j] = Integer
												.parseInt(tokenizer.sval);
									} else
										break;
								}
								if (j < W) {
									break;
								}
							}
							if (i < H) {
								break;
							}

							writer.format("Case #%d:\n", testCount);
							drainageBasinMathrix = problemSolver
									.getDrainageBasinMathrix(H, W,
											altitudeMatrix);
							for (i = 0; i < H; ++i) {
								writer.print(drainageBasinMathrix[i][0]);
								for (j = 1; j < W; ++j) {
									writer.print(" "
											+ drainageBasinMathrix[i][j]);
								}
								writer.print("\n");
							}
							writer.flush();
						}
					}
				}
			}
		} catch (NumberFormatException e) {
		} catch (IOException e) {
		} finally {
			writer.flush();
			writer.close();
		}
	}

	public static void main(String args[]) {
		try {
			BufferedReader reader = new BufferedReader(new InputStreamReader(
					System.in));
			StreamTokenizer tokenizer = new StreamTokenizer(reader);
			Solution solution = new Solution();
			solution.prepare(tokenizer);
			solution.process(tokenizer);
			reader.close();
		} catch (IOException e) {

		}
	}
}

class Position {
	int row, col;

	public Position(int row, int col) {
		this.row = row;
		this.col = col;
	}

	public int getRow() {
		return row;
	}

	public void setRow(int row) {
		this.row = row;
	}

	public int getCol() {
		return col;
	}

	public void setCol(int col) {
		this.col = col;
	}

}

class WaterShedsSolver {

	private Position findSink(int row, int col, int H, int W, int[][] altitude) {
		int i;
		int nearRow, nearCol;
		int nextRow, nextCol;
		boolean findNextCell;
		boolean sinkStatus = true;
		int minAltitude;

		findNextCell = true;
		nextRow = row;
		nextCol = col;
		while (findNextCell) {
			findNextCell = false;
			minAltitude = altitude[row][col];
			for (i = 0; i < 4; ++i) {
				nearRow = row + DIR_OFFSET[i][0];
				nearCol = col + DIR_OFFSET[i][1];
				if ((nearRow >= 0) && (nearRow < H)) {
					if ((nearCol >= 0) && (nearCol < W)) {
						if (minAltitude > altitude[nearRow][nearCol]) {
							minAltitude = altitude[nearRow][nearCol];
							findNextCell = true;
							nextRow = nearRow;
							nextCol = nearCol;
						}
					}
				}
			}
			row = nextRow;
			col = nextCol;
		}
		return new Position(row, col);
	}
	
	private boolean isWaterMovesFromFirstToSecondCell(int H, int W,
			int firstCellRow, int firstCellColumn, int secondCellRow,
			int secondCellColumn, int[][] altitude) {
		int sinkRow = firstCellRow;
		int sinkCol = firstCellColumn;
		int nearRow, nearCol;
		int minAltitude = altitude[firstCellRow][firstCellColumn];
		int i;
		
		for (i = 0; i < 4; ++i) {
			nearRow = firstCellRow + DIR_OFFSET[i][0];
			nearCol = firstCellColumn + DIR_OFFSET[i][1];
			if ((nearRow >= 0) && (nearRow < H)) {
				if ((nearCol >= 0) && (nearCol < W)) {
					if (minAltitude > altitude[nearRow][nearCol]) {
						minAltitude = altitude[nearRow][nearCol];
						sinkRow = nearRow;
						sinkCol = nearCol;
					}
				}
			}
		}
		return ((sinkRow == secondCellRow) && (sinkCol == secondCellColumn));
	}

	private void fillDrainageBasin(int row, int col, int H, int W,
			int[][] altitude, char[][] drainageBasinMatrix,
			char drainageBasinLetter) {
		int i;
		ArrayDeque<Integer> rowDeque = new ArrayDeque<Integer>(2 * W + 2 * H);
		ArrayDeque<Integer> colDeque = new ArrayDeque<Integer>(2 * W + 2 * H);
		int currentRow, currentCol;
		int nextCellRow, nextCellCol;

		rowDeque.add(row);
		colDeque.add(col);
		drainageBasinMatrix[row][col] = drainageBasinLetter;
		while (!rowDeque.isEmpty()) {
			currentRow = rowDeque.poll();
			currentCol = colDeque.poll();
			for (i = 0; i < 4; ++i) {
				nextCellRow = currentRow + DIR_OFFSET[i][0];
				nextCellCol = currentCol + DIR_OFFSET[i][1];
				if ((nextCellRow >= 0) && (nextCellRow < H)) {
					if ((nextCellCol >= 0) && (nextCellCol < W)) {
						if (isWaterMovesFromFirstToSecondCell(H, W, nextCellRow,
								nextCellCol, currentRow, currentCol, altitude)) {
							if (drainageBasinMatrix[nextCellRow][nextCellCol] != drainageBasinLetter) {
								drainageBasinMatrix[nextCellRow][nextCellCol] = drainageBasinLetter;
								rowDeque.add(nextCellRow);
								colDeque.add(nextCellCol);
							}
						}
					}
				}
			}
		}
	}

	public char[][] getDrainageBasinMathrix(int H, int W, int[][] altitude) {
		int i, j;
		char[][] drainageBasinMatrix = new char[H][W];
		Position sink;
		char drainageLetter = 'a';

		for (i = 0; i < H; ++i) {
			for (j = 0; j < W; ++j) {
				if (drainageBasinMatrix[i][j] == 0) {
					sink = findSink(i, j, H, W, altitude);
					fillDrainageBasin(sink.getRow(), sink.getCol(), H, W,
							altitude, drainageBasinMatrix, drainageLetter);
					++drainageLetter;
				}
			}
		}
		return drainageBasinMatrix;
	}

	private static final int[][] DIR_OFFSET = { { -1, 0 }, { 0, -1 }, { 0, 1 },
			{ 1, 0 }, };
}
