package code.google.codejam2k12.qualfication;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;

public class Language {
	private static final BufferedReader BR=new BufferedReader(new InputStreamReader(System.in));
	
	private static final int SMALL_ALPHABETS = 26;
	private static final char[] mappings = new char[SMALL_ALPHABETS];
	
	private static final String MAPPING_FILE = "Mappings";
	
	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		Language l = new Language();
		//l.findMappings();
		l.doStuff();
	}

	private void findMappings() throws IOException {
		loadMappings();
		System.out.println("Input G text: ");
		String g = BR.readLine();

		System.out.println("Input E text: ");
		String e = BR.readLine();
		
		if(g.length() != e.length()){
			throw new IllegalArgumentException("Strings not of same size");
		}
		
		for(int i=0;i<e.length();i++){
			char ce = e.charAt(i);
			char cg = g.charAt(i);
			
			if(ce < 'a' || ce > 'z'){
				continue;
			}
			
			if(mappings[charToIndex(cg)] == 0){
				mappings[charToIndex(cg)] = ce;
				continue;
			}
			
			if(mappings[charToIndex(cg)] != ce){
				throw new IllegalArgumentException("Conflicting maping found: [" + ce + "->" + cg + "]" + ", " +
						"[" + mappings[charToIndex(cg)] + "->" + cg + "]" );
			}
		}
		
		persistMappings();
	}

	private void persistMappings() throws IOException {
		FileWriter fw = new FileWriter(MAPPING_FILE);
		
		System.out.println("Writing...");
		for(int i=0;i<SMALL_ALPHABETS;i++){
			char ce = mappings[i];
			if(ce != 0){
				char cg = indexToChar(i);
				System.out.println(ce+"->"+cg);
				fw.write(ce +  " " + cg + '\n');
			}
		}
		
		fw.close();
	}

	private void doStuff() throws IOException {
		loadMappings();
		int N = readInteger();
		
		int i = 1;
		FileWriter fw = new FileWriter("Output");
		do{
			String g = BR.readLine();
			String o = "Case #" + i +": " + toEnglish(g);
			System.out.println(o);
			fw.write(o + '\n');
		}while(++i <= N);
		fw.close();
	}

	private String toEnglish(String g) {
		StringBuilder sb = new StringBuilder(g.length());
		
		for(int i=0;i<g.length();i++){
			char gch = g.charAt(i);
			if(gch >= 'a' && gch<='z'){
				sb.append(mappings[charToIndex(gch)]);
			}else{
				sb.append(gch);
			}
		}
		return sb.toString();
	}

	private int readInteger() throws NumberFormatException, IOException{
		return Integer.parseInt(BR.readLine());
	}
	
	private void loadMappings() throws IOException {
		//printCwd();
		FileReader fr = new FileReader(MAPPING_FILE);
		BufferedReader br=new BufferedReader(fr);
		
		String line;
		int size = 0;
		while((line = br.readLine()) != null){
			char ce = line.charAt(0);
			char cg = line.charAt(2);
			//System.out.println(ce+"->"+cg);
			mappings[charToIndex(cg)] = ce;
			size++;
		}
		
	//	System.out.println("Found " + size + " mappings...");
		fr.close();
	}

	private void printCwd() {
		File f = new File(".");
		System.out.println("cwd: " + f.getAbsolutePath());
	}

	private int charToIndex(char c){
		return c - 'a';
	}
	
	private char indexToChar(int i){
		return (char) ('a' + i);
	}
}
