import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.StringTokenizer;


public class TicTacToe {
	/**
	 * Input Output Stream Initilization
	 */
	
	private static  BufferedReader fileReader = null;
	
	private static BufferedWriter fileWriter = null;
	
	private static void createReader(String fileName) throws IOException{
		fileReader = new BufferedReader(new FileReader(new File(fileName)));
	}
	
	private static void createWriter(String fileName) throws IOException{
		fileWriter = new BufferedWriter(new FileWriter(new File(fileName)));
	}
	
	private static void close() throws IOException{
		if(fileReader != null){
			fileReader.close();
		}
		if(fileWriter != null){
			fileWriter.close();
		}
	}
	
	private static String readLine() throws IOException{
		return fileReader.readLine();
	}
	
	private static ArrayList<Integer> getIntTokens() throws IOException{
		return getIntTokens(readLine()," ");
	}
	
	private static ArrayList<Integer> getIntTokens(String dlim) throws IOException{
		return getIntTokens(readLine(),dlim);
	}
	
	private static ArrayList<Integer> getIntTokens(String line,String dlim) throws IOException{
		StringTokenizer tokens = new StringTokenizer(line,dlim);
		ArrayList<Integer> list = new ArrayList<Integer>();
		if(tokens != null){
			while(tokens.hasMoreTokens()){
				list.add(Integer.valueOf(tokens.nextToken()));
			}
		}
		return list;
	}
	
	private static ArrayList<String> getTokens() throws IOException{
		return getTokens(readLine()," ");
	}
	
	private static ArrayList<String> getTokens(String dlim) throws IOException{
		return getTokens(readLine(),dlim);
	}
	
	private static ArrayList<String> getTokens(String line,String dlim) throws IOException{
		StringTokenizer tokens = new StringTokenizer(line,dlim);
		ArrayList<String> list = new ArrayList<String>();
		if(tokens != null){
			while(tokens.hasMoreTokens()){
				list.add(tokens.nextToken());
			}
		}
		return list;
	}
	
	/**
	 * readline and space
	 * @return
	 * @throws IOException
	 */
	private static int countTokens() throws IOException{
		return countTokens(readLine()," ");
	}
	
	/**
	 * readline
	 * @param dlim
	 * @return
	 * @throws IOException
	 */
	private static int countTokens(String dlim) throws IOException{
		return countTokens(readLine(),dlim);
	}
	/**
	 * all you have to provide
	 * @param line
	 * @param dlim
	 * @return
	 * @throws IOException
	 */
	private static int countTokens(String line,String dlim) throws IOException{
		StringTokenizer tokens = new StringTokenizer(line,dlim);
		return tokens.countTokens();
	}
	
	private static void write(Object value) throws IOException{
		fileWriter.write(value.toString());
	}
	
	private static void writeln(Object value) throws IOException{
		fileWriter.write(value.toString() + "\n");
	}
	
	private static int getInt() throws IOException{
		return Integer.parseInt(getTokens().get(0));
	}
	
	private static long getLong() throws IOException{
		return Long.parseLong(getTokens().get(0));
	}
	
	private static double getDouble() throws IOException{
		return Double.parseDouble(getTokens().get(0));
	}
	
	private static final String prefix = "Case #";
	
	public static void main(String [] args){
		try{
			createReader("abc.in");
			createWriter("abc.out");
			executeAlgo();
			close();
		}catch(Exception ex){
			System.out.println(ex.getMessage());
		}
	}
	
	private static final String XWON = "X won";
	private static final String OWON = "O won";
	private static final String DRAW = "Draw";
	private static final String NOT_COMPLETED = "Game has not completed";
	
	private static final String X_Row_Win = "XXXX";
	private static final String X_Row_Win_T = "XXXT";
	private static final String O_Row_Win = "OOOO";
	private static final String O_Row_Win_T = "OOOT";
	
	private static int[] columnwin = { 0,4,8,12}; 
	private static int[] leftDiagonal = { 3,6,9,12};
	private static int[] rightDiagonal = { 0,5,10,15};
	private static boolean XRowWin = false;
	private static boolean ORowWin = false;
	
	
	
	private static void executeAlgo() throws IOException {
		int noOfCases = getIntTokens().get(0);
		String row;
		StringBuffer data;
		for(int i=0; i< noOfCases ; i++){
			data = new StringBuffer();
			XRowWin = false;
			ORowWin = false;
			
			for(int j=0;j<4;j++){
				row = fileReader.readLine();
				if(X_Row_Win.equals(row) || X_Row_Win_T.equals(row)){
					XRowWin = true;
				}else if(O_Row_Win.equals(row) || O_Row_Win_T.equals(row)){
					ORowWin = true;
				}
				data.append(row);
			}
			fileReader.readLine();
			if(XRowWin || checkColumnWin('X',data) || checkDiagonalWin('X', data)){
				writeln(prefix + (i+1) +": " + XWON);
			}else if(ORowWin || checkColumnWin('O',data) || checkDiagonalWin('O', data)){
				writeln(prefix + (i+1) +": " + OWON);
			}else if(checkDraw(data)){
				writeln(prefix + (i+1) +": " + DRAW);
			}else{
				writeln(prefix + (i+1) +": " + NOT_COMPLETED);
			}
		}
	}
	
	private static boolean checkDraw(StringBuffer data){
		if(data.indexOf(".")<0){
			return true;
		}
		return false;
	}
	private static boolean checkColumnWin(char token,StringBuffer data){
		int count ;
		char c;
		for(int offset=0;offset<4;offset++){
			count =0;
			for(int index  : columnwin){
				c = data.charAt(index + offset);
				if(c == token || c == 'T'){
					count++;
				}
			}
			if(count == 4){
				return true;
			}
		}
		return false;
	}
	
	private static boolean checkDiagonalWin(char token,StringBuffer data){
		int count =0 ;
		char c;
		for(int index  : leftDiagonal){
			c = data.charAt(index);
			if(c == token || c == 'T'){
				count++;
			}
		}
		if(count == 4){
				return true;
		}
		
		count = 0;
		for(int index  : rightDiagonal){
			c = data.charAt(index);
			if(c == token || c == 'T'){
				count++;
			}
		}
		if(count == 4){
				return true;
		}
		return false;
	}
	
	
}


