import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class Main {
	List<Integer> primes = new ArrayList<Integer>();
	public int maxLen = 32, maxJ = 500, certainty = 90, limit = 99999991;
	boolean[] sieve = new boolean[limit + 5];

	public void prime_sieve() {

		for (int n = 3; n <= limit; n = n + 2) {
			if (!sieve[n]) {
				for (int m = 2 * n; m <= limit; m += n) {
					sieve[m] = true;
				}
			}
		}

		primes.add(2);
		for (int i = 3; i <= limit; i += 2) {
			if (!sieve[i]) {
				primes.add(i);
			}
		}
	}

	private int getDivisor(BigInteger b) {
		for (int i = 0; i < primes.size(); i++) {
			if (b.mod(new BigInteger(String.valueOf(primes.get(i)))) == BigInteger.ZERO) {
				return primes.get(i);
			}
		}
		return -1;
	}

	public boolean printDivisors(String jc) {
		List<Integer> divisors = new ArrayList<Integer>();
		for (int base = 2; base <= 10; base++) {
			BigInteger b = new BigInteger(jc, base);
			int div = getDivisor(b);
			if(div != -1){
				divisors.add(div);
			}else{
				return false;
			}
		}
		
		System.out.print(jc + " ");
		for(int i=0;i<divisors.size();i++){
			System.out.print(divisors.get(i) + " ");
		}
		System.out.println();

		return true;
	}

	private Boolean solve(String s) {
		BigInteger num = new BigInteger(s);

		for (int base = 2; base <= 10; base++) {
			BigInteger numInBase = new BigInteger(num.toString(), base);
			if (numInBase.isProbablePrime(certainty)) {
				return false;
			}
		}

		return true;
	}

	public List<String> solve(int length) {
		List<String> list = new ArrayList<String>();
		// System.out.println("Solving Length: " + length);

		for (int i = 0; i < (1 << length - 2); i++) {
			String num = "1";

			for (int j = 0; j < length - 2; j++) {
				if ((i & (1 << j)) > 0) {
					num += '1';
				} else {
					num += '0';
				}
			}
			num += '1';
			BigInteger number = new BigInteger(num);
			int cnt = 0;
			if (!number.isProbablePrime(certainty) && solve(num)) {
				list.add(num);
				cnt++;
				if (cnt >= maxJ)
					break;
			}
		}
		// System.out.println("Number of jamcoins of found: " + list.size());
		return list;
	}

	public static void main(String[] args) throws NumberFormatException, IOException {
		Main m = new Main();
		m.prime_sieve();
		Scanner sc = new Scanner(System.in);

		int t = sc.nextInt();
		for (int _T = 1; _T <= t; _T++) {
			System.out.println("Case #" + _T + ":");
			int len = sc.nextInt();

			int mm = sc.nextInt();
			m.maxJ = mm+100;

			List<String> jamcoins = m.solve(len);

			int cnt = 0;
			for (String jc : jamcoins) {
				if (m.printDivisors(jc)) {
					cnt++;
				}
				if (cnt >= mm)
					break;
			}
		}

		sc.close();
	}
}
