import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Scanner;
import java.util.StringTokenizer;

/**
 * Bot Trust. Qualification round 2011, Problem A.
 * 
 * @author Bicheng Cao
 */
public class BotTrust {
	
	static class Input {
		int n;
		Command[] commands;
	}
	
	static class Command {
		char bot;
		int button;
	}
	
	static class Output {
		int result;
	}
	
	public static void main(String[] args) throws IOException {
		Input[] inputs = getInputs();
		Output[] outputs = process(inputs);
		printOutputs(outputs);
	}
	
	private static Input[] getInputs() throws IOException {
		Scanner in = new Scanner(new FileInputStream("input.txt"));
		int t = in.nextInt();
		Input[] inputs = new Input[t];
		for (int i = 0; i < t; i++) {
			Input input = inputs[i] = new Input();
			input.n = in.nextInt();
			input.commands = new Command[input.n];
			for (int j = 0; j < input.n; j++) {
				Command command = input.commands[j] = new Command();
				command.bot = in.next().charAt(0);
				command.button = in.nextInt();
			}
		}
		in.close();
		return inputs;
	}
	
	private static Output[] process(Input[] inputs) {
		Output[] outputs = new Output[inputs.length];
		for (int i = 0; i < inputs.length; i++) {
			outputs[i] = process(inputs[i]);
		}
		return outputs;
	}

	private static Output process(Input input) {
		Output output = new Output();
		int position[] = {1, 1};
		for (int i = 0; i < input.n; i++) {
			Command command = input.commands[i];
			if (command.bot == 'O') {
				int moves = Math.abs(position[1] - command.button) + 1;
				output.result += moves;
				position[1] = command.button;
				for (int j = i + 1; j < input.n; j++) {
					if (input.commands[j].bot == 'O') {
						continue;
					}
					if (input.commands[j].button >= position[0]) {
						position[0] = Math.min(position[0] + moves, input.commands[j].button);
					} else {
						position[0] = Math.max(position[0] - moves, input.commands[j].button);
					}
					break;
				}
			} else {
				int moves = Math.abs(position[0] - command.button) + 1;
				output.result += moves;
				position[0] = command.button;
				for (int j = i + 1; j < input.n; j++) {
					if (input.commands[j].bot == 'B') {
						continue;
					}
					if (input.commands[j].button >= position[1]) {
						position[1] = Math.min(position[1] + moves, input.commands[j].button);
					} else {
						position[1] = Math.max(position[1] - moves, input.commands[j].button);
					}
					break;
				}
			}
//			System.out.println("step " + i + ": " + output.result);
//			System.out.println("Position Orange: " + position[1]);
//			System.out.println("Position Blue: " + position[0]);
		}
		return output;
	}
	
	private static void printOutputs(Output[] outputs) throws IOException {
		PrintWriter out = new PrintWriter(new BufferedWriter(new FileWriter("output.txt")));
		for (int i = 0; i < outputs.length; i++) {
			Output output = outputs[i];
			out.print("Case #" + (i + 1) + ": ");
			out.print(output.result);
			out.println();
		}
		out.close();
	}
}
