package tictac;

import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class TicTac {
	static enum Status {
		X_WON,
		O_WON,
		CONTINUED,
		DRAW,
	}
	
	public static void main(String[] args) throws IOException {
		Scanner sc = new Scanner(new FileReader("input.txt"));
		PrintWriter pw = new PrintWriter(new FileWriter("output.txt"));	
		int caseCnt = sc.nextInt();
		for (int i = 0; i < caseCnt; i++) {
			String[][] caze = readCase(sc);

			pw.printf("Case #%d: ", i +1 );
			pw.println(getName(getCaseStatus(caze)));
		}
		
		pw.flush();
		pw.close();
		sc.close();
	}
	
	private static String getName(Status status){
		switch (status) {
		case X_WON:
			return "X won";
		case O_WON:
			return "O won";
		case CONTINUED:
			return "Game has not completed";
		case DRAW:
			return "Draw";
		default:
			throw new RuntimeException();
		}
	}

	private static String[][] readCase(Scanner sc) {
		String[][] result = new String[4][4];
		for (int i = 0; i < 4; i++) {
			String line = sc.next();
			for (int j = 0; j < 4; j++) {
				result[i][j] = line.charAt(j) + "";
			}
		}
		return result;
	}
	
	static Status getCaseStatus(String[][] caze){
		List<Status> statusList = new ArrayList<Status>();
		for (int i = 0; i < 4; i++) {
			Status status = getStatus(caze[i]);
			statusList.add(status);
			if (status == Status.X_WON || status == Status.O_WON) {
				return status;
			}
		}
		for (int i = 0; i < 4; i++) {
			String[] temp = new String[4];
			for (int j = 0; j < 4; j++) {
				temp[j] = caze[j][i];
			}
			Status status = getStatus(temp);
			statusList.add(status);
			if (status == Status.X_WON || status == Status.O_WON) {
				return status;
			}
		}
		String[] diagonal = new String[4];
		for (int i = 0; i < 4; i++) {
			diagonal[i] = caze[i][i];
		}
		Status status = getStatus(diagonal);
		statusList.add(status);
		if (status == Status.X_WON || status == Status.O_WON) {
			return status;
		}
		diagonal = new String[4];
		for (int i = 0; i < 4; i++) {
			diagonal[i] = caze[3-i][i];
		}
		status = getStatus(diagonal);
		statusList.add(status);
		if (status == Status.X_WON || status == Status.O_WON) {
			return status;
		}
		for (int i = 0; i < statusList.size(); i++) {
			if (statusList.get(i) == Status.CONTINUED) {
				return Status.CONTINUED;
			}
		}
		return Status.DRAW;
	}
	
	static Status getStatus(String[] line){
		if (isXWon(line)) {
			return Status.X_WON;
		}else if (isOWon(line)) {
			return Status.O_WON;
		}else if (hadDot(line)) {
			return Status.CONTINUED;
		}
		return Status.DRAW;
	}
	
	static boolean hadDot(String[] line) {
		for (int i = 0; i < line.length; i++) {
			if (line[i].equals(".")){
				return true;
			}
		}
		return false;
	}
	
	static boolean isXWon(String[] line) {
		for (int i = 0; i < line.length; i++) {
			if (!line[i].equals("X") && !line[i].equals("T")) {
				return false;
			}
		}
		return true;
	}
	
	static boolean isOWon(String[] line) {
		for (int i = 0; i < line.length; i++) {
			if (!line[i].equals("O") && !line[i].equals("T")) {
				return false;
			}
		}
		return true;
	}
}
