package contest2014.minesweeper;

import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Scanner;
import java.util.Set;

public class MinesweeperMaster {
	public static void main(String[] args) throws IOException {
		Scanner sc = new Scanner(new FileReader("input.txt"));
		PrintWriter pw = new PrintWriter(new FileWriter("output.txt"));
		int caseCnt = sc.nextInt();
		for (int i = 0; i < caseCnt; i++) {
			int r = sc.nextInt();
			int c = sc.nextInt();
			int m = sc.nextInt();
			pw.printf("Case #%d: ", i + 1);
			pw.println();
			pw.print(getResult(r, c, m));
		}
		pw.flush();
		pw.close();
		sc.close();
		

	}

	private static String getResult(int row, int col, int m) {
		Combination cb = new Combination(row * col - m, row * col);
		while (true) {
			int[] i = cb.next();
//			for (int j = 0; i != null && j < i.length; j++) {
//				System.out.print(i[j] + " ");
//			}
			if (i != null) {
				Board board = new Board(row, col);
				board.init(i);
				int c = board.findC();
				if (c != -1) {
					return board.print(c);
				}
			} else {
				return "Impossible\n";
			}
		}		
	}

}

class Combination {
	int n, m;
	int[] pre;// previous combination.

	public Combination(int n, int m) {
		this.n = n;
		this.m = m;
	}

	public int[] next() {
		if (pre == null) {
			pre = new int[n];
			for (int i = 0; i < pre.length; i++) {
				pre[i] = i;
			}
			int[] ret = new int[n];
			System.arraycopy(pre, 0, ret, 0, n);
			return ret;
		}
		int ni = n - 1, maxNi = m - 1;
		while (pre[ni] + 1 > maxNi) {
			ni--;
			maxNi--;
			if (ni < 0)
				return null;
		}
		pre[ni]++;
		while (++ni < n) {
			pre[ni] = pre[ni - 1] + 1;
		}
		int[] ret = new int[n];
		System.arraycopy(pre, 0, ret, 0, n);
		return ret;
	}

}

class Board {
	boolean[] data;
	private int row;
	private int col;
	private Set<Integer> values = new HashSet<Integer>();

	Board(int row, int col) {
		this.row = row;
		this.col = col;
		data = new boolean[row * col];
//		for (int i = 0; i < data.length; i++) {
//			data[i] = true;
//		}
	}

	void init(int[] values) {
		for (int i = 0; i < values.length; i++) {
			this.values.add(values[i]);
		}

		for (int i = 0; i < values.length; i++) {
			setValue(values[i]);
		}
	}

	private void setValue(int i) {
		data[i] = true;
	}

	String print(int c) {
		StringBuffer bf = new StringBuffer();
		for (int i = 0; i < data.length; i++) {
			if (i == c) {
				bf.append("C");
			}else if (data[i]) {
				bf.append(".");
			} else {
				bf.append("*");
			}
			if ((i + 1) % col == 0) {
				bf.append("\n");
			}
		}
		return bf.toString();
	}
	
	int findC(){
		for (Iterator iterator = values.iterator(); iterator.hasNext();) {
			int c = (int) iterator.next();
			Set<Integer> allOpened = clickOn(c, new HashSet<Integer>());
			if (!allOpened.isEmpty() && allOpened.equals(values)) {
				return c;
			}
		}
		return -1;
	}

	Set<Integer> clickOn(int value, Set<Integer> set) {
		set.add(value);
		Set<Integer> allNeighbors = getAllNeighbors(value);
		if (values.containsAll(allNeighbors)) {
			for (Iterator iterator = allNeighbors.iterator(); iterator
					.hasNext();) {
				int neighbor = (int) iterator.next();
				if (!set.contains(neighbor)) {
					clickOn(neighbor, set);
				}
			}
		}
		return set;
	}

	private Set<Integer> getAllNeighbors(int value) {
		Set<Integer> set = new HashSet<Integer>();
		for (int i = 0; i < data.length; i++) {
			if (isNeighbors(value, i)) {
				set.add(i);
			}
		}
		return set;
	}

	boolean isNeighbors(int value1, int value2) {
		int i1 = value1 / col;
		int j1 = value1 - col * i1;
		int i2 = value2 / col;
		int j2 = value2 - col * i2;
		return isNeighbors(i1, j1, i2, j2);
	}

	boolean isNeighbors(int i1, int j1, int i2, int j2) {
		return (Math.abs(i1 - i2) <= 1 && Math.abs(j1 - j2) <= 1);
	}

}
