package codejam;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

import codejam.CodeJamRunner;

import com.google.common.base.Splitter;
import com.google.common.base.Strings;

public class ProblemC extends CodeJamRunner {

	private int nrOfCases;
	private int testCaseIndex = 1;
	private int inTestCaseIndex;

	private int min;
	private int max;
	private String minString;
	private String maxString;
	private int recycledPairs;
	private int[] tempDigits;
	private int[] maxDigits;
	
	private NumberRecycler numberRecycler;

	public void process(int lineNr, String line) {
		System.out.println(lineNr + ":" + line);
		if (lineNr == 1) {
			nrOfCases = Integer.valueOf(line);
		} else {
				Iterator<String> split = Splitter.on(" ").split(line).iterator();
				minString = split.next();
				maxString = split.next();
				min = Integer.parseInt(minString);
				max = Integer.parseInt(maxString);
				calc();
				write();
				testCaseIndex++;
		}
	}

	private void write() {
		String resultLine = "Case #" + testCaseIndex + ": " + recycledPairs;
		printlnOutput(resultLine);
	}

	private void calc() {
		recycledPairs = 0;
		int[] minDigits = toDigits(minString);
		int[] currDigits = toDigits(minString);
		maxDigits = toDigits(maxString);
		tempDigits = new int[minDigits.length]; // reuse
		numberRecycler = new NumberRecycler(minDigits.length);
		while ( firstBigger( maxDigits, currDigits  ) ){
			addOne( currDigits );
			if ( isOverflow( currDigits )){
				break;
			}
			recycledPairs = recycledPairs + countRecPair( currDigits );
		}
	}

	private int countRecPair( int[] currDigits ){
		int count = 0;
		List<int[]> generated = new ArrayList<int[]>();
		for ( int i=1; i<currDigits.length; i++ ){
			int[] recycled = numberRecycler.createRecycling( currDigits, i );
			if ( firstBigger( recycled, currDigits ) && firstBigger( maxDigits, recycled ) && ! contains( generated, recycled )){
				count++;
				generated.add(recycled);
				dumpPairs( String.valueOf(i), currDigits, recycled );
			}
		}
		return count;
	}
	
	private boolean contains( List<int[]> list, int[] one){
		for ( int[] listElement : list ){
			if ( deepEquals(one, listElement )) {
				return true;
			}
		}
		return false;
	}
	
	private boolean deepEquals( int[] one, int[] two ) {
		for ( int i=0; i<one.length; i++){
			if ( one[i] != two[i]){
				return false;
			}
		}
		return true;
	}
	
	
	private void dumpPairs( String prefix, int[] one, int[] two ){
		System.out.println(toStringCompact(one) +";" + toStringCompact(two));
		//System.out.println( prefix + "(" + toString(one) + "-" + toString(two) + ")");
	}

	private String toStringCompact( int[] one ){
		StringBuilder sb = new StringBuilder();
		for ( int i : one ){
			sb.append(String.valueOf(i ));
		}
		return sb.toString();
	}

	private String toString( int[] one ){
		StringBuilder sb = new StringBuilder();
		for ( int i : one ){
			sb.append(i + " ");
		}
		return sb.toString();
	}

	private int[] createRecycling( int[] currDigits, int size )
	{
		System.arraycopy(currDigits, currDigits.length - size, tempDigits, 0, size);
		System.arraycopy(currDigits, 0, tempDigits, currDigits.length - size, size);
		return tempDigits;
	}
	
	
	private boolean isOverflow( int[] digits ){
		return digits[0] >= 10;
	}

	private void addOne( int[] digits ){
		int last = digits.length - 1;
		digits[last] = digits[last] + 1;
		for ( int i = last; i>0; i-- ) {
			if ( digits[i] < 10 ){
				break;
			}
			else {
				digits[i] = 0;
				digits[i-1] = digits[i-1] + 1;
			}
		}
	}
	
	private boolean firstBigger( int[] minDigits, int[] maxDigits){
		for ( int i = 0; i<minDigits.length; i++ )
		{
			if ( minDigits[i] > maxDigits[i])
				return true;
			if ( minDigits[i] < maxDigits[i])
				return false;
		}
		return false;
	}
	
	private int[] toDigits( String number ){
		int[] digitArray = new int[number.length()];
		for ( int i=0; i<number.length(); i++ ) {
			digitArray[i] = Integer.parseInt(String.valueOf(number.charAt(i)));
		}
		return digitArray;
	}
	
	public static void main(String args[]) {
		ProblemC ao = new ProblemC();
		ao.run(args);
	}
}
