import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;

public class Roller {
	public static void main(String[] args) {
		
		if(args.length < 1) {
			System.err.println("Usage: java Roller inputFile");
			System.exit(1);
		}
		
		BufferedReader in = null;
		PrintWriter out = null;
		try {
			// read the input file
			String inputFile = args[0];
			in = new BufferedReader(new FileReader(inputFile));
			
			// output the file
			String outputFile = inputFile.substring(0, inputFile.indexOf(".")) + ".out";
			out = new PrintWriter(new BufferedWriter(new FileWriter(outputFile)));
			
		    int t = 0; // no of test cases (1 <= T <= 50)
		    // Integer.MAX_VALUE = 2^31 - 1
		    int r; // no of rides per day (1 <= R <= 10^8)
		    int k; // capacity of roller coaster (1 <= k <= 10^9)
		    int n; // no of groups (1 <= N <= 1000)
		    
		    int i = 1; // counter
			
			String s, s2;
			StringBuilder sb;
			
			// first line gives t
			if( (s = in.readLine()) != null)
				t = Integer.parseInt(s);
			else {
				System.err.println("Input file " + inputFile + " is empty");
				System.exit(1);
			}
			
			// for each test case
			while( (t-- > 0) && ( s = in.readLine()) != null ) {
				String[] tokens = s.trim().split("\\s+");
				r = Integer.parseInt(tokens[0]);
				k = Integer.parseInt(tokens[1]);
				n = Integer.parseInt(tokens[2]);
				
				// n groups
				int groups[] = new int[n];
				if( (s2 = in.readLine()) != null ) {
					String[] groupTokens = s2.trim().split("\\s+");
					// group size (1 <= gi <= 10^7)
					for(int z = 0; z < n; z++)
						groups[z] = Integer.parseInt(groupTokens[z]);
				}
				else {
					System.err.println("Group line missing in input file - " + inputFile);
					System.exit(1);
				}

				// logic
				long sum = 0; // max r * k (10^8 * 10^9) - Long.MAX_VALUE = 2^63 - 1
				int p = 0, j = 0, c = 0; // j = current group index, c = starting group index
				
				for(int m = 0; m < r; m++) { // for each ride
					p = 0; c = j;
					while( (p + groups[j]) <= k) {
						p += groups[j];
						j = (j+1)%n;
						
						if(j == c) break;
					}
					sum += p; // running sum
				}
				
				sb = new StringBuilder();
				sb.append("Case #").append(i++).append(": ").append(sum);
				
				out.println(sb.toString());
			}
			
		}
		catch(NumberFormatException nfe) {
			System.err.println("Number format exception: " + nfe.getMessage());
		}
		catch(IOException io) {
			System.err.println("IO Exception: " + io.getMessage());
		}
		finally {
			try {
				if(in != null) in.close();
				if(out != null) out.close();
			}
			catch(Exception e) { e.printStackTrace(); }
		}
		

	}

}
