import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigInteger;

public class JamCode {
	public static void main(String[] args) {
		
		if(args.length < 1) {
			System.err.println("Usage: java JamCode inputFile");
			System.exit(1);
		}
		
		BufferedReader in = null;
		PrintWriter out = null;
		try {
			// read the input file
			String inputFile = args[0];
			in = new BufferedReader(new FileReader(inputFile));
			
			// output the file
			String outputFile = inputFile.substring(0, inputFile.indexOf(".")) + ".out";
			out = new PrintWriter(new BufferedWriter(new FileWriter(outputFile)));
			
		    int t = 0; // no of test cases (1 <= t <= 100)
		    // Integer.MAX_VALUE = 2^31 - 1
		    int n; // no of great events (2 <= n <= 1000)
		    BigInteger events[];
		    int i = 1; // counter
			
			String s;
			StringBuilder sb;
			
			// first line gives t
			if( (s = in.readLine()) != null)
				t = Integer.parseInt(s);
			else {
				System.err.println("Input file " + inputFile + " is empty");
				System.exit(1);
			}
			
			// for each test case
			while( (t-- > 0) && ( s = in.readLine()) != null ) {
				String[] tokens = s.trim().split("\\s+");
				n = Integer.parseInt(tokens[0]);
				
				events = new BigInteger[n];
				for(int z = 0; z < n; z++) // read each event time
					events[z] = new BigInteger(tokens[z+1]);

				// logic
				// find diff of each pair of elements
				BigInteger diffEvents[] = new BigInteger[n-1];
				for(int z = 0; z < events.length - 1; z++) {
					diffEvents[z] = (events[z]).subtract(events[z+1]);
					diffEvents[z] = diffEvents[z].abs();
				}
				// get the gcd of diff events
				BigInteger tempGCD = diffEvents[0];
				for(int z = 1; z < diffEvents.length; z++) {
					tempGCD = tempGCD.gcd(diffEvents[z]);
				}
				
				BigInteger t1 = (events[0]).mod(tempGCD);
				BigInteger answer = BigInteger.ZERO;
				if(t1.compareTo(BigInteger.ZERO) != 0)
					answer = tempGCD.subtract(t1);
				
				sb = new StringBuilder();
				sb.append("Case #").append(i++).append(": ").append(answer.toString());
				
				out.println(sb.toString());
			}
			
		}
		catch(NumberFormatException nfe) {
			System.err.println("Number format exception: " + nfe.getMessage());
		}
		catch(IOException io) {
			System.err.println("IO Exception: " + io.getMessage());
		}
		finally {
			try {
				if(in != null) in.close();
				if(out != null) out.close();
			}
			catch(Exception e) { e.printStackTrace(); }
		}
		

	}

}
