package gcjquald;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.Scanner;

/**
 *
 * @author Birch
 */
public class D implements Runnable {

    protected FileLoader inFile;
    protected Scanner in;
    protected StringBuilder out;
    private static final String CASE = "Case #%d:";

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
	(new D()).run();
    }

    public D() {
	inFile = new FileLoader("src\\input.txt");
	out = new StringBuilder();
    }

    public void run() {
	try {
	    in = inFile.getScanner();
	    solve();
	} catch (FileNotFoundException fnfe) {
	    System.out.println("File not found. Exiting.");
	    System.out.println(fnfe);
	}
    }

    //Commence magic
    public void solve() {
	int totalTests = Integer.parseInt(in.nextLine());
	//For each case line, print the answer
	for (int i = 0; i < totalTests; i++) {
	    out.append("Case #").append(i + 1).append(": ").append(solveLine(in.nextLine(), in.nextLine()));
	    //If we're not at the end, we'll need a new line.
	    if (i + 1 != totalTests) {
		out.append('\n');
	    }
	}
	System.out.println(out);
    }

    public String solveLine(String firstLine, String secondLine) {
	int size = Integer.parseInt(firstLine);
	ArrayList<Item> items = new ArrayList<Item>(size);
	String[] stringItems = secondLine.split(" ");
	int sortCount = 0;

	for (int i = 0; i < size; i++) {
	    int value = Integer.parseInt(stringItems[i]) - 1;

	    Item item = new Item(value);
	    if (value == i) {
		item.sorted = true;
	    }
	    items.add(item);
	}

	int index = 0;
	while (index < items.size()) {

	    int itemCount = 1;
	    Item startItem = items.get(index);
	    if (startItem.visited || startItem.sorted) {
		index++;
		continue;
	    }
	    startItem.visited = true;
	    Item nextItem = items.get(startItem.value);
	    nextItem.visited = true;

	    while (nextItem != startItem) {
		Item currentItem = items.get(nextItem.value);
		nextItem = currentItem;
		currentItem.visited = true;
		itemCount++;
	    }
	    
	    index++;
	    sortCount += (itemCount - 1) * 2;
	}



	return pad(sortCount);
    }

    public String pad(int value){
	StringBuilder sb = new StringBuilder();
	sb.append(value);
	//Append 6 0s to fudge accuracy
	sb.append(".000000");
	return sb.toString();
    }

    public class Item {

	protected int value;
	boolean visited;
	boolean sorted;

	public Item(int value) {
	    this.value = value;
	    visited = false;
	    sorted = false;
	}

	@Override
	public boolean equals(Object obj) {
	    if (obj == null) {
		return false;
	    }
	    if (getClass() != obj.getClass()) {
		return false;
	    }
	    final Item other = (Item) obj;
	    return true;
	}

	@Override
	public int hashCode() {
	    int hash = 7;
	    hash = 47 * hash + this.value;
	    return hash;
	}
    }

    //Get our file stuff from here. Each case instance loaded sequentially,
    //so not entirely worried about buffered streams.
    public class FileLoader {

	protected String filename;
	protected InputStream stream;
	protected Scanner scanner;

	public FileLoader(String filename) {
	    this.filename = filename;
	}

	public InputStream getStream() throws FileNotFoundException {
	    if (stream == null) {
		stream = new FileInputStream(filename);
	    }
	    return stream;
	}

	public Scanner getScanner() throws FileNotFoundException {
	    if (scanner == null) {
		scanner = new Scanner(this.getStream());
	    }
	    return scanner;
	}
    }
}
