package gcjquala;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.util.Scanner;

/**
 *
 * @author Birch
 */
public class A implements Runnable {

    protected FileLoader inFile;
    protected Scanner in;
    protected StringBuilder out;

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
	(new A()).run();
    }

    public A() {
	inFile = new FileLoader("src\\input.txt");
	out = new StringBuilder();
    }

    public void run() {
	try {
	    in = inFile.getScanner();
	    solve();
	} catch (FileNotFoundException fnfe) {
	    System.out.println("File not found. Exiting.");
	    System.out.println(fnfe);
	    fnfe.printStackTrace();
	}
    }

    //Commence overall magic
    protected void solve() {
	int totalTests = Integer.parseInt(in.nextLine());
	//For each case line, print the answer
	for (int i = 0; i < totalTests; i++) {
	    out.append("Case #").append(i + 1).append(": ").append(solveCase(in.nextLine()));
	    //If we're not at the end, we'll need a new line.
	    if (i + 1 != totalTests) {
		out.append('\n');
	    }
	}
	System.out.println(out);
    }

    //Commence case magic
    protected int solveCase(String inLine) {
	String[] entries = inLine.split(" ");
	int buttonPresses = Integer.parseInt(entries[0]);

	//We expect then that the size of entries is 2 * buttonPresses + 1
	//Every odd index is O/B
	//every even index is 01<=x<=100
	Round[] rounds = new Round[buttonPresses];
	for (int i = 0; i < buttonPresses; i++) {
	    rounds[i] = new Round(entries[(2 * i) + 1], Integer.parseInt(entries[2 * (i + 1)]));
	}

	Bot orange = new Bot();
	Bot blue = new Bot();
	int currentRound = 0;
	int count = 0;
	boolean hit = false;;

	int blueIndex = findNextPos('B', rounds, 0);
	int orangeIndex = findNextPos('O', rounds, 0);

	while (blueIndex != -1 || orangeIndex != -1) {
	    hit = false;
	    count++;
	    orange.moved = false;
	    blue.moved = false;

	    //Blue Do
	    if (blueIndex != -1) {

		blue.setNext(rounds[blueIndex].position);
		blue.move();
		// My round and I haven't moved and I'm in the right spot
		if (rounds[currentRound].colour == 'B' && !blue.moved && blue.currentPos == rounds[currentRound].position ) {
		    //I would have hit the button here
		    hit = true;
		    blueIndex = findNextPos('B', rounds, blueIndex + 1);
		}
	    }
	    
	    //Orange Do
	    if (orangeIndex != -1) {
		orange.setNext(rounds[orangeIndex].position);
		orange.move();
		// My round and I haven't moved and I'm in the right spot
		if (rounds[currentRound].colour == 'O' && !orange.moved && orange.currentPos == rounds[currentRound].position) {
		    //I would have hit the button here
		    hit = true;
		    orangeIndex = findNextPos('O', rounds, orangeIndex + 1);
		}
	    }

	    if (hit) currentRound++;

	}

	return count;
    }

    protected int findNextPos(char colour, Round[] rounds, int currentIndex) {
	for (int i = currentIndex; i < rounds.length; i++) {
	    if (rounds[i].colour == colour) {
		return i;
	    }
	}
	return -1;
    }

    //Lets over-ly Java-ise this for fun
    public class Bot {

	protected int currentPos;
	protected int desiredNext;
	protected boolean moved;
	protected boolean hit;

	public Bot() {
	    currentPos = 1;
	    desiredNext = 1;
	    moved = false;
	}

	public int getPos() {
	    return currentPos;
	}

	public void move() {
	    if (currentPos < desiredNext) {
		moveUp();
		moved = true;
	    } else if (currentPos > desiredNext) {
		moveDown();
		moved = true;
	    }
	}

	public void setNext(int desiredNext) {
	    this.desiredNext = desiredNext;
	}

	protected void moveUp() {
	    currentPos++;
	}

	protected void moveDown() {
	    currentPos--;
	}

	public String hasCake() {
	    return "no";
	}
    }

    public class Round {

	protected char colour;
	protected int position;

	public Round(String colour, int position) {
	    this.colour = colour.charAt(0);
	    this.position = position;
	}
    }

    //Get our file stuff from here. Each case instance loaded sequentially,
    //so not entirely worried about buffered streams.
    public class FileLoader {

	protected String filename;
	protected InputStream stream;
	protected Scanner scanner;

	public FileLoader(String filename) {
	    this.filename = filename;
	}

	public InputStream getStream() throws FileNotFoundException {
	    if (stream == null) {
		stream = new FileInputStream(filename);
	    }
	    return stream;
	}

	public Scanner getScanner() throws FileNotFoundException {
	    if (scanner == null) {
		scanner = new Scanner(this.getStream());
	    }
	    return scanner;
	}
    }
}
