package gcjqualb;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.Set;
import java.util.Stack;

/**
 *
 * @author Birch
 */
public class B implements Runnable {

    protected FileLoader inFile;
    protected Scanner in;
    protected StringBuilder out;

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
	(new B()).run();
    }

    public B() {
	inFile = new FileLoader("src\\input.txt");
	out = new StringBuilder();
    }

    public void run() {
	try {
	    in = inFile.getScanner();
	    solve();
	} catch (FileNotFoundException fnfe) {
	    System.out.println("File not found. Exiting.");
	    System.out.println(fnfe);
	}
    }

    //Commence magic
    public void solve() {
	int totalTests = Integer.parseInt(in.nextLine());
	//For each case line, print the answer
	for (int i = 0; i < totalTests; i++) {
	    out.append("Case #").append(i + 1).append(": ").append(solveLine(in.nextLine()));
	    //If we're not at the end, we'll need a new line.
	    if (i + 1 != totalTests) {
		out.append('\n');
	    }
	}
	System.out.println(out);
    }

    //commence magic on a per-line basis
    public String solveLine(String inLine) {

	String[] tokenisedString = inLine.split(" ");
	int index = 0;

	//Pull alchemical count
	int alchemicalCount = Integer.parseInt(tokenisedString[index]);
	index++;

	//generate alchemical string
	String alchemicalString = "";
	if (alchemicalCount != 0) {
	    for (int i = index; i < alchemicalCount; i++) {
		alchemicalString = tokenisedString[index + i];
	    }
	    index += alchemicalCount;

	}

	//pull obliterative count
	int obliterativeIndex = Integer.parseInt(tokenisedString[index]);
	index++;


	//generate obliterative string
	String obliterativeString = "";
	if (obliterativeIndex != 0) {
	    for (int i = index; i < obliterativeIndex; i++) {

		obliterativeString = tokenisedString[index + i];
	    }
	}


	//pull entry and convert
	String entry = tokenisedString[tokenisedString.length - 1];

	Case runCase = new Case(entry, obliterativeString, alchemicalString);

	//Solve case
	return runCase.solve().toString();
    }

    public class Case {

	Map<Pair, Powers> pairs;
	Stack<Character> stack;
	char[] entry;
	final char[] possible = new char[]{'Q', 'W', 'E', 'R', 'A', 'S', 'D', 'F'};

	public Case(String entryString, String obliterativeString, String alchemicalString) {
	    pairs = new HashMap<Pair, Powers>();
	    stack = new Stack<Character>();
	    entry = new char[entryString.length()];

	    for (int i = 0; i < entry.length; i++) {
		entry[i] = entryString.charAt(i);
	    }

	    for (int o = 0; o < obliterativeString.length(); o += 2) {
		char one = obliterativeString.charAt(o);
		char two = obliterativeString.charAt(o + 1);
		addObliterative(one, two);
	    }

	    for (int a = 0; a < alchemicalString.length(); a += 3) {
		char one = alchemicalString.charAt(a);
		char two = alchemicalString.charAt(a + 1);
		char three = alchemicalString.charAt(a + 2);
		addAlchemical(one, two, three);
	    }

	}

	private void addObliterative(char one, char two) {
	    Powers powers = getPowers(new Pair(one, two));
	    powers.obliterative = true;
	}

	private void addAlchemical(char one, char two, char three) {
	    Powers powers = getPowers(new Pair(one, two));
	    powers.alchemical = true;
	    powers.replacement = three;
	}

	protected boolean containsObliterative(char testAgainstMe) {
	    for (char withMe : possible) {
		Pair pair = new Pair(testAgainstMe, withMe);
		if (getPowers(pair).obliterative) {
		    if (stack.contains(withMe)) {
			return true;
		    }
		}
	    }
	    return false;
	}

	protected boolean isAlchemical(Pair pair) {
	    return getPowers(pair).alchemical;
	}

	protected Powers getPowers(Pair pair) {
	    if (!pairs.containsKey(pair)) {
		pairs.put(pair, new Powers());
	    }
	    return pairs.get(pair);
	}

	public Stack<Character> solve() {
	    stack.push(entry[0]);
	    int entryPointer = 1;
	    while (entryPointer != entry.length) {
		if (stack.empty()) {
		    stack.push(entry[entryPointer]);
		    entryPointer++;
		    continue;
		}
		char one = stack.peek();
		char two = entry[entryPointer];

		Pair tempPair = new Pair(one, two);

		if (isAlchemical(tempPair)) {
		    stack.pop();
		    stack.push(getPowers(tempPair).replacement);
		} else if (containsObliterative(two)) {
		    stack.clear();
		} else {
		    stack.push(entry[entryPointer]);
		}

		entryPointer++;
	    }

	    return stack;
	}

	public class Powers {

	    boolean obliterative;
	    boolean alchemical;
	    char replacement;

	    public Powers() {
		obliterative = false;
		alchemical = false;
	    }
	}

	public class Pair implements Comparable {

	    private char itemOne;
	    private char itemTwo;

	    public Pair(char itemOne, char itemTwo) {
		//Always in order
		if (itemOne > itemTwo) {
		    this.itemOne = itemOne;
		    this.itemTwo = itemTwo;
		} else {
		    this.itemOne = itemTwo;
		    this.itemTwo = itemOne;
		}
	    }

	    public boolean equals(Object o) {
		if (!(o instanceof Pair)) {
		    throw new ClassCastException("Not a Pair");
		}
		Pair p = (Pair) o;
		if (p.itemOne == itemOne && p.itemTwo == itemTwo) {
		    return true;
		}
		return false;
	    }

	    @Override
	    public int hashCode() {
		int hash = 7;
		hash = 67 * hash + this.itemOne;
		hash = 67 * hash + this.itemTwo;
		return hash;
	    }

	    public int compareTo(Object o) {

		Pair p = (Pair) o;

		if (itemOne < p.itemOne) {
		    return -1;
		}
		if (itemOne > p.itemOne) {
		    return 1;
		}
		if (itemTwo < p.itemTwo) {
		    return -1;
		}
		if (itemTwo > p.itemTwo) {
		    return 1;
		}
		return 0;
	    }
	}
    }

    //Get our file stuff from here. Each case instance loaded sequentially,
    //so not entirely worried about buffered streams.
    public class FileLoader {

	protected String filename;
	protected InputStream stream;
	protected Scanner scanner;

	public FileLoader(String filename) {
	    this.filename = filename;
	}

	public InputStream getStream() throws FileNotFoundException {
	    if (stream == null) {
		stream = new FileInputStream(filename);
	    }
	    return stream;
	}

	public Scanner getScanner() throws FileNotFoundException {
	    if (scanner == null) {
		scanner = new Scanner(this.getStream());
	    }
	    return scanner;
	}
    }
}
