import java.io.*;
import java.lang.*;
import java.util.*;

public class TrainTimetable {

	static boolean debug=true;	// Debug parameter - if true displays additional information on the screen.

	public static void main(String[] args) {

		try {
			
			BufferedReader br = new BufferedReader(new FileReader(args[0]));
			BufferedWriter bw = new BufferedWriter(new FileWriter("results.txt"));
			
			String thisLine="";
			int currentCaseNum;
			thisLine = br.readLine();
			int num_Tests = Integer.parseInt(thisLine); // Read number of test cases
			
			
			int turnAroundTimeMinutes; // Turnaround Time in Minutes (as read from file)
			int num_A; // Number of trips from A
			int num_B; // Number of trips from B
			int num_Trains_A; // Number of trains needed for station A
			int num_Trains_B; // Number of trains needed for station B
			
			String[] splitter;
			String[] HHMMsplitter; // Auxilliary variables for splitting strings
		
			
			GregorianCalendar[][] timesAB;
			GregorianCalendar[][] timesBA;
			
			GregorianCalendar[] trueArrivalsB; // "True arrivals" to B (from A) considering turnaround time
			GregorianCalendar[] trueArrivalsA; // "True arrivals" to A (from B) considering turnaround time
			
			boolean[] trainTakenB; // Need to keep track of trains available at B (according to trueArrivalsB) and whether they have been considered for certain trips
			boolean[] trainTakenA; // Need to keep track of trains available at A (according to trueArrivalsA) and whether they have been considered for certain trips

			
			for (currentCaseNum=1; currentCaseNum <= num_Tests; currentCaseNum++) {
			
				thisLine = br.readLine();
				int turnAroundTime = Integer.parseInt(thisLine); // 0 <= T <= 60 in minutes
	
				
				thisLine = br.readLine();
				splitter = thisLine.split(" ");
				num_A = Integer.parseInt(splitter[0]);
				num_B = Integer.parseInt(splitter[1]);
				
				timesAB = new GregorianCalendar[num_A][2]; // Departure and arrival times for different trips from A to B
				timesBA = new GregorianCalendar[num_B][2]; // Departure and arrival times for different trips from B to A

				trueArrivalsB = new GregorianCalendar[num_A];
				trueArrivalsA = new GregorianCalendar[num_B];
				
							
				trainTakenB = new boolean[num_A];
				trainTakenA = new boolean[num_B];
				
				String[] tempArray;
				
				tempArray = new String[num_A];
				for (int i=0; i<num_A; i++) {
					tempArray[i] = br.readLine();
				}
				Arrays.sort(tempArray);
												
				for (int i=0; i<num_A; i++) { // Read travel times from A to B
					
					splitter = tempArray[i].split(" ");
					HHMMsplitter = splitter[0].split(":");					
					timesAB[i][0] = new GregorianCalendar(2008,07,17,Integer.parseInt(HHMMsplitter[0]),Integer.parseInt(HHMMsplitter[1]));
					HHMMsplitter = splitter[1].split(":");
					timesAB[i][1] = new GregorianCalendar(2008,07,17,Integer.parseInt(HHMMsplitter[0]),Integer.parseInt(HHMMsplitter[1]));				
					
					//DebugPrint(timesAB[i][0]);
					//DebugPrint(timesAB[i][1]);
					
				}
				
				tempArray = new String[num_B];
				for (int i=0; i<num_B; i++) {
					tempArray[i] = br.readLine();
				}
				Arrays.sort(tempArray);
				
				for (int i=0; i<num_B; i++) { // Read travel times from B to A
					
					splitter = tempArray[i].split(" ");
					HHMMsplitter = splitter[0].split(":");
					timesBA[i][0] = new GregorianCalendar(2008,07,17,Integer.parseInt(HHMMsplitter[0]),Integer.parseInt(HHMMsplitter[1]));
					HHMMsplitter = splitter[1].split(":");
					timesBA[i][1] = new GregorianCalendar(2008,07,17,Integer.parseInt(HHMMsplitter[0]),Integer.parseInt(HHMMsplitter[1]));		

					//DebugPrint(timesBA[i][0]);
					//DebugPrint(timesBA[i][1]);					
				}
				
				
				for (int i=0; i<num_A; i++) { // Calculate "true arrival" times at B of trips departing from A			
					
					trueArrivalsB[i] = 	new GregorianCalendar(
											timesAB[i][1].get(Calendar.YEAR),
											timesAB[i][1].get(Calendar.MONTH),
											timesAB[i][1].get(Calendar.DAY_OF_MONTH),
											timesAB[i][1].get(Calendar.HOUR_OF_DAY),
											timesAB[i][1].get(Calendar.MINUTE)
										);
					trueArrivalsB[i].add(Calendar.MINUTE,turnAroundTime); // Add turnaround time to arrivals for each trip
					trainTakenB[i] = false; // Initialize to false
					
				}
				
				for (int i=0; i<num_B; i++) { // Calculate "true arrival" times at A of trips departing from B	
								
					trueArrivalsA[i] = 	new GregorianCalendar(
											timesBA[i][1].get(Calendar.YEAR),
											timesBA[i][1].get(Calendar.MONTH),
											timesBA[i][1].get(Calendar.DAY_OF_MONTH),
											timesBA[i][1].get(Calendar.HOUR_OF_DAY),
											timesBA[i][1].get(Calendar.MINUTE)
										);
					trueArrivalsA[i].add(Calendar.MINUTE,turnAroundTime); // Add turnaround time to arrivals for each trip
					trainTakenA[i] = false; // Initialize to false
					
				}
				
				num_Trains_A = 0;
				for (int i=0; i<num_A; i++) { // Calculate number of trains needed for station A, looping through each trip from A to B
					//System.out.println("Probando: ");
					//DebugPrint(timesAB[i][0]);
					boolean train_still_needed = true; // Assume a train is still needed
					int j=0;
					while (j<num_B && train_still_needed) {
						//System.out.println("  Opciones: ");
						//DebugPrint(trueArrivalsA[j]);
						//System.out.println(trainTakenA[j]);
						
						if (!timesAB[i][0].before(trueArrivalsA[j]) && !trainTakenA[j]) { // There is a train available to take that trip at that hour
							trainTakenA[j] = true;
							train_still_needed = false;
						}
						else {
							j++;
						}
					}
					if (j == num_B) {
						//System.out.println("El tren no tiene opcin, incrementar num_Trains ");
						num_Trains_A++; // Increment number of trains needed in station A
					}
					
				}
				
				num_Trains_B = 0;
				for (int i=0; i<num_B; i++) { // Calculate number of trains needed for station B, looping through each trip from B to A
					
					boolean train_still_needed = true; // Assume a train is still needed
					int j=0;
					while (j<num_A && train_still_needed) {
						if (!timesBA[i][0].before(trueArrivalsB[j]) && !trainTakenB[j]) { // There is a train available to take that trip at that hour
							trainTakenB[j] = true;
							train_still_needed = false;
						}
						else {
							j++;
						}
					}
					if (j == num_A) {
						num_Trains_B++; // Increment number of trains needed in station B
					}
					
				}
				
				DebugPrint("Case #"+currentCaseNum+": "+num_Trains_A+" "+num_Trains_B);
				bw.write("Case #"+currentCaseNum+": "+num_Trains_A+" "+num_Trains_B+"\r\n");
			}
			
			bw.close();
			br.close();
		}
		catch (IOException ioe) {
			ioe.printStackTrace();
		}
		
	}
	
	
	
	
	private static void DebugPrint(String msg) {
		if (debug) {
			System.out.println(msg);
		}
	}
	
	private static void DebugPrint(int n) {
		DebugPrint( (new Integer(n)).toString() );
	}
	
	private static void DebugPrint(GregorianCalendar g) { 
		int hour = g.get(Calendar.HOUR_OF_DAY);
		int min = g.get(Calendar.MINUTE);
		String hourPadded="";
		String minPadded="";
		if (hour<10) {
			hourPadded = "0"+String.valueOf(hour);
		}
		else {
			hourPadded = String.valueOf(hour);
		}
		if (min<10) {
			minPadded = "0"+String.valueOf(min);
		}
		else {
			minPadded = String.valueOf(min);
		}
		System.out.println(hourPadded+":"+minPadded);
	}
	
	private static int maxArray(int[] a,int whatToReturn) { 
		int max=a[0];
		int maxIndex=0;
		for (int i=1; i<a.length; i++) {
			if (max < a[i]) {
				max = a[i];
				maxIndex = i;
			}
		}
		if (whatToReturn == 1) { // Return the maximum value
			return max;
		}
		if (whatToReturn == 2) { // Return the currentCaseNum of the maximum value
			return maxIndex;
		}
		return -1;
	}
	private static void DebugPrintArray(String[] a) {
		if (debug) {
			String txt="[";
			for (int i=0;i<a.length;i++) {
				txt=txt+a[i];
				if (i<a.length-1) {
					txt=txt+"|";
				}
			}
			txt=txt+"]";
			System.out.println(txt);
		}
	}
	private static void DebugPrintArray(int[] a) {
		if (debug) {
			String txt="[";
			for (int i=0;i<a.length;i++) {
				txt=txt+a[i];
				if (i<a.length-1) {
					txt=txt+"|";
				}
			}
			txt=txt+"]";
			System.out.println(txt);
		}
	}
	
}
