import java.io.*;
import java.lang.*;
import java.util.*;

public class SearchEngineChoiceMinimization {

	static boolean debug=true;	// Debug parameter - if true displays additional information on the screen.

	public static void main(String[] args) {
		
		try {
			BufferedReader br = new BufferedReader(new FileReader(args[0]));
			BufferedWriter bw = new BufferedWriter(new FileWriter("results.txt"));
			
			String thisLine;
			int index;
			
			int num_Tests; // Number of test cases
			
			int num_SE; // Number of search engines per test case
			int num_Query; // Number of queries per test case
			String[] SE; // Search engine names per test case
			String[] Query; // Query list per test case
			String[] Choices; // List of search engine choices. Note that this array includes the initial choice.
			
			int[] InitialPosition; // The method optimizes by keeping track of the first appearance of each search engine name within the query sequence.
			
			int num_Switches; // Number of switches per test case
					
			
			
			thisLine = br.readLine(); // Read number of test cases
			num_Tests = Integer.parseInt(thisLine); // 0<N<=20
			
			DebugPrint(num_Tests);
			
			for (int currentCaseNum=1; currentCaseNum<=num_Tests; currentCaseNum++) {	// Loop through all test cases
				
				num_Switches = 0; // Initialize in 0 each time
				
				thisLine = br.readLine(); // Read number of search engines for this test case
				num_SE = Integer.parseInt(thisLine); // 2 <= S
				SE = new String[num_SE]; // Allocates space for  num_SE  search engines
				InitialPosition = new int[num_SE]; // Defines the array for initial positions for each test case
								
				DebugPrint(num_SE);
				
				for (index=0; index < num_SE; index++) { // Read search engine names
					thisLine = br.readLine();
					SE[index] = thisLine;
				}
	
				if (debug) {
					for (int i=0;i<num_SE;i++) {
						System.out.println(SE[i]);
					}
				}
	
				thisLine = br.readLine(); // Read number of queries for this test case
				num_Query = Integer.parseInt(thisLine); // 0 <= Q
				
				if (num_Query > 0) { // Only execute if number of queries is greater than zero
					Query = new String[num_Query];
					
					for (index=0; index < num_Query; index++) { // Read queries
						thisLine = br.readLine();
						Query[index] = thisLine;
					}
					
					
					String[] SubQuery; // Define a query sequence  Q{k}  as a subsequence of the original sequence  Query
					int num_SubQuery;
					
					num_SubQuery = num_Query; // First time around, Q{0}=Query
					int SubQueryStart = 0; // First time around, sub-query starts at position 0 of Query
					
					SubQuery = new String[num_SubQuery]; // Initialize object					
					System.arraycopy( Query, SubQueryStart, SubQuery, 0, num_SubQuery ); // Create the sub-array
					
					DebugPrint("\t ==> Query: ");
					DebugPrintArray(Query);
					DebugPrint("\t ==> Subquery: ");
					DebugPrintArray(SubQuery);
					
					while (SubQuery != null) {
										
						for (int i=0; i<num_SE; i++) {	// Loop through the list of search engines to find initial position in the query list
							int j=0;
							boolean found=false;							
							while (j<num_SubQuery && !found) {	// Find the first occurrence within the Query array
								if (SubQuery[j].equals(SE[i])) {
									found=true;
								}
								else {
									j++;
								}
							}
							
							InitialPosition[i] = j; // If search engine was not found,  InitialPosition  will be equal to  num_SubQuery  , otherwise it will be equal to a number less than that.
							
						}
						
						int maxPos = maxArray(InitialPosition,1);
						int maxPosIndex = maxArray(InitialPosition,2);
						
						if (num_SubQuery != num_Query) { // Only count a switch if this is not the initial choice
							num_Switches++; // Increment switches						
						}
						
						String[] TmpQuery = new String[num_SubQuery]; // Temporary array
						System.arraycopy( SubQuery, 0, TmpQuery, 0, num_SubQuery ); // Copy SubQuery into temporary array
						
						DebugPrint("\t ==> Temporary Query: ");
						DebugPrintArray(TmpQuery);
						
						num_SubQuery = num_SubQuery - maxPos; // Define length of new sub-query
						int subQueryStart = maxPos;
												
						SubQuery = null;						
						
						if (num_SubQuery > 0) {
							SubQuery = new String[num_SubQuery]; // Create new sub-query  Q{k}						
							System.arraycopy( TmpQuery, subQueryStart, SubQuery, 0, num_SubQuery ); // Create the sub-array for Q{k}
							DebugPrint("num_Subquery="+num_SubQuery+",subQueryStart="+subQueryStart);
							DebugPrint("\t ==> Nueva Subquery: ");
							DebugPrintArray(SubQuery);
						}
						
						
						
						if (debug) {
							for (int i=0; i<num_SE; i++) {
								System.out.println(SE[i]+" => "+InitialPosition[i]);
							}
							if (maxPos == num_SubQuery) {
								System.out.println("Case #"+currentCaseNum+": choice "+num_Switches+" - "+SE[maxPosIndex]+" dado que no aparece" );
							}
							else {
								System.out.println("Case #"+currentCaseNum+": choice "+num_Switches+" - "+SE[maxPosIndex]+" en la pos. "+maxPos);
							}
						}		
					}

					bw.write("Case #"+currentCaseNum+": "+num_Switches+"\r\n");
					
				}
				else {	// The optimal solution for this case is 0
				
					if (debug) {
						System.out.println("Case #"+currentCaseNum+": 0\r\n");
					}
					bw.write("Case #"+currentCaseNum+": 0\r\n");				
				}
				
				
			}
		
			bw.close();
			br.close();
		}
		catch (IOException ioe) {
			ioe.printStackTrace();
		}
	}
	
	private static void DebugPrint(String msg) {
		if (debug) {
			System.out.println(msg);
		}
	}
	private static void DebugPrint(int n) {
		DebugPrint( (new Integer(n)).toString() );
	}
	private static int maxArray(int[] a,int whatToReturn) { 
		int max=a[0];
		int maxIndex=0;
		for (int i=1; i<a.length; i++) {
			if (max < a[i]) {
				max = a[i];
				maxIndex = i;
			}
		}
		if (whatToReturn == 1) { // Return the maximum value
			return max;
		}
		if (whatToReturn == 2) { // Return the index of the maximum value
			return maxIndex;
		}
		return -1;
	}
	private static void DebugPrintArray(String[] a) {
		if (debug) {
			String txt="[";
			for (int i=0;i<a.length;i++) {
				txt=txt+a[i];
				if (i<a.length-1) {
					txt=txt+"|";
				}
			}
			txt=txt+"]";
			System.out.println(txt);
		}
	}
	private static void DebugPrintArray(int[] a) {
		if (debug) {
			String txt="[";
			for (int i=0;i<a.length;i++) {
				txt=txt+a[i];
				if (i<a.length-1) {
					txt=txt+"|";
				}
			}
			txt=txt+"]";
			System.out.println(txt);
		}
	}
	
}

/*
class Point {

	private int x;
	private int y;
	
	public Point(int x, int y) {
		this.x = x;
		this.y = y;
	}
	
	public String toString() {
		return "("+this.x+","+this.y+")";
	}
	
	public boolean equals(Object b) {
		if (b == null) {
			return false;
		} 
		else if (!b.getClass().equals(this.getClass())) {
			return false;
		}
		else {
			return (this.x == ((Point) b).x && this.y == ((Point) b).y);
		}
	}

}
*/