import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;
import java.util.Arrays;
import java.util.Comparator;


public class Round1B {
	private static BufferedReader r;
	private static PrintStream outFile;
	private static PrintStream out = new PrintStream(new OutputStream() {
		@Override
		public void write(int b) throws IOException {
			System.out.write(b);
			outFile.write(b);
		}
	});

	public static void main(String[] args) throws IOException {
		File f = new File(args[0]);
		r = new BufferedReader(new FileReader(f));
		outFile = new PrintStream(new FileOutputStream(new File("output")));
		final int numCases = readInt();
		
		for(int i = 0; i < numCases; i++) {
			out.print("Case #" + (i+1) + ": ");

			solve();
			
			out.println();
		}
		
		out.close();
	}
	
	private static class Segment {
		float pos;
		int length;
		float timeToSpread;
	}
	
	private static void solve() throws IOException {
		int[] data = readIntArray(2);
		int numPoints = data[0];
		int minDist = data[1];
		
		Segment[] segments = new Segment[numPoints];
		
		float spreadTime = 0;
		for(int i = 0; i < numPoints; i++) {
			data = readIntArray(2);
			Segment s = new Segment();
			s.pos = data[0] - (data[1]-1) * minDist * 0.5f;
			s.length = data[1] * minDist;
			s.timeToSpread = (data[1] - 1) / 2.0f * minDist;
			segments[i] = s;
			if(s.timeToSpread > spreadTime) {
				spreadTime = s.timeToSpread; 
			}
		}
		
		Arrays.sort(segments, new Comparator<Segment>() {
			@Override
			public int compare(Segment arg0, Segment arg1) {
				return new Float(arg0.pos).compareTo(arg1.pos);
			}});

		
		boolean overlap = false;
		boolean adjusted = false;
		do {
			overlap = false;
			adjusted = false;
			Segment lastSegment = null;
			float lastPos = 0;
			for(Segment s : segments) {
				if(lastSegment == null) {
					lastSegment = s;
					lastPos = s.pos + s.length;
					continue;
				}
				if(lastPos > s.pos) {
					overlap = true;
					float overlapAmount = lastPos - s.pos;
					if(lastSegment.timeToSpread < s.timeToSpread) {
						float timeOverlap = s.timeToSpread - lastSegment.timeToSpread;
						float adj = Math.min(timeOverlap, overlapAmount);
						lastSegment.pos -= adj;
						lastSegment.timeToSpread += adj;
						adjusted = true;
						break;
					} else if (s.timeToSpread < lastSegment.timeToSpread) {
						float timeOverlap = lastSegment.timeToSpread - s.timeToSpread;
						float adj = Math.min(timeOverlap, overlapAmount);
						s.pos += adj;
						s.timeToSpread += adj;
						adjusted = true;
						break;
					}
				}
				lastSegment = s;
				lastPos = s.pos + s.length;
			}
		} while(overlap && adjusted);
		
		
		float curOverlap = 0;
		float maxOverlap = 0;
		float lastPos = segments[0].pos;
		for(Segment s : segments) {
			if(lastPos > s.pos) {
				curOverlap += lastPos - s.pos;
				if(curOverlap > maxOverlap) {
					maxOverlap = curOverlap;
				}
			} else {
				curOverlap -= s.pos - lastPos;
				if(curOverlap < 0) {
					curOverlap = 0;
				}
			}
			lastPos = s.pos + s.length;
		}
		
		out.print((float)maxOverlap / 2.0 + spreadTime);
	}

	private static int[] readIntArray(int maxItems) throws IOException {
		int[] array = new int[maxItems];
		String line = r.readLine().trim();
		String[] data = line.split(" ");
		for(int i = 0; i < data.length && i < maxItems; i++) {
			array[i] = new Integer(data[i]);
		}
		return array;
	}

	private static int readInt() throws IOException {
		String line = r.readLine().trim();
		return new Integer(line);
	}
	
	private static long readLong() throws IOException {
		String line = r.readLine().trim();
		return new Long(line);
	}

}
