package com.bkraszewski;

import java.io.IOException;

public class BathroomStalls {

    public static Cabin findLastOccupiedCabin(long numberOfStalls, long queueLenght) {

        Cabin[] cabins = initializeCabins((int) numberOfStalls);

        Cabin nextCabin = null;

        for (int a = 0; a < queueLenght; a++) {
            long minLsRs = Long.MIN_VALUE;
            long maxLsRs = Long.MIN_VALUE;
            setupCabinDistances(cabins);
            nextCabin = findBestCabin(cabins, minLsRs, maxLsRs, nextCabin);

            if (nextCabin != null) {
                nextCabin.occupied = true;
            }
        }

        return nextCabin;
    }

    private static Cabin[] initializeCabins(int numberOfStalls) {
        Cabin[] cabins = new Cabin[numberOfStalls + 2];
        for (int a = 0; a < cabins.length; a++) {
            Cabin cabin = new Cabin();
            cabin.occupied = a == 0 || a == cabins.length - 1;
            cabins[a] = cabin;
        }
        return cabins;
    }

    private static Cabin findBestCabin(Cabin[] cabins, long minLsRs, long maxLsRs, Cabin nextCabin) {
        for (int a = 1; a < cabins.length - 1; a++) {
            Cabin cabin = cabins[a];
            if (cabin.occupied) {
                continue;
            }

            if (cabin.minLsRs > minLsRs) {
                nextCabin = cabin;
                minLsRs = cabin.minLsRs;
                maxLsRs = cabin.maxLsRs;
            } else if (cabin.minLsRs == minLsRs) {
                if (cabin.maxLsRs > maxLsRs) {
                    nextCabin = cabin;
                    minLsRs = cabin.minLsRs;
                    maxLsRs = cabin.maxLsRs;
                }
            }
        }
        return nextCabin;
    }

    private static void setupCabinDistances(Cabin[] cabins) {
        for (int a = 1; a < cabins.length - 1; a++) {
            Cabin cabin = cabins[a];
            int ls = calculateDistanceToFirstOccupiedLeft(a - 1, cabins);
            int rs = calculateDistanceToFirstOccupiedRight(a + 1, cabins);
            cabin.minLsRs = Math.min(ls, rs);
            cabin.maxLsRs = Math.max(ls, rs);
        }
    }

    private static int calculateDistanceToFirstOccupiedLeft(int index, Cabin[] cabins) {
        int ls = 0;
        for (int a = index; a > -1; a--) {
            Cabin neightbour = cabins[a];
            if (neightbour.occupied) {
                return ls;
            } else {
                ls++;
                continue;
            }
        }

        return ls;
    }

    private static int calculateDistanceToFirstOccupiedRight(int index, Cabin[] cabins) {
        int rs = 0;
        for (int a = index; a < cabins.length; a++) {
            Cabin neightbour = cabins[a];
            if (neightbour.occupied) {
                return rs;
            } else {
                rs++;
                continue;
            }
        }

        return rs;
    }


    public static class Cabin {
        public boolean occupied = false;
        public long maxLsRs = 0;
        public long minLsRs = 0;

        @Override
        public String toString() {
            return "Cabin{" +
                    "occupied=" + occupied +
                    ", maxLsRs=" + maxLsRs +
                    ", minLsRs=" + minLsRs +
                    '}';
        }
    }

    public static void main(String args[]) throws IOException {
//        String fileName = "B-small-practice";
        String fileName = "C-small-1-attempt0";

        String inputFile = String.format("./input/bathrooms/%s.in", fileName);
        String outputFile = String.format("./output/bathrooms/%s.out", fileName);

        GenericLineReader reader = new GenericLineReader();
        reader.mapInputToOutput(inputFile, outputFile, (line) ->
                {
                    String[] params = line.split("\\s+");
                    long stalls = Long.valueOf(params[0]);
                    long queue = Long.valueOf(params[1]);

                    Cabin cabin = findLastOccupiedCabin(stalls, queue);
                    return String.format("%d %d", cabin.maxLsRs, cabin.minLsRs);

                }
        );
    }
}
