import java.util.*;
import java.math.*;
import java.io.*;

public class TicketSwapping {

    class Point implements Comparable<Point> {
        int d;
        int p;
        int stop;
        Point(int d, int p, int stop) {
            this.d = d;
            this.p = p;
            this.stop = stop;
        }
        public int compareTo(Point that) {
            if (this.d != that.d) return this.d - that.d;
            else return this.stop - that.stop;
        }
    }

    private void solve() throws Exception {
        int N = cr.nextInt();
        int M = cr.nextInt();
        Point[] points = new Point[2 * M];
        long normal = 0;
        for (int i = 0; i < M; i++) {
            int start = cr.nextInt() - 1;
            int end = cr.nextInt() - 1;
            int p = cr.nextInt();
            int m = end - start;
            points[2 * i] = new Point(start, p, 0);
            points[2 * i + 1] = new Point(end, p, 1);
            normal += m * (N + N + 1 - m) / 2 * p;
        }
        Arrays.sort(points);

        long cost = 0;
        TreeMap<Integer, Integer> in = new TreeMap<Integer, Integer>();
        for (Point q : points) {
            if (q.stop == 0) {
                if (in.containsKey(q.d)) {
                    int inside = in.get(q.d);
                    in.put(q.d, q.p + inside);
                } else {
                    in.put(q.d, q.p);
                }
            } else {
                int current = q.d;
                int leave = q.p;
                while (leave > 0) {
                    int last = in.lastKey();
                    int num = in.get(last);
                    int left = 0;
                    if (num <= leave) {
                        in.remove(last);
                        left = num;
                        leave -= num;
                    } else {
                        num = num - leave;
                        in.put(last, num);
                        left = leave;
                        leave = 0;
                    }
                    int m = current - last;
                    cost += m * (2 * N + 1 - m) / 2 * left;
                }
            }
        }
//        System.out.println(in.size());
        System.out.println(N);
        System.out.println(M);
        pw.println(normal - cost);
    }

    ContestReader cr;
    PrintWriter pw;

    public TicketSwapping(InputStream in, Writer out) {
        this.cr = new ContestReader(in);
        this.pw = new PrintWriter(out);
    }

    public static void main(String[] args) throws Exception {
        TicketSwapping solver = new TicketSwapping(new FileInputStream("A-small-attempt2.in"), new FileWriter("A-small-attempt2.out"));

        int T = solver.cr.nextInt();
        for (int caseNum = 1; caseNum <= T; caseNum++) {
            System.out.println("Processing case " + caseNum);
            solver.pw.print("Case #" + caseNum + ": ");
            solver.solve();
        }

        solver.pw.flush();
        solver.pw.close();
    }

    class ContestReader {
        BufferedReader reader;
        StringTokenizer tokenizer;

        public ContestReader(InputStream input) {
            reader = new BufferedReader(new InputStreamReader(input));
            tokenizer = new StringTokenizer("");
        }

        public String next() throws Exception {
            while (!tokenizer.hasMoreTokens()) {
                tokenizer = new StringTokenizer(reader.readLine());
            }
            return tokenizer.nextToken();
        }

        public int nextInt() throws Exception {
            return Integer.parseInt(next());
        }

        public double nextDouble() throws Exception {
            return Double.parseDouble(next());
        }
    }
}
