import java.io.*;
import java.util.Scanner;
import java.text.DecimalFormat;

public class B {

    private static double dist(double[] values) {
        double d = 0;
        for (int i=0; i<3; ++i) {
            d += values[i]*values[i];
        }
        return Math.sqrt(d);
    }

    private static double[] buildV(double[] p1, double[] p2) {
        double[] p = new double[3];
        for (int i=0; i<3; ++i) {
            p[i] = p2[i] - p1[i];
        }
        return p;
    }

    private static double dot(double[] a, double[] b, double[] c) {
        double[] ab = buildV(a, b);
        double[] bc = buildV(b, c);
        return dotV(ab, bc);
    }

    private static double dotV(double[] v1, double[] v2) {
        double d= 0;
        for (int i=0; i<3; ++i) {
            d += v1[i] * v2[i];
        }
        return d;
    }
    private static double[] cross(double[] v1, double[] v2) {
        double i = v1[1]*v2[2] - v2[1]*v1[2];
        double j = v2[0]*v1[2] - v1[0]*v2[2];
        double k = v1[0]*v2[1] - v2[0]*v1[1];
        return new double[]{i,j,k};
    }

    public static double[] solve(double[] values) {
        double dcb = dist(values);
        double dmin = 0;
        double t = 0;
        double[] c = new double[]{0,0,0};

        double[] a = new double[3];
        for (int i=0; i<3; ++i) {
            a[i] = values[i] + values[i+3]*1;
        }

        double dt = dot(a, values, c);
        double[] ab = buildV(a, values);
        double dab = dist(ab);

        if (dt > 0 || dab == 0) {
            return new double[]{dcb, 0};
        }

        double cross = dist(cross(ab, values));

        dmin = Math.abs(cross/dab);

        dt = Math.sqrt(dcb*dcb - dmin*dmin);
        t = dt/dab;

        return new double[]{dmin, t};
    }

    public static void main(String[] args) throws IOException {
        File fIn = new File("C:\\Work\\GCJ\\download\\B-large.in");
        File fOut = new File("C:\\Work\\GCJ\\src\\b.out");

        FileReader fileReader = new FileReader(fIn);
        FileWriter fileWriter = new FileWriter(fOut);

        BufferedReader in = new BufferedReader(fileReader);
        BufferedWriter out = new BufferedWriter(fileWriter);

        DecimalFormat df = new DecimalFormat("0.00000000");
        try {
            Scanner sc = new Scanner(in);
            int testCases = readIntsLine(sc, 1)[0];

            for (int i = 0; i < testCases; ++i) {
                int N = readIntsLine(sc, 1)[0];
                double[] values = new double[6];
                for (int j=0; j<N; ++j) {
                    int[] cValues = readIntsLine(sc, 6);
                    for (int k =0; k<6; ++k) {
                        values[k] += cValues[k];
                    }
                }
                for (int k =0; k<6; ++k) {
                    values[k] = values[k] / N;
                }
                double[] res = solve(values);

                String resultStr = "Case #" + (i + 1) + ": " +
                        df.format(res[0]) + " " + df.format(res[1]);

                if (i != 0) {
                    out.newLine();
                }
                out.append(resultStr);
                out.flush();
            }
        } finally {
            in.close();
            out.close();
        }
    }


    private static String[] readTokensLine(Scanner sc, int len) {
        Scanner lineScanner = new Scanner(sc.nextLine());
        String[] res = new String[len];
        for (int i = 0; i < len; ++i) {
            res[i] = lineScanner.next();
        }
        return res;
    }

    private static int[] readIntsLine(Scanner sc, int len) {
        Scanner lineScanner = new Scanner(sc.nextLine());
        int[] res = new int[len];
        for (int i = 0; i < len; ++i) {
            res[i] = lineScanner.nextInt();
        }
        return res;
    }

    private static double[] readDblsLine(Scanner sc, int len) {
        Scanner lineScanner = new Scanner(sc.nextLine());
        double[] res = new double[len];
        for (int i = 0; i < len; ++i) {
            res[i] = lineScanner.nextInt();
        }
        return res;
    }

}
