import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.DecimalFormat;
import java.util.Scanner;

public class FlySwatter
{

    private static double findPeres(double R, double coord)
    {
        return Math.sqrt((R * R) - (coord * coord));
    }

    private static double cross(double x1, double y1,
                                double x2, double y2)
    {
        return (x1 * y2) - (x2 * y1);
    }

    private static double triangleArea(double x1, double y1,
                                       double x2, double y2) {
        return Math.abs(cross(x1,y1,x2,y2) / 2.0);
    }


    private static double circleSector(double R, double x, double y)
    {
        double angle1 = Math.acos(x / R);
        double angle2 = Math.asin(y / R);
        double alpha = Math.abs(angle2 - angle1);
        return R * R * alpha / 2.0;
    }

    private static double circleArea(double r)
    {
        return r * r * Math.PI;
    }

    private static double circleAngleArea(double R, double x, double y)
    {
        double y2 = findPeres(R, x);
        double x2 = findPeres(R, y);

        double areaSector = circleSector(R, x, y);
        double areaTriange1 = triangleArea(x, y, x, y2);
        double areaTriange2 = triangleArea(x, y, x2, y);
        return areaSector - areaTriange1 - areaTriange2;
    }

    private static boolean isInside(double R, double x, double y)
    {
        return ((x * x) + (y * y)) < (R * R);
    }

    public static double intersect(double r, double x, double y, double l)
    {
        double x2 = x + l;
        double y2 = y + l;
        if (isInside(r, x2, y2)) {
            return l * l;
        }
        if (!isInside(r, x, y)) {
            return 0.0;
        }

        double area = 0;
        if (isInside(r, x, y)) {
            area += circleAngleArea(r, x, y);
        }
        if (isInside(r, x2, y)) {
            area -= circleAngleArea(r, x2, y);
        }
        if (isInside(r, x, y2)) {
            area -= circleAngleArea(r, x, y2);
        }

        return area;
    }


    public static double solve(double f, double R, double t, double r, double g)
    {
        double l = g -  f - f;
        if (l <= 0.0) {
            return 1.0;
        }

        double totalArea = circleArea(R) / 4.0;

        double innerR = R - t - f;

        double start = r + f;
        double step = g + (2.0 * r);

        double result = 0.0;
        double curX = start;
        double curY = start;
        while (curX <= innerR) {
            while (curY <= innerR) {
                result += intersect(innerR, curX, curY, l);
                curY += step;
            }
            curX += step;
            curY = start;
        }

        return 1.0 - (result / totalArea);
    }


    public static void main(String[] args) throws IOException
    {
        File dir = new File(args[0]);
        File fIn = new File(dir, args[1]);
        File fOut = new File(dir, "a.out");

        FileReader fileReader = new FileReader(fIn);
        FileWriter fileWriter = new FileWriter(fOut);

        BufferedReader in = new BufferedReader(fileReader);
        BufferedWriter out = new BufferedWriter(fileWriter);

        try {
            Scanner sc = new Scanner(in);
            int n = readIntsLine(sc, 1)[0];

            for (int i = 0; i < n; ++i) {
                //f, R, t, r and g
                double f = sc.nextDouble();
                double R = sc.nextDouble();
                double t = sc.nextDouble();
                double r = sc.nextDouble();
                double g = sc.nextDouble();

                double res = solve(f, R, t, r, g);
                DecimalFormat df = new DecimalFormat("0.000000");
                String resultStr = "Case #" + (i + 1) + ": " + df.format(res);
                if (i != 0) {
                    out.newLine();
                }
                out.append(resultStr);
            }
            out.flush();
        } finally {
            in.close();
            out.close();
        }
    }


    private static int[] readIntsLine(Scanner sc, int len)
    {
        Scanner lineScanner = new Scanner(sc.nextLine());
        int[] res = new int[len];
        for (int i = 0; i < len; ++i) {
            res[i] = lineScanner.nextInt();
        }
        return res;
    }

}