import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.LinkedList;
import java.util.List;
import java.util.PriorityQueue;
import java.util.Scanner;

public class TrainTimetable
{

    private static void goThrough(TableTime max,
                                  TableTime min,
                                  PriorityQueue<TableTime> maxQ,
                                  PriorityQueue<TableTime> minQ,
                                  Pool maxPool,
                                  Pool minPool,
                                  int turnaround)
    {
        TableTime currentMin = min;
        while (currentMin != null &&
               (max == null || currentMin.compareTo(max) <= 0)) {
            minPool.get(currentMin.getStartClock());
            maxPool.put(currentMin.getReadyTime(turnaround));
            currentMin = minQ.poll();
        }
        if (max != null) {
            maxQ.add(max);
        }
        if (currentMin != null) {
            minQ.add(currentMin);
        }
    }

    public static int[] solve(PriorityQueue<TableTime> queueA,
                              PriorityQueue<TableTime> queueB,
                              int turnaround)
    {
        Pool poolA = new Pool();
        Pool poolB = new Pool();

        TableTime currentA = queueA.poll();
        TableTime currentB = queueB.poll();
        while (currentA != null || currentB != null) {
            if (currentA == null ||
                (currentB != null && currentA.compareTo(currentB) > 0)) {
                goThrough(currentA, currentB,
                          queueA, queueB,
                          poolA, poolB,
                          turnaround);
            } else {
                goThrough(currentB, currentA,
                          queueB, queueA,
                          poolB, poolA,
                          turnaround);
            }
            currentA = queueA.poll();
            currentB = queueB.poll();
        }

        return new int[]{poolA.getInitSize(), poolB.getInitSize()};
    }


    public static void main(String[] args) throws IOException
    {
        File dir = new File(args[0]);
        File fIn = new File(dir, args[1]);
        File fOut = new File(dir, "a.out");

        FileReader fileReader = new FileReader(fIn);
        FileWriter fileWriter = new FileWriter(fOut);

        BufferedReader in = new BufferedReader(fileReader);
        BufferedWriter out = new BufferedWriter(fileWriter);


        try {
            Scanner sc = new Scanner(in);
            int n = readIntsLine(sc, 1)[0];

            for (int i = 0; i < n; ++i) {
                int turnaround = readIntsLine(sc, 1)[0];
                int[] nn = readIntsLine(sc, 2);
                PriorityQueue<TableTime> queueA = new PriorityQueue<TableTime>();
                PriorityQueue<TableTime> queueB = new PriorityQueue<TableTime>();
                for (int j = 0; j < nn[0]; ++j) {
                    queueA.add(new TableTime(sc.nextLine()));
                }
                for (int j = 0; j < nn[1]; ++j) {
                    queueB.add(new TableTime(sc.nextLine()));
                }
                int[] res = solve(queueA, queueB, turnaround);

                String resultStr = "Case #" + (i + 1) + ": " + res[0] + " " +
                                   res[1];
                if (i != 0) {
                    out.newLine();
                }
                out.append(resultStr);
            }
            out.flush();
        } finally {
            in.close();
            out.close();
        }
    }


    private static int[] readIntsLine(Scanner sc, int len)
    {
        Scanner lineScanner = new Scanner(sc.nextLine());
        int[] res = new int[len];
        for (int i = 0; i < len; ++i) {
            res[i] = lineScanner.nextInt();
        }
        return res;
    }

    private static class TableTime implements Comparable<TableTime>
    {
        private Clock startClock = null;
        private Clock finishClock = null;

        public TableTime(Clock startClock, Clock finishClock)
        {
            this.startClock = startClock;
            this.finishClock = finishClock;
        }

        public TableTime(String line)
        {
            Scanner sc = new Scanner(line);
            sc.useDelimiter(" ");
            startClock = new Clock(sc.next());
            finishClock = new Clock(sc.next());
        }

        public Clock getReadyTime(int turnaround)
        {
            return finishClock.addMinutes(turnaround);
        }

        public Clock getStartClock()
        {
            return startClock;
        }

        public Clock getFinishClock()
        {
            return finishClock;
        }

        public int compareTo(TableTime o)
        {
            return startClock.compareTo(o.getStartClock());
        }

        public String toString()
        {
            return startClock.toString() + " " + finishClock.toString();
        }
    }

    private static class Clock implements Comparable<Clock>
    {
        int h;
        int m;

        public Clock(int h, int m)
        {
            this.h = h;
            this.m = m;
        }

        public Clock(String s)
        {
            Scanner sc = new Scanner(s);
            sc.useDelimiter(":");
            h = sc.nextInt();
            m = sc.nextInt();
        }

        public Clock addMinutes(int t)
        {
            int nm = m + t;
            int nh = h + (nm / 60);
            nm %= 60;
            return new Clock(nh, nm);
        }

        public int compareTo(Clock c)
        {
            if (h < c.h || (h == c.h && m < c.m)) {
                return -1;
            } else if (h > c.h || (h == c.h && m > c.m)) {
                return 1;
            } else {
                return 0;
            }
        }

        public String toString()
        {
            return h +":"+m;
        }
    }

    private static class Pool
    {

        private int initSize = 0;
        private List<Clock> availableClocks = new LinkedList<Clock>();

        public void get(Clock c)
        {

            Clock minClock = null;
            int minClockIndex = -1;

            int index = 0;
            for (Clock clock : availableClocks) {
                if (clock.compareTo(c) <= 0) {
                    if (minClock == null) {
                        minClock = clock;
                        minClockIndex = index;
                    } else if (clock.compareTo(minClock) < 0) {
                        minClock = clock;
                        minClockIndex = index;
                    }
                }
                ++index;
            }
            if (minClock != null) {
                availableClocks.remove(minClockIndex);
            } else {
                ++initSize;
            }
        }

        public void put(Clock c)
        {
            availableClocks.add(c);
        }

        public int getInitSize()
        {
            return initSize;
        }
    }

}
