package codejam;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.Scanner;

import org.junit.Assert;
import org.junit.Test;

public class CBathroomStalls {

	static class Pair {
		long val1;
		long val2;
	}
	
	static class Occupation {
		int closest;
		int farthest;
		int index;
	}
	
	private Pair solve(long n, long k) {
		return solveBrutforce(n, k);
	}
	
	private Occupation occupy(boolean[] stalls) {
		int index = -1;
		int maxClosest = Integer.MIN_VALUE;
		int maxFarthest = Integer.MIN_VALUE;
		
		for (int i = 1; i < stalls.length - 1; i++) {
			if (!stalls[i]) {
				int empty = 0;
				for (int j = i - 1; j >= 0; j--) {
					if (!stalls[j]) {
						empty++;
					} else {
						break;
					}
				}
				int emptyLeft = empty;
				
				empty = 0;
				for (int j = i + 1; j < stalls.length; j++) {
					if (!stalls[j]) {
						empty++;
					} else {
						break;
					}
				}
				
				int emptyRight = empty;
				
				int closest = Math.min(emptyLeft, emptyRight);
				int farthest = Math.max(emptyLeft, emptyRight);
				if (closest > maxClosest) {
					index = i;
					maxClosest = closest;
					maxFarthest = farthest;
				} else if (closest == maxClosest) {					
					if (farthest > maxFarthest) {
						index = i;
						maxClosest = closest;
						maxFarthest = farthest;	
					}
				}
			}
		}
		
		Occupation o = new Occupation();
		o.index = index;
		o.closest = maxClosest;
		o.farthest = maxFarthest;
		return o;
	}
	
	private Pair solveBrutforce(long n, long k) {
		boolean[] stalls = new boolean[(int) n + 2];
		stalls[0] = true;
		stalls[stalls.length - 1] = true;
		
		Occupation o = null;
		for (int i = 0; i < k; i++) {
			o = occupy(stalls);
			stalls[o.index] = true;
		}
		
		Pair pair = new Pair();
		pair.val1 = o.farthest;
		pair.val2 = o.closest;
		return pair;
	}

	@Test
	public void testOccupation() {
		Occupation o = occupy(new boolean[] { true, false, false, false, true });
		Assert.assertEquals(2, o.index);
		Assert.assertEquals(1, o.closest);
		Assert.assertEquals(1, o.farthest);
		
		o = occupy(new boolean[] { true, false, true });
		Assert.assertEquals(1, o.index);
		Assert.assertEquals(0, o.closest);
		Assert.assertEquals(0, o.farthest);
		
		o = occupy(new boolean[] { true, false, false, true });
		Assert.assertEquals(1, o.index);
		Assert.assertEquals(0, o.closest);
		Assert.assertEquals(1, o.farthest);
		
		o = occupy(new boolean[] { true, false, false, false, false, true });
		Assert.assertEquals(2, o.index);
		Assert.assertEquals(1, o.closest);
		Assert.assertEquals(2, o.farthest);
		
		o = occupy(new boolean[] { true, false, true, false, false, true });
		Assert.assertEquals(3, o.index);
		Assert.assertEquals(0, o.closest);
		Assert.assertEquals(1, o.farthest);
	}
	
	@Test
	public void testBrutforce() {
		Pair p = solveBrutforce(4, 2);
		Assert.assertEquals(1, p.val1);
		Assert.assertEquals(0, p.val2);
		
		p = solveBrutforce(5, 2);
		Assert.assertEquals(1, p.val1);
		Assert.assertEquals(0, p.val2);
		
		p = solveBrutforce(6, 2);
		Assert.assertEquals(1, p.val1);
		Assert.assertEquals(1, p.val2);
		
		p = solveBrutforce(1000, 1000);
		Assert.assertEquals(0, p.val1);
		Assert.assertEquals(0, p.val2);
		
		p = solveBrutforce(1000, 1);
		Assert.assertEquals(500, p.val1);
		Assert.assertEquals(499, p.val2);
	}
	
	@Test
	public void testLarge() {
		Pair p = solveBrutforce(10000, 1);
		Assert.assertEquals(5000, p.val1);
		Assert.assertEquals(4999, p.val2);
	}
	
	@Test
	public void testPerfomance() {
		Pair p = solveBrutforce(1000, 1);
		Assert.assertEquals(500, p.val1);
		Assert.assertEquals(499, p.val2);
	}
	
	public static void main(String[] args) throws Exception {
		FileInputStream fis = new FileInputStream("d:\\1\\c.in");
		BufferedReader br = new BufferedReader(new InputStreamReader(fis));
		Scanner scan = new Scanner(br);
		int numberOfCases = scan.nextInt();

		for (int i = 0; i < numberOfCases; i++) {
			long nStalls = scan.nextLong();
			long kPeople = scan.nextLong();
			

			Pair result = new CBathroomStalls().solve(nStalls, kPeople);
			System.out.println("Case #" + (i + 1) + ": " + result.val1 + " " + result.val2);
		}

		scan.close();
	}

}
