package codejam;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;
import java.util.Scanner;

import org.junit.Assert;
import org.junit.Test;

public class DFashionShow {
	class GreedyQueens {
		Random r = new Random();

		static final int ATTEMPTS = 10;
		static final int QUEEN = -1;
		int[][] board;
		int n;
		int q;
		int firstPos = -1;

		public GreedyQueens() {
		}

		public GreedyQueens(int n, int q) {
			this.n = n;
			this.q = q;
		}

		private void init() {
			for (int i = 0; i < n; i++) {
				for (int j = 0; j < n; j++) {
					board[i][j] = 0;
				}
			}

			if (firstPos >= 0) {
				board[0][firstPos] = QUEEN;
				for (int i = 1; i < q; i++) {
					board[i][r.nextInt(n)] = QUEEN;
				}
			} else {
				for (int i = 0; i < q; i++) {
					board[i][r.nextInt(n)] = QUEEN;
				}
			}
		}

		private boolean isValid() {
			return isValid(this.board, this.n);
		}

		public boolean isValid(int[][] board, int n) {
			for (int i = 0; i < n; i++) {
				for (int j = 0; j < n; j++) {
					boolean valid = true;

					if (board[i][j] == QUEEN) {
						for (int k = 0; k < n; k++) {
							if (board[i][k] == QUEEN && k != j) {
								valid = false;
							}
							if (board[k][j] == QUEEN && k != i) {
								valid = false;
							}
							if (!valid) {
								break;
							}
						}

						int x = j + 1;
						int y = i + 1;
						while (x < n && y < n) {
							if (board[y][x] == QUEEN) {
								valid = false;
							}
							x++;
							y++;
						}

						x = j - 1;
						y = i - 1;
						while (x >= 0 && y >= 0) {
							if (board[y][x] == QUEEN) {
								valid = false;
							}
							x--;
							y--;
						}

						x = j + 1;
						y = i - 1;
						while (x < n && y >= 0) {
							if (board[y][x] == QUEEN) {
								valid = false;
							}
							x++;
							y--;
						}

						x = j - 1;
						y = i + 1;
						while (x >= 0 && y < n) {
							if (board[y][x] == QUEEN) {
								valid = false;
							}
							x--;
							y++;
						}
					}

					if (!valid) {
						return false;
					}
				}
			}

			return true;
		}

		private void debugPrint() {
			for (int i = 0; i < n; i++) {
				for (int j = 0; j < n; j++) {
					System.out.print(board[i][j] + " ");
				}
				System.out.println();
			}
			System.out.println();
		}

		private void countAttacks() {
			countAttacks(this.board, this.n);
		}

		public void countAttacks(int[][] board, int n) {
			for (int i = 0; i < n; i++) {
				for (int j = 0; j < n; j++) {
					if (board[i][j] != QUEEN) {
						board[i][j] = 0;
					}
				}
			}

			for (int i = 0; i < n; i++) {
				for (int j = 0; j < n; j++) {
					if (board[i][j] == QUEEN) {
						for (int k = 0; k < n; k++) {
							if (board[i][k] != QUEEN && k != j) {
								board[i][k]++;
							}
							if (board[k][j] != QUEEN && k != i) {
								board[k][j]++;
							}
						}

						int x = j + 1;
						int y = i + 1;
						while (x < n && y < n) {
							if (board[y][x] != QUEEN) {
								board[y][x]++;
							}
							x++;
							y++;
						}

						x = j - 1;
						y = i - 1;
						while (x >= 0 && y >= 0) {
							if (board[y][x] != QUEEN) {
								board[y][x]++;
							}
							x--;
							y--;
						}

						x = j + 1;
						y = i - 1;
						while (x < n && y >= 0) {
							if (board[y][x] != QUEEN) {
								board[y][x]++;
							}
							x++;
							y--;
						}

						x = j - 1;
						y = i + 1;
						while (x >= 0 && y < n) {
							if (board[y][x] != QUEEN) {
								board[y][x]++;
							}
							x--;
							y++;
						}
					}
				}
			}
		}

		public boolean find() {
			return find(-1);
		}
		
		public boolean find(int firstPos) {
			this.firstPos = firstPos;
			
			board = new int[n][];
			for (int i = 0; i < n; i++) {
				board[i] = new int[n];
			}

			init();
			if (isValid()) {
				return true;
			}

			if (n == 3 && firstPos >= 0) {
				for (int i = 1; i < n; i++) {
					for (int j = 0; j < n; j++) {
						board[i][j] = QUEEN;
						if (isValid()) {
							return true;
						}
						board[i][j] = 0;
					}
				}
			}
			
			countAttacks();
			boolean found = false;
			while (!found) {
				for (int k = 0; k < ATTEMPTS; k++) {
					for (int i = 0; i < n; i++) {
						if (i == 0 && firstPos >= 0) {
							i = 1;
						}
						
						int queenIndex = -1;
						int minAttackIndex = -1;
						int minAttack = Integer.MAX_VALUE;
						for (int j = 0; j < n; j++) {
							if (board[i][j] == QUEEN) {
								queenIndex = j;
							} else {
								if (board[i][j] < minAttack) {
									minAttack = board[i][j];
									minAttackIndex = j;
								}
							}
						}

						if (queenIndex >= 0) {
							board[i][queenIndex] = minAttack;
							board[i][minAttackIndex] = QUEEN;

							countAttacks();
						}
					}

					if (isValid()) {
						found = true;
						break;
					}
				}

				if (!found) {
					init();
					if (isValid()) {
						found = true;
						break;
					}

					countAttacks();
				}
			}

			return found;
		}
	}

	@Test
	public void testGreedyQueensFindLarge() {
		GreedyQueens gq = new GreedyQueens(16, 15);
		boolean found = gq.find();
		Assert.assertTrue(found);
	}

	@Test
	public void testGreedyQueensFindFirstSet() {
		GreedyQueens gq = new GreedyQueens(3, 2);
		gq.find(0);
		
		gq = new GreedyQueens(3, 2);
		gq.find(1);
		
		gq = new GreedyQueens(3, 2);
		gq.find(2);
	}
	
	@Test
	public void testGreedyQueensFind() {
		GreedyQueens gq = new GreedyQueens(3, 2);
		gq.find();

		gq = new GreedyQueens(4, 4);
		gq.find();
		
		gq = new GreedyQueens(8, 8);
		gq.find();

		gq = new GreedyQueens(10, 10);
		gq.find();
	}

	@Test
	public void testGreedyQueensCountAttacks() {
		int[][] board = new int[][] { { -1, 0, 0 }, { 0, 0, 0 }, { 0, 0, 0 } };
		new GreedyQueens().countAttacks(board, 3);
		int[][] attacks = new int[][] { { -1, 1, 1 }, { 1, 1, 0 }, { 1, 0, 1 } };
		Assert.assertArrayEquals(attacks, board);

		board = new int[][] { { -1, 0, 0 }, { 0, 0, -1 }, { 0, 0, 0 } };
		new GreedyQueens().countAttacks(board, 3);
		attacks = new int[][] { { -1, 2, 2 }, { 2, 2, -1 }, { 1, 1, 2 } };
		Assert.assertArrayEquals(attacks, board);
	}

	@Test
	public void testGreedyQueensValid() {
		int[][] board = new int[][] { { 0, -1 }, { 0, 0 } };
		boolean valid = new GreedyQueens().isValid(board, 2);
		Assert.assertTrue(valid);

		board = new int[][] { { 0, -1 }, { 0, -1 } };
		valid = new GreedyQueens().isValid(board, 2);
		Assert.assertFalse(valid);

		board = new int[][] { { -1, -1 }, { 0, 0 } };
		valid = new GreedyQueens().isValid(board, 2);
		Assert.assertFalse(valid);

		board = new int[][] { { 0, -1 }, { -1, 0 } };
		valid = new GreedyQueens().isValid(board, 2);
		Assert.assertFalse(valid);

		board = new int[][] { { 0, 0, 0 }, { 0, 0, 0 }, { 0, 0, 0 } };
		valid = new GreedyQueens().isValid(board, 3);
		Assert.assertTrue(valid);

		board = new int[][] { { -1, 0, 0 }, { 0, 0, -1 }, { 0, 0, 0 } };
		valid = new GreedyQueens().isValid(board, 3);
		Assert.assertTrue(valid);

		board = new int[][] { { -1, 0, 0 }, { 0, 0, -1 }, { 0, -1, 0 } };
		valid = new GreedyQueens().isValid(board, 3);
		Assert.assertFalse(valid);

		board = new int[][] { { -1, 0, 0 }, { 0, 0, 0 }, { 0, 0, -1 } };
		valid = new GreedyQueens().isValid(board, 3);
		Assert.assertFalse(valid);

		board = new int[][] { { -1, 0, 0 }, { 0, -1, 0 }, { 0, 0, 0 } };
		valid = new GreedyQueens().isValid(board, 3);
		Assert.assertFalse(valid);

		board = new int[][] { { 0, 0, -1 }, { 0, -1, 0 }, { 0, 0, 0 } };
		valid = new GreedyQueens().isValid(board, 3);
		Assert.assertFalse(valid);

		board = new int[][] { { 0, 0, 0 }, { 0, -1, 0 }, { -1, 0, 0 } };
		valid = new GreedyQueens().isValid(board, 3);
		Assert.assertFalse(valid);

		board = new int[][] { { 0, 0, 0 }, { 0, -1, 0 }, { 0, 0, -1 } };
		valid = new GreedyQueens().isValid(board, 3);
		Assert.assertFalse(valid);
	}

	static enum Cell {
		EMPTY("."), EX("x"), PLUS("+"), OU("o");

		String value;

		private Cell(String value) {
			this.value = value;
		}

		@Override
		public String toString() {
			return value;
		}
	}

	static class Model {
		String type;
		int x;
		int y;

		public Cell toCell() {
			if (type.equals("+")) {
				return Cell.PLUS;
			}
			if (type.equals("o")) {
				return Cell.OU;
			}
			if (type.equals("x")) {
				return Cell.EX;
			}

			throw new IllegalArgumentException("Type was not set");
		}
	}

	static class Solution {
		int points;
		int changes;

		List<Model> altered = new ArrayList<>();

		@Override
		public String toString() {
			StringBuilder sb = new StringBuilder(points + " " + changes);
			int count = 0;
			for (Model model : altered) {				
				if (count == 0) {
					sb.append("\n");
				}
				
				sb.append(model.type);
				sb.append(" ");
				sb.append(model.y + 1);
				sb.append(" ");
				sb.append(model.x + 1);
				
				count++;
				if (count < altered.size()) {
					sb.append("\n");	
				}
			}
			return sb.toString();
		}

		public void alter(Cell cell, int x, int y) {
			changes++;
			Model model = new Model();
			model.type = cell.toString();
			model.x = x;
			model.y = y;
			altered.add(model);
		}
	}

	private void debugPrint(Cell[][] grid) {
		for (int i = 0; i < grid.length; i++) {
			for (int j = 0; j < grid.length; j++) {
				System.out.print(grid[i][j] + " ");
			}
			System.out.println();
		}
		System.out.println();
	}

	private int calculateScore(Cell[][] grid) {
		int score = 0;

		for (int i = 0; i < grid.length; i++) {
			for (int j = 0; j < grid.length; j++) {
				int add = 0;
				switch (grid[i][j]) {
				case PLUS:
				case EX:
					add = 1;
					break;

				case OU:
					add = 2;
					break;
				}
				score += add;
			}
		}

		return score;
	}

	Solution solution = new Solution();

	private Solution solve(int gridSize, List<Model> list) {
		Cell[][] grid = new Cell[gridSize][];
		for (int i = 0; i < gridSize; i++) {
			grid[i] = new Cell[gridSize];
			for (int j = 0; j < gridSize; j++) {
				grid[i][j] = Cell.EMPTY;
			}
		}
		for (Model model : list) {
			Cell cell = model.toCell();
			grid[model.y][model.x] = cell;
		}

		solution = new Solution();
		solution.points = calculateScore(grid);
		improve(grid);
		solution.points = calculateScore(grid);
		
		return solution;
	}

	private void placeQuens(Cell[][] grid) {
		// What is the maximum number of queens that can be placed on an n×n
		// chessboard such that no two attack one another?
		// The answer is n-1 queens for n=2 or n=3 and n queens otherwise, which
		// gives eight queens for the usual 8×8 board
		int maxQueens;
		if (grid.length == 1) {
			maxQueens = 1;
		} else if (grid.length <= 3) {
			maxQueens = grid.length - 1;
		} else {
			maxQueens = grid.length;
		}

		int queenPosition = -1;
		for (int j = 0; j < grid.length; j++) {
			if (grid[0][j] == Cell.OU) {
				queenPosition = j;
			}
		}

		if (grid.length > 10) {
			maxQueens = (int) ((float) maxQueens * 0.8f);
		}

		GreedyQueens gq = new GreedyQueens(grid.length, maxQueens);
		gq.find(queenPosition);
		int[][] board = gq.board;

		for (int i = 0; i < grid.length; i++) {
			for (int j = 0; j < grid.length; j++) {
				if (board[i][j] == GreedyQueens.QUEEN) {
					if (grid[i][j] != Cell.OU) {
						solution.points += 2;
						solution.alter(Cell.OU, j, i);
						grid[i][j] = Cell.OU;
					}					
				}
			}
		}
	}

	private void improve(Cell[][] grid) {
		placeQuens(grid);
		
		placeBishops(grid);
		
		placeRookies(grid);
	}
	
	private void placeBishops(Cell[][] grid) {
		int n = grid.length;
		for (int i = 0; i < grid.length; i++) {
			for (int j = 0; j < grid.length; j++) {
				if (grid[i][j] == Cell.EMPTY) {
					boolean hasQueenOrBishopInDiagonal = false;
					
					int x = j + 1;
					int y = i + 1;
					while (x < n && y < n) {
						if (grid[y][x] == Cell.OU || grid[y][x] == Cell.PLUS) {
							hasQueenOrBishopInDiagonal = true;
						}
						x++;
						y++;
					}

					x = j - 1;
					y = i - 1;
					while (x >= 0 && y >= 0) {
						if (grid[y][x] == Cell.OU || grid[y][x] == Cell.PLUS) {
							hasQueenOrBishopInDiagonal = true;
						}
						x--;
						y--;
					}

					x = j + 1;
					y = i - 1;
					while (x < n && y >= 0) {
						if (grid[y][x] == Cell.OU || grid[y][x] == Cell.PLUS) {
							hasQueenOrBishopInDiagonal = true;
						}
						x++;
						y--;
					}

					x = j - 1;
					y = i + 1;
					while (x >= 0 && y < n) {
						if (grid[y][x] == Cell.OU || grid[y][x] == Cell.PLUS) {
							hasQueenOrBishopInDiagonal = true;
						}
						x--;
						y++;
					}
					
					if (!hasQueenOrBishopInDiagonal) {
						solution.points += 1;
						solution.alter(Cell.PLUS, j, i);
						grid[i][j] = Cell.PLUS;
					}
				}
			}
		}
	}
	
	private void placeRookies(Cell[][] grid) {
		for (int i = 0; i < grid.length; i++) {
			for (int j = 0; j < grid.length; j++) {
				if (grid[i][j] == Cell.EMPTY) {
					boolean hasRookieOrQueenInLine = false;
					boolean emptyLines = true;
					for (int k = 0; k < grid.length; k++) {
						//if (grid[i][k] == Cell.PLUS || grid[k][j] == Cell.PLUS || grid[i][k] == Cell.OU || grid[k][j] == Cell.OU) {
						if (grid[i][k] == Cell.EX || grid[k][j] == Cell.EX) {
							hasRookieOrQueenInLine = true;
						}
						if (grid[i][k] != Cell.EMPTY || grid[k][j] != Cell.EMPTY) {
							emptyLines = false;
						}
					}
					if (!hasRookieOrQueenInLine || emptyLines) {
						solution.points += 1;
						solution.alter(Cell.EX, j, i);
						grid[i][j] = Cell.EX;
					}
				}
			}
		}
	}

	@Test
	public void testEmpty() {
		int gridSize = 3;

		Cell[][] grid = new Cell[gridSize][];
		for (int i = 0; i < gridSize; i++) {
			grid[i] = new Cell[gridSize];
			for (int j = 0; j < gridSize; j++) {
				grid[i][j] = Cell.EMPTY;
			}
		}
		grid[0][1] = Cell.OU;

		solution = new Solution();
		solution.points = calculateScore(grid);
		
		debugPrint(grid);
		improve(grid);
		debugPrint(grid);		
	}

	public static void main(String[] args) throws Exception {
		FileInputStream fis = new FileInputStream("d:\\1\\D-small-attempt0.in");
		BufferedReader br = new BufferedReader(new InputStreamReader(fis));
		Scanner scan = new Scanner(br);
		int numberOfCases = scan.nextInt();

		for (int i = 0; i < numberOfCases; i++) {
			int gridSize = scan.nextInt();
			int models = scan.nextInt();
			List<Model> list = new ArrayList<>();
			for (int j = 0; j < models; j++) {
				String type = scan.next();
				int row = scan.nextInt();
				int col = scan.nextInt();

				Model model = new Model();
				model.type = type;
				model.y = row - 1;
				model.x = col - 1;

				list.add(model);
			}

			Solution result = new DFashionShow().solve(gridSize, list);
			System.out.println("Case #" + (i + 1) + ": " + result);
		}

		scan.close();
	}

}
