package dmg;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.math.BigInteger;

public class A {

    public static class In {
        private final InputStreamReader in;
        private final StringBuilder stringBuilder = new StringBuilder();
        public In(final InputStream in) {
            this.in = new InputStreamReader(in);
        }
        public char readChar() throws IOException {
            return (char) in.read();
        }
        public char readNonWS() throws IOException {
            int c;
            while (Character.isWhitespace(c = in.read())) {}
            return (char) c;
        }
        public short readShort() throws NumberFormatException, IOException {
            return Short.parseShort(readString());
        }
        public int readInt() throws NumberFormatException, IOException {
            return Integer.parseInt(readString());
        }
        public long readLong() throws NumberFormatException, IOException {
            return Long.parseLong(readString());
        }
        public BigInteger readBigInt() throws IOException {
            return new BigInteger(readString());
        }
        public float readFloat() throws NumberFormatException, IOException {
            return Float.parseFloat(readString());
        }
        public double readDouble() throws NumberFormatException, IOException {
            return Double.parseDouble(readString());
        }
        public String readString() throws IOException {
            int c;
            stringBuilder.setLength(0);
            while ((c = in.read()) != -1) {
                if (Character.isWhitespace(c)) {
                    if (stringBuilder.length() > 0) {
                        return stringBuilder.toString();
                    }
                } else {
                    stringBuilder.append((char)c);
                }
            }
            return stringBuilder.toString();
        }
    }

    private final static In I = new In(System.in);
    private final static PrintStream O = System.out;
    private final static PrintStream D = System.err;

    public static String toString(final int[][] f) {
        final StringBuilder sb = new StringBuilder();
        for (final int[] r: f) {
            for (final int v: r) {
                if (v == 1) {
                    sb.append('R');
                }
                if (v == -1) {
                    sb.append('B');
                }
                if (v == 0) {
                    sb.append('.');
                }
            }
            sb.append('\n');
        }
        return sb.toString();
    }


    public static void main(final String[] args) {
        try {
            for (int i = 1, li = I.readInt(); i <= li; i++) {
                O.print("Case #");
                O.print(i);
                O.print(": ");

                D.println();

                final int size = I.readInt();
                final int needed = I.readInt();
                final int field[][] = new int[size][size];
                for (int row = 0; row < size; row++) {
                    final StringBuilder sb = new StringBuilder();
                    for (int col = 0; col < size; col++) {
                        switch (I.readNonWS()) {
                        case 'R':
                            D.print('R');
                            sb.append('R');
                            break;
                        case 'B':
                            D.print('B');
                            sb.append('B');
                            break;
                        default:
                            D.print('.');
                        }
                    }
                    D.println();
                    final int off = size - sb.length();
                    for (int j = 0; j < sb.length(); j++) {
                        if (sb.charAt(j) == 'R') {
                            field[off + j][size - row - 1] =  1;
                        } else {
                            field[off + j][size - row - 1] = -1;
                        }
                    }
                }
                D.println();
                D.println("+ " + needed);
                D.print(toString(field));
                boolean rwin = false;
                boolean bwin = false;
                for (int x = 0; x < size; x++) {
                    for (int y = 0; y < size; y++) {
                        final int val = field[x][y];
                        if (val == 0) {
                            continue;
                        }
                        if (val == 1 && rwin) {
                            continue;
                        }
                        if (val == -1 && bwin) {
                            continue;
                        }
                        for (int dx = -1; dx <= 0; dx++) {
                            for (int dy = -1; dy <= 0; dy++) {
                                if (dx == 0 && dy == 0) {
                                    continue;
                                }
                                boolean win = true;
                                for (int p = 1; p < needed && win; p++) {
                                    final int px = x + p * dx;
                                    final int py = y + p * dy;
                                    if (px < 0 || py < 0 || px >= size || py >= size) {
                                        win = false;
                                        continue;
                                    }
                                    win &= field[px][py] == val;
                                }
                                if (!win) {
                                    continue;
                                }
                                if (val == 1) {
                                    rwin = true;
                                }
                                if (val == -1) {
                                    bwin = true;
                                }
                            }
                        }
                    }
                }
                if (rwin) {
                    if (bwin) {
                        O.println("Both");
                    } else {
                        O.println("Red");
                    }
                } else {
                    if (bwin) {
                        O.println("Blue");
                    } else {
                        O.println("Neither");
                    }
                }
            }
        } catch (final NumberFormatException e) {
            e.printStackTrace();
        } catch (final IOException e) {
            e.printStackTrace();
        }
    }

}
