package dmg;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.math.BigInteger;
import java.util.BitSet;
import java.util.TreeSet;

public class C {

    public static class In {
        private final InputStreamReader in;
        private final StringBuilder stringBuilder = new StringBuilder();
        public In(final InputStream in) {
            this.in = new InputStreamReader(in);
        }
        public char readChar() throws IOException {
            return (char) in.read();
        }
        public char readNonWS() throws IOException {
            int c;
            while (Character.isWhitespace(c = in.read())) {}
            return (char) c;
        }
        public short readShort() throws NumberFormatException, IOException {
            return Short.parseShort(readString());
        }
        public int readInt() throws NumberFormatException, IOException {
            return Integer.parseInt(readString());
        }
        public long readLong() throws NumberFormatException, IOException {
            return Long.parseLong(readString());
        }
        public BigInteger readBigInt() throws IOException {
            return new BigInteger(readString());
        }
        public BigInteger readBigInt(int radix) throws IOException {
            return new BigInteger(readString(), radix);
        }
        public float readFloat() throws NumberFormatException, IOException {
            return Float.parseFloat(readString());
        }
        public double readDouble() throws NumberFormatException, IOException {
            return Double.parseDouble(readString());
        }
        public String readString() throws IOException {
            int c;
            stringBuilder.setLength(0);
            while ((c = in.read()) != -1) {
                if (Character.isWhitespace(c)) {
                    if (stringBuilder.length() > 0) {
                        return stringBuilder.toString();
                    }
                } else {
                    stringBuilder.append((char)c);
                }
            }
            return stringBuilder.toString();
        }
    }

    private final static In I = new In(System.in);
    private final static PrintStream O = System.out;
    private final static PrintStream D = System.err;
    public static byte[][] field;

    private static class Result implements Comparable<Result> {
        int col = -1;
        int row = -1;
        int size = 0;
        @Override
        public int compareTo(Result o) {
            if (size > o.size) { return -1; }
            if (size < o.size) { return  1; }
            if (row  < o.row)  { return -1; }
            if (row  > o.row)  { return  1; }
            if (col  < o.col)  { return -1; }
            if (col  > o.col)  { return  1; }
            return 0;
        }
        @Override
        public int hashCode() {
            final int prime = 31;
            int result = 1;
            result = prime * result + col;
            result = prime * result + row;
            result = prime * result + size;
            return result;
        }
        @Override
        public boolean equals(Object obj) {
            if (this == obj)
                return true;
            if (obj == null)
                return false;
            if (getClass() != obj.getClass())
                return false;
            Result other = (Result) obj;
            if (col != other.col)
                return false;
            if (row != other.row)
                return false;
            if (size != other.size)
                return false;
            return true;
        }
    }

    public static int testColor(int row, int col, int size) {
        int color = field[row][col];
        if (color == -1) {
            return 0;
        }
        if (size == 1) {
            return 1;
        }
        int t = testColor(row, col, size - 1);
        if (t < size - 1) {
            return t;
        }
        if (col + size > field[0].length) {
            return t;
        }
        if (row + size > field.length) {
            return t;
        }
        int r = row + size - 1, c;
        for (c = col; c < col + size; c++) {
            int icolor = field[r][c];
            if (icolor == -1) {
                return t;
            }
            int eq = (c - col + r - row) % 2;
            if (eq == 0 && icolor != color) {
                return t;
            }
            if (eq == 1 && icolor == color) {
                return t;
            }
        }
        c = col + size - 1;
        for (r = row; r < row + size; r++) {
            int icolor = field[r][c];
            if (icolor == -1) {
                return t;
            }
            int eq = (c - col + r - row) % 2;
            if (eq == 0 && icolor != color) {
                return t;
            }
            if (eq == 1 && icolor == color) {
                return t;
            }
        }
        return size;
    }

    public static void clear(int row, int col, int len) {
        int ecol = col + len;
        int erow = row + len;
        for (int r = row; r < erow; r++) {
            for (int c = col; c < ecol; c++) {
                field[r][c] = -1;
            }
        }
    }

    public static void main(String[] args) {
        try {
            for (int cs = 1, limit = I.readInt(); cs <= limit; cs++) {
                O.print("Case #");
                O.print(cs);
                O.print(": ");
                final int rows = I.readInt();
                final int cols = I.readInt();
                field = new byte[rows][cols];
                for (int i = 0; i < rows; i++) {
                    byte[] row = new byte[cols];
                    for (int c = 0; c < cols/4; c++) {
                        char character = I.readNonWS();
                        int v = 0;
                        switch(character) {
                        case '0': v =  0; break; case '1': v =  1; break;
                        case '2': v =  2; break; case '3': v =  3; break;
                        case '4': v =  4; break; case '5': v =  5; break;
                        case '6': v =  6; break; case '7': v =  7; break;
                        case '8': v =  8; break; case '9': v =  9; break;
                        case 'A': v = 10; break; case 'B': v = 11; break;
                        case 'C': v = 12; break; case 'D': v = 13; break;
                        case 'E': v = 14; break; case 'F': v = 15; break;
                        }
                        if ((v >> 3) > 0) {
                            row[c*4] = 1;
                        }
                        if (((v >> 2) & 1) > 0) {
                            row[c*4 + 1] = 1;
                        }
                        if (((v >> 1) & 1) > 0) {
                            row[c*4 + 2] = 1;
                        }
                        if ((v & 1) > 0) {
                            row[c*4 + 3] = 1;
                        }
                    }
                    field[i] = row;
                }
                for (int row = 0; row < rows; row ++) {
                    for (int col = 0; col < cols; col++) {
                        D.print(field[row][col] == 1 ? 'X' : '.');
                    }
                    D.println();
                }
                TreeSet<Result> results = new TreeSet<Result>();
                int result[] = new int[513];
                boolean rerun = false;
                int maxsize = 513;
                do {
                    int size = 2;
                    rerun = false;
                    results.clear();
                    for (int row = 0; row < rows; row++) {
                        for (int col = 0; col < cols; col++) {
                            int max = testColor(row, col, maxsize);
                            if (max < size) {
                                continue;
                            }
                            Result r = new Result();
                            r.size = max;
                            r.col = col;
                            r.row = row;
                            if (max > size) {
                                results.clear();
                                size = max;
                            }
                            results.add(r);
                        }
                    }
                    if (results.size() > 0) {
                        rerun = true;
                        Result r;
                        while ((r = results.pollFirst()) != null) {
                            if (testColor(r.row, r.col, r.size) != r.size) {
                                continue;
                            }
                            clear(r.row, r.col, r.size);
                            result[size]++;
                        }
                        maxsize = size;
                    }
                } while (rerun);
                for (int row = 0; row < field.length; row++) {
                    for (int col = 0; col < field[row].length; col++) {
                        if (field[row][col] != -1) {
                            result[1]++;
                        }
                    }
                }
                int diff = 0;
                for (int i = 0; i < result.length; i++) {
                    if (result[i] > 0) {
                        diff++;
                    }
                }
                O.println(diff);
                for (int i = result.length - 1; i > 0; i--) {
                    if (result[i] > 0) {
                        O.println(i + " " + result[i]);
                    }
                }
            }
        } catch (NumberFormatException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

}
