package dmg;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import java.util.TreeSet;

public class B {

    public static class In {
        private final InputStreamReader in;
        private final StringBuilder stringBuilder = new StringBuilder();
        public In(final InputStream in) {
            this.in = new InputStreamReader(in);
        }
        public char readChar() throws IOException {
            return (char) in.read();
        }
        public char readNonWS() throws IOException {
            int c;
            while (Character.isWhitespace(c = in.read())) {}
            return (char) c;
        }
        public short readShort() throws NumberFormatException, IOException {
            return Short.parseShort(readString());
        }
        public int readInt() throws NumberFormatException, IOException {
            return Integer.parseInt(readString());
        }
        public long readLong() throws NumberFormatException, IOException {
            return Long.parseLong(readString());
        }
        public BigInteger readBigInt() throws IOException {
            return new BigInteger(readString());
        }
        public float readFloat() throws NumberFormatException, IOException {
            return Float.parseFloat(readString());
        }
        public double readDouble() throws NumberFormatException, IOException {
            return Double.parseDouble(readString());
        }
        public String readString() throws IOException {
            int c;
            stringBuilder.setLength(0);
            while ((c = in.read()) != -1) {
                if (Character.isWhitespace(c)) {
                    if (stringBuilder.length() > 0) {
                        return stringBuilder.toString();
                    }
                } else {
                    stringBuilder.append((char)c);
                }
            }
            return stringBuilder.toString();
        }
    }

    private final static In I = new In(System.in);
    private final static PrintStream O = System.out;
    private final static PrintStream D = System.err;

    private static class Pair<U, V> implements Comparable<Pair<U, V>> {
        public final U u;
        public final V v;
        public Pair(final U u, final V v) {
            this.u = u;
            this.v = v;
        }

        @SuppressWarnings("unchecked")
        @Override
        public int compareTo(final Pair<U, V> o) {
            int cmp = ((Comparable<Object>)u).compareTo(o.u);
            if (cmp != 0) {
                return cmp;
            }
            cmp = ((Comparable<Object>)v).compareTo(o.v);
            if (cmp != 0) {
                return cmp;
            }
            return 0;
        }
        @Override
        public int hashCode() {
            final int prime = 31;
            int result = 1;
            result = prime * result + (u == null ? 0 : u.hashCode());
            result = prime * result + (v == null ? 0 : v.hashCode());
            return result;
        }
        @Override
        public boolean equals(final Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null) {
                return false;
            }
            if (getClass() != obj.getClass()) {
                return false;
            }
            final Pair<?, ?> other = (Pair<?, ?>) obj;
            if (u == null) {
                if (other.u != null) {
                    return false;
                }
            } else if (!u.equals(other.u)) {
                return false;
            }
            if (v == null) {
                if (other.v != null) {
                    return false;
                }
            } else if (!v.equals(other.v)) {
                return false;
            }
            return true;
        }
    }

    private static class State implements Comparable<State>{
        int pos = -1;
        int cost = 0;
        int value = -1;
        public List<State> expand(final int pixel[], final int delta, final int cdelete, final int cinsert) {
            final ArrayList<State> states = new ArrayList<State>();
            State s;
            // delete
            s = clone();
            s.pos++;
            s.cost += cdelete;
            states.add(s);
            // insert
            if (value >= 0) {
                final int low = Math.max(0, value - delta);
                final int high = Math.min(255, value + delta);
                for (int v = low; v <= high; v++) {
                    s = clone();
                    s.cost += cinsert;
                    s.value = v;
                    states.add(s);
                }
            }
            // modify + move
            if (pos + 1 < pixel.length) {
                if (value >= 0) {
                    final int low = Math.max(0, value - delta);
                    final int high = Math.min(255, value + delta);
                    for (int v = low; v <= high; v++) {
                        s = clone();
                        s.cost += Math.abs(v - pixel[pos + 1]);
                        s.value = v;
                        s.pos++;
                        states.add(s);
                    }
                } else {
                    s = clone();
                    s.value = pixel[pos + 1];
                    s.pos++;
                    states.add(s);
                }
            } else {
                s = clone();
                s.pos++;
                states.add(s);
            }

            return states;
        }
        @Override
        public State clone() {
            final State state = new State();
            state.pos = pos;
            state.cost = cost;
            state.value = value;
            return state;
        }
        @Override
        public int compareTo(final State o) {
            if (cost < o.cost) {
                return -1;
            }
            if (cost > o.cost) {
                return 1;
            }
            if (pos < o.pos) {
                return 1;
            }
            if (pos > o.pos) {
                return -1;
            }
            if (value < o.value) {
                return -1;
            }
            if (value > o.value) {
                return 1;
            }
            return 0;
        }
    }

    public static void main(final String[] args) {
        try {
            for (int cs = 1, li = I.readInt(); cs <= li; cs++) {
                D.println(cs);
                O.print("Case #");
                O.print(cs);
                O.print(": ");
                final int delete = I.readInt();
                int insert = I.readInt();
                final int delta = I.readInt();
                final int size = I.readInt();
                D.println(delete + " " + insert + " " + delta + " " + size);
                final int pixel[] = new int[size];
                for (int i = 0; i < size; i++) {
                    pixel[i] = I.readInt();
                }
                if (delete == 0|| delta == 255) {
                    O.println("0");
                    continue;
                }
                if (insert == 0 && delta > 0) {
                    O.println("0");
                    continue;
                }
                if (delta == 0) {
                    insert = 65535;
                }
                final TreeSet<State> states = new TreeSet<State>();
                states.add(new State());
                State winner = null;
                while (states.size() > 0 && winner == null) {
                    final State state = states.pollFirst();
                    if (state.pos == size) {
                        winner = state;
                        continue;
                    }
                    states.addAll(state.expand(pixel, delta, delete, insert));
                }
                O.println(winner.cost);
            }
        } catch (final IOException e) {
            e.printStackTrace();
        }
    }

}
