package net.nixdev.gcj11.bottrust;

import java.io.BufferedReader;
import java.io.DataInputStream;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.util.Map;

import net.nixdev.gcj11.bottrust.model.ERobot;
import net.nixdev.gcj11.bottrust.model.IRobot;
import net.nixdev.gcj11.bottrust.model.Robot;
import net.nixdev.gcj11.bottrust.model.Task;
import net.nixdev.gcj11.bottrust.model.TaskList;

public class BotTrust {

	TaskList taskList = new TaskList();
	Map<ERobot, IRobot> robotMap = new HashMap<ERobot, IRobot>();
	Map<ERobot, Integer> gapMap = new HashMap<ERobot, Integer>();
	
	public BotTrust(String initialData) {
		String[] data = initialData.split(" ");
		Integer counter = Integer.valueOf(data[0]);
		
		IRobot orangeRobot = new Robot("Orange");
		IRobot blueRobot = new Robot("Blue");
		robotMap.put(ERobot.ORANGE, orangeRobot);
		robotMap.put(ERobot.BLUE, blueRobot);

		gapMap.put(ERobot.ORANGE, 0);
		gapMap.put(ERobot.BLUE, 0);

		
		for (int i = 0; i < counter; i++) {
			taskList.addTask(new Task(ERobot.getRobot(data[i*2+1]), Integer.valueOf(data[i*2+2])));
		}
	}
	
	public Integer solve() {
		Task currentTask = taskList.getCurrentTask();
		IRobot previousActiveRobot = null; 
		Integer stepCounter = 0;
		
		while (currentTask != null) {
			
			IRobot activeRobot = robotMap.get(currentTask.robot);
			ERobot inactiveRobot = revertRobot(currentTask.robot);
			
			int currentRobotPosition = activeRobot.getPosition();			
			int concurrentActions = 0;
			
			while (currentRobotPosition != currentTask.button) {
				//   -   
				stepCounter++;				
				concurrentActions++;				
				
				if (currentRobotPosition < currentTask.button) {
					//System.out.println("Step " + stepCounter + ". " + activeRobot + ". Right.");
					activeRobot.moveRight();
				}
			
				if (currentRobotPosition > currentTask.button) {
					//System.out.println("Step " + stepCounter + ". " + activeRobot + ". Left.");
					activeRobot.moveLeft();
				}
				currentRobotPosition = activeRobot.getPosition();
			}								
			
			//    
			Integer activeRobotResource = gapMap.get(currentTask.robot);
			if (activeRobotResource == 0) {
				// 
			} else if (activeRobotResource > concurrentActions){
				stepCounter = stepCounter - concurrentActions;
				gapMap.put(currentTask.robot, 0);				
			} else {
				stepCounter = stepCounter - activeRobotResource;
				gapMap.put(currentTask.robot, 0);
			}
			
			//  
			//   
			stepCounter++;
			//System.out.println("Step " + stepCounter + ". " + activeRobot + ". Push.");
			activeRobot.push();
			
			if (previousActiveRobot == activeRobot) {
				gapMap.put(currentTask.robot, 0);
			}
									
			//     
			gapMap.put(inactiveRobot, gapMap.get(inactiveRobot) + concurrentActions + 1);
			
			previousActiveRobot = activeRobot;
			currentTask = taskList.finishTask();
		}
		
		return stepCounter;
	}
	
	public ERobot revertRobot(ERobot robot) {
		switch (robot) {
		case ORANGE:
			return ERobot.BLUE;
		case BLUE:
			return ERobot.ORANGE;
		default:
			return ERobot.UNKNOWN;
		}
	}
	public static void main (String[] args) {
		
		Integer testCaseNum = 0;
		Integer testCaseId = 0;
		    
	    try {	    	
		    FileInputStream fstream = new FileInputStream("A-small-attempt0.in");
		    // Get the object of DataInputStream
		    DataInputStream in = new DataInputStream(fstream);
		    BufferedReader br = new BufferedReader(new InputStreamReader(in));

	    	testCaseNum = Integer.valueOf(br.readLine());
	      
	    	//dis.available() returns 0 if the file does not have more lines.
	    	while (testCaseId < testCaseNum) {
	    		String caseString;
	    		Integer caseResult;
	    	  
	    		testCaseId++;
	    		//System.out.println("Process case " + testCaseId + "/" + testCaseNum);
	    		caseString = br.readLine();
	    	  
	    		BotTrust botTrust = new BotTrust(caseString);
	    		caseResult = botTrust.solve();
	    		System.out.println("Case #" + testCaseId + ": " + caseResult);
	    	}

	      // dispose all the resources after using them.
	      in.close();

	    } catch (FileNotFoundException e) {
	      e.printStackTrace();
	    } catch (IOException e) {
	      e.printStackTrace();
	    }				
		
	}
}
