import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;

class Solver {

	int result = 0;
	InputData data;
	
	
	public Solver () {
		Queue<Integer> queue = new LinkedList<Integer>();
		queue.add(1);
		queue.add(4);
		queue.add(2);
		queue.add(1);			

		data = new InputData(4, 6, 4, queue);
	}
	
	public Solver (InputData data) {
		this.data = data;
	}
	
	public void solve () {
		
		for (int i = 1; i <= data.repeatTimes; i++) {
			int currentSize = 0;
			Queue<Integer> currentRide = new LinkedList<Integer>();
			
			while (!data.queue.isEmpty() && currentSize + data.queue.peek() <= data.peopleAtOnce) {
				int current = data.queue.poll();
				currentSize += current;
				currentRide.add(current);
			}
			
			for (Integer oneOf: currentRide) {
				data.queue.add(oneOf);
			}
			currentRide.clear();
			
			result  += currentSize;
		}
	}

	public int getResult () {
		return result;
	}
}

class InputData {
	//Repeat count
	//1 ≤ repeatTimes ≤ 10^8.
	int repeatTimes = 0;
	
	//Size
	//1 ≤ peopleAtOnce ≤ 10^9.
	int peopleAtOnce = 0;

	//Group numbers
	//1 ≤ N ≤ 1000.
	int numberPeopleGroups = 0;
	
	Queue<Integer> queue = new LinkedList<Integer>();

	public InputData (int R, int k, int N, Queue<Integer> g) {
		repeatTimes = R;
		peopleAtOnce = k;
		numberPeopleGroups = N;
		queue.addAll(g);
	}

	public int getRepeatTimes() {
		return repeatTimes;
	}

	public int getPeopleAtOnce() {
		return peopleAtOnce;
	}

	public int getNumberPeopleGroups() {
		return numberPeopleGroups;
	}

	public Queue<Integer> getQueue() {
		return queue;
	}
}


public class CThemePark {
	//Test-case count
	//1 ≤ testCaseCount ≤ 50.
	int testCaseCount = 0;
	
	//
	Queue<InputData> inputData = new LinkedList<InputData>();
	//Solve result
	List<Integer> results = new ArrayList<Integer>();
	
	public void read (InputStream input) {

		try {
			InputStreamReader inputStreamReader = new InputStreamReader(input);
			BufferedReader bufferedReader = new BufferedReader (inputStreamReader);
			
			testCaseCount = Integer.valueOf(bufferedReader.readLine()); 
			
			for (int i = 1; i <= testCaseCount; i++) {
				int r, k, n;
				Queue<Integer> queue = new LinkedList<Integer>();

				String paramsLine =  bufferedReader.readLine();
				String[] params = paramsLine.split(" ");
				r = Integer.valueOf(params[0]);
				k = Integer.valueOf(params[1]);
				n = Integer.valueOf(params[2]);
				
				for (String group: bufferedReader.readLine().split(" ")) {
					queue.add(Integer.valueOf(group));
				}
				inputData.add(new InputData(r, k, n, queue));
			}		
		} catch (FileNotFoundException e) {
			System.err.println (e.getMessage());
		} catch (IOException e) {
			System.err.println (e.getMessage());
		}
	}

	public void solve () {
		for (InputData testCase: inputData) {
			Solver solver = new Solver(testCase);
			solver.solve();
			results.add(solver.getResult());
		}
	}
		
	public void write(PrintStream out) {
		int i = 1;
		for (int result: results) { 
			out.println("Case #" + i + ": " + result);
			i++;
		}
	}
	
	public static void main(String[] args) {
		CThemePark solver = new CThemePark();
		
		try {
			//solver.read(System.in);
			solver.read(new FileInputStream(new File("input.data")));
			solver.solve();
			solver.write(new PrintStream(new PrintStream(new File("output.data"))));
			solver.write(System.out);
			
		} catch (FileNotFoundException e) {
			System.err.println (e.getMessage());
		}
	}
}
