import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;

class Snapper {
	boolean power = false;
	boolean state = false;
	boolean input = false;
	
	public Snapper () {
		
	}
	
	public Snapper (boolean power, boolean state, boolean input) {
		this.power = power;
		this.state = state;
		this.input = input;
	}
	
	public boolean trigger(boolean newInput) {
		
		if (input) {
			state = !state;
		}
		
		input = newInput;
		power = newInput  && state;
		
		return power;
	}
}

class Solver {

	boolean result = false;
	InputData data;
	
	
	public Solver () {
		data = new InputData(1, 0);
	}
	
	public Solver (InputData data) {
		this.data = data;
	}
	
	public void solve () {
		List<Snapper> snappers = new LinkedList<Snapper>();
		
		for (int i = 1; i <= data.numberOfSnapper; i++) {
			if (i == 1) {
				snappers.add(new Snapper(false, false, true));
			} else {
				snappers.add(new Snapper());
			}

		}
		
		for (int i = 1; i <= data.numberOfSwitches; i++) {
			boolean power = true;
			for (Snapper snapper: snappers) {
				power = snapper.trigger(power);
			}
		}
		
		result = snappers.get(snappers.size()-1).power; 
	}		

	public boolean getResult () {
		return result;
	}
}

class InputData {
	//Number of Snapper
	//1 ≤ N ≤ 30;
	int numberOfSnapper = 0;
	
	//Number of switches
	//0 ≤ K ≤ 108
	int numberOfSwitches = 0;

	public InputData (int N, int K) {
		numberOfSnapper = N;
		numberOfSwitches = K;
	}

	public int getNumberOfSnapper() {
		return numberOfSnapper;
	}

	public int getNumberOfSwitches() {
		return numberOfSwitches;
	}
}


public class ASnapperChain {
	//Test-case count
	//1 ≤ testCaseCount ≤ 50.
	int testCaseCount = 0;
	
	//
	Queue<InputData> inputData = new LinkedList<InputData>();
	//Solve result
	List<Boolean> results = new ArrayList<Boolean>();
	
	public void read (InputStream input) {

		try {
			InputStreamReader inputStreamReader = new InputStreamReader(input);
			BufferedReader bufferedReader = new BufferedReader (inputStreamReader);
			
			testCaseCount = Integer.valueOf(bufferedReader.readLine()); 
			
			for (int i = 1; i <= testCaseCount; i++) {
				int N, K;

				String paramsLine =  bufferedReader.readLine();
				String[] params = paramsLine.split(" ");
				N = Integer.valueOf(params[0]);
				K = Integer.valueOf(params[1]);

				inputData.add(new InputData(N, K));
			}		
		} catch (FileNotFoundException e) {
			System.err.println (e.getMessage());
		} catch (IOException e) {
			System.err.println (e.getMessage());
		}
	}

	public void solve () {
		int i = 1;
		for (InputData testCase: inputData) {
			Long start = new Date().getTime();
			
			boolean result = false;
			Solver solver = new Solver(testCase);
			solver.solve();
			result = solver.getResult();
			results.add(result);
			
			System.out.println("Case #" + i + ": " + (result ? "ON" : "OFF") + " in " + (new Date().getTime() - start) / 1000);
			i++;
		}
	}
		
	public void write(PrintStream out) {
		int i = 1;
		for (boolean result: results) { 
			out.println("Case #" + i + ": " + (result ? "ON" : "OFF"));
			i++;
		}
	}
	
	public static void main(String[] args) {
		ASnapperChain solver = new ASnapperChain();
		
		Long start = new Date().getTime();
		
		try {
			solver.read(new FileInputStream(new File("input.data")));
			solver.solve();
			solver.write(new PrintStream(new PrintStream(new File("output.data"))));
			//solver.write(System.out);
			
		} catch (FileNotFoundException e) {
			System.err.println (e.getMessage());
		}
		
		System.out.println("Total time is " + (new Date().getTime() - start) / 1000 / 60);
	}
}