import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;

class Solver {

	int result = -100;
	InputData data;
		
	public Solver (InputData data) {
		this.data = data;
	}
	
	public void solve () {
		
		if (data.isImpossible()) {
			result = -1;
			return;
		}
		
		if (data.isPossible()) {			
			result = 0;
			return;
		}
		
		result = getPickCount();
		//data.printStatus();		
	}
	
	public int getPickCount() {
		int result = 0;
		int rescued = 0;
		List<Chicken> list = data.chikens;
		Collections.reverse(list);
		
		int c = 0;
		for (Chicken chicken: list) {
			if (chicken.isDead()) {
				c++;
			} else {
				result += c;
				rescued++;
			}
			
			if (rescued >= data.K) {
				break;
			}
		}
		
		return result;
	}

	public int getResult () {
		return result;
	}
}

class Chicken {
	int x;
	int v;
	Boolean isDead = false;
	
	public Chicken(String x, String v) {
		this.x = Integer.valueOf(x);
		this.v = Integer.valueOf(v);
	}
	
	public void markToDead () {
		this.isDead = true;
	}
	
	public Boolean isDead () {
		return isDead;
	}
}

class InputData {
	int N  = 0;
	int K = 0;
	int B = 0;
	int T = 0;

	List<Chicken> chikens = new LinkedList<Chicken>();

	public InputData (int n, int k, int b, int t, List<Chicken> chiken) {
		this.N = n;
		this.K = k;
		this.B = b;
		this.T = t;
		
		this.chikens = chiken;
	}
	
	public Boolean isPossible() {
		int liveCount = 0;
		
		for (Chicken chicken: chikens) {
			if (chicken.isDead()) {
				liveCount = 0;
			} else {
				liveCount++;
			}
		}
		
		return (liveCount >= K);
	}
	
	public Boolean isImpossible() {
		int liveCount = 0;
		for (Chicken chicken: chikens) {
			if (B - chicken.x - chicken.v * T > 0) {
				chicken.markToDead();
			} else {
				liveCount++;
			}
		}
		
		return (liveCount < K);
	}
	
	public void printStatus() {
		char[] status = new char[B+1];
		
		for (int i = 0; i <= B; i++) {
			status[i] = '.';
		}
		
		for (Chicken chicken : chikens) {
			status[chicken.x] = chicken.isDead ? 'x' : 'C'; 
		}
		status[B] = 'H';
		System.out.println(String.valueOf(status));
			
	}
}


public class ProblemB {
	//Test-case count
	//1 ≤ testCaseCount ≤ 50.
	int testCaseCount = 0;
	
	//
	Queue<InputData> inputData = new LinkedList<InputData>();
	//Solve result
	List<Integer> results = new ArrayList<Integer>();
	
	public void read (InputStream input) {

		try {
			InputStreamReader inputStreamReader = new InputStreamReader(input);
			BufferedReader bufferedReader = new BufferedReader (inputStreamReader);
			
			testCaseCount = Integer.valueOf(bufferedReader.readLine()); 
			
			for (int i = 1; i <= testCaseCount; i++) {
				int n, k, b, t;
				List<Chicken> chikens = new LinkedList<Chicken>();

				String paramsLine =  bufferedReader.readLine();
				String[] params = paramsLine.split(" ");
				n = Integer.valueOf(params[0]);
				k = Integer.valueOf(params[1]);
				b = Integer.valueOf(params[2]);
				t = Integer.valueOf(params[3]);
				
				String[] locations = bufferedReader.readLine().split(" ");
				String[] speeds = bufferedReader.readLine().split(" ");
				
				if (locations.length != speeds.length) {
					System.err.println ("Bad!");
				}
				
				for (int j = 0; j < locations.length; j++) {
					chikens.add(new Chicken(locations[j], speeds[j]));
				}
				inputData.add(new InputData(n, k, b, t,  chikens));
			}		
		} catch (FileNotFoundException e) {
			System.err.println (e.getMessage());
		} catch (IOException e) {
			System.err.println (e.getMessage());
		}
	}

	public void solve () {
		int i = 1;
		for (InputData testCase: inputData) {
			Long start = new Date().getTime();
			
			int result = 0;
			Solver solver = new Solver(testCase);
			solver.solve();
			result = solver.getResult();
			results.add(result);
			
			System.out.println("Case #" + i + ": " + result + " in " + (new Date().getTime() - start) / 1000);
			i++;
		}
	}
		
	public void write(PrintStream out) {
		int i = 1;
		for (int result: results) {
			if (result == -1)
				out.println("Case #" + i + ": " + "IMPOSSIBLE");
			else
				out.println("Case #" + i + ": " + result);
			i++;
		}
	}
	
	public static void main(String[] args) {
		ProblemB solver = new ProblemB();
		
		Long start = new Date().getTime();
		
		try {
			solver.read(new FileInputStream(new File("input.data")));
			solver.solve();
			solver.write(new PrintStream(new PrintStream(new File("output.data"))));
			//solver.write(System.out);
			
		} catch (FileNotFoundException e) {
			System.err.println (e.getMessage());
		}
		
		System.out.println("Total time is " + (new Date().getTime() - start) / 1000 / 60);
	}
}