import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

enum PARSER_STATE {
	NONBASE_COUNT,
	NONBASE,
	OPPOSITE_COUNT,
	OPPOSITE,
	ELEMENTS_COUNT,
	ELEMENTS,
	FINISHED;
}

public class Magica_Solver {

	Map<String, String> nonBaseRules = new HashMap<String, String>();
	Map<String, String> oppositeRules = new HashMap<String, String>();
	List<Character> elementsList = new LinkedList<Character>();
	List<Character> result = new LinkedList<Character>();
	
	public String solve(String testCase) {
		clear();
		parse(testCase);
		String res = "";
		
		for (Character element: elementsList) {
			res+= element;
			
			//   
			for (Entry<String, String> nonBaseRule: nonBaseRules.entrySet()) {
				if (res.contains(nonBaseRule.getKey())) {
					res = res.replace(nonBaseRule.getKey(), nonBaseRule.getValue());
				}
			}
			
			// 
			for (Entry<String, String> oppositeRule: oppositeRules.entrySet()) {
				if (res.contains(oppositeRule.getKey()) && res.contains(oppositeRule.getValue())) {
					res = "";
				}
			}
		}
		
		return res;
	}
	
	private void clear() {
		nonBaseRules.clear();
		oppositeRules.clear();
		elementsList.clear();
		result.clear();
	}
	
	private void parse(String testCase) {
		String[] parts = testCase.split(" ");
		PARSER_STATE state = PARSER_STATE.NONBASE_COUNT;
		int nonBaseCount = 0;
		int oppositeCount = 0;
		int elementsCount = 0;
		
		for (int i = 0; i < parts.length; i++) {
			switch (state) {
			
			case NONBASE_COUNT:
				nonBaseCount = Integer.valueOf(parts[i]);
				if (nonBaseCount > 0)
					state = PARSER_STATE.NONBASE;
				else
					state = PARSER_STATE.OPPOSITE_COUNT;
				break;
				
			case NONBASE:
				if (nonBaseRules.size() < nonBaseCount) {
					nonBaseRules.put(parts[i].substring(0,2), parts[i].substring(2));
					nonBaseRules.put(parts[i].substring(1,2) + parts[i].substring(0,1), parts[i].substring(2));
					break;
				} else {
					state = PARSER_STATE.OPPOSITE_COUNT;
				}
								
			case OPPOSITE_COUNT:
				oppositeCount = Integer.valueOf(parts[i]);
				if (oppositeCount > 0) 
					state = PARSER_STATE.OPPOSITE;
				else 
					state = PARSER_STATE.ELEMENTS_COUNT;
				break;
				
			case OPPOSITE:
				if (oppositeRules.size() < oppositeCount) {
					oppositeRules.put(parts[i].substring(0,1), parts[i].substring(1,2));
					break;
				} else {
					state = PARSER_STATE.ELEMENTS_COUNT;
				}				
			
			case ELEMENTS_COUNT:
				elementsCount = Integer.valueOf(parts[i]);
				state = PARSER_STATE.ELEMENTS;
				break;

			case ELEMENTS:
				String elements = parts[i];
				for (char element: elements.toCharArray()) {
					elementsList.add(element);					
				}
			}
		}
	}
	
	public static void main (String args[]) {
		List<String> cases = DataReader.read("B-small-attempt0.in");
		List<String> results = new LinkedList<String>();
		
		Magica_Solver solver = new Magica_Solver();
		
		for (String testCase: cases) {
			results.add(solver.solve(testCase));
		}
		
		DataWriter.write("B-small-attempt0.out", results);
	}
}

class DataReader {

	public static List<String> read (String fileName) {
		Integer testCaseNum = 0;
		Integer testCaseId = 0;
	 
		List<String> data = new LinkedList<String>();
		
		try {	    	
			FileInputStream fstream = new FileInputStream(fileName);
			//Get the object of DataInputStream
			DataInputStream in = new DataInputStream(fstream);
			BufferedReader br = new BufferedReader(new InputStreamReader(in));

			testCaseNum = Integer.valueOf(br.readLine());
			
			while (testCaseId < testCaseNum) {
				String caseString;
				testCaseId++;
				caseString = br.readLine();
				
				data.add(caseString);
			}

			//dispose all the resources after using them.
			in.close();

		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}				
		
		return data;
	}
}

class DataWriter {
	
	public static void write (String fileName, List<String> data) {
		try {	    	
			FileOutputStream fstream = new FileOutputStream(fileName);
			//Get the object of DataInputStream
			DataOutputStream out = new DataOutputStream(fstream);
			BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(out));

			int i = 0;
			for (String result: data) {
				i++;
				bw.write("Case #" + i + ": [" + convert(result) + "]\n");
				bw.flush();
			}
			out.close();

		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}						
	}
	
	public static String convert (String str) {
		
		String result = "";
		String prefix = ", ";
		
		for (char element: str.toCharArray()) {
			if (result.isEmpty()) {
				result += element;				
			} else {
				result += prefix + element;
			}
		}
		
		return result;
	}
}