package Round1A;

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Scanner;

public class Ratatouille {

	static Scanner s = null;
	static PrintWriter pw = null;
	static double eps = 0.0000001;

	private static class Graph {

		int[][] graph;
		int ROWS, COLS;

		public Graph(int[][] graph) {
			this.graph = graph;
			this.ROWS = graph.length;
			this.COLS = graph[0].length;
		}

		public boolean BFS(int s, int t, int[] parent) {
			boolean[] visited = new boolean[ROWS];
			ArrayList<Integer> queue = new ArrayList<Integer>();
			queue.add(s);
			visited[s] = true;

			while (!queue.isEmpty()) {
				int cur = queue.remove(0);
				for (int i = 0; i < COLS; i++) {
					int val = graph[cur][i];
					if (!visited[i] && val > 0) {
						queue.add(i);
						visited[i] = true;
						parent[i] = cur;
					}
				}
			}
			return visited[t];
		}

		public int maxFlow(int SOURCE, int SINK) {
			int flow = 0;
			int[] parent = new int[ROWS];
			Arrays.fill(parent, -1);

			while (this.BFS(SOURCE, SINK, parent)) {
				int path_flow = Integer.MAX_VALUE;
				int s = SINK;
				while (s != SOURCE) {
					path_flow = Math.min(path_flow, this.graph[parent[s]][s]);
					s = parent[s];
				}
				flow += path_flow;

				int v = SINK;
				while (v != SOURCE) {
					int u = parent[v];
					this.graph[u][v] -= path_flow;
					this.graph[v][u] += path_flow;
					v = parent[v];
				}
			}

			return flow;
		}
	}

	public static HashSet<Integer> valid(int pack, int req) {
		HashSet<Integer> ret = new HashSet<Integer>();
		for (int i = (int) Math.floor(1.0 * pack / req); i > 0 && pack <= req * i * 1.1 + eps
				&& pack >= req * i * 0.9 - eps; i++)
			ret.add(i);
		for (int i = (int) Math.ceil(1.0 * pack / req); pack <= req * i * 1.1 + eps && pack >= req * i * 0.9 - eps; i--)
			ret.add(i);
		return ret;
	}

	public static void go() {

		int T = s.nextInt();
		for (int t = 1; t <= T; t++) {
			System.out.printf("Solving case %d/%d\n", t, T);

			// node N is source, node N + 1 is sink
			// each node will be represented by an integer array of it's valid
			// serving sizes
			// an edge will be drawn from a node to all packages of the next
			// ingredient iff they share a serving size

			ArrayList<HashSet<Integer>> packs = new ArrayList<HashSet<Integer>>();
			int N = s.nextInt(), P = s.nextInt();
			int[] req = new int[N];
			for (int i = 0; i < N; i++)
				req[i] = s.nextInt();
			for (int ing = 0; ing < N; ing++) {
				for (int i = 0; i < P; i++) {
					packs.add(valid(s.nextInt(), req[ing]));
				}
				// System.out.println("============================");
			}
			int[][] adjMat = new int[N * P + 2][N * P + 2];
			// add source to package 1 iff it has any valid pack amount
			for (int i = 0; i < P; i++)
				adjMat[N * P][i] = packs.get(i).isEmpty() ? 0 : 1;
			// add sink to package P iff it has any valid pack amount
			for (int i = 0; i < P; i++)
				adjMat[(N - 1) * P + i][N * P + 1] = packs.get((N - 1) * P + i).isEmpty() ? 0 : 1;

			for (int n = 0; n < N - 1; n++) {
				for (int p = 0; p < P; p++) {
					HashSet<Integer> cur = packs.get(n * P + p);
					// if any of this package's values are doable by a pack in
					// the next
					// ingredient, construct an edge
					for (int pp = 0; pp < P; pp++) {
						HashSet<Integer> consider = packs.get((n + 1) * P + pp);
						for (int i : cur) {
							if (consider.contains(i)) {
								adjMat[n * P + p][(n + 1) * P + pp] = 1;
								break;
							}
						}
					}
				}
			}

			Graph G = new Graph(adjMat);
			int ans = G.maxFlow(N * P, N * P + 1);
			pw.printf("Case #%d: %d\n", t, ans);

		}

	}

	public static void main(String[] args) throws IOException {

		// s = new Scanner(System.in);
		s = new Scanner(new File("1A/B-small.in"));
		// s = new Scanner(new File("1A/B-large.in"));
		// pw = new PrintWriter(System.out);
		pw = new PrintWriter(new File("1A/B-small.out"));
		// pw = new PrintWriter(new File("1A/B-large.out"));

		go();

		s.close();
		pw.close();

	}

}
