package be.blop.round1c;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.stream.Collectors;

public class A {
	private BufferedReader reader;
	private BufferedWriter writer;
	private Scanner scanner;

	public static void main(String[] args) throws Exception {
		if (args.length != 2) System.exit(1);
		new A(new BufferedReader(new FileReader(args[0])), new BufferedWriter(new FileWriter(args[1]))).run();
	}

	private A(BufferedReader reader, BufferedWriter writer) {
		this.reader = reader;
		this.writer = writer;
		this.scanner = new Scanner(reader);
	}

	private void run() {
		try {
			codejam();
			writer.flush();
			writer.close();
			reader.close();
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	private void codejam() throws Exception {
		int cases = scanner.nextInt();
		for (int c = 1; c <= cases; c++) {
			writer.write("Case #" + c + ": ");
			solve();
		}
	}

	private void solve() throws Exception {
		int numberOfParty = scanner.nextInt();
		int totalMembers = 0;

		Map<String, Integer> members = new HashMap<>();
		for (int p = 0; p < numberOfParty; p++) {
			String partyName = Character.toString((char) ('A' + p));
			Integer numberOfMember = scanner.nextInt();
			totalMembers += numberOfMember;
			members.put(partyName, numberOfMember);
		}

		while (totalMembers > 0) {
			// Sort party by number of member
			List<String> partyNames = members.entrySet().stream()
					.sorted((e1, e2) -> e1.getValue().compareTo(e2.getValue()) * -1)
					.map(Map.Entry::getKey).collect(Collectors.toList());

			// Try with 2 members of same party
			List<String> selectedPartyNames = Arrays.asList(partyNames.get(0), partyNames.get(0));
			boolean checkMajority = checkMajority(totalMembers, members, selectedPartyNames);

			if (!checkMajority) {
				// Try with 2 member of different party
				selectedPartyNames = partyNames.subList(0, 2);
				checkMajority = checkMajority(totalMembers, members, selectedPartyNames);
			}

			if (!checkMajority) {
				// Try with 1 member
				selectedPartyNames = partyNames.subList(0, 1);
				checkMajority = checkMajority(totalMembers, members, selectedPartyNames);
			}

			// Evacuate member(s) of the party(s)
			if (checkMajority) {
				for (String partyName : selectedPartyNames) {
					writer.write(partyName);
					members.put(partyName, members.get(partyName) - 1);
					totalMembers--;
				}
				writer.write(" ");
			}
		}

		writer.write("\n");
	}

	private boolean checkMajority(int totalMembers, Map<String, Integer> members, Collection<String> selectedPartyNames) {
		int majority = ((totalMembers - selectedPartyNames.size()) / 2) + 1;

		for (Map.Entry<String, Integer> entry : members.entrySet()) {
			String partyName = entry.getKey();
			Integer membersOfParty = entry.getValue();
			if (selectedPartyNames.contains(partyName)) {
				membersOfParty -= 1;
			}

			if (membersOfParty >= majority) {
				return false;
			}
		}

		return true;
	}
}