package be.blop.round1c;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Scanner;

public class C {
	private BufferedReader reader;
	private BufferedWriter writer;
	private Scanner scanner;

	public static void main(String[] args) throws Exception {
		if (args.length != 2) System.exit(1);
		new C(new BufferedReader(new FileReader(args[0])), new BufferedWriter(new FileWriter(args[1]))).run();
	}

	private C(BufferedReader reader, BufferedWriter writer) {
		this.reader = reader;
		this.writer = writer;
		this.scanner = new Scanner(reader);
	}

	private void run() {
		try {
			codejam();
			writer.flush();
			writer.close();
			reader.close();
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	private void codejam() throws Exception {
		int cases = scanner.nextInt();
		for (int c = 1; c <= cases; c++) {
			writer.write("Case #" + c + ": ");
			solve();
		}
	}

	private class Outfit {
		int j;
		int p;
		int s;

		JacketPant jacketPant;
		JacketShirt jacketShirt;
		ShirtPant shirtPant;

		public Outfit(int j, int p, int s) {
			this.j = j;
			this.p = p;
			this.s = s;

			this.jacketPant = new JacketPant(j, p);
			this.jacketShirt = new JacketShirt(j, s);
			this.shirtPant = new ShirtPant(s, p);
		}

		@Override
		public boolean equals(Object o) {
			if (this == o) return true;
			if (o == null || getClass() != o.getClass()) return false;

			Outfit outfit = (Outfit) o;

			if (j != outfit.j) return false;
			if (p != outfit.p) return false;
			return s == outfit.s;

		}

		@Override
		public int hashCode() {
			int result = j;
			result = 31 * result + p;
			result = 31 * result + s;
			return result;
		}
	}

	private class JacketPant {
		int j;
		int p;

		public JacketPant(int j, int p) {
			this.j = j;
			this.p = p;
		}

		@Override
		public boolean equals(Object o) {
			if (this == o) return true;
			if (o == null || getClass() != o.getClass()) return false;

			JacketPant that = (JacketPant) o;

			if (j != that.j) return false;
			return p == that.p;

		}

		@Override
		public int hashCode() {
			int result = j;
			result = 31 * result + p;
			return result;
		}
	}

	private class JacketShirt {
		int j;
		int s;

		public JacketShirt(int j, int s) {
			this.j = j;
			this.s = s;
		}

		@Override
		public boolean equals(Object o) {
			if (this == o) return true;
			if (o == null || getClass() != o.getClass()) return false;

			JacketShirt that = (JacketShirt) o;

			if (j != that.j) return false;
			return s == that.s;

		}

		@Override
		public int hashCode() {
			int result = j;
			result = 31 * result + s;
			return result;
		}
	}

	private class ShirtPant {
		int s;
		int p;

		public ShirtPant(int p, int s) {
			this.p = p;
			this.s = s;
		}

		@Override
		public boolean equals(Object o) {
			if (this == o) return true;
			if (o == null || getClass() != o.getClass()) return false;

			ShirtPant shirtPant = (ShirtPant) o;

			if (s != shirtPant.s) return false;
			return p == shirtPant.p;

		}

		@Override
		public int hashCode() {
			int result = s;
			result = 31 * result + p;
			return result;
		}
	}

	private int getSafeInt(Integer integer) {
		return (integer != null) ? integer : 0;
	}

	private void planOutfit(List<Outfit> outfitList, List<List<Outfit>> outfitPlannings, List<Outfit> outfitPlanning, Map<JacketPant, Integer> jacketPantMap, Map<JacketShirt, Integer> jacketShirtMap, Map<ShirtPant, Integer> shirtPantMap, Outfit previousOutfit, int K) {
		if (outfitPlanning == null) {
			outfitPlanning = new ArrayList<>();
			outfitPlannings.add(outfitPlanning);
		}

		// Search for an outfit
		List<Outfit> foundOutfits = new ArrayList<>();
		for (Outfit outfit : outfitList) {
			// Check for not twice the same outfit
			if (previousOutfit == null || !previousOutfit.equals(outfit)) {
				// Check for two-garment policy
				int jpValue = getSafeInt(jacketPantMap.get(outfit.jacketPant));
				int jsValue = getSafeInt(jacketShirtMap.get(outfit.jacketShirt));
				int spValue = getSafeInt(shirtPantMap.get(outfit.shirtPant));

				if (jpValue < K && jsValue < K && spValue < K) {
					foundOutfits.add(outfit);
				}
			}
		}

		// Select outfit
		if (!foundOutfits.isEmpty()) {
			boolean first = true;
			for (Outfit selectedOutfit : foundOutfits) {
				// Create new planning
				if (!first) {
					outfitPlanning = new ArrayList<>(outfitPlanning);
					outfitPlannings.add(outfitPlanning);
					jacketPantMap = new HashMap<>(jacketPantMap);
					jacketShirtMap = new HashMap<>(jacketShirtMap);
					shirtPantMap = new HashMap<>(shirtPantMap);
				}
				first = false;

				// Add to planning
				outfitPlanning.add(selectedOutfit);

				int jpValue = getSafeInt(jacketPantMap.get(selectedOutfit.jacketPant));
				int jsValue = getSafeInt(jacketShirtMap.get(selectedOutfit.jacketShirt));
				int spValue = getSafeInt(shirtPantMap.get(selectedOutfit.shirtPant));
				jacketPantMap.put(selectedOutfit.jacketPant, jpValue + 1);
				jacketShirtMap.put(selectedOutfit.jacketShirt, jsValue + 1);
				shirtPantMap.put(selectedOutfit.shirtPant, spValue + 1);

				planOutfit(outfitList, outfitPlannings, outfitPlanning, jacketPantMap, jacketShirtMap, shirtPantMap, selectedOutfit, K);
			}
		}
	}

	private void solve() throws Exception {
		int J = scanner.nextInt();
		int P = scanner.nextInt();
		int S = scanner.nextInt();
		int K = scanner.nextInt();

		// Build list of all possible outfits
		List<Outfit> outfitList = new ArrayList<>();
		for (int j = 1; j <= J; j++) {
			for (int p = 1; p <= P; p++) {
				for (int s = 1; s <= S; s++) {
					Outfit outfit = new Outfit(j, p, s);
					outfitList.add(outfit);
				}
			}
		}

		// Build maximum ordered outfits planning that respect the rules
		List<List<Outfit>> outfitPlannings = new ArrayList<>();
		planOutfit(outfitList, outfitPlannings, null, new HashMap<>(), new HashMap<>(), new HashMap<>(), null, K);

		// Select best outfit planning
		List<Outfit> outfitPlanning = outfitPlannings.stream().sorted((o1, o2) -> Integer.compare(o1.size(), o2.size()) * -1).findFirst().orElse(null);

		// Output maximum of days (= number of outfits)
		if (outfitPlanning != null) {
			writer.write(outfitPlanning.size() + "\n");
			for (Outfit outfit : outfitPlanning) {
				writer.write(outfit.j + " " + outfit.p + " " + outfit.s + "\n");
			}
		} else {
			writer.write("0\n");
		}
	}
}