package be.blop;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.OutputStreamWriter;

public class CountingSheep {
	private File inputFile;
	private OutputStreamWriter outputWriter;

	public CountingSheep(File inputFile, File outputFile) throws FileNotFoundException {
		this.inputFile = inputFile;
		this.outputWriter = new OutputStreamWriter(new FileOutputStream(outputFile));
	}

	public void run() throws IOException {
		int lineNumber = 0;
		try (BufferedReader br = new BufferedReader(new FileReader(inputFile))) {
			String line;
			while ((line = br.readLine()) != null) {
				if (lineNumber > 0) {
					Long startValue = Long.parseLong(line);
					sleep(lineNumber, startValue);
				}
				lineNumber++;
			}
		}

		outputWriter.flush();
		outputWriter.close();
	}

	private void sleep(Integer caseNumber, Long startValue) throws IOException {
		int digitsCount = 10;
		boolean[] digits = new boolean[digitsCount];

		if (startValue.equals(0L)) {
			outputWriter.write("Case #" + caseNumber + ": INSOMNIA\n");
			return;
		}

		Long currentValue = null;
		int i = 1;

		while (digitsCount != 0) {
			currentValue = i++ * startValue;

			byte[] bytes = currentValue.toString().getBytes();
			for (byte aByte : bytes) {
				int digitIndex = aByte - 48;
				boolean seen = digits[digitIndex];
				if (!seen) {
					digits[digitIndex] = true;
					digitsCount--;
				}
			}
		}

		outputWriter.write("Case #" + caseNumber + ": " + currentValue + "\n");
	}

	public static void main(String[] args) throws Exception {
		if (args.length != 2) System.exit(1);
		File inputFile = new File(args[0]);
		File outputFile = new File(args[1]);
		CountingSheep countingSheep = new CountingSheep(inputFile, outputFile);
		countingSheep.run();
	}
}
