package be.blop;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.math.BigInteger;

public class CoinJam {
	public static final int[] BASES = new int[]{2, 3, 4, 5, 6, 7, 8, 9, 10};

	private File inputFile;
	private OutputStreamWriter outputWriter;

	public CoinJam(File inputFile, File outputFile) throws FileNotFoundException {
		this.inputFile = inputFile;
		this.outputWriter = new OutputStreamWriter(new FileOutputStream(outputFile));
	}

	public void run() throws IOException {
		int lineNumber = 0;
		try (BufferedReader br = new BufferedReader(new FileReader(inputFile))) {
			String line;
			while ((line = br.readLine()) != null) {
				if (lineNumber > 0) {
					String[] parts = line.split("\\s+");
					Integer n = Integer.valueOf(parts[0]);
					Integer j = Integer.valueOf(parts[1]);
					coinJam(lineNumber, n, j);
				}
				lineNumber++;
			}
		}

		outputWriter.flush();
		outputWriter.close();
	}

	private void coinJam(int caseNumber, int n, int j) throws IOException {
		outputWriter.write("Case #" + caseNumber + ":\n");

		long coin = (1L << (n - 1)) + ((n > 0) ? 1 : 0);
		int coinCount = 0;
		while (true) {
			String coinStr = Long.toBinaryString(coin);
			if (coinStr.length() > n) {
				throw new IllegalArgumentException("Cannot find " + j + " coins of size " + n);
			}

			boolean foundAllDivisors = true;
			Long[] divisors = new Long[BASES.length];
			for (int b = 0; b < BASES.length && foundAllDivisors; b++) {
				int base = BASES[b];
				BigInteger numberInBase = new BigInteger(coinStr, base);
				divisors[b] = findNonTrivialDivisor(numberInBase);
				foundAllDivisors = (divisors[b] != null);
			}

			if (foundAllDivisors) {
				coinCount++;

				outputWriter.write(coinStr);
				for (int b = 0; b < BASES.length; b++) {
					outputWriter.write(" " + divisors[b]);
				}
				outputWriter.write("\n");
				outputWriter.flush();

				if (coinCount == j) {
					break;
				}
			}
			coin += 2;
		}
	}

	private Long findNonTrivialDivisor(BigInteger number) {
		long stop = 1000L; // speed things up a bit
		for (long d = 2; d < stop; d++) {
			if (number.mod(BigInteger.valueOf(d)).equals(BigInteger.ZERO)) {
				return d;
			}
		}
		return null;
	}

	public static void main(String[] args) throws Exception {
		if (args.length != 2) System.exit(1);
		File inputFile = new File(args[0]);
		File outputFile = new File(args[1]);
		CoinJam countingSheep = new CoinJam(inputFile, outputFile);
		countingSheep.run();
	}
}
