package net.codejam.alien;

import java.io.BufferedReader;
import java.io.FileReader;
import java.util.*;

public class StationManager
{
    enum Station {A, B}

    public int[] numberOfTrains(List<Trip> trips, int turnAround)
    {
        List<Train> trains = new ArrayList<Train>();

        for (Iterator<Trip> iterator = trips.iterator(); iterator.hasNext();)
        {
            Trip trip = iterator.next();

            boolean foundAvailableTrain = false;
            for (Train train : trains)
            {
                if (train.canTakeTrip(trip))
                {
                    train.setTrip(trip);
                    foundAvailableTrain = true;
                    break;
                }
            }

            if (!foundAvailableTrain)
            {
                Train newTrain = new Train(turnAround, trip.getOrigin());
                newTrain.setTrip(trip);
                trains.add(newTrain);
            }
        }

        int aTrains = 0;
        int bTrains = 0;

        for (Train train : trains)
        {
            if (train.getStartedAt() == Station.A)
                aTrains++;
            else
                bTrains++;
        }

        return new int[] {aTrains, bTrains};
    }

    public static void main(String[] args) throws Exception
    {
        StationManager stationManager = new StationManager();
        BufferedReader reader = new BufferedReader(new FileReader("/Users/dave/Desktop/codejam/B-small-attempt2.in"));

        int N = Integer.parseInt(reader.readLine());
        int counter = 1;

        for (int i = 0; i < N; i++)
        {
            int turnAround = Integer.parseInt(reader.readLine());
            String[] splittedTrips = reader.readLine().split(" ");
            int fromATrips = Integer.parseInt(splittedTrips[0]);
            int fromBTrips = Integer.parseInt(splittedTrips[1]);

            List<Trip> trips = new ArrayList<Trip>(fromATrips + fromBTrips);
            for (int j = 0; j < fromATrips; j++)
                trips.add(parseTrip(reader.readLine(), Station.A, Station.B));
            for (int j = 0; j < fromBTrips; j++)
                trips.add(parseTrip(reader.readLine(), Station.B, Station.A));

            Collections.sort(trips);

            int[] numberOfTrains = stationManager.numberOfTrains(trips, turnAround);
            System.out.println("Case #" + counter++ + ": " + numberOfTrains[0] + " " + numberOfTrains[1]);
        }
    }

    static Trip parseTrip(String trip, Station origin, Station destination)
    {
        String[] splittedTrip = trip.split(" ");
        return new Trip(origin, destination, new Time(splittedTrip[0]), new Time(splittedTrip[1]));
    }

    static class Train
    {
        private int turnAround;
        private Station startedAt;
        private Trip trip;

        public Train(int turnAround, Station startedAt)
        {
            this.turnAround = turnAround;
            this.startedAt = startedAt;
        }

        public boolean isReadyToDepartAt(Time expectedTime)
        {
            if (trip == null)
                return true;
            else
            {
                Time timeIncludingTurnover = expectedTime.subtract(turnAround);

                if (timeIncludingTurnover == Time.INVALID) 
                    return false;
                else
                    return trip.isCompleteBy(timeIncludingTurnover);
            }
        }

        public boolean canTakeTrip(Trip candidateTrip)
        {
            if (trip == null)
                return candidateTrip.getOrigin() == startedAt;
            else
                return candidateTrip.getOrigin() == trip.getDestination() && isReadyToDepartAt(candidateTrip.getDeparture());
        }

        public void setTrip(Trip candidateTrip)
        {
            if (!canTakeTrip(candidateTrip))
                throw new IllegalArgumentException("Train cannot take this trip: " + candidateTrip);

            this.trip = candidateTrip;
        }

        public Station getStartedAt()
        {
            return startedAt;
        }
    }

    static class Trip implements Comparable<Trip>
    {
        private final Station origin;
        private final Station destination;
        private final Time departure;
        private final Time arrival;

        public Trip(Station origin, Station destination, Time departure, Time arrival)
        {
            this.origin = origin;
            this.destination = destination;
            this.departure = departure;
            this.arrival = arrival;
        }

        public int compareTo(Trip o)
        {
            return departure.compareTo(o.departure);
        }

        public String toString()
        {
            return "[" + origin + " to " + destination + "] " + departure + " - " + arrival;
        }

        public boolean isCompleteBy(Time time)
        {
            return time.compareTo(arrival) >= 0;
        }

        public Station getOrigin()
        {
            return origin;
        }

        public Station getDestination()
        {
            return destination;
        }

        public Time getDeparture()
        {
            return departure;
        }

        public Time getArrival()
        {
            return arrival;
        }
    }

    static class Time implements Comparable<Time>
    {
        private final int hours;
        private final int minutes;

        public static Time INVALID = new Time(-1, -1);

        public Time(int hours, int minutes)
        {
            this.hours = hours;
            this.minutes = minutes;
        }

        public Time(String time)
        {
            String[] tempTime = time.split(":");
            this.hours = Integer.parseInt(tempTime[0]);
            this.minutes = Integer.parseInt(tempTime[1]);
        }

        public int compareTo(Time o)
        {
            if (hours < o.hours)
                return -1;
            if (hours > o.hours)
                return 1;
            if (minutes < o.minutes)
                return -1;
            if (minutes > o.minutes)
                return 1;

            return 0;
        }

        public Time subtract(int minutes)
        {
            int minutesToSubtract = minutes % 60;
            int hoursToSubtract = minutes / 60;

            if (hoursToSubtract > this.hours || (this.hours == 0 && minutesToSubtract > this.minutes))
                return INVALID;
            else
            {
                int minuteResult = this.minutes - minutesToSubtract;

                if (minuteResult < 0)
                {
                    hoursToSubtract++;
                    minuteResult += 60;
                }

                return new Time(this.hours - hoursToSubtract, minuteResult);
            }
        }

        public int getHours()
        {
            return hours;
        }

        public int getMinutes()
        {
            return minutes;
        }

        public boolean equals(Object o)
        {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Time time = (Time) o;

            if (hours != time.hours) return false;
            if (minutes != time.minutes) return false;

            return true;
        }

        public int hashCode()
        {
            int result;
            result = hours;
            result = 31 * result + minutes;
            return result;
        }

        public String toString()
        {
            return (hours < 10 ? "0" : "") + hours + ":" + (minutes < 10 ? "0" : "") + minutes;
        }
    }
}
