package net.codejam.alien;

import junit.framework.TestCase;

public class TestStationManager extends TestCase
{
    public void testCompareToTime()
    {
        StationManager.Time time = new StationManager.Time("00:00");
        StationManager.Time time2 = new StationManager.Time("01:00");
        StationManager.Time time3 = new StationManager.Time("00:00");
        StationManager.Time time4 = new StationManager.Time("01:30");
        assertTrue(time.compareTo(time2) < 0);
        assertTrue(time2.compareTo(time) > 0);
        assertEquals(0, time.compareTo(time3));
        assertTrue(time2.compareTo(time4) < 0);
        assertTrue(time4.compareTo(time2) > 0);
    }

    public void testSubtractTime()
    {
        StationManager.Time time = new StationManager.Time("00:03");
        StationManager.Time time2 = new StationManager.Time("13:45");
        StationManager.Time time3 = new StationManager.Time("09:00");
        assertEquals(new StationManager.Time("00:02"), time.subtract(1));
        assertEquals(new StationManager.Time("12:45"), time2.subtract(60));
        assertEquals(new StationManager.Time("11:45"), time2.subtract(120)); 
        assertEquals(new StationManager.Time("11:35"), time2.subtract(130)); 
        assertEquals(StationManager.Time.INVALID, new StationManager.Time("1:45").subtract(120));
        assertEquals(StationManager.Time.INVALID, time.subtract(4));
        assertEquals(new StationManager.Time("00:00"), time.subtract(3));
        assertEquals(new StationManager.Time("08:59"), time3.subtract(1));
        assertEquals(time3, time3.subtract(0));
    }

    public void testTrainIsReadyToDepart()
    {
        StationManager.Train train = new StationManager.Train(5, StationManager.Station.A);
        assertTrue(train.isReadyToDepartAt(new StationManager.Time("00:03")));

        try
        {
            train.setTrip(new StationManager.Trip(StationManager.Station.B, StationManager.Station.A,
                new StationManager.Time("13:30"), new StationManager.Time("13:40")));
            fail(); 
        }
        catch (IllegalArgumentException e)
        {
            // expected
        }

        train.setTrip(new StationManager.Trip(StationManager.Station.A, StationManager.Station.B,
            new StationManager.Time("00:01"), new StationManager.Time("00:02")));

        assertFalse(train.canTakeTrip(new StationManager.Trip(StationManager.Station.B, StationManager.Station.A,
            new StationManager.Time("00:02"), new StationManager.Time("00:03"))));

        assertTrue(train.canTakeTrip(new StationManager.Trip(StationManager.Station.B, StationManager.Station.A,
            new StationManager.Time("00:07"), new StationManager.Time("00:08"))));

        assertTrue(train.isReadyToDepartAt(new StationManager.Time("00:07")));
        assertFalse(train.isReadyToDepartAt(new StationManager.Time("00:06")));
        assertFalse(train.isReadyToDepartAt(new StationManager.Time("00:03")));
    }

    public void testIsCompleteBy()
    {
        StationManager.Time departure = new StationManager.Time("01:30");
        StationManager.Time arrival = new StationManager.Time("02:30");
        StationManager.Trip trip = new StationManager.Trip(StationManager.Station.A, StationManager.Station.B, departure, arrival);
        assertTrue(trip.isCompleteBy(new StationManager.Time("02:30")));
        assertTrue(trip.isCompleteBy(new StationManager.Time("02:31")));
        assertTrue(trip.isCompleteBy(new StationManager.Time("22:31")));
        assertFalse(trip.isCompleteBy(new StationManager.Time("02:29")));
        assertFalse(trip.isCompleteBy(new StationManager.Time("00:00")));
    }
}
