package net.codejam.alien;

import java.io.BufferedReader;
import java.io.StringReader;
import java.io.FileReader;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;
import java.util.TreeMap;

public class UniversePreservingSearcher
{
    public int minimumSwitches(List<String> searchEngines, List<String> queries)
    {
        return innerMinimumSwitches(0, searchEngines, queries, null);
    }

    int innerMinimumSwitches(int startPos, List<String> searchEngines, List<String> queries, String currentSearchEngine)
    {
        if (startPos >= queries.size())
            return 0;

        TreeMap<Integer, String> matchPositions = new TreeMap<Integer, String>();

        List<String> queriesSublist = queries.subList(startPos, queries.size());
        for (String searchEngine : searchEngines)
        {
            if (searchEngine.equals(currentSearchEngine))
                continue; // cannot switch to the same engine

            int matchPosition = queriesSublist.indexOf(searchEngine);

            if (matchPosition == -1)
                return 0; // we've found a search engine that can handle all queries without switching
            else
                matchPositions.put(matchPosition + startPos, searchEngine);
        }

        // if we have found matches for all engines, pick the engine that is furthest down the list
        // of queries
        Integer farthestIndex = matchPositions.lastKey();
        return 1 + innerMinimumSwitches(farthestIndex + 1, searchEngines, queries, matchPositions.get(farthestIndex));
    }

    public static void main(String[] args) throws Exception
    {
        UniversePreservingSearcher searcher = new UniversePreservingSearcher();

//        BufferedReader reader = new BufferedReader(new StringReader(generateData(true, 10)));
        BufferedReader reader = new BufferedReader(new FileReader("/Users/dave/Desktop/codejam/A-small-attempt0.in"));

        int N = Integer.parseInt(reader.readLine());
        int counter = 1;

        for (int i = 0; i < N; i++)
        {
            int S = Integer.parseInt(reader.readLine());
            List<String> searchEngines = new ArrayList<String>(S);

            for (int j = 0; j < S; j++)
                searchEngines.add(reader.readLine());

            int Q = Integer.parseInt(reader.readLine());
            List<String> queries = new ArrayList<String>(Q);

            for (int k = 0; k < Q; k++)
                queries.add(reader.readLine());

            System.out.println("Case #" + counter++ + ": " + searcher.minimumSwitches(searchEngines, queries));
        }
    }

    static String generateData(boolean print, int numSearchEngines)
    {
        StringBuilder builder = new StringBuilder();
        builder.append(1).append("\n");
        builder.append(numSearchEngines).append("\n");

        List<String> engines = new ArrayList<String>(numSearchEngines);
        for (int i = 0; i < numSearchEngines; i++)
        {
            String name = "Google" + (i + 1);
            engines.add(name);
            builder.append(name).append("\n");
        }

        Random random = new Random();
        builder.append(1000).append("\n");
        for (int i = 0; i < 1000; i++)
            builder.append(engines.get(random.nextInt(numSearchEngines))).append("\n");

        String result = builder.toString();

        if (print)
            System.out.println(result);

        return result;
    }
}
