package gcj.y2014.qualification;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;
import java.util.Arrays;

public class MinesweeperMaster {
	
	private static enum Cell {
		EMPTY,
		MINE
	}
	
	private static class MineField {
		
		private final int rowCount;
		private final int colCount;
		private final Cell[][] field; // field[row][col]
		private final int mineCount;
		
		public MineField(int rows, int cols, int mineCount) {
			rowCount = rows;
			colCount = cols;
			field = new Cell[rows][cols];
			this.mineCount = mineCount;
			populate();
		}

		private void populate() {
			int emptyAllowance = (rowCount * colCount) - mineCount;
			for (int row = 0; row < rowCount; row++) {
				for (int col = 0; col < colCount; col++) {
					emptyAllowance -= populateSquare(row, col, emptyAllowance);
				}
			}
		}
		
		private int populateSquare(int row, int col, int emptyAllowance) {
			int emptyCount = 0;
			for (int i = row; i < rowCount && i < row + 2; i++) {
				for (int j = col; j < colCount && j < col + 2; j++) {
					if (field[i][j] == null) {
						field[i][j] = Cell.MINE;
						if (emptyCount < emptyAllowance) {
							field[i][j] = Cell.EMPTY;
							emptyCount++;
						}
					}
				}
			}
			return emptyCount;
		}
		
		public boolean hasOneClickSolution() {
			boolean result = false;
			for (int row = 0; row < rowCount; row++) {
				for (int col = 0; col < colCount; col++) {
					int emptyCount = countEmptyCells(row, col);
					if (emptyCount > 0) {
						result = hasOneClickSolution(row, col);
						if (!result) {
							break;
						}
					}
				}
			}
			return result;
		}
		
		private int countEmptyCells(int row, int col) {
			int emptyCount = 0;
			for (int i = row; i < rowCount && i < row + 2; i++) {
				for (int j = col; j < colCount && j < col + 2; j++) {
					if (field[i][j] == Cell.EMPTY) {
						emptyCount++;
					}
				}
			}
			return emptyCount;
		}
		
		private boolean hasOneClickSolution(int row, int col) {
			boolean result = false;
			int emptyCount = countEmptyCells(row, col);
			if (emptyCount > 0) {
				if (emptyCount == 4) {
					result = true;
				} else if (emptyCount == 3) {
					result = row > 0 && col > 0;
				} else if (emptyCount == 2) {
					result = col > 0 || row > 0 || colCount == 1 || rowCount == 1;
				} else if (emptyCount == 1) {
					result = (row > 0 && col > 0) || (row == 0 && col == 0) || colCount == 1 || rowCount == 1;
				}
			}
			return result;
		}
		
		@Override
		public String toString() {
			StringBuffer buffer = new StringBuffer();
			for (int row = 0; row < rowCount; row++) {
				for (int col = 0; col < colCount; col++) {
					if (row == 0 && col == 0) {
						buffer.append("c");
					} else if (field[row][col] == Cell.EMPTY) {
						buffer.append(".");
					} else if (field[row][col] == Cell.MINE) {
						buffer.append("*");
					} else {
						buffer.append(" ");
					}
				}
				if (row < rowCount - 1) {
					buffer.append("\n");
				}
			}
			return buffer.toString();
		}
	}

	public static void main(String[] args) throws IOException {
		BufferedReader reader = new BufferedReader(new FileReader("C-small-attempt0.in"));
		Writer writer = new BufferedWriter(new FileWriter("C-small-attempt0.out"));
		int testCount = Integer.parseInt(reader.readLine());
		for (int t = 0; t < testCount; t++) {
			String[] tokens = reader.readLine().split(" ");
			int rows = Integer.parseInt(tokens[0]);
			int cols = Integer.parseInt(tokens[1]);
			int mineCount = Integer.parseInt(tokens[2]);
			System.out.println(Arrays.toString(tokens));
			MineField field = new MineField(rows, cols, mineCount);
			String result = formatResult(t, field);
			writer.write(result + "\n");
			System.out.println(result);
		}
		reader.close();
		writer.close();
	}

	private static String formatResult(int t, MineField field) {
		return String.format("Case #%d:\n%s", t + 1, field.hasOneClickSolution() ? field.toString() : "Impossible");
	}
}
