import java.io.*;
import java.util.*;

public class C {
	public static boolean DEBUG = true;
	public static int INFINITY = 2000000000;
	
	public static void main(String[] args) throws Exception{
		BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
		PrintWriter pw = new PrintWriter(System.out);
		
		int cases = Integer.parseInt(br.readLine());
		
		for(int t = 1; t <= cases; t++){
			pw.print("Case #" + t + ": ");
			
			int n = nextInt(br);
			NFNode[] nodes = new NFNode[n];
			
			for(int i = 0; i < n; i++){
				NFNode node = new NFNode();
				StringTokenizer st = getst(br);
				nodes[i] = node;
				
				while(st.hasMoreTokens()){
					node.words.add(st.nextToken());
				}
			}
			
			for(int i = 0; i < n; i++){
				for(int j = i+1; j < n; j++){
					HashSet<String> k = intersect(nodes[i], nodes[j]);
					if(k.size() > 0){
						//debug(i + " " + j + " " + k);
						NFEdge edge = new NFEdge(nodes[i], nodes[j], k.size(), k);
						edge.cb = k.size();
					}
				}
			}
			
			//debug("thing " + n);
			pushRelabel(nodes[0], nodes[1], n);
			//debug("no thing");
			
			HashSet<String> solution = new HashSet<String>();
			dfs(nodes[0]);
			
			//debug("");
			
			for(int i = 0; i < n; i++){
				//debug(nodes[i]);
				for(NFEdge e : nodes[i].edges){
					if(e.a.mark ^ e.b.mark){
						solution.addAll(e.words);
					}
				}
			}
			
			for(int i = 0; i < n; i++){
				nodes[i].mark = false;
			}
			
			int ans = solution.size();
			
			solution = new HashSet<String>();
			
			dfs(nodes[1]);
			
			for(int i = 0; i < n; i++){
				//debug(nodes[i]);
				for(NFEdge e : nodes[i].edges){
					if(e.a.mark ^ e.b.mark){
						solution.addAll(e.words);
					}
				}
			}
			
			pw.println(Math.min(ans, solution.size()));
		}
		
		br.close();
		pw.close();
	}
	
	public static void pushRelabel(NFNode source, NFNode sink, int size){
		Queue<NFNode> queue = new LinkedList<NFNode>();
		initialize(source, size, queue);
		while(!queue.isEmpty()){
			//debug(queue);
			//debug(sink);
			NFNode next = queue.peek();
			for(NFEdge edge : next.edges){
				if(edge.other(next).height < next.height){
					long before = next.surplus;
					next.surplus = edge.push(edge.other(next), next.surplus);
					if(next.surplus < before && edge.other(next) != source && edge.other(next) != sink){
						queue.add(edge.other(next));
					}
					if(next.surplus == 0){
						break;
					}
				}
			}
			if(next.surplus > 0 && next != sink){
				int label = next.height;
				relabel(next);
				if(next.height == label){
					queue.poll();
				}
			} else {
				queue.poll();
			}
		}
	}
	
	public static void initialize(NFNode source, int size, Queue<NFNode> queue){
		source.height = size;
		source.surplus = INFINITY;
		for(NFEdge edge : source.edges){
			edge.push(edge.other(source), source.surplus);
			queue.add(edge.other(source));
		}
	}
	
	public static void relabel(NFNode node){
		node.height = 1000000000;
		for(NFEdge edge : node.edges){
			if(edge.capacityTo(edge.other(node)) > 0){
				node.height = Math.min(node.height, edge.other(node).height + 1);
			}
		}
	}
	
	static class NFNode{
		public HashSet<NFEdge> edges;
		public long surplus;
		public int height;
		public HashSet<String> words;
		public boolean mark;
		
		public NFNode(){
			edges = new HashSet<NFEdge>();
			surplus = 0;
			height = 0;
			words = new HashSet<String>();
			mark = false;
		}
		
		public String toString(){
			return "(" + surplus + "," + height + "," + mark + ")";
		}
	}
	
	static class NFEdge{
		public NFNode a;
		public NFNode b;
		public long cf;
		public long cb;
		public HashSet<String> words;
		
		public NFEdge(NFNode ma, NFNode mb, long c, HashSet<String> w){
			a = ma;
			b = mb;
			cf = c;
			cb = 0;
			a.edges.add(this);
			b.edges.add(this);
			words = w;
		}
		
		public long push(NFNode toward, long cap){
			a.surplus -= cf;
			b.surplus -= cb;
			if(a == toward){
				cap -= cb;
				if(cap >= 0){
					cf += cb;
					cb = 0;
				} else {
					cf = cf + cb + cap;
					cb = -cap;
					cap = 0;
				}
			} else {
				cap -= cf;
				if(cap >= 0){
					cb += cf;
					cf = 0;
				} else {
					cb = cf + cb + cap;
					cf = -cap;
					cap = 0;
				}
			}
			a.surplus += cf;
			b.surplus += cb;
			return cap;
		}
		
		public long capacityTo(NFNode toward){
			if(a == toward){
				return cb;
			}
			return cf;
		}
		
		public NFNode other(NFNode c){
			if(a == c){
				return b;
			}
			return a;
		}
	}
	
	public static void dfs(NFNode a){
		if(a.mark){
			return;
		}
		a.mark = true;
		for(NFEdge e : a.edges){
			if(e.cf > 0 && e.cb > 0){
				dfs(e.other(a));
			}
		}
	}
	
	public static HashSet<String> intersect(NFNode a, NFNode b){
		HashSet<String> ret =  new HashSet<String>();
		ret.addAll(a.words);
		ret.retainAll(b.words);
		return ret;
	}
	
	public static void debug(Object o){
		if(DEBUG){
			System.out.println("~" + o);
		}
	}
	
	public static StringTokenizer getst(BufferedReader br) throws Exception{
		return new StringTokenizer(br.readLine(), " ");
	}
	
	public static int nextInt(BufferedReader br) throws Exception{
		return Integer.parseInt(br.readLine());
	}
	
	public static int nextInt(StringTokenizer st) throws Exception{
		return Integer.parseInt(st.nextToken());
	}
}