import java.util.HashSet;
import java.util.Scanner;
import java.util.Set;


public class Dijkstra {

	private static Set<Integer> suffixForK;
	
	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		int T = in.nextInt();
		for (int i = 1; i <= T; i++) {
			in.nextInt();
			int X = in.nextInt();
			in.nextLine();
			String part = in.nextLine();
			StringBuilder sb = new StringBuilder(part);
			for (int x = 1; x < X; x++) {
				sb.append(part);
			}
			String s = sb.toString();
			populateSuffixForK(s);
			System.out.print("Case #" + i + ": ");
			if (canGetIJK(s, 0)) {
				System.out.println("YES");
			} else {
				System.out.println("NO");
			}
		}
		in.close();
	}

	private static void populateSuffixForK(String s) {
		suffixForK = new HashSet<Integer>();
		int pos = s.length() - 1;
		Elem elem = ElemBase.fromChar(s.charAt(pos));
		while (pos >= 0) {
			if (elem.elemBase == ElemBase.K && elem.sign) {
				suffixForK.add(pos);
			}
			pos--;
			if (pos >= 0) {
				elem = Elem.multiply(ElemBase.fromChar(s.charAt(pos)), elem);
			}
		}	
	}

	private static boolean canGetIJK(String s, int start) {
		Elem elem = ElemBase.fromChar(s.charAt(start));
		for (int limit = start; limit <= s.length() - 3; limit++) {
			if (elem.elemBase == ElemBase.I && elem.sign && canGetJK(s, limit + 1)){
				return true;
			}
			elem = Elem.multiply(elem, ElemBase.fromChar(s.charAt(limit + 1)));
		}
		return false;
	}
	
	private static boolean canGetJK(String s, int start) {
		Elem elem = ElemBase.fromChar(s.charAt(start));
		for (int limit = start; limit <= s.length() - 2; limit++) {
			if (elem.elemBase == ElemBase.J && elem.sign && canGetK(s, limit + 1)){
				return true;
			}
			elem = Elem.multiply(elem, ElemBase.fromChar(s.charAt(limit + 1)));
		}
		return false;
	}
	
	private static boolean canGetK(String s, int start) {
		return suffixForK.contains(start);
	}
	
	private static class Elem {
		ElemBase elemBase;
		boolean sign;
		
		public Elem(ElemBase elemBase, boolean sign) {
			this.elemBase = elemBase;
			this.sign = sign;
		}
		
		private static Elem multiply(Elem a, Elem b) {
			if (a.elemBase == ElemBase.ONE) {
				return new Elem(b.elemBase, multiplySign(a, b));
			}
			if (b.elemBase == ElemBase.ONE) {
				return new Elem(a.elemBase, multiplySign(a, b));
			}
			if (a.elemBase == b.elemBase) {
				return new Elem(ElemBase.ONE, multiplySignAndNegate(a, b));
			}
			if (a.elemBase == ElemBase.I && b.elemBase == ElemBase.J) {
				return new Elem(ElemBase.K, multiplySign(a, b));
			}
			if (a.elemBase == ElemBase.I && b.elemBase == ElemBase.K) {
				return new Elem(ElemBase.J, multiplySignAndNegate(a, b));
			}
			if (a.elemBase == ElemBase.J && b.elemBase == ElemBase.I) {
				return new Elem(ElemBase.K, multiplySignAndNegate(a, b));
			}
			if (a.elemBase == ElemBase.J && b.elemBase == ElemBase.K) {
				return new Elem(ElemBase.I, multiplySign(a, b));
			}
			if (a.elemBase == ElemBase.K && b.elemBase == ElemBase.I) {
				return new Elem(ElemBase.J, multiplySign(a, b));
			}
			if (a.elemBase == ElemBase.K && b.elemBase == ElemBase.J) {
				return new Elem(ElemBase.I, multiplySignAndNegate(a, b));
			}
			throw new IllegalArgumentException();
		}

		private static boolean multiplySignAndNegate(Elem a, Elem b) {
			return !multiplySign(a, b);
		}

		private static boolean multiplySign(Elem a, Elem b) {
			if (a.sign == b.sign) {
				return true;
			}
			return false;
		}
	}
	
	private enum ElemBase {
		ONE,
		I,
		J,
		K;
		
		private static Elem fromChar(char c) {
			switch(c) {
			case 'i':
				return new Elem(I, true);
			case 'j':
				return new Elem(J, true);
			case 'k':
				return new Elem(K, true);
			}
			throw new IllegalArgumentException();
		}
	}
}
