package main;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;

public class Main {

	public static void main(String[] args) throws IOException
	{
		DecimalFormat df = new DecimalFormat("0.00");
		df.setMinimumFractionDigits(8);
		DecimalFormatSymbols dfs = df.getDecimalFormatSymbols();
		dfs.setDecimalSeparator('.');
		df.setDecimalFormatSymbols(dfs);
		
		BufferedReader f_in = new BufferedReader(new FileReader("B-small-attempt1(2).in"));
		FileWriter f_out= new FileWriter("firefly.out");
		
		int n_cases = Integer.parseInt(f_in.readLine());
		
		for(int i = 0; i < n_cases; i++)
		{
			// Obtain info from file.
			int n_fireflies = Integer.parseInt(f_in.readLine());
			int[][] ff_info = new int[n_fireflies][6];
			
			for(int f = 0; f < n_fireflies; f++)
			{
				String[] current_ff_info = f_in.readLine().split(" ");
				for(int a = 0; a < 6; a++)
					ff_info[f][a] = Integer.parseInt(current_ff_info[a]);
			}
			
			// Print info.
			System.out.println("No fireflies: " + n_fireflies);
			for(int f = 0; f < n_fireflies; f++)
			{
				for(int a = 0; a < 6; a++)
					System.out.print(ff_info[f][a] + " ");
				System.out.println();
			}
			
			// Solve the problem.
			double[] center_pos = {0,0,0};
			double[] center_vel = {0,0,0};
			for(int f = 0; f < n_fireflies; f++)
			{
				center_pos[0] += ff_info[f][0];
				center_pos[1] += ff_info[f][1];
				center_pos[2] += ff_info[f][2];
				
				center_vel[0] += ff_info[f][3];
				center_vel[1] += ff_info[f][4];
				center_vel[2] += ff_info[f][5];
			}
			
			center_pos[0] /= n_fireflies;
			center_pos[1] /= n_fireflies;
			center_pos[2] /= n_fireflies;
			
			center_vel[0] /= n_fireflies;
			center_vel[1] /= n_fireflies;
			center_vel[2] /= n_fireflies;
			
			System.out.println("Center info:");
			System.out.println("Position: " + center_pos[0] + " " + center_pos[1] + " " + center_pos[2]);
			System.out.println("Speed: " + center_vel[0] + " " + center_vel[1] + " " + center_vel[2]);
			
			double vel_mod = (center_vel[0] * center_vel[0] + center_vel[1] * center_vel[1] + center_vel[2] * center_vel[2]);
			double time_min = 0;
			double distance;
			
			if(vel_mod != 0)
				time_min = Math.max(0, - (center_pos[0] * center_vel[0] + center_pos[1] * center_vel[1] + center_pos[2] * center_vel[2]) / vel_mod);
			
			distance = Math.sqrt(Math.pow(center_pos[0] + time_min * center_vel[0], 2) + Math.pow(center_pos[1] + time_min * center_vel[1], 2) + Math.pow(center_pos[2] + time_min * center_vel[2], 2));
			
			// Print the solution.
			System.out.println("Case #" + (i + 1) + ": " + df.format(distance) + " " + df.format(time_min) + "\n");
			f_out.write("Case #" + (i + 1) + ": " + df.format(distance) + " " + df.format(time_min) + "\n");
			
		}

		f_in.close();
		f_out.close();
	
		System.out.println("END");
		
	}
}
