import java.util.*;

public class B {
  private static int[][] map;
  private static char[][] label;
  private static int H;
  private static int W;
  private static char l, newL;

  private static boolean inRange(int r, int c) {
    return r >= 0 && r < H && c >= 0 && c < W;
  }

  private static boolean flowsSouth(int r, int c) {
    return (map[r+1][c] < map[r][c]) &&
             (!inRange(r-1, c) || (map[r-1][c] > map[r+1][c])) &&
             (!inRange(r, c-1) || (map[r][c-1] > map[r+1][c])) &&
             (!inRange(r, c+1) || (map[r][c+1] > map[r+1][c]));
  }

  private static boolean flowsEast(int r, int c) {
    return (map[r][c+1] < map[r][c]) && //east
      (!inRange(r-1, c) || (map[r-1][c] > map[r][c+1])) && //north
      (!inRange(r+1, c) || (map[r+1][c] >= map[r][c+1])) && //south
      (!inRange(r, c-1) || (map[r][c-1] > map[r][c+1])); //west
  }

  private static boolean flowsWest(int r, int c) {
    return (map[r][c-1] < map[r][c]) && //west
      (!inRange(r-1, c) || (map[r-1][c] > map[r][c-1])) && //north
      (!inRange(r+1, c) || (map[r+1][c] >= map[r][c-1])) && //south
      (!inRange(r, c+1) || (map[r][c+1] >= map[r][c-1])); //east
  }

  private static boolean flowsNorth(int r, int c) {
    return (map[r-1][c] < map[r][c]) && //north
      (!inRange(r, c-1) || (map[r][c-1] >= map[r-1][c])) && //west
      (!inRange(r, c+1) || (map[r][c+1] >= map[r-1][c])) && //east
      (!inRange(r+1, c) || (map[r+1][c] >= map[r-1][c])); //south
  }

  private static void spread(int r, int c) {
    label[r][c] = l;
//System.err.print(l);
//System.err.println(" " + r + " " + c);
    if(inRange(r-1, c) && label[r-1][c] == 0 && flowsSouth(r-1, c)) {
      spread(r-1, c);
    }
    if(inRange(r, c-1) && label[r][c-1] == 0 && flowsEast(r, c-1)) {
      spread(r, c-1);
    }
    if(inRange(r, c+1) && label[r][c+1] == 0 && flowsWest(r, c+1)) {
      spread(r, c+1);
    }
    if(inRange(r+1, c) && label[r+1][c] == 0 && flowsNorth(r+1, c)) {
      spread(r+1, c);
    }
  }

  private static void relabel(int r, int c) {
    label[r][c] = newL;
    if(inRange(r-1, c) && label[r-1][c] == l)
      relabel(r-1, c);
    if(inRange(r+1, c) && label[r+1][c] == l)
      relabel(r+1, c);
    if(inRange(r, c-1) && label[r][c-1] == l)
      relabel(r, c-1);
    if(inRange(r, c+1) && label[r][c+1] == l)
      relabel(r, c+1);
  }

  private static boolean isSink(int r, int c) {
    return ((!inRange(r-1, c) || (map[r-1][c] >= map[r][c])) &&
            (!inRange(r, c-1) || (map[r][c-1] >= map[r][c])) &&
            (!inRange(r+1, c) || (map[r+1][c] >= map[r][c])) &&
            (!inRange(r, c+1) || (map[r][c+1] >= map[r][c]))
           );
  }

  public static void main(String[] args) {
    Scanner in = new Scanner(System.in);
    int times = in.nextInt();
    for(int i = 1; i <= times; ++i) {
      H = in.nextInt();
      W = in.nextInt();
      map = new int[H][W];
      label = new char[H][W];
      for(int j = 0; j < H; ++j) {
        for(int k = 0; k < W; ++k) {
          map[j][k] = in.nextInt();
          label[j][k] = 0;
        }
      }
      l = 'A';
      for(int j = 0; j < H; ++j) {
        for(int k = 0; k < W; ++k) {
          if(isSink(j, k)) {
//System.err.println("" + j + " " + k);
            spread(j, k);
            l++;
          }
        }
      }

      Set<Character> s = new TreeSet<Character>();
      newL = 'a';
      for(int j = 0; j < H; ++j) {
        for(int k = 0; k < W; ++k) {
          l = label[j][k];
          if(!s.contains(l)) {
            s.add(newL);
            relabel(j, k);
            newL++;
          }
        }
      }
      System.out.println("Case #" + i + ":");
      for(int j = 0; j < H; ++j) {
        for(int k = 0; k < W; ++k) {
          System.out.print(label[j][k]);
          if(k != W-1) System.out.print(" ");
        }
        System.out.println();
      }
    }
  }
}
