import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.util.Scanner;
import java.util.Vector;


public class WelcomeToCodeJam {		
	private int N;
	private Vector<Integer> results;

	public static final String SEQUENCE = "welcome to code jam";
	public static final int CUTOFF = 10000;
	
	public Vector<String> texts;
	
	public WelcomeToCodeJam(String fileName) {
		FileInputStream finStr = null;
		try {
			finStr = new FileInputStream(fileName);
		} catch (Exception e) {
			System.err.println("[WelcomeToCodeJam::Constructor("+fileName+")] Unable to open input file");
			e.printStackTrace();
			return;
		}

		readData(finStr);

		try {
			finStr.close();
		} catch (Exception e) {
			System.err.println("[WelcomeToCodeJam::Constructor("+fileName+")] Unable to close input file");
			e.printStackTrace();
			return;
		}

		regularizeData();
	}

	private void readData(InputStream inputStream) {
		Scanner consoleInput = new Scanner(inputStream);
		N = consoleInput.nextInt();
		consoleInput.nextLine();
		
		texts = new Vector<String>();
		for (int i=0; i<N; ++i) {
			texts.add(consoleInput.nextLine());
		}
		results = null;
	}

	private void regularizeData() {

	}


	private Integer crunchDataOneCase(String text, String sequence, int cutoff) {
		int resultMatrix[][] = new int[text.length()][];
		for (int i=0; i<text.length(); ++i) {
			resultMatrix[i] = new int[sequence.length()];
			for (int j=0; j<sequence.length(); ++j) {
				resultMatrix[i][j] = -1;
			}
		}
		
		for (int j=0;j<sequence.length()-1;++j) {
			resultMatrix[text.length()-1][j] = 0;
		}
		
		if (text.charAt(text.length()-1) == sequence.charAt(sequence.length()-1)) resultMatrix[text.length()-1][sequence.length()-1] = 1;
		else resultMatrix[text.length()-1][sequence.length()-1] = 0;
		
		for (int i=text.length()-2; i>=0;--i) {
			int addon = 0;
			if (text.charAt(i) == sequence.charAt(sequence.length()-1)) addon = 1;
			resultMatrix[i][sequence.length()-1] = resultMatrix[i+1][sequence.length()-1] + addon;
			resultMatrix[i][sequence.length()-1] = resultMatrix[i][sequence.length()-1] % cutoff;
		}
		
		for (int j=sequence.length()-2; j>=0; --j) {
			for (int i=text.length()-2; i>=0;--i) {
				int addon = 0;
				if (text.charAt(i) == sequence.charAt(j)) addon = resultMatrix[i+1][j+1];
				resultMatrix[i][j] = resultMatrix[i+1][j] + addon;
				resultMatrix[i][j] = resultMatrix[i][j] % cutoff;
			}
		}
		return new Integer(resultMatrix[0][0]);
	}

	public void crunchData() {
		results = new Vector<Integer>();
		for (int i=0; i<N; ++i) {
			results.add(crunchDataOneCase(texts.elementAt(i), SEQUENCE, CUTOFF));	
		}
	}

	public void writeResults(String fileName) {
		FileWriter fwriter = null;
		try {
			fwriter = new FileWriter(fileName);
		} catch (IOException e) {
			System.err.println("Unable to open output file");
			e.printStackTrace();
			return;
		}
		BufferedWriter fbwriter = new BufferedWriter(fwriter);

		try {
			for (int i=0; i<N; ++i) {
				fbwriter.write("Case #"+(i+1)+": "+String.format("%04d",results.elementAt(i)));
				fbwriter.newLine();
			}
		} catch (IOException e) {
			System.err.println("Unable to write to output file");
			e.printStackTrace();
			try {
				fbwriter.close();
				fwriter.close();
			} catch (IOException e2) {
				System.err.println("Unable to close output file");
				e2.printStackTrace();
			}
			return;
		}

		try {
			fbwriter.close();
			fwriter.close();
		} catch (IOException e) {
			System.err.println("Unable to close output file");
			e.printStackTrace();
		}        
	}

	public static void main(String[] args) {
		WelcomeToCodeJam mainObject = new WelcomeToCodeJam("C-large.in");
		mainObject.crunchData();
		mainObject.writeResults("C-large.out");
	}
}
