import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Scanner;


public class Watersheds {		
	private int T;
	private int maps[][][];
	private int results[][][];

	public Watersheds(String fileName) {
		FileInputStream finStr = null;
		try {
			finStr = new FileInputStream(fileName);
		} catch (Exception e) {
			System.err.println("[Watersheds::Constructor("+fileName+")] Unable to open input file");
			e.printStackTrace();
			return;
		}

		readData(finStr);

		try {
			finStr.close();
		} catch (Exception e) {
			System.err.println("[Watersheds::Constructor("+fileName+")] Unable to close input file");
			e.printStackTrace();
			return;
		}

		regularizeData();
	}

	private void readData(InputStream inputStream) {
		Scanner consoleInput = new Scanner(inputStream);
		T = consoleInput.nextInt();
		consoleInput.nextLine();
		
		maps = new int[T][][];
		results = new int[T][][];
		for (int i=0; i<T; ++i) {
			int H = consoleInput.nextInt();
			int W = consoleInput.nextInt();
			consoleInput.nextLine();
			maps[i] = new int[H][];
			results[i] = new int[H][];
			int p = 0;
			for (int j=0;j<H;++j) {
				maps[i][j] = new int[W];
				results[i][j] = new int[W];
				for (int k=0;k<W;++k) {
					maps[i][j][k] = consoleInput.nextInt();
					results[i][j][k] = p++;
				}
				if (i!=T-1 || j!=H-1) consoleInput.nextLine();
			}
		}
	}

	private void regularizeData() {

	}


	private void crunchDataOneCase(int map[][], int result[][]) {
		int n = map.length;
		int m = map[0].length;
		boolean changePresent = true;
		while (changePresent) {
			changePresent = false;
			for (int i=0; i<n; ++i) {
				for (int j=0; j<m; ++j) {
					int color = -1;
					int alt = map[i][j];
					if (i-1 >= 0 && map[i-1][j] < alt) {
						alt = map[i-1][j];
						color = result[i-1][j];
					}
					if (j-1 >= 0 && map[i][j-1] < alt) {
						alt = map[i][j-1];
						color = result[i][j-1];
					}
					if (j+1 < m && map[i][j+1] < alt) {
						alt = map[i][j+1];
						color = result[i][j+1];
					}
					if (i+1 < n && map[i+1][j] < alt) {
						alt = map[i+1][j];
						color = result[i+1][j];
					}
					if (color != -1 && color != result[i][j]) {
						changePresent = true;
						for (int i1=0;i1<n;++i1) {
							for (int j1=0;j1<m;++j1) {
								if (result[i1][j1] == result[i][j]) {
									result[i1][j1] = color;
								}
							}
						}
					}
				}
			}
		}
		HashMap<Integer,Integer> aux = new HashMap<Integer, Integer>();
		int p = 0;
		for (int i=0;i<n;++i) {
			for (int j=0;j<m;++j) {
				if (!aux.containsKey(result[i][j]))
					aux.put(result[i][j], p++); 
			}
		}
		
		for (int i=0;i<n;++i) {
			for (int j=0;j<m;++j) {
				result[i][j] = aux.get(result[i][j]); 
			}
		}
	}

	public void crunchData() {
		for (int i=0; i<T; ++i) {
			crunchDataOneCase(maps[i],results[i]);	
		}
	}

	public void writeResults(String fileName) {
		FileWriter fwriter = null;
		try {
			fwriter = new FileWriter(fileName);
		} catch (IOException e) {
			System.err.println("Unable to open output file");
			e.printStackTrace();
			return;
		}
		BufferedWriter fbwriter = new BufferedWriter(fwriter);

		try {
			for (int i=0; i<T; ++i) {
				fbwriter.write("Case #"+(i+1)+": ");
				fbwriter.newLine();
				for (int j=0; j<results[i].length; ++j) {
					fbwriter.write(('a'+results[i][j][0]));
					for (int k=1; k<results[i][j].length; ++k) {
						fbwriter.write(" ");
						fbwriter.write(('a'+results[i][j][k]));
					}
					fbwriter.newLine();
				}
			}
		} catch (IOException e) {
			System.err.println("Unable to write to output file");
			e.printStackTrace();
			try {
				fbwriter.close();
				fwriter.close();
			} catch (IOException e2) {
				System.err.println("Unable to close output file");
				e2.printStackTrace();
			}
			return;
		}

		try {
			fbwriter.close();
			fwriter.close();
		} catch (IOException e) {
			System.err.println("Unable to close output file");
			e.printStackTrace();
		}        
	}

	public static void main(String[] args) {
		Watersheds mainObject = new Watersheds("B-small-attempt0.in");
		mainObject.crunchData();
		mainObject.writeResults("B-small-attempt0.out");
	}
}
