import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.util.Scanner;


public class GCJ2009_R1B_P2_MainClass {
	
	private static final String CLASSNAME = "GCJ2009_R1B_P2_MainClass";
	private int T;
	private byte[][] numbers;
	private byte[][] results;
	
	public GCJ2009_R1B_P2_MainClass(String fileName) {
		FileInputStream finStr = null;
		try {
			finStr = new FileInputStream(fileName);
		} catch (Exception e) {
			System.err.println("["+CLASSNAME+"::Constructor("+fileName+")] Unable to open input file");
			e.printStackTrace();
			return;
		}
		
		readData(finStr);
		
		try {
			finStr.close();
		} catch (Exception e) {
			System.err.println("["+CLASSNAME+"::Constructor("+fileName+")] Unable to close input file");
			e.printStackTrace();
			return;
		}
		
		regularizeData();
	}
	
	private void readData(InputStream inputStream) {
		Scanner consoleInput = new Scanner(inputStream);
		T = consoleInput.nextInt();
		consoleInput.nextLine();
		
		numbers = new byte[T][];
		for (int i=0;i<T;++i) {
			String line = consoleInput.nextLine();
			numbers[i] = new byte[line.length()];
			for (int j=0;j<line.length();++j) {
				numbers[i][j] = Byte.parseByte(""+line.charAt(j));
			}
		}
		results = null;
	}
	
	private void regularizeData() {
		
	}
	
	
	private void sortAscending(byte[] number, int li, int lf) {
		assert(li>=0 && lf<number.length && lf >=li);
		for (int i=li;i<lf;++i) {
			for (int j=i+1;j<=lf;++j) {
				if (number[i] > number[j]) {
					byte aux = number[i];
					number[i] = number[j];
					number[j] = aux;
				}
			}
		}
	}
	
	private byte[] computeOneCase(byte[] number) {
		int n = number.length;
		byte[] result = new byte[n+1];
		for (int i=0;i<n;++i) {
			result[i+1] = number[i];
		}
		int pos = -1;
		for (int i=2;i<n+1;++i) {
			if (result[i] > result[i-1]) {
				pos = i-1;
			}
		}
		if (pos == -1) {
			sortAscending(result,1,n);
			int idx = -1;
			for (int i=1;i<n+1;++i) {
				if (result[i] != 0) {
					idx = i;
					break;
				}
			}
			result[0] = result[idx];
			result[idx] = 0;
			return result;
		} else {
			int min_i = pos+1;
			for (int i=pos+2;i<n+1;++i) {
				if (result[i] > result[pos] && result[i] < result[min_i]) min_i = i;
			}
			byte aux = result[pos];
			result[pos] = result[min_i];
			result[min_i] = aux;
			
			sortAscending(result,pos+1,n);
			byte[] newresult = new byte[n];
			for (int i=0;i<n;++i) {
				newresult[i] = result[i+1];
			}
			return newresult;
		}
	}
	
	public void compute() {
		results = new byte[T][];
		for (int i=0; i<T; ++i) {
			results[i]= computeOneCase(numbers[i]);	
		}
	}
	
	public void writeResults(String fileName) {
		FileWriter fwriter = null;
		try {
			fwriter = new FileWriter(fileName);
		} catch (IOException e) {
			System.err.println("["+CLASSNAME+"::writeResults("+fileName+"] Unable to open output file");
			e.printStackTrace();
			return;
		}
        BufferedWriter fbwriter = new BufferedWriter(fwriter);
        
        try {
        	for (int i=0; i<T; ++i) {
            	fbwriter.write("Case #"+(i+1)+": ");
            	for (int j=0; j<results[i].length; ++j) {
            		fbwriter.write(""+results[i][j]);
            	}
            	fbwriter.newLine();
            }
        } catch (IOException e) {
			System.err.println("["+CLASSNAME+"::writeResults("+fileName+"] Unable to write to output file");
			e.printStackTrace();
			try {
				fbwriter.close();
				fwriter.close();
			} catch (IOException e2) {
				System.err.println("["+CLASSNAME+"::writeResults("+fileName+"] Unable to close output file");
				e2.printStackTrace();
			}
			return;
		}
        
        try {
			fbwriter.close();
			fwriter.close();
		} catch (IOException e) {
			System.err.println("["+CLASSNAME+"::writeResults("+fileName+"] Unable to close output file");
			e.printStackTrace();
		}        
	}
	
	public static void main(String[] args) {
		if (args.length == 2) {
			GCJ2009_R1B_P2_MainClass mainObject = new GCJ2009_R1B_P2_MainClass(args[0]);
			mainObject.compute();
			mainObject.writeResults(args[1]);
		} else {
			System.err.println("["+CLASSNAME+"::main] Not enough arguments (please run with arguments: _inputfile _outputfile)");
		}
	}
}
