import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.util.Scanner;
import java.util.Vector;


public class AlienLanguage {
	
	private int N;
	private int D;
	private int L;
	private Vector<String> words;
	private Vector<Vector<Vector<Character>>> transmissions;
	private Vector<Vector<Integer>> transmissionsKey;
	private Vector<Vector<Integer>> originalIndex;
	private Vector<Integer> results;
	
	public AlienLanguage(String fileName) {
		FileInputStream finStr = null;
		try {
			finStr = new FileInputStream(fileName);
		} catch (Exception e) {
			System.err.println("[AlienLanguage::Constructor("+fileName+")] Unable to open input file");
			e.printStackTrace();
			return;
		}
		
		readData(finStr);
		
		try {
			finStr.close();
		} catch (Exception e) {
			System.err.println("[AlienLanguage::Constructor("+fileName+")] Unable to close input file");
			e.printStackTrace();
			return;
		}
		
		regularizeData();
	}
	
	private void readData(InputStream inputStream) {
		Scanner consoleInput = new Scanner(inputStream);
		L = consoleInput.nextInt();
		D = consoleInput.nextInt();
		N = consoleInput.nextInt();
		consoleInput.nextLine();
		
		words = new Vector<String>();
		for (int i=0;i<D;++i) {
			words.add(consoleInput.nextLine());
		}
		
		transmissions = new Vector<Vector<Vector<Character>>>();
		transmissionsKey = new Vector<Vector<Integer>>();
		originalIndex = new Vector<Vector<Integer>>();
		for (int i=0;i<N;++i) {
			String transmission = consoleInput.nextLine();
			transmissions.add(new Vector<Vector<Character>>());
			transmissionsKey.add(new Vector<Integer>());
			originalIndex.add(new Vector<Integer>());
			int stringIndex = 0;
			for (int j=0;j<L;++j) {
				int counter = 0;
				transmissions.elementAt(i).add(new Vector<Character>());
				if (transmission.charAt(stringIndex) != '(') {
					counter = 1;
					transmissions.elementAt(i).elementAt(j).add(transmission.charAt(stringIndex));
					++stringIndex;
				} else {
					++stringIndex;
					while (transmission.charAt(stringIndex) != ')') {
						++counter;
						transmissions.elementAt(i).elementAt(j).add(transmission.charAt(stringIndex));
						++stringIndex;
					}
					++stringIndex;
				}
				transmissionsKey.elementAt(i).add(new Integer(counter));
				originalIndex.elementAt(i).add(j);
			}
		}
		
		results = null;
	}
	
	private void regularizeData() {
		for (int i=0; i<N; ++i) {
			for (int j=0; j<transmissionsKey.elementAt(i).size()-1; ++j) {
				for (int k=j+1; k<transmissionsKey.elementAt(i).size(); ++k) {
					Integer aux1,aux2;
					Vector<Character> aux3,aux4;
					if (transmissionsKey.elementAt(i).elementAt(j) > transmissionsKey.elementAt(i).elementAt(k)) {
						aux1 = transmissionsKey.elementAt(i).elementAt(j);
						aux2 = transmissionsKey.elementAt(i).elementAt(k);
						transmissionsKey.elementAt(i).remove(j);
						transmissionsKey.elementAt(i).add(j,aux2);
						transmissionsKey.elementAt(i).remove(k);
						transmissionsKey.elementAt(i).add(k,aux1);
						
						aux1 = originalIndex.elementAt(i).elementAt(j);
						aux2 = originalIndex.elementAt(i).elementAt(k);
						originalIndex.elementAt(i).remove(j);
						originalIndex.elementAt(i).add(j,aux2);
						originalIndex.elementAt(i).remove(k);
						originalIndex.elementAt(i).add(k,aux1);
						
						aux3 = transmissions.elementAt(i).elementAt(j);
						aux4 = transmissions.elementAt(i).elementAt(k);
						transmissions.elementAt(i).remove(j);
						transmissions.elementAt(i).add(j,aux4);
						transmissions.elementAt(i).remove(k);
						transmissions.elementAt(i).add(k,aux3);
					}
				}
			}
		}
	}
	
	
	private Integer crunchDataOneCase(Vector<Vector<Character>> sequence, Vector<Integer> sequenceKey, Vector<Integer> originalIndex) {
		Vector<String> currentMatch = new Vector<String>(words);
		for (int i=0; i<sequence.size(); ++i) {
			Vector<Character> currentSymbol = sequence.elementAt(i);
			for (int j=0; j<currentMatch.size();) {
				if (currentSymbol.indexOf(currentMatch.elementAt(j).charAt(originalIndex.elementAt(i))) < 0) {
					currentMatch.remove(j);
				} else {
					++j;
				}
			}
			if (currentMatch.size() == 0) break;
		}
		
		return new Integer(currentMatch.size());
	}
	
	public void crunchData() {
		results = new Vector<Integer>();
		for (int i=0; i<N; ++i) {
			results.add(crunchDataOneCase(transmissions.elementAt(i), transmissionsKey.elementAt(i), originalIndex.elementAt(i)));	
		}
	}
	
	public void writeResults(String fileName) {
		FileWriter fwriter = null;
		try {
			fwriter = new FileWriter(fileName);
		} catch (IOException e) {
			System.err.println("Unable to open output file");
			e.printStackTrace();
			return;
		}
        BufferedWriter fbwriter = new BufferedWriter(fwriter);
        
        try {
        	for (int i=0; i<N; ++i) {
            	fbwriter.write("Case #"+(i+1)+": "+results.elementAt(i));
            	fbwriter.newLine();
            }
        } catch (IOException e) {
			System.err.println("Unable to write to output file");
			e.printStackTrace();
			try {
				fbwriter.close();
				fwriter.close();
			} catch (IOException e2) {
				System.err.println("Unable to close output file");
				e2.printStackTrace();
			}
			return;
		}
        
        try {
			fbwriter.close();
			fwriter.close();
		} catch (IOException e) {
			System.err.println("Unable to close output file");
			e.printStackTrace();
		}        
	}
	
	public static void main(String[] args) {
		AlienLanguage mainObject = new AlienLanguage("A-small-attempt0.in");
		mainObject.crunchData();
		mainObject.writeResults("A-small-attempt0.out");
	}
}
