import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.util.Scanner;

class Query {
	public String name;
	public String[] features;
	
	Query(String _name, String[] _features) {
		name = _name;
		features = _features;
	}
}


class Node {
	public String name;
	public double value;
	public Node left, right;
	
	public Node (double _value) {
		value = _value;
		left = null;
		right = null;
		name = null;
	}
	
	public Node (double _value, String _name, Node _left, Node _right) {
		value = _value;
		name = _name;
		left = _left;
		right = _right;
	}
	
	public static Node parseStringToNode(String input) {
		int i=0;
		double weight;
		weight = 0;
		
		while (input.charAt(i) == ' ')                 ++i;
		assert(input.charAt(i) == '(');
		                                               ++i;
		while (input.charAt(i) == ' ')                 ++i;
		assert(Character.isDigit(input.charAt(i)));
		                                               int j = i;
		while (Character.isDigit(input.charAt(i)))     ++i;
		if (input.charAt(i) == '.') {                  
			                                           ++i;
			assert(Character.isDigit(input.charAt(i)));
			while (Character.isDigit(input.charAt(i))) ++i;
		}
		
		weight = Double.parseDouble(input.substring(j,i));
		
		assert(input.charAt(i) == ' ' || input.charAt(i) == ')');
		while (input.charAt(i) == ' ')                  ++i;
		assert(input.charAt(i) == ')' || (Character.isLetter(input.charAt(i)) && Character.isLowerCase(input.charAt(i))));
		
		if (input.charAt(i) == ')') {
			return new Node(weight);
		} else {
			j = i;
			while (Character.isLetter(input.charAt(i)) && Character.isLowerCase(input.charAt(i))) ++i;
			String feature = input.substring(j,i);
			assert(input.charAt(i) == ' ' || input.charAt(i) == '(');
			while (input.charAt(i) == ' ')                  ++i;
			assert(input.charAt(i) == '(');
			j = i;
			int count = 1;
			++i;
			while (count !=0) {
				if (input.charAt(i) == '(') ++count;
				else if (input.charAt(i) == ')') --count;
				++i;
			}
			Node left = Node.parseStringToNode(input.substring(j,i));
			assert(input.charAt(i) == ' ' || input.charAt(i) == '(');
			while (input.charAt(i) == ' ')                  ++i;
			assert(input.charAt(i) == '(');
			j = i;
			count = 1;
			++i;
			while (count !=0) {
				if (input.charAt(i) == '(') ++count;
				else if (input.charAt(i) == ')') --count;
				++i;
			}
			Node right = Node.parseStringToNode(input.substring(j,i));
			assert(input.charAt(i) == ' ' || input.charAt(i) == ')');
			while (input.charAt(i) == ' ')                  ++i;
			assert(input.charAt(i) == ')');
			
			return new Node(weight, feature, left, right);
		}
	}
}

public class GCJ2009_R1B_P1_MainClass {
	
	private static final String CLASSNAME = "GCJ2009_R1B_P1_MainClass";
	private int T;
	private Node[] roots;
	private Query[][] queries;
	
	private double[][] results;
	
	public GCJ2009_R1B_P1_MainClass(String fileName) {
		FileInputStream finStr = null;
		try {
			finStr = new FileInputStream(fileName);
		} catch (Exception e) {
			System.err.println("["+CLASSNAME+"::Constructor("+fileName+")] Unable to open input file");
			e.printStackTrace();
			return;
		}
		
		readData(finStr);
		
		try {
			finStr.close();
		} catch (Exception e) {
			System.err.println("["+CLASSNAME+"::Constructor("+fileName+")] Unable to close input file");
			e.printStackTrace();
			return;
		}
		
		regularizeData();
	}
	
	private void readData(InputStream inputStream) {
		Scanner consoleInput = new Scanner(inputStream);
		T = consoleInput.nextInt();
		consoleInput.nextLine();
		
		roots = new Node[T];
		queries = new Query[T][];
		for (int i=0;i<T;++i) {
			int L = consoleInput.nextInt();
			consoleInput.nextLine();
			StringBuilder sb = new StringBuilder();
			for (int j=0;j<L;++j) {
				sb.append(consoleInput.nextLine());
			}
			roots[i] = Node.parseStringToNode(sb.toString());
			
			int A;
			A = consoleInput.nextInt();
			consoleInput.nextLine();
			
			queries[i] = new Query[A];
			for (int j=0; j<A; ++j) {
				String line = consoleInput.nextLine();
				int k1 = 0;
				int k2 = line.indexOf(' ', k1);
				String name = line.substring(k1,k2);
				k1 = k2+1; k2 = line.indexOf(' ', k1);
				int n;
				if (k2 == -1) {
					n = Integer.parseInt(line.substring(k1));
					assert(n == 0);
				} else {
					n = Integer.parseInt(line.substring(k1,k2));
				}
				String[] features = new String[n];
				for (int l=0;l<n-1;++l) {
					k1 = k2+1; k2 = line.indexOf(' ', k1);
					features[l] = line.substring(k1,k2);
				}
				if (n>0) features[n-1] = line.substring(k2+1);
				queries[i][j] = new Query(name,features);
			}
			
		}
		
		results = null;
	}
	
	private void regularizeData() {
		for (int i=0; i<queries.length; ++i) {
			for (int j=0; j<queries[i].length; ++j) {
				int n = queries[i][j].features.length;
				for (int i1 = 0; i1<n-1;++i1) {
					for (int j1 = i1+1; j1<n;++j1) {
						if (queries[i][j].features[i1].compareTo(queries[i][j].features[j1]) > 0) {
							String aux = queries[i][j].features[i1];
							queries[i][j].features[i1] = queries[i][j].features[j1];
							queries[i][j].features[j1] = aux;
						}
					}
				}
			}
		}
	}
	
	private int searchQuery(Query q, String feature) {
		return binarySearch(q.features,feature,0,q.features.length-1);
	}
	
	private int binarySearch(String[] list, String element, int li, int lf) {
		if (lf < li) return -1;
		int m = (li + lf) / 2;
		int compresult = list[m].compareTo(element); 
		if (compresult == 0) return m;
		else if (compresult > 0) return binarySearch(list,element,li,m-1);
		else return binarySearch(list,element,m+1,lf);
	}
	
	private static final double PRECISION = 0.0000001;
	private double computeOneQuery(Node root, Query q) {
		double p = 1;
		Node iterator = root;
		while (iterator != null) {
			p *= iterator.value;
			if (iterator.name != null) {
				int i = searchQuery(q,iterator.name);
				if (i == -1) iterator = iterator.right;
				else iterator = iterator.left;
			} else {
				iterator = null;
			}
			if (p < PRECISION) return 0;
		}
		return p;
	}
	
	private double[] computeOneCase(Node root, Query[] q) {
		int n = q.length;
		double[] result = new double[n];
		for (int i=0;i<n;++i) {
			result[i] = computeOneQuery(root,q[i]);
		}
		return result;
	}
	
	public void compute() {
		results = new double[T][];
		for (int i=0; i<T; ++i) {
			results[i]= computeOneCase(roots[i],queries[i]);	
		}
	}
	
	public void writeResults(String fileName) {
		FileWriter fwriter = null;
		try {
			fwriter = new FileWriter(fileName);
		} catch (IOException e) {
			System.err.println("["+CLASSNAME+"::writeResults("+fileName+"] Unable to open output file");
			e.printStackTrace();
			return;
		}
        BufferedWriter fbwriter = new BufferedWriter(fwriter);
        
        try {
        	for (int i=0; i<T; ++i) {
            	fbwriter.write("Case #"+(i+1)+": ");
            	fbwriter.newLine();
            	for (int j=0;j<results[i].length;++j) {
            		fbwriter.write(""+String.format("%.7f",results[i][j]));
                	fbwriter.newLine();
            	}
            }
        } catch (IOException e) {
			System.err.println("["+CLASSNAME+"::writeResults("+fileName+"] Unable to write to output file");
			e.printStackTrace();
			try {
				fbwriter.close();
				fwriter.close();
			} catch (IOException e2) {
				System.err.println("["+CLASSNAME+"::writeResults("+fileName+"] Unable to close output file");
				e2.printStackTrace();
			}
			return;
		}
        
        try {
			fbwriter.close();
			fwriter.close();
		} catch (IOException e) {
			System.err.println("["+CLASSNAME+"::writeResults("+fileName+"] Unable to close output file");
			e.printStackTrace();
		}        
	}
	
	public static void main(String[] args) {
		if (args.length == 2) {
			GCJ2009_R1B_P1_MainClass mainObject = new GCJ2009_R1B_P1_MainClass(args[0]);
			mainObject.compute();
			mainObject.writeResults(args[1]);
		} else {
			System.err.println("["+CLASSNAME+"::main] Not enough arguments (please run with arguments: _inputfile _outputfile)");
		}
	}
}
