/*
 * bohlampijar@gmail.com
 * Question 1: Saving the Universe
 *
 */

import java.util.*;

public class SaveUniverse {
  
  // Class Data Members:
  static SearchEngines [] names; // array of search engines
  static int s;                  // number of search engines
  static int q;                  // number of queries
  static int changeLog;          // number of search engine switches
  
  
  /*
   * Main Class of the Programme
   * Pre-condition  : None
   * Post-condition : Result Printed
   * 
   */
  public static void main (String[]args) {
    
    // Scanner Class for reading input
    Scanner sc = new Scanner (System.in);
    // Number of test cases
    int n = sc.nextInt();
    
    // Initialize a temporary String for reading search engines' names and queries
    String name = "";
    
    //Loop for each test cases
    for (int i=0; i<n; i++) {
      
      changeLog = 0; // Initialize the changeLog to 0 for each use
      s = sc.nextInt(); // Number of search engines
      names = new SearchEngines[s]; // Initialize the array for each use
      sc.nextLine(); // Clear the line end for input
      
      // Loop to get all the search engines' names
      for (int j=0; j<s; j++) {
        
        name = sc.nextLine(); // Get the input for search engine name
        names[j] = new SearchEngines (name); // Initialize the SearchEngines class with the required name
        
      } // End of For Loop
      
      // Number of queries
      q = sc.nextInt();
      sc.nextLine(); // Clear the line end for input
      
      // Loop to get all the queries
      for (int k=0; k<q; k++) {
        
        name = sc.nextLine(); // Get the input for queries
        setSearchEngineSearched (name, names); // Set the SearchEngines queried to true
        
        // For each query, check whether all have been queried
        if (check(names, 0, s-1)) { // If all have been queried, reset the query except the last one
          reset (name, names);      // i.e. the last query is the search engine used for the previous queries
          changeLog++;              // Increment the number of switches made
        }
      } // End of For Loop
      
      // Print the result for each case
      System.out.println ("Case #" + (i+1) + ": " + changeLog);
      
    } // End of For Loop
    
  } // End of Main Method
  
  /*
   * Method to reset all the SearchEngines instances to have their searched data member be false
   * Pre-condition  : All the SearchEngines have their searched data member as true,
   *                  inputs are correct, and no null pointer
   * Post-condition : All the SearchEngines have their searched data member as false,
   *                  escept for the last queried SearchEngines
   * 
   */
  public static void reset (String name, SearchEngines[] check) {
    
    String tempName = ""; // Temporary storage of name for the SearchEngines exception
                          // i.e. the last SearchEngines queried
    
    // Loop to make each SearchEngines to reset to false except for the exception
    for (int i=0; i<check.length; i++) {
      
      tempName = check[i].getName(); // Getting the name of the current SearchEngines
      
      if (!(tempName.equals(name))) { // Unless the current is the last queried SearchEngines
        // Set its searched data member to false
        check[i].setSearched(false);
        
      }
    } // End of For Loop
    
  } // End of Reset Method
  
  /*
   * Method to set the required SearchEngines to have its searched data member be true
   * Pre-condition  : Inputs are correct, no null pointer
   * Post-condition : The required SearchEngines has its searched data member as true
   * 
   */
  public static void setSearchEngineSearched (String name, SearchEngines[] check) {
    
    String tempName = ""; // Temporary storage of name to check for the required SearchEngine
    
    // Loop to find the required SearchEngines and set its searched data member to true
    for (int i=0; i<check.length; i++) {
      
      tempName = check[i].getName(); // Getting the name of the current SearchEngines
      
      if (tempName.equals(name)) { // If the current is the required SearchEngines
        // Set its searched data member to true
        check[i].setSearched(true);
        return;
        
      }
    } // End of For Loop
    
  } // End of setSearchEngineSearched Method
  
  /*
   * Recursive method to check the SearchEngines Array if all has been searched already
   * Pre-condition  : Inputs are correct, no null pointer
   * Post-condition : Return true if all is searched, false otherwise
   * 
   */
  public static boolean check (SearchEngines[] toCheck, int current, int max)  {
    
    // Recursive Case
    if (toCheck[current].isSearched()) {
      // If have not reached the end of the Array
      if (current != max) {
        
        return (true && check(toCheck, current+1, max));
        
      }
      // If the end of the Array is reached
      else {
        
        return true;
        
      }
    }
    
    // Base Case, if anyone of the SearchEngine not searched yet, then it's false
    return false;    
    
  }
  
}

/*
 * SearchEngines Class
 */
class SearchEngines {
  
  // Class Data Members:
  private String name = "";
  private boolean searched = false;
  
  /*
   * Constructor
   * Pre-condition  : None
   * Post-condition : SearchEngine with the required name is created
   * 
   */
  public SearchEngines (String theName) {
    name = theName;
  } // End of Public Constructor
  
  /*
   * Method to enquire whether this SearchEngines have been searched
   * Pre-condition  : SearchEngines is initialized
   * Post-condition : Return true if searched, false otherwise
   * 
   */
  public boolean isSearched () {
    return searched;
  } // End of isSearched Method
  
  /*
   * Method to set the searched data member
   * Pre-condition  : SearchEngines is initialized
   * Post-condition : Set the searched to be newSearched
   * 
   */
  public void setSearched (boolean newSearched) {
    searched = newSearched;
  } // End of setSearched Method
  
  /*
   * Method to get the name of the SearchEngines
   * Pre-condition  : SearchEngines is initialized
   * Post-condition : Return the name of the SearchEngines
   * 
   */
  public String getName () {
    return name;
  } // End of getName method
  
}