import java.util.ArrayList;
import java.util.Collections;
import java.util.List;


public class Game {
	List<Integer> currentKeys;
	List<Chest> chests;
	
	public Game() {
		this(new ArrayList<Integer>(), new ArrayList<Chest>());
	}
	
	public Game(List<Integer> startingKeys, List<Chest> chests) {
		setKeys(startingKeys);
		setChests(chests);
	}

	public void setKeys(List<Integer> keys) {
		currentKeys = new ArrayList<Integer>();
		for (Integer i : keys) currentKeys.add(i);
	}
	
	public void setChests(List<Chest> allChests) {
		chests = new ArrayList<Chest>();
		for (Chest c : allChests) chests.add(c);
	}
	
	/**
	 * Below method returns a sequence of chest IDs corresponding to the order
	 * in which to visit them in order for all of them to be visited.
	 * Several solutions might be possible.
	 * In this case, the returned solution corresponds to the smallest one in
	 * lexicographical order.
	 * For example, if 2,1,3,4 and 2,3,1,4 are both solutions, the first one is returned.
	 * @return
	 */
	public void solve(List<Chest> path) {
		List<Chest> candidates = new ArrayList<Chest>();
		List<Chest> visited = new ArrayList<Chest>();
		
		// Build initial list of candidates, and sort them by ID
		for (Chest c : chests) {
			for (Integer key : currentKeys) {
				if (c.openedBy(key) && !candidates.contains(c)) {
					candidates.add(c);
				}
			}
		}
		
		Collections.sort(candidates, new Chest.ChestComparatorByID());
		
		findPath(currentKeys, candidates, 0, visited, path);
	}
	
	public void findPath(List<Integer> keys, List<Chest> candidates, int nextChest, List<Chest> visited, List<Chest> path) {
		if (nextChest >= candidates.size()) return;
		
		Chest nextCandidate = candidates.get(nextChest);
		Integer keyToOpen = nextCandidate.getOpeningKey();
		
		List<Integer> keysInsideChoseChest = nextCandidate.getKeys();
		List<Integer> newListOfKeys = new ArrayList<Integer>();
		newListOfKeys.addAll(keys);
		newListOfKeys.addAll(keysInsideChoseChest);
		newListOfKeys.remove(keyToOpen);
		
		List<Chest> newVisited = new ArrayList<Chest>();
		newVisited.addAll(visited);
		newVisited.add(nextCandidate);
		
		List<Chest> newPath = new ArrayList<Chest>();
		newPath.addAll(path);
		newPath.add(nextCandidate);
		
		List<Chest> newCandidates = getCandidates(newListOfKeys, newVisited);
		
		Collections.sort(newCandidates, new Chest.ChestComparatorByID());
		
		if (newCandidates.isEmpty()) {
			if (newPath.containsAll(chests)) {
				path.add(nextCandidate);
				return;
			} else {
				findPath(keys, candidates, nextChest+1, visited, path);
			}
		} else {
			keys = newListOfKeys;
			candidates = newCandidates;
			nextChest = 0;
			visited.add(nextCandidate);
			path.add(nextCandidate);
			findPath(keys, candidates, nextChest, visited, path);
		}
	}
	
	public List<Chest> getCandidates(List<Integer> keys, List<Chest> visited) {
		List<Chest> candidates = new ArrayList<Chest>();
		
		for (Chest c : chests) {
			for (Integer key : keys) {
				if (c.openedBy(key) && !visited.contains(c) && !candidates.contains(c)) candidates.add(c);
			}
		}
		
		return candidates;
	}
}
