package net.bo.util;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.StringReader;
import java.io.StringWriter;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Arrays;

public abstract class Parent {
	protected static final String folder = "D:\\Utilisateurs\\a160420\\Documents\\contest\\";
	protected static final Charset UFT8 = Charset.forName("UTF-8");
	
	boolean debug = getDebug();
	boolean debugRead = debug;
	
	private BufferedReader read;
	private BufferedWriter write;
	
	protected abstract boolean getDebug();
	
	protected abstract String getFilename();

	protected abstract String executeOne() throws Exception;

	protected abstract String getTestCase();
	
	protected abstract String getTestCaseResult();
	
	StringWriter myResponse;
	public Parent() throws Exception {
		if(getFilename() == null) {
			read =  new BufferedReader(new StringReader(getTestCase()));
			
			myResponse = new StringWriter();
			write = new BufferedWriter(myResponse);
		}
		else {
			Path inPath = Paths.get(folder, getFilename());
			read = new BufferedReader(new InputStreamReader( new FileInputStream(inPath.toFile()), UFT8));
			
			Path outPath = Paths.get(folder, getFilename() + ".out");
			Files.deleteIfExists(outPath);
			write = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(outPath.toFile())));
		}
	}
	
	protected void exe() throws Exception {
		int testCount = init();
		
		for(int test=1; test<=testCount; test++) {
			if(debug){
				System.out.println("------------------------------------------------------------");
				System.out.println("TEST " + test);
			}
			String one = executeOne();
			if(debug){
				System.out.println("Case #" + test + ": "+ one);
			}
			write.write("Case #" + test + ": "+ one);
			write.newLine();
			
			if(debug){
				System.out.println("------------------------------------------------------------");
			}
		}
		write.flush();
		write.close();
		read.close();
		
		if(myResponse != null) {
			if(myResponse.toString().trim().equals(getTestCaseResult())) {
				System.err.println("TEST OK");
			}
			else {
				System.err.println("TEST NOT OK!!!!!!!!!");
			}
		}
	}
	
	protected int init() throws Exception {
		return readInt("#TEST");
	}
	
	
	
	
	//--------------------------------------------------------------------------------------------------------------------
	//
	//													READERS
	//
	//--------------------------------------------------------------------------------------------------------------------
	
	protected String readString(String... name) throws Exception {
		String s = read.readLine();
		if(debugRead){
			if(name != null && name.length>0) {
				System.out.print(name[0] + " ");
			}
			System.out.println(s);
		}
		return s;
	}
	
	protected int readInt(String... name) throws Exception {
		int i = Integer.parseInt(read.readLine());
		if(debugRead){
			if(name != null && name.length>0) {
				System.out.print(name[0] + " ");
			}
			System.out.println(i);
		}
		return i;
	}
	
	protected float readFloat(String... name) throws Exception {
		float f = Float.parseFloat(read.readLine());
		if(debugRead){
			if(name != null && name.length>0) {
				System.out.print(name[0] + " ");
			}
			System.out.println(f);
		}
		return f;
	}
	
	protected String[] readStrings(String... name) throws Exception {
		String[] strings = read.readLine().split(" ");
		if(debugRead){
			if(name != null && name.length>0) {
				System.out.print(name[0] + " ");
			}
			System.out.println(Arrays.toString(strings));
		}
		return strings;
	}
	
	protected int[] readInts(String... name) throws Exception {
		String[] strings = read.readLine().split(" ");
		int[] ints = new int[strings.length];
		if(debugRead){
			if(name != null && name.length>0) {
				System.out.print(name[0] + " ");
			}
			System.out.println(Arrays.toString(strings));
		}
		for (int i=0; i<strings.length; i++) {
			ints[i] = Integer.parseInt(strings[i]);
		}
		return ints;
	}
	
	protected float[] readFloats(String... name) throws Exception {
		String[] strings = read.readLine().split(" ");
		float[] floats = new float[strings.length];
		if(debugRead){
			if(name != null && name.length>0) {
				System.out.print(name[0] + " ");
			}
			System.out.println(Arrays.toString(strings));
		}
		for (int i=0; i<strings.length; i++) {
			floats[i] = Float.parseFloat(strings[i]);
		}
		return floats;
	}
}
