package gcj;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.InputStreamReader;
import java.io.StringReader;

public class Rpi {
    public static void main(String[] args) throws Exception {
	BufferedReader br = new BufferedReader(new InputStreamReader(
		new FileInputStream(args[0])));

	String response = new Rpi().solve(br);

	FileWriter fileWriter = new FileWriter(args[0]
		+ (System.currentTimeMillis() % 100000) + ".out");
	fileWriter.write(response);
	fileWriter.close();
    }

    public String solve(String string) throws Exception {
	return solve(new BufferedReader(new StringReader(string)));
    }

    private String solve(BufferedReader br) throws Exception {
	int t = Integer.parseInt(br.readLine());

	StringBuilder sb = new StringBuilder();
	for (int i = 0; i < t; i++) {
	    sb.append("Case #" + (i + 1) + ":\n" + solveOne(br)).append("\n");
	}

	return sb.toString();
    }

    private String solveOne(BufferedReader br) throws Exception {
	int n = Integer.parseInt(br.readLine());

	int[][] table = new int[n][n];

	for (int i = 0; i < n; i++) {
	    String line = br.readLine().trim();
	    populateTableRow(line, table, i);
	}

	int[] wins = new int[n];
	int[] played = new int[n];
	for (int i = 0; i < n; i++) {
	    wins[i] = computeWins(table, i, n);
	    played[i] = computePlayed(table, i, n);
	}

	double[] prob = new double[n];

	for (int i = 0; i < n; i++) {
	    prob[i] = 1.0 * wins[i] / played[i];

	    // System.out.println(String.format("prob[%d] = %f", i, prob[i]));
	}

	double[] owp = new double[n];
	double[] oowp = new double[n];

	for (int i = 0; i < n; i++) {
	    owp[i] = countOwp(table, wins, played, i, n);
	}

	// System.out.println(String.format("owp[3 (D)] = %s", owp[3]));

	for (int i = 0; i < n; i++) {
	    oowp[i] = countOowp(table, owp, i, n);
	}

	StringBuilder sb = new StringBuilder();
	for (int i = 0; i < n; i++) {
	    double ri = 0.25 * prob[i] + 0.5 * owp[i] + 0.25 * oowp[i];

	    sb.append(ri).append("\n");
	}

	return sb.toString();
    }

    private double countOowp(int[][] table, double[] owp, int team, int n) {
	double sum = 0.0;
	int teams = 0;

	for (int i = 0; i < n; i++) {
	    if (i == team) {
		continue;
	    }

	    if (table[i][team] == -1) {
		continue;
	    }

	    sum += owp[i];
	    teams++;
	}

	return sum / teams;
    }

    private double countOwp(int[][] table, int[] wins, int[] played, int team,
	    int n) {

	double sum = 0.0;
	int teams = 0;

	for (int i = 0; i < n; i++) {
	    if (i == team) {
		continue;
	    }

	    if (table[i][team] == -1) {
		continue;
	    }

	    int winsi = wins[i];
	    int playedi = played[i];
	    if (table[i][team] == 1) {
		winsi--;
	    }
	    playedi--;

	    double probi = 1.0 * winsi / playedi;
	    teams++;

	    // if (team == 3) {
	    // System.out.println(String.format("owp[3 (D)] [%d] = %s", i,
	    // probi));
	    // }

	    sum += probi;
	}

	return sum / teams;
    }

    private int computePlayed(int[][] table, int team, int n) {
	int sum = 0;

	for (int i = 0; i < n; i++) {
	    if (table[team][i] != -1) {
		sum++;
	    }
	}

	return sum;
    }

    private int computeWins(int[][] table, int team, int n) {
	int sum = 0;

	for (int i = 0; i < n; i++) {
	    if (table[team][i] == 1) {
		sum++;
	    }
	}

	return sum;
    }

    private void populateTableRow(String line, int[][] table, int i) {
	int j = 0;
	for (char c : line.toCharArray()) {
	    switch (c) {
	    case '0':
		table[i][j] = 0;
		break;
	    case '1':
		table[i][j] = 1;
		break;
	    case '.':
		table[i][j] = -1;
		break;
	    }
	    j++;
	}
    }
}
