package gcj;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.InputStreamReader;
import java.io.StringReader;
import java.util.Queue;
import java.util.StringTokenizer;
import java.util.concurrent.ConcurrentLinkedQueue;

public class Dash {
    public static void main(String[] args) throws Exception {
	BufferedReader br = new BufferedReader(new InputStreamReader(
		new FileInputStream(args[0])));

	String response = new Dash().solve(br);

	FileWriter fileWriter = new FileWriter(args[0]
		+ (System.currentTimeMillis() % 100000) + ".out");
	fileWriter.write(response);
	fileWriter.close();
    }

    public String solve(String string) throws Exception {
	return solve(new BufferedReader(new StringReader(string)));
    }

    private String solve(BufferedReader br) throws Exception {
	int t = Integer.parseInt(br.readLine());

	StringBuilder sb = new StringBuilder();
	for (int i = 0; i < t; i++) {
	    sb.append("Case #" + (i + 1) + ":\n" + solveOne(br)).append("\n");
	}

	return sb.toString();
    }

    private String solveOne(BufferedReader br) throws Exception {
	String line = br.readLine();
	StringTokenizer tokens = new StringTokenizer(line, " ");
	int r = Integer.parseInt(tokens.nextToken().trim());
	int c = Integer.parseInt(tokens.nextToken().trim());

	int[][] table = new int[r][c];
	Queue<XY> corners = new ConcurrentLinkedQueue<XY>();

	for (int i = 0; i < r; i++) {
	    String line2 = br.readLine().trim();
	    populateTableRow(line2, table, i);
	}
	if (r > 1 && c > 2) {

	    for (int i = 0; i < r; i++) {
		for (int j = 0; j < c; j++) {
		    int type = isCorner(table, i, j, r, c);

		    if (type != 0) {
			corners.add(new XY(i, j, type));
		    }
		}
	    }

	    for (XY corner : corners) {
		if (table[corner.getX()][corner.getY()] != '1') {
		    continue;
		}

		boolean placed = place(table, corner.getX(), corner.getY(),
			corner.getType(), r, c, corners);

		if (!placed) {
		    return "Impossible";
		}

		// StringBuilder sb = new StringBuilder();
		// for (int i = 0; i < r; i++) {
		// for (int j = 0; j < c; j++) {
		// sb.append((char) table[i][j]);
		// }
		// sb.append("\n");
		// }
		// System.out.println(sb.toString());
	    }
	} else {
	    for (int i = 0; i < r; i++) {
		for (int j = 0; j < c; j++) {
		    if (table[i][j] == '1' | table[i][j] == '#') {
			return "Impossible";
		    }
		}
	    }
	}

	StringBuilder sb = new StringBuilder();
	for (int i = 0; i < r; i++) {
	    for (int j = 0; j < c; j++) {
		sb.append((char) table[i][j]);
	    }
	    sb.append("\n");
	}

	return sb.toString();
    }

    private boolean place(int[][] table, int x, int y, int type, int r, int c,
	    Queue<XY> corners) {

	int xx = 0;
	int yy = 0;
	switch (type) {
	case 1:
	    xx = x;
	    yy = y;
	    break;
	case 2:
	    xx = x - 1;
	    yy = y;
	    break;
	case 3:
	    xx = x;
	    yy = y - 1;
	    break;
	case 4:
	    xx = x - 1;
	    yy = y - 1;
	    break;
	}

	if (canPlace(table, xx, yy, r, c)) {
	    table[xx][yy] = '/';
	} else {
	    return false;
	}

	if (canPlace(table, xx + 1, yy, r, c)) {
	    table[xx + 1][yy] = '\\';
	} else {
	    return false;
	}

	if (canPlace(table, xx, yy + 1, r, c)) {
	    table[xx][yy + 1] = '\\';
	} else {
	    return false;
	}

	if (canPlace(table, xx + 1, yy + 1, r, c)) {
	    table[xx + 1][yy + 1] = '/';
	} else {
	    return false;
	}

	checkPoint(table, r, c, corners, xx - 1, yy);
	checkPoint(table, r, c, corners, xx - 1, yy + 1);
	checkPoint(table, r, c, corners, xx + 2, yy);
	checkPoint(table, r, c, corners, xx + 2, yy + 1);
	checkPoint(table, r, c, corners, xx, yy - 1);
	checkPoint(table, r, c, corners, xx + 1, yy - 1);
	checkPoint(table, r, c, corners, xx, yy + 2);
	checkPoint(table, r, c, corners, xx + 1, yy + 2);

	return true;
    }

    private void checkPoint(int[][] table, int r, int c, Queue<XY> corners,
	    int i, int j) {
	int type2 = isCorner(table, i, j, r, c);
	if (type2 != 0) {
	    corners.add(new XY(i, j, type2));
	}
    }

    private boolean canPlace(int[][] table, int i, int j, int c, int r) {
	if (i < 0 || i > c - 1 || j < 0 || j > r - 1) {
	    return false;
	}

	return table[i][j] == '1';
    }

    private int isCorner(int[][] table, int i, int j, int c, int r) {
	if (i < 0 || i > c - 1 || j < 0 || j > r - 1) {
	    return 0;
	}

	if (table[i][j] != '1') {
	    return 0;
	}

	if (i == 0) {
	    if (j == 0) {
		return 1;
	    }

	    if (j == r - 1) {
		return 3;
	    }

	    if (table[i][j - 1] != '1') {
		return 1;
	    }

	    if (table[i][j + 1] != '1') {
		return 3;
	    }
	} else

	if (i == c - 1) {
	    if (j == 0) {
		return 2;
	    }

	    if (j == r - 1) {
		return 4;
	    }

	    if (table[i][j - 1] != '1') {
		return 2;
	    }

	    if (table[i][j + 1] != '1') {
		return 4;
	    }
	} else

	if (j == 0) {
	    if (table[i - 1][j] != '1') {
		return 1;
	    }

	    if (table[i + 1][j] != '1') {
		return 2;
	    }
	} else

	if (j == r - 1) {
	    if (table[i - 1][j] != '1') {
		return 3;
	    }

	    if (table[i + 1][j] != '1') {
		return 4;
	    }
	} else

	if (table[i - 1][j] != '1' && table[i][j - 1] != '1') {
	    return 1;
	} else

	if (table[i][j - 1] != '1' && table[i + 1][j] != '1') {
	    return 2;
	} else

	if (table[i + 1][j] != '1' && table[i][j + 1] != '1') {
	    return 4;
	} else

	if (table[i][j + 1] != '1' && table[i - 1][j] != '1') {
	    return 3;
	}

	return 0;
    }

    private void populateTableRow(String line, int[][] table, int i) {
	int j = 0;
	for (char c : line.toCharArray()) {
	    switch (c) {
	    case '.':
		table[i][j] = '.';
		break;
	    case '#':
		table[i][j] = '1';
		break;
	    }
	    j++;
	}
    }
}

class XY {
    private final int x;
    private final int y;
    private final int type;

    public XY(int x, int y, int type) {
	this.x = x;
	this.y = y;
	this.type = type;
    }

    public int getX() {
	return x;
    }

    public int getY() {
	return y;
    }

    public int getType() {
	return type;
    }
}