import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

public class DijkstraSolver {
	
	public static final String INPUT = "C-small-attempt1.in";
	public static final String OUTPUT = "C-small-attempt1.out";

	/** Input representation */
	private int[] input;
	
	/**
	 * Parses an instance of dijkstra
	 * @param s the input string representing the instance
	 * @return the data representation of the instance
	 */
	public DijkstraSolver(String s1, String s2) {
		String[] params = s1.split(" ");
		int length = Integer.parseInt(params[0]) * Integer.parseInt(params[1]);
		input = new int[length];
		for (int i = 0; i < Integer.parseInt(params[1]); i++) {
			for (int j = 0; j < Integer.parseInt(params[0]); j++) {
				input[i * Integer.parseInt(params[0]) + j] = s2.charAt(j);
			}
		}
	}
	
	/** Multiplication chart */
	public int multiply(int a, int b) {
		if (a < 0)
			return -multiply(-a, b);
		if (b < 0)
			return -multiply(a, -b);
		if (a == 1) 
			return b;
		if (b == 1) 
			return a;
		if (a == b)
			return -1;
		if (a == 'i') {
			if (b == 'j')
				return 'k';
			if (b == 'k')
				return -'j';
		}
		if (a == 'j') {
			if (b == 'i')
				return -'k';
			if (b == 'k')
				return 'i';
		}
		if (a == 'k') {
			if (b == 'i')
				return 'j';
			if (b == 'j')
				return -'i';
		}
		
		return -1;
	}
	
	/**
	 * Solves an instance of dijkstra
	 * @return whether this instance can be reduced to ijk
	 */
	public String solve() {
		int iacc = 1;
		for (int i = 0; i < input.length - 2; i++) {
			iacc = multiply(iacc, input[i]);
			if (iacc == 'i') {
				int jacc = 1;
				for (int j = i+1; j < input.length - 1; j++) {
					jacc = multiply(jacc, input[j]);
					if (jacc == 'j') {
						int kacc = 1;
						for (int k = j+1; k < input.length; k++) {
							kacc = multiply(kacc, input[k]);
						}
						if (kacc == 'k') return "YES";
					}
				}
			}
		}
		return "NO";
	}

	/**
	 * Outputs the solution to an input file 
	 * containing instances of standing ovation
	 * @param args
	 */
	public static void main(String[] args) {
		
		BufferedReader br = null;
		File file = new File(OUTPUT);
		FileWriter fw = null;
		 
		try {
			String line;
			br = new BufferedReader(new FileReader(INPUT));
		    fw = new FileWriter(file);
			
			int numInstances = 0;
			// Read number of instances
			if ((line = br.readLine()) != null) {
				numInstances = Integer.parseInt(line);
			}
			// Parse each instance
			for (int i = 0; i < numInstances; i++) {
//				System.out.println("Solving instance" + i);
				DijkstraSolver ds = new DijkstraSolver(br.readLine(), br.readLine());
				fw.write("Case #"+(i+1)+": "+ds.solve() + "\n");
			}
			
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if (br != null)
					br.close();
				if (fw != null) {
					fw.flush();
					fw.close();
				}
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}

}
