import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Collections;
import java.util.LinkedList;

public class DeceitfulWar {
	private int caseNum;
	private int dw_score;
	private int w_score;

	/**
	 * @param nBlock
	 *            sorted list of Naomi's blocks
	 * @param kBlock
	 *            sorted list of Ken's blocks
	 * @param caseNum
	 *            case number
	 */
	public DeceitfulWar(LinkedList<Double> nBlock, LinkedList<Double> kBlock,
			int caseNum) {
		this.caseNum = caseNum;
		
		// Calculating deceitful war score
		LinkedList<Double> dw_nBlock = (LinkedList<Double>) nBlock.clone();
		LinkedList<Double> dw_kBlock = (LinkedList<Double>) kBlock.clone();

		dw_score = deceitWarRound(dw_nBlock, dw_kBlock);

		// Calculating war score
		w_score = warRound(nBlock, kBlock);
	}

	/**
	 * Recursive function for simulating a deceitful war round
	 */
	private int deceitWarRound(LinkedList<Double> nBlock,
			LinkedList<Double> kBlock) {
		// Base Case: size = 1
		if (nBlock.size() == 1) {
			return (nBlock.poll() > kBlock.poll()) ? 1 : 0;
		}

		// Recursive Case

		// Naomi takes her smallest block and
		double n_val = nBlock.poll();
		
		// If it's smaller than Ken's smallest block, make Ken throw away his
		// largest block by reporting a slightly smaller value
		if (n_val < kBlock.peek()) {
			kBlock.removeLast();
			return deceitWarRound(nBlock, kBlock);
		}
		
		// If it's larger than Ken's largest block, make Ken throw away his
		// smallest block by reporting a value largest than his largest
		else {
			kBlock.poll();
			return 1 + deceitWarRound(nBlock, kBlock);
		}
	}

	/**
	 * Recursive function for simulating a fair war round
	 */
	private int warRound(LinkedList<Double> nBlock, LinkedList<Double> kBlock) {

		// Base Case: size = 1
		if (nBlock.size() == 1) {
			return (nBlock.poll() > kBlock.poll()) ? 1 : 0;
		}

		// Recursive Case

		// Naomi takes a block
		double n_val = nBlock.poll();

		// Ken plays the block with the next highest value
		double k_val = 0;
		for (int i = 0; i < kBlock.size(); i++) {
			if (kBlock.get(i) > n_val) {
				k_val = kBlock.remove(i);
				break;
			}
		}
		// or his smallest value if there is none
		if (k_val == 0)
			k_val = kBlock.poll();

		// Recursive call
		if (n_val > k_val) {
			return 1 + warRound(nBlock, kBlock);
		} else {
			return warRound(nBlock, kBlock);
		}
	}

	public String toString() {
		return "Case #" + caseNum + ": " + dw_score + " " + w_score + "\n";
	}

	public static void main(String[] args) {
		StringBuilder sb = new StringBuilder();

		try {
			BufferedReader in = new BufferedReader(new FileReader(args[0]));

			// First line is number of cases
			int numCases = 0;
			if (in.ready()) {
				numCases = Integer.parseInt(in.readLine());
			}

			// Next are details of cases
			for (int i = 0; i < numCases; i++) {

				int numBlocks = Integer.parseInt(in.readLine());

				String[] ns = in.readLine().split(" ");
				String[] ks = in.readLine().split(" ");

				LinkedList<Double> nBlocks = new LinkedList<Double>();
				LinkedList<Double> kBlocks = new LinkedList<Double>();

				for (int j = 0; j < numBlocks; j++) {
					nBlocks.add(Double.parseDouble(ns[j]));
					kBlocks.add(Double.parseDouble(ks[j]));
				}

				// Sort the lists of blocks for ease later
				Collections.sort(nBlocks);
				Collections.sort(kBlocks);

				// Calculate scores
				DeceitfulWar cc = new DeceitfulWar(nBlocks, kBlocks, i + 1);
				sb.append(cc);
			}

			// Write the file once it's done
			FileWriter fw = new FileWriter("DW_Solution.txt");
			fw.write(sb.toString());
			fw.close();

			in.close();
		} catch (FileNotFoundException e) {
			System.out.println("File not found!");
		} catch (IOException e) {
			System.out.println("Error while reading!");
		}
	}

}
