import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

public class MushroomSolver {
	public static final String INPUT = "A-large.in";
	public static final String OUTPUT = "A-large.out";

	/** Input representation */
	private int[] input;
	
	/**
	 * Parses an instance of mushroom monster
	 * @param s the input string representing the instance
	 * @return the data representation of the instance
	 */
	public MushroomSolver(String s1, String s2) {
		int length = Integer.parseInt(s1);
		input = new int[length];
		String[] params = s2.split(" ");
		for (int i = 0; i < length; i++) {
			input[i] = Integer.parseInt(params[i]);
		}
	}
	
	/**
	 * Solves an instance of mushroom monster using the first assumption
	 * @return the minimum number of mushrooms eaten under the first assumption
	 */
	public int solveInstant() {
		int acc = 0;
		for (int i = 1; i < input.length; i++) {
			int diff = input[i-1] - input[i];
			if (diff > 0) { // Kaylin ate some mushrooms
				acc += diff;
			}
		}
		return acc;
	}
	
	/**
	 * Solves an instance of mushroom monster using the second assumption
	 * @return the minimum number of mushrooms eaten under the second assumption
	 */
	public int solveRate() {
		int rate = 0; // number of mushrooms eaten per 10 seconds, constrained by highest rate
		for (int i = 1; i < input.length; i++) {
			int diff = input[i-1] - input[i];
			if (diff > 0 && rate < diff) { // Kaylin ate some mushrooms faster than we thought
				rate = diff;
			}
		}
		
		int acc = 0;
		for (int i = 0; i < input.length - 1; i++) { // We look ahead to see how many mushrooms will be left
			if (input[i] <= rate) { // Kaylin eats all the mushrooms in this 10 second span
				acc += input[i];
			} else { // Kaylin eats at her rate and there's some mushrooms left over
				acc += rate;
			}
			
		}
		return acc;
	}

	/**
	 * Outputs the solution to an input file 
	 * containing instances of standing ovation
	 * @param args
	 */
	public static void main(String[] args) {
		
		BufferedReader br = null;
		File file = new File(OUTPUT);
		FileWriter fw = null;
		 
		try {
			String line;
			br = new BufferedReader(new FileReader(INPUT));
		    fw = new FileWriter(file);
			
			int numInstances = 0;
			// Read number of instances
			if ((line = br.readLine()) != null) {
				numInstances = Integer.parseInt(line);
			}
			// Parse each instance
			for (int i = 0; i < numInstances; i++) {
//				System.out.println("Solving instance" + i);
				MushroomSolver ms = new MushroomSolver(br.readLine(), br.readLine());
				fw.write("Case #"+(i+1)+": "+ms.solveInstant()+" "+ms.solveRate()+"\n");
			}
			
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if (br != null)
					br.close();
				if (fw != null) {
					fw.flush();
					fw.close();
				}
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}
}
