import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.PrintWriter;
import java.util.Arrays;

/**
 * Solver for the Revenge of the Pancakes problem
 * @author Bobby (Bo Yuan) Zhou
 */
public class PancakeSolution {
	
	public static final String in = "B-large.in"; // input file name
	public static final String out = "B-large.out"; // output file name
	
	private boolean[] happy; // stack of pancakes and whether they're happy side up
	
	public PancakeSolution(String input) {
		happy = new boolean[input.length()];
		for (int i = 0; i < input.length(); i++) {
			happy[i] = (input.charAt(i) == '+');
		}
	}
	
	/**
	 * Recursive helper function
	 * @param stack		array of booleans denoting which pancakes on the stack are happy side up
	 * @param length	length of the stack to consider, starting from the top (first)
	 * @return the number of flips to make all the pancakes happy
	 */
	private int turnHappy(boolean[] stack, int length) {
		int numFlips = 0;
		int happyLength = 0;
		
		// Base: No pancakes to flip
		if (length <= 0) {
			return 0;
		}
		// Begin with happy up 
		else if (stack[0]) {
			// Calculate continuous number of happy pancakes
			happyLength = 1;
			while (happyLength < length && stack[happyLength]) {
				happyLength++;
			}
			
			// Flip over the stack of happy pancakes to make them all blank if necessary
			if (happyLength < length) {
				numFlips++;
				for (int i = 0; i < happyLength; i++) {
					stack[i] = false;
				}
				numFlips += turnHappy(stack, length);
			}
		}
		// Begin with blank up
		else {
			// Calculate continuous number of blank pancakes
			happyLength = 1;
			while (happyLength < length && !stack[happyLength]) {
				happyLength++;
			}
			
			// Flip over all the pancakes so that the top blank ones are now happy on the bottom and 
			// recurse if necessary
			numFlips++;
			
			if (happyLength < length) {
				// Flip
				boolean[] opposite = new boolean[length];
				for (int i = 0; i < length; i++) {
					opposite[i] = !stack[i];
				}
				for (int i = 0; i < length; i++) {
					stack[i] = opposite[length - 1 - i];
				}
				
				// Recurse
				numFlips += turnHappy(stack, length - happyLength);
			}
			
		}
		return numFlips;
	}
	
	/**
	 * Returns the last number uttered before going to sleep or INSOMNIA
	 */
	public String getSolution() {
		// Calculate bottom number of pancakes already happy
		int happyLengthBot = 0;
		while (happyLengthBot < happy.length && happy[happy.length - happyLengthBot - 1]) {
			happyLengthBot++;
		}
		return "" + turnHappy(happy, happy.length - happyLengthBot);
	}
	
	/**
	 * Main execution call for solver
	 */
	public static void main(String[] args) {
		try {
			// Setup io
			BufferedReader reader = new BufferedReader(new FileReader(new File(in)));
			PrintWriter writer = new PrintWriter(out);
			
			// Iterate through cases
			int numCases = Integer.parseInt(reader.readLine());
			for (int i = 0; i < numCases; i++) {
				PancakeSolution solution = new PancakeSolution(reader.readLine());
				writer.write("Case #" + (i + 1) + ": " + solution.getSolution() + "\n");
			}
			
			// Shut off io
			writer.close();
			reader.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

}
