import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

public class StandingOvationSolver {
	
	/** Input representation */
	private int[] input;
	
	/**
	 * Parses an instance of standing ovation
	 * @param s the input string representing the instance
	 * @return the data representation of the instance
	 */
	public StandingOvationSolver(String s) {
		String[] params = s.split(" ");
		int length = Integer.parseInt(params[0]) + 1;
		input = new int[length];
		for (int j = 0; j < length; j++) {
			input[j] = Character.getNumericValue(params[1].charAt(j));
		} 
	}
	
	/**
	 * Solves an instance of standing ovation
	 * @param input an array of Si values
	 * @return the minimum number needed to guarantee a standing ovation
	 */
	public int solve() {
		int acc = 0;
		int numAdded = 0;
		for (int i = 0; i < input.length; i++) {
			while (acc < i) {
				acc++;
				numAdded++;
			}
			acc+=input[i];
		}
		return numAdded;
	}

	/**
	 * Outputs the solution to an input file 
	 * containing instances of standing ovation
	 * @param args
	 */
	public static void main(String[] args) {
		
		BufferedReader br = null;
		File file = new File("A-large.out");
		FileWriter fw = null;
		 
		try {
			String line;
			br = new BufferedReader(new FileReader("./A-large.in"));
		    fw = new FileWriter(file);
			
			int numInstances = 0;
			// Read number of instances
			if ((line = br.readLine()) != null) {
				numInstances = Integer.parseInt(line);
			}
			// Parse each instance
			for (int i = 0; i < numInstances; i++) {
				line = br.readLine();
				StandingOvationSolver sos = new StandingOvationSolver(line);
				fw.write("Case #"+(i+1)+": "+sos.solve() + "\n");
			}
			
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if (br != null)
					br.close();
				if (fw != null) {
					fw.flush();
					fw.close();
				}
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}

}
