import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.PrintWriter;

/**
 * Solver for the Counting Sheep problem
 * @author Bobby Zhou
 */
public class CountingSheepSolution {
	
	public static final String in = "A-large.in"; // input file name
	public static final String out = "A-large.out"; // output file name
	public static final int ASCII_0 = 48;
	
	private int start;
	
	public CountingSheepSolution(int n) {
		start = n;
	}
	
	/**
	 * Returns the last number uttered before going to sleep or INSOMNIA
	 */
	public String getSolution() {
		
		// Insomnia case
		if (start == 0) return "INSOMNIA";
		
		int iteration = 0;
		String cur = "";
		boolean allFound = false;
		boolean[] foundDigits = new boolean[10];
		
		// Continue until all digits found
		while (!allFound) {
			
			iteration++;
			cur = "" + (start * iteration);
			
			// Update found digits
			for (int i = 0; i < cur.length(); i++) {
				int digit = cur.charAt(i) - ASCII_0; // convert digit to int 
				foundDigits[digit] = true;
			}
			
			// Check all digits found
			allFound = true;
			for (boolean foundDigit : foundDigits) {
				if (!foundDigit) allFound = false;
			}
		}
		
		return cur;
	}
	
	/**
	 * Main execution call for solver
	 */
	public static void main(String[] args) {
		try {
			// Setup io
			BufferedReader reader = new BufferedReader(new FileReader(new File(in)));
			PrintWriter writer = new PrintWriter(out);
			
			// Iterate through cases
			int numCases = Integer.parseInt(reader.readLine());
			for (int i = 0; i < numCases; i++) {
				int n = Integer.parseInt(reader.readLine());
				CountingSheepSolution solution = new CountingSheepSolution(n);
				writer.write("Case #" + (i + 1) + ": " + solution.getSolution() + "\n");
			}
			
			// Shut off io
			writer.close();
			reader.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

}
