import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class PancakeSolver {
	
	public static final String INPUT = "B-small-attempt0.in";
	public static final String OUTPUT = "B-small-attempt0.out";

	/** Input representation */
	private List<Integer> input;
	
	/**
	 * Parses an instance of infinite house of pancakes
	 * @param s the input string representing the instance
	 * @return the data representation of the instance
	 */
	public PancakeSolver(String s1, String s2) {
		int length = Integer.parseInt(s1);
		String[] params = s2.split(" ");
		input = new ArrayList<Integer>();
		for (int i = 0; i < length; i++) {
			input.add(Integer.parseInt(params[i]));
		}
	}
	
	/**
	 * Solves an instance of infinite house of pancakes
	 * @return whether the minimum amount of time it takes to finish all pancakes
	 */
	public int solve() {
		int acc = 0;
		int max = Collections.max(input);
		while (max > 0) {
			if (max > 2 && max % 2 == 0 && Collections.frequency(input, max) <= (max / 2)) { // Special minute
				input.set(input.indexOf(max), max / 2);
				input.add(max / 2);
			} else { // Regular minute
				for (int i = 0; i < input.size(); i++)
					input.set(i, input.get(i) - 1);
			}
			max = Collections.max(input); // Recalculate max
			acc++;
		}
		return acc;
	}

	/**
	 * Outputs the solution to an input file 
	 * containing instances of standing ovation
	 * @param args
	 */
	public static void main(String[] args) {
		
		BufferedReader br = null;
		File file = new File(OUTPUT);
		FileWriter fw = null;
		 
		try {
			String line;
			br = new BufferedReader(new FileReader(INPUT));
		    fw = new FileWriter(file);
			
			int numInstances = 0;
			// Read number of instances
			if ((line = br.readLine()) != null) {
				numInstances = Integer.parseInt(line);
			}
			// Parse each instance
			for (int i = 0; i < numInstances; i++) {
				System.out.println("Calculating instance: " + i);
				PancakeSolver ps = new PancakeSolver(br.readLine(), br.readLine());
				fw.write("Case #"+(i+1)+": "+ps.solve() + "\n");
			}
			
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if (br != null)
					br.close();
				if (fw != null) {
					fw.flush();
					fw.close();
				}
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}
}
