package codjam.bpeck.qualification.traintimetable;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Scanner;

/**
 * Solves the TimeTable Problem
 * @author Brian
 *
 */
public class TimeTable {

	private ArrayList<Time> departuresFromA;

	private ArrayList<Time> arrivalsToB;

	private ArrayList<Time> departuresFromB;

	private ArrayList<Time> arrivalsToA;

	private int numTrainsA;

	private int numTrainsB;

	private int turnAroundTime;

	public TimeTable(int tat) {
		turnAroundTime = tat;
		departuresFromA = new ArrayList<Time>();
		arrivalsToB = new ArrayList<Time>();
		departuresFromB = new ArrayList<Time>();
		arrivalsToA = new ArrayList<Time>();
	}

	public void addDepA(String aTime) {
		departuresFromA.add(new Time(aTime));
	}

	public void addDepB(String aTime) {
		departuresFromB.add(new Time(aTime));
	}

	public void addArvA(String aTime) {
		arrivalsToA.add(new Time(aTime));
	}

	public void addArvB(String aTime) {
		arrivalsToB.add(new Time(aTime));
	}

	public void run() {
		numTrainsA = departuresFromA.size();
		numTrainsB = departuresFromB.size();

		// quick base case check
		if ((numTrainsA == 0) || (numTrainsB == 0)) {
			return;
		}

		int minDepA[] = new int[numTrainsA];
		int minArvB[] = new int[numTrainsA];
		for (int i = 0; i < minDepA.length; i++) {
			minDepA[i] = departuresFromA.get(i).getTotalMinutes();
			minArvB[i] = arrivalsToB.get(i).getTotalMinutes();
		}

		int minDepB[] = new int[numTrainsB];
		int minArvA[] = new int[numTrainsB];
		for (int i = 0; i < minDepB.length; i++) {
			minDepB[i] = departuresFromB.get(i).getTotalMinutes();
			minArvA[i] = arrivalsToA.get(i).getTotalMinutes();
		}

		Arrays.sort(minDepA);
		Arrays.sort(minArvB);

		Arrays.sort(minDepB);
		Arrays.sort(minArvA);

		// start from last B departure and see if any trains arrive from A early
		// enough to take use.
		int currentATrain = minArvB.length - 1;
		for (int i = minDepB.length - 1; i >= 0; i--) {
			int currentTime = minDepB[i];
			for(int j = currentATrain; j >= 0; j--) {
				int lastArrivalTime = minArvB[j];
				if(lastArrivalTime + turnAroundTime <= currentTime) {
					numTrainsB--;
					currentATrain = j - 1;
					break;
				}
			}
		}
		
		
		
		// repeat with A departures
		int currentBTrain = minArvA.length - 1;
		for (int i = minDepA.length - 1; i >= 0; i--) {
			int currentTime = minDepA[i];
			for(int j = currentBTrain; j >= 0; j--) {
				int lastArrivalTime = minArvA[j];
				if(lastArrivalTime + turnAroundTime <= currentTime) {
					numTrainsA--;
					currentBTrain = j - 1;
					break;
				}
			}
		}

	}

	public int getNumTrainsA() {
		return numTrainsA;
	}

	public int getNumTrainsB() {
		return numTrainsB;
	}
	
	public static void main(String[] args) {
		Scanner keyboard = new Scanner(System.in);
		System.out.print("File name: ");
		
		String fileName = keyboard.nextLine();
		long start = System.nanoTime();
		File theFile = new File(fileName);
		BufferedWriter out;
		try {
			out = new BufferedWriter(new FileWriter(fileName + "out"));
			Scanner read = new Scanner(new FileInputStream(theFile));
			// get total
			int total = read.nextInt();
			read.nextLine();
			// loop through each case
			for(int i = 0; i < total; i++) {
				// determind the turn around time
				int tat = read.nextInt();
				read.nextLine();
				TimeTable tt = new TimeTable(tat);
				// get number of routes
				int aRoutes = read.nextInt();
				int bRoutes = read.nextInt();
				read.nextLine();
				for(int j = 0; j < aRoutes; j++) {
					tt.addDepA(read.next("\\d\\d:\\d\\d"));
					tt.addArvB(read.next("\\d\\d:\\d\\d"));
					if(read.hasNext()) {
						read.nextLine();
					}
				}
				for(int j = 0; j < bRoutes; j++) {
					tt.addDepB(read.next("\\d\\d:\\d\\d"));
					tt.addArvA(read.next("\\d\\d:\\d\\d"));
					if(read.hasNext()) {
						read.nextLine();
					}
				}
				// run.
				tt.run();
				out.write("Case #" + (i + 1) + ": ");
				out.write(tt.getNumTrainsA() + " ");
				out.write(tt.getNumTrainsB() + "\n");
			}
			out.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
		long end = System.nanoTime();
		double elapsed = (end - start) / 1000000000.0;
		System.out.println("Completed in: " + elapsed);
	}

}
