package google.code.jam;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;

public class Watersheds {

	private static String encoding = "UTF-8";
	private static String[] labels = { "a", "b", "c", "d", "e", "f", "g", "h",
			"i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s", "t", "u",
			"v", "w", "x", "y", "z" };
	private static String sink = ".";
	private static String[] neighboursAndMeLabel = { sink, "N", "W", "E", "S" };
	private Integer numOfMaps;
	List<Integer[][]> mapList;
	List<String[][]> directionMapList;
	List<String[][]> resultMapList;

	private static String empty = "";
	private static String space = " ";
	private static Integer highest = Integer.MAX_VALUE;

	private static int min(Integer[] t) {
		int minimum = t[0]; // start with the first value
		int minindex = 0;
		for (int i = 1; i < t.length; i++) {
			if (t[i] < minimum) {
				minimum = t[i]; // new minimum
				minindex = i;
			}
		}
		return minindex;
	}

	private String getCellDirection(int row, int col, int rows, int cols,
			Integer[][] map) {
		Integer N = null;
		Integer E = null;
		Integer S = null;
		Integer W = null;
		if (row + 1 < rows) {
			S = map[row + 1][col];
		} else {
			S = highest;
		}
		if (row - 1 > -1) {
			N = map[row - 1][col];
		} else {
			N = highest;
		}
		if (col + 1 < cols) {
			E = map[row][col + 1];
		} else {
			E = highest;
		}
		if (col - 1 > -1) {
			W = map[row][col - 1];
		} else {
			W = highest;
		}
		Integer[] neighboursAndMe = { map[row][col], N, W, E, S };
		return neighboursAndMeLabel[min(neighboursAndMe)];
	}

	private static void printMap(BufferedWriter writer, String[][] map,
			Integer mapNumber) throws IOException {
		writer.write("Case #" + mapNumber + ":");
		writer.newLine();
		int lineNumber = 1;
		for (String[] ml : map) {
			String resultLine = empty;
			for (String mval : ml) {
				resultLine = resultLine + mval + space;
			}
			writer.write(resultLine.trim());
			writer.newLine();
			lineNumber++;
		}
	}

	private static void printMap(BufferedWriter writer, Integer[][] map,
			Integer mapNumber) throws IOException {
		writer.write("Case #" + mapNumber + ":");
		writer.newLine();
		int lineNumber = 1;
		for (Integer[] ml : map) {
			String resultLine = empty;
			for (Integer mval : ml) {
				resultLine = resultLine + mval + space;
			}
			writer.write(resultLine.trim());
			writer.newLine();
			lineNumber++;
		}
	}

	private String[][] getDirectionMap(Integer[][] map) throws IOException {
		// ////////////////////////
		int rows = map.length;
		int cols = map[0].length;

		String[][] directionMap = new String[rows][cols];
		for (int row = 0; row < map.length; row++) {
			for (int col = 0; col < map[0].length; col++) {
				directionMap[row][col] = getCellDirection(row, col, rows, cols,
						map);
			}
		}
		return directionMap;
	}

	private void processInputFile(InputStream inputStream, OutputStream outputStream) throws IOException {
		BufferedReader reader = null;
		reader = new BufferedReader(
				new InputStreamReader(inputStream, encoding));
		String line;
		int lineNumber = 0;
		int mapLineNumber = 0;
		int mapNumber = 0;
		boolean foundNewMap = false;
		Integer H = new Integer(0);
		Integer V = new Integer(0);
		Integer[][] map = null;
		mapList = new LinkedList<Integer[][]>();
		directionMapList = new LinkedList<String[][]>();
		try {
			while ((line = reader.readLine()) != null) {
				if (lineNumber == 0) {
					numOfMaps = new Integer(line);
					foundNewMap = true;
				} else {
					if (foundNewMap) {
						foundNewMap = false;
						String[] sizes = line.split(" ");
						H = new Integer(sizes[1]);
						V = new Integer(sizes[0]);
						map = new Integer[V][H];
						mapList.add(map);
						mapNumber++;
						mapLineNumber = 0;
					} else {
						mapLineNumber++;
						if (mapLineNumber == V) {
							foundNewMap = true;
						}
						Integer[] mapLine = new Integer[H];
						String[] mapLineString = line.split(space);
						for (int i = 0; i < H; i++) {
							mapLine[i] = new Integer(mapLineString[i]);
						}
						map[mapLineNumber - 1] = mapLine;
					}
				}
				lineNumber++;
			}
		} finally {
			reader.close();
		}

		BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(
				outputStream, encoding));
		try {

			for (int j = 0; j < mapList.size(); j++) {
				//printMap(writer, mapList.get(j), j + 1);

				String[][] dirMap = getDirectionMap(mapList.get(j));
				directionMapList.add(dirMap);
				//printMap(writer, dirMap, j + 1);

				boolean notready = true;
				while (notready) {
					notready = transformMap(dirMap);
					//printMap(writer, dirMap, j + 1);
				}

				Set<String> switched = new HashSet<String>();
				notready = true;
				boolean szviccs = false;
				int rows = dirMap.length;
				int cols = dirMap[0].length;
				String prev = dirMap[0][0];
				while (notready) {
					szviccs = false;
					for (int row = 0; row < rows; row++) {
						for (int col = 0; col < cols; col++) {
							String val = dirMap[row][col];
							if (!prev.equals(val)) {
								if (prev.compareTo(val) > 0) {
									if (!switched.contains(val + prev)) {
										switched.add(val + prev);
										switched.add(prev + val);
										switchLabel(dirMap, val, prev);
										szviccs = true;
										break;
									}
								}
							}
						}
						if (szviccs) {
							break;
						}
					}
					notready = szviccs;
				}

				printMap(writer, dirMap, j + 1);
			}

		} finally {
			writer.close();
		}

	}

	private void switchLabel(String[][] dirMap, String val, String replacement) {
		int rows = dirMap.length;
		int cols = dirMap[0].length;
		for (int row = 0; row < rows; row++) {
			for (int col = 0; col < cols; col++) {
				String cell = dirMap[row][col];
				if (cell.equals(val)) {
					dirMap[row][col] = replacement;
				} else if (cell.equals(replacement)) {
					dirMap[row][col] = val;
				}
			}
		}
	}

	private boolean transformMap(String[][] dirMap) {
		boolean result = false;
		int cnt = -1;
		int rows = dirMap.length;
		int cols = dirMap[0].length;
		for (int row = 0; row < rows; row++) {
			for (int col = 0; col < cols; col++) {
				String cell = dirMap[row][col];
				if (cell.equals(sink)) {
					dirMap[row][col] = labels[++cnt];
					result = true;
				} else if (cell.equals("W") || cell.equals("N")
						|| cell.equals("E") || cell.equals("S")) {

					if (cell.equals("N") && row - 1 > -1) {
						String neighbour = dirMap[row - 1][col];
						if (!(neighbour.equals("W") || neighbour.equals("N")
								|| neighbour.equals("E")
								|| neighbour.equals("S") || neighbour
								.equals(sink))) {
							dirMap[row][col] = neighbour;
							result = true;
						}
					}

					if (cell.equals("S") && row + 1 < rows) {
						String neighbour = dirMap[row + 1][col];
						if (!(neighbour.equals("W") || neighbour.equals("N")
								|| neighbour.equals("E")
								|| neighbour.equals("S") || neighbour
								.equals(sink))) {
							dirMap[row][col] = neighbour;
							result = true;
						}
					}

					if (cell.equals("E") && col + 1 < cols) {
						String neighbour = dirMap[row][col + 1];
						if (!(neighbour.equals("W") || neighbour.equals("N")
								|| neighbour.equals("E")
								|| neighbour.equals("S") || neighbour
								.equals(sink))) {
							dirMap[row][col] = neighbour;
							result = true;
						}
					}

					if (cell.equals("W") && col - 1 > -1) {
						String neighbour = dirMap[row][col - 1];
						if (!(neighbour.equals("W") || neighbour.equals("N")
								|| neighbour.equals("E")
								|| neighbour.equals("S") || neighbour
								.equals(sink))) {
							dirMap[row][col] = neighbour;
							result = true;
						}
					}

				}
			}
		}
		return result;
	}

	/**
	 * @param args
	 * @throws IOException
	 * @throws FileNotFoundException
	 */
	public static void main(String[] args) throws FileNotFoundException,
			IOException {
		if (args.length < 2) {
			System.err
					.println("usage: AlienLanguage <input file path> <output file path>");
			System.exit(-1);
		}

		Watersheds watersheds = new Watersheds();
		watersheds.processInputFile(new FileInputStream(args[0]), new FileOutputStream(args[1]));
	}

}
