/**
 * 
 */
package BotTrust;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.StringTokenizer;

/**
 * @author Brighton Vino
 * 
 */
public class BotTrust {

	public static File input;
	public static File output;
	public static FileReader inputreader;
	public static FileWriter outputwriter;
	public static BufferedReader in;
	public static BufferedWriter out;
	public static final String ProblemName = "BotTrust";
	public static StringTokenizer ST;
	
	public static int NoOfTestCases = 0;
	public static int Tested = 0;
	/**
	 * @param args
	 * @throws IOException
	 */
	public static void main(String[] args) throws IOException {	
		INITProblem();
		NoOfTestCases = INT(TOKEN());
		while (Tested < NoOfTestCases) {
			TestCase TC = new TestCase(new StringTokenizer(in.readLine()));
			println("Case #"+(Tested+1)+": "+TC.Solve());
			Tested++;
		}
		CLOSE();
	}
	
	public static void INITProblem() throws IOException {
		setInput(ProblemName + ".in");
		setOutput(ProblemName + ".out");
		ST = new StringTokenizer(in.readLine());
	}

	/** - INPUT/OUPUT - **/

	public static void setInput(String filename) throws IOException {
		input = new File(filename);
		inputreader = new FileReader(input);
		in = new BufferedReader(inputreader);
	}

	public static void setOutput(String filename) throws IOException {
		output = new File(filename);
		outputwriter = new FileWriter(output);
		out = new BufferedWriter(outputwriter);
	}

	public static void CLOSE() throws IOException {
		if (in != null)
			in.close();
		if (inputreader != null)
			inputreader.close();

		if (out != null)
			out.flush();
		if (out != null)
			out.close();
		if (outputwriter != null)
			outputwriter.close();
	}

	/** - CONVERSIONS - **/

	static int INT(String A) throws IOException {
		return Integer.parseInt(A);
	}

	static long LONG(String A) throws IOException {
		return Long.parseLong(A);
	}

	static double DOUBLE(String A) throws IOException {
		return Double.parseDouble(A);
	}

	static BigInteger BIGINT(String A) throws IOException {
		return new BigInteger(A);
	}

	/** - CUSTOM PRINTS - **/

	public static void println() throws IOException {
		out.write("\n");
		System.out.println();
	}

	public static void println(Object obj) throws IOException {
		out.write(obj.toString());
		out.write("\n");
		System.out.println(obj.toString());
	}

	public static void print(Object obj) throws IOException {
		out.write(obj.toString());
		System.out.print(obj.toString());
	}

	public static void println(long number) throws IOException {
		out.write(Long.toString(number));
		out.write("\n");
		System.out.println(number);
	}

	public static void print(long number) throws IOException {
		out.write(Long.toString(number));
		System.out.print(number);
	}

	public static void println(char c) throws IOException {
		out.write(Character.toString(c));
		out.write("\n");
		System.out.println(c);
	}

	public static void print(char c) throws IOException {
		out.write(Character.toString(c));
		System.out.print(c);
	}

	public static void println(String line) throws IOException {
		out.write(line);
		out.write("\n");
		System.out.println(line);
	}

	public static void print(String line) throws IOException {
		out.write(line);
		System.out.print(line);
	}

	/** - READING INPUT - **/

	static String TOKEN() throws IOException {
		while (ST == null || !ST.hasMoreTokens()) {

		}
		return ST.nextToken();
	}
}

class Bot {
	public String BotName;
	public int Position;

	Bot(String C) {
		BotName = C;
		Position = 0;
	}

	public void set(int Pos, boolean b) {
		Position = Pos;
	}

	public int diff(Bot tB) {
		return Math.abs(this.Position - tB.Position);
	}

	public void Move(Bot T) {
		if (T.Position > this.Position) {
			this.Position++;
		} else if (T.Position < this.Position) {
			this.Position--;
		}
	}
}


class TestCase {
	int NoOfButtonPress;
	int Pressed = 0;
	StringTokenizer ST;
	Bot O, B, TO, TB;
	ArrayList<String> BotNames = new ArrayList<String>();
	ArrayList<Integer> BotPos = new ArrayList<Integer>();

	TestCase(StringTokenizer ST) throws IOException {
		this.ST = ST;
		NoOfButtonPress = BotTrust.INT(TOKEN(this.ST));
		O = new Bot("O");
		TO = new Bot("O");
		B = new Bot("B");
		TB = new Bot("B");
	}

	public int Solve() throws IOException {
		int TotalMoves = 0;
		GetSequence();
		int Moves = 0;
		String Name;
		for (int i = 0; i < NoOfButtonPress; i++) {
			Name = BotNames.get(i);
			setTarget(i);						//Next Targets for Bots
			
			if(Name.equalsIgnoreCase("O")){		//Identifying the Move
				Moves = O.diff(TO);
			} else {
				Moves = B.diff(TB);
			}
			
			for(int j = 0; j < Moves; j++)		//Move to Next Target
			{
				O.Move(TO);
				B.Move(TB);
				TotalMoves++;
			}
		
			TotalMoves++;						//Button Press Move			
			if(Name.equalsIgnoreCase("O")){
				B.Move(TB);
			} else {
				O.Move(TO);
			}
		}		
		return (TotalMoves-1);					//Cancelling Last Case
	}

	public void setTarget(int State) {
		for (int i = State; i < NoOfButtonPress; i++) {
			if (BotNames.get(i).equalsIgnoreCase("O")) {
				TO.set(BotPos.get(i), true);
				break;
			}
		}
		for (int i = State; i < NoOfButtonPress; i++) {
			if (BotNames.get(i).equalsIgnoreCase("B")) {
				TB.set(BotPos.get(i), true);
				break;
			}
		}
	}

	public void GetSequence() throws IOException {
		while (Pressed < NoOfButtonPress) {
			BotNames.add(TOKEN(this.ST));
			BotPos.add(BotTrust.INT(TOKEN(this.ST)));
			Pressed++;
		}
	}

	public String TOKEN(StringTokenizer ST) throws IOException {
		if (ST == null || !ST.hasMoreTokens()) {
			return null;
		}
		return ST.nextToken();
	}
}