import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Scanner;

public class A {
	
	static final String[] colors = new String[]{"R", "O", "Y", "G", "B", "V"};
	static final int numberColors = 6;
	static final String BLACK = "BLACK";
	static final String WHITE = "WHITE";
	
	static class Node {
		public String hairColour;
		public String colored = null;
		public int component = -1;
		
		public List<Node> neighbours;
		
		public Node(String colour) {
			this.hairColour = colour;
			this.neighbours = new ArrayList<>();
		}
		
		@Override
		public String toString() {
			return hairColour + " coloured in " + colored;
		}
	}
	
	public static boolean startColoring(Node source) {
		boolean isBipartite = true;
		LinkedList<Node> queue = new LinkedList<>();
		queue.addLast(source);
		source.colored = WHITE;
		//System.out.println(source);
		while (!queue.isEmpty()) {
			Node cur = queue.removeFirst();
			List<Node> neighbours = cur.neighbours;
			for (Node neigh : neighbours) {
				if (neigh.colored == null) {
					//System.out.println("cur is " + cur);
					if (cur.colored.equals(WHITE)) {
						neigh.colored = BLACK;
					} else {
						neigh.colored = WHITE;
					}
					//System.out.println(neigh);
					queue.addLast(neigh);
				} else {
					if (neigh.colored.equals(cur.colored)) {
						return false;
					}
				}
			}
		}
		
		return true;
	}
	
	public static void linkThem(List<Node> nodes) {
		int L = nodes.size();
		for (int i = 0; i < L-1; i++) {
			for (int j = i+1; j < L; j++) {
				Node u = nodes.get(i);
				Node v = nodes.get(j);
				u.neighbours.add(v);
				v.neighbours.add(u);
			}
		}
	}
	
	public static List<List<Node>> components(Collection<Node> nodes) {
		List<List<Node>> allComponents = new LinkedList<>();
		
		for (Node n : nodes) {
			if (n.component < 0) {
				List<Node> currentComponent = new LinkedList<>();
				n.component = allComponents.size();
				LinkedList<Node> queue = new LinkedList<>();
				queue.addLast(n);
				currentComponent.add(n);
				while (!queue.isEmpty()) {
					Node cur = queue.removeFirst();
					for (Node neigh : cur.neighbours) {
						if (neigh.component < 0) {
							neigh.component = cur.component;
							queue.addLast(neigh);
							currentComponent.add(neigh);
						}
					}
				}
				
				//System.out.println("component " + currentComponent);
				
				allComponents.add(currentComponent);
			}
		}
		
		return allComponents;
	}
	
	public static void main(String[] args) {
		Scanner sc = new Scanner(System.in);
		
		int T = sc.nextInt();
		
		for (int ca = 1; ca <= T; ca++) {
			Map<String, List<Node>> colorMap = new HashMap<>();
			Collection<Node> allNodes = new ArrayList<>();
			int N = sc.nextInt();
			for (String color : colors) {
				int numNodes = sc.nextInt();

				List<Node> nodes = new ArrayList<>();
				
				for (int i = 0; i < numNodes; i++) {
					nodes.add(new Node(color));
				}
				
				colorMap.put(color, nodes);
				allNodes.addAll(nodes);
			}
			
			// Build graph
			// Red an orange
			List<Node> reds = colorMap.get("R");
			List<Node> oranges = colorMap.get("O");
			List<Node> yellows = colorMap.get("Y");
			List<Node> greens = colorMap.get("G");
			List<Node> blues = colorMap.get("B");
			List<Node> violets = colorMap.get("V");
			
			linkThem(reds);
			linkThem(oranges);
			linkThem(yellows);
			linkThem(greens);
			linkThem(blues);
			linkThem(violets);
			
			for (Node r : reds) {
				for (Node v : violets) {
					r.neighbours.add(v);
					v.neighbours.add(r);
				}
				for (Node o : oranges) {
					r.neighbours.add(o);
					o.neighbours.add(r);
				}
			}
			for (Node y : yellows) {
				for (Node g: greens) {
					y.neighbours.add(g);
					g.neighbours.add(y);
				}
				for (Node o : oranges) {
					y.neighbours.add(o);
					o.neighbours.add(y);
				}
			}
			for (Node y : blues) {
				for (Node g: greens) {
					y.neighbours.add(g);
					g.neighbours.add(y);
				}
				for (Node o : violets) {
					y.neighbours.add(o);
					o.neighbours.add(y);
				}
			}
			
			//System.out.println(allNodes);
			
			// All connected components have to be colored
			boolean isBipartite = true;
			for (Node node : allNodes) {
				if (node.colored == null) {
					boolean res = startColoring(node);
					isBipartite = isBipartite & res;
				}
				
				if (!isBipartite) {
					break;
				}
			}
			
			if (!isBipartite) {
				System.out.printf("Case #%d: IMPOSSIBLE\n", ca);
			} else {
				
				List<List<Node>> comps = components(allNodes);
				String res = "";
				
				for (List<Node> comp : comps) {
					LinkedList<Node> whites = new LinkedList<>();
					LinkedList<Node> blacks = new LinkedList<>();
					
					for (Node node : comp) {
						if (node.colored.equals(BLACK)) {
							blacks.addLast(node);
						}
						else {
							whites.add(node);
						}
					}
					
					//System.out.println(whites);
					//System.out.println(blacks);
					
					if (comp.size() % 2 == 0 && !(N > comp.size()+1)) {
						isBipartite = false;
						//System.out.println("Special case");
					}
					
					int L = comp.size();
					for (int i = 0; i < L; i++) {
						if (i % 2 == 0) {
							res += whites.removeFirst().hairColour;
						} else {
							res += blacks.removeFirst().hairColour;
						}
					}
				}
				if (isBipartite) {
					System.out.printf("Case #%d: %s\n", ca, res);
				} else {
					System.out.printf("Case #%d: IMPOSSIBLE\n", ca);
				}
					
			}
		}
	}

}
