

import java.io.*;


public class Prob1 {

  final static int NONE = 10000000;     // for case of query == search engine

  private String inFile = null;         // input file name
  private String outFile = null;        // output file name

  final static boolean debug = true;

  public Prob1(String inFile, String outFile) {
    this.inFile = inFile;
    this.outFile = outFile;
  }


  /* initialze the board data
   */
  private void initBoard(int[][] board, String[] searchEngines, String[] queries) {
    int rows = queries.length;
    int cols = searchEngines.length;

    for (int i = 0; i < rows; i++) {
      for (int j = 0; j < cols; j++) {
        if (queries[i].equals(searchEngines[j]))
          board[i][j] = NONE;
        else
          board[i][j] = 0;
      }
    }
  }

  /* get the minimum value ammong data in a row of board
   */
  private int getMin(int[] rowData) {
    int n = rowData.length;
    int min = rowData[0];
    for (int i = 1; i < n; i++) {
      if (rowData[i] < min) min = rowData[i];
    }
    return min;
  }


  /* debugging purpose
   * print a row data
   */
  private void printRowData(int[] rowData) {
    if (!debug) return;

    int n = rowData.length;
    for (int i = 0; i < n; i++) {
      if (rowData[i] == NONE)
        System.out.print(" x");
      else
        System.out.print(" " + rowData[i]);
    }
    System.out.println();
  }


  private int solveACase(String[] searchEngines, String[] queries) {
    int q_count =  queries.length;
    if (q_count <= 1) return 0;

    int s_count = searchEngines.length;

    int[][] board = new int[q_count][s_count];
    initBoard(board, searchEngines, queries);

    printRowData(board[0]);

    for (int i = 1; i < q_count; i++) {
      int min = getMin(board[i-1]);

      for (int j = 0; j < s_count; j++) {
        if (board[i][j] == NONE) continue;

        if (board[i-1][j] == NONE) board[i][j] = min + 1;
        else board[i][j] = board[i-1][j];
      }
      printRowData(board[i]);
    }

    int switches = getMin(board[q_count-1]);

    return switches;
  }


  public void solveAll() {
    try {
      // open input/output files
      LineNumberReader lnr = new LineNumberReader(new FileReader(inFile));
      Writer out = new BufferedWriter(new FileWriter(outFile));

      String str = lnr.readLine();      // read cases
      int cases = Integer.parseInt(str);

      // solve the cases
      for (int i = 0; i < cases; i++) {
        str = lnr.readLine();           // read the number of search engines
        int s_count = Integer.parseInt(str);

        String[] searchEngines = new String[s_count];

        for (int j = 0; j < s_count; j++)
          searchEngines[j] = lnr.readLine();  // read a name of search engine

        str = lnr.readLine();           // read the number of queries
        int q_count = Integer.parseInt(str);

        String[] queries = new String[q_count];

        for (int j = 0; j < q_count; j++)
          queries[j] = lnr.readLine();  // read a query string

        int switches = solveACase(searchEngines, queries);

        out.write("Case #" + (i + 1) + ": " + switches + "\n");

        if (debug)
          System.out.println("Case #" + (i + 1) + ": " + switches);
      }

      lnr.close();
      out.close();
    }
    catch (Exception ex) {
      System.err.println("Exception - " + ex.getMessage());
      ex.printStackTrace();
    }
  }


  public static void main(String[] args) {
    if (args.length != 2) {
      System.err.println("Usage: java Prob1 <input file> <output file>");
      return;
    }

    Prob1 prob = new Prob1(args[0], args[1]);

    prob.solveAll();
  }
}

// end
