

import java.io.*;


public class Prob2 {

  private String inFile = null;         // input file name
  private String outFile = null;        // output file name

  final static boolean debug = true;


  public Prob2(String inFile, String outFile) {
    this.inFile = inFile;
    this.outFile = outFile;
  }

  /* convert time string to minutes from 00:00
   * if time == "12:07", then return (12*60 + 7)
   */
  private int getTimeInMin(String time) {
    try {
      String[] tmp = time.split(":");
      int hour = Integer.parseInt(tmp[0]);
      int min = Integer.parseInt(tmp[1]);

      if (debug) {
        System.out.println(time + " -> " + (hour*60 + min));
      }

      return hour*60 + min;
    }
    catch (Exception ex) {
      System.err.println("Exception - " + ex.getMessage());
      ex.printStackTrace();
    }
    return 0;
  }

  private void initTable(int[][] table, int turn_time, int[][] trip_time_A2B, int[][] trip_time_B2A) {
    int a2b = trip_time_A2B.length;
    int b2a = trip_time_B2A.length;

    int rows = table.length;
    int cols = table[0].length;

    for (int i = 0; i < rows; i++) {
      for (int j = 0; j < cols; j++) {
        table[i][j] = 0;
      }
    }

    for (int i = 0; i < a2b; i++) {
      int start = trip_time_A2B[i][0];
      int end = trip_time_A2B[i][1] + turn_time;

      table[i][start] = 1;
      table[i][end] = 2;
    }

    for (int i = 0; i < b2a; i++) {
      int start = trip_time_B2A[i][0];
      int end = trip_time_B2A[i][1] + turn_time;

      table[a2b+i][start] = 3;
      table[a2b+i][end] = 4;
    }

    /*
    for (int i = 0; i < a2b; i++) {
      int end = trip_time_A2B[i][1] + turn_time;
      for (int j = trip_time_A2B[i][0]; j < end; j++) {
        table[i][j] = 'A';
      }
    }

    for (int i = 0; i < b2a; i++) {
      int end = trip_time_B2A[i][1] + turn_time;
      for (int j = trip_time_B2A[i][0]; j < end; j++) {
        table[i][j] = 'B';
      }
    }
    */
  }

  private int[] solveACase(int turn_time, int[][] trip_time_A2B, int[][] trip_time_B2A) {
    int a2b = trip_time_A2B.length;
    int b2a = trip_time_B2A.length;

    if (a2b == 0 && b2a == 0)
      return new int[] {0, 0};

    int[][] table = new int[a2b+b2a][24*60+turn_time];

    initTable(table, turn_time, trip_time_A2B, trip_time_B2A);

    int rows = table.length;
    int cols = 24*60;

    int trainsAt_A = 0;
    int trainsAt_B = 0;
    int trainsNeed_A = 0;
    int trainsNeed_B = 0;

    for (int j = 0; j < cols; j++) {
      for (int i = 0; i < rows; i++) {
        if (table[i][j] == 2) {
          trainsAt_B++;
        }
        else if (table[i][j] == 4) {
          trainsAt_A++;
        }
      }

      for (int i = 0; i < rows; i++) {
        if (table[i][j] == 1) {
          if (trainsAt_A == 0) {
            trainsNeed_A++;
          }
          else {
            trainsAt_A--;
          }
        }
        else if (table[i][j] == 3) {
          if (trainsAt_B == 0) {
            trainsNeed_B++;
          }
          else {
            trainsAt_B--;
          }
        }
      }
      /*
      if (debug)
        System.out.println(time + " -> " + (hour*60 + min));
      */
    }
    return new int[] {trainsNeed_A, trainsNeed_B};
  }


  public void solveAll() {
    try {
      // open input/output files
      LineNumberReader lnr = new LineNumberReader(new FileReader(inFile));
      Writer out = new BufferedWriter(new FileWriter(outFile));

      String str = lnr.readLine();      // read cases
      int cases = Integer.parseInt(str);

      // solve the cases
      for (int i = 0; i < cases; i++) {
        str = lnr.readLine();           // read the turnarround time
        int turn_time = Integer.parseInt(str);

        str = lnr.readLine();           // read trip counts pair e.g. "3 4"

        String[] tmp = str.split(" ");

        int trip_count_A2B = Integer.parseInt(tmp[0]);
        int trip_count_B2A = Integer.parseInt(tmp[1]);

        // read the time table from A to B
        int[][] trip_time_A2B = new int[trip_count_A2B][2];
        for (int j = 0; j < trip_count_A2B; j++) {
          str = lnr.readLine();  // read a time table pair e.g. "09:30 11:14"
          tmp = str.split(" ");

          trip_time_A2B[j][0] = getTimeInMin(tmp[0]);
          trip_time_A2B[j][1] = getTimeInMin(tmp[1]);
        }

        // read the time table from B to A
        int[][] trip_time_B2A = new int[trip_count_B2A][2];
        for (int j = 0; j < trip_count_B2A; j++) {
          str = lnr.readLine();  // read a time table pair e.g. "09:30 11:14"
          tmp = str.split(" ");

          trip_time_B2A[j][0] = getTimeInMin(tmp[0]);
          trip_time_B2A[j][1] = getTimeInMin(tmp[1]);
        }

        int[] trains = solveACase(turn_time, trip_time_A2B, trip_time_B2A);

        String result = "Case #" + (i + 1) + ": " + trains[0] + " " + trains[1] + "\n";

        out.write(result);

        if (debug)
          System.out.print(result);
      }

      lnr.close();
      out.close();
    }
    catch (Exception ex) {
      System.err.println("Exception - " + ex.getMessage());
      ex.printStackTrace();
    }
  }


  public static void main(String[] args) {
    if (args.length != 2) {
      System.err.println("Usage: java Prob2 <input file> <output file>");
      return;
    }

    Prob2 prob = new Prob2(args[0], args[1]);

    prob.solveAll();
  }
}
