import java.io.*;


public class BooleanTree {

   private static class TreeNode {
      private int operation;
      private boolean changeable;
      private TreeNode left;
      private TreeNode right;
      private boolean value;
      private boolean isLeaf;

      TreeNode (int operation, boolean changeable) {
         this.operation = operation;
         this.changeable = changeable;
         this.isLeaf = false;
      }

      TreeNode (boolean value) {
         this.value = value;
         this.isLeaf = true;
      }

      public void setChildrens (TreeNode left, TreeNode right) {
         this.left = left;
         this.right = right;
      }
   }


   private static int readNumber (BufferedReader reader)
         throws Exception {
      String line = reader.readLine();

      if (line == null) {
         throw new Exception (
            "End of file unexpected");
      }

      return Integer.parseInt(line.trim());
   }

   private static String readString (BufferedReader reader)
         throws Exception {
      String line = reader.readLine();

      if (line == null) {
         throw new Exception (
            "End of file unexpected");
      }

      return line.trim();
   }

   public static boolean treeValue (TreeNode node) {
      if (node.isLeaf) {
         return node.value;
      } else {
         return (node.operation == 1)
            ? (treeValue (node.left) && treeValue (node.right))
            : (treeValue (node.left) || treeValue (node.right));
      }
   }

   public static int minChanges (TreeNode[] nodes, boolean rootValue, int index) {
      int numInterior = (nodes.length-1)/2;

      for ( ; index < numInterior; index++) {
         if (nodes[index].changeable) {
            break;
         }
      }

      if (index < numInterior) {
         int original = minChanges (nodes, rootValue, index+1);
         nodes[index].operation = 1 - nodes[index].operation;
         int changed = 1 + minChanges (nodes, rootValue, index+1);
         nodes[index].operation = 1 - nodes[index].operation;

         if ((original >= 0) && (changed >= 0)) {
            if (original < changed) {
               return original;
            } else {
               return changed;
            }
         } else if (original >= 0) {
            return original;
         } else if (changed >= 0) {
            return changed;
         } else {
            return Integer.MIN_VALUE;
         }
      } else {
         if (treeValue (nodes[0]) == rootValue) {
            return 0;
         } else {
            return Integer.MIN_VALUE;
         }
      }
   }

   public static void main (String[] args) {
      if (args.length == 0) {
         System.err.println ("Uso: BooleanTree <fichero>");
         return;
      }

      try {
         BufferedReader reader
            = new BufferedReader (
               new FileReader (args[0]));

         int nCases = readNumber (reader);

         for (int i = 0; i < nCases; i++) {
            String[] data = readString (reader).split (" ");

            int numNodes = Integer.parseInt (data[0]);
            boolean rootValue = (Integer.parseInt (data[1]) == 1);

            TreeNode[] nodes = new TreeNode[numNodes];

            int numInterior = (numNodes-1)/2;

            for (int j = 0; j < numInterior; j++) {
               data = readString (reader).split (" ");

               nodes[j] = new TreeNode (
                  Integer.parseInt (data[0])
                  , (Integer.parseInt (data[1]) == 1));
            }

            int numLeaf = (numNodes+1)/2;

            for (int j = 0; j < numLeaf; j++) {
               data = readString (reader).split (" ");

               nodes[numInterior+j] = new TreeNode (
                  Integer.parseInt (data[0]) == 1);
            }

            for (int j = 0; j < numInterior; j++) {
               nodes[j].setChildrens (nodes[2*j+1], nodes[2*j+2]);
            }

            int changes = minChanges (nodes, rootValue, 0);

            System.out.println ("Case #" + (i+1) + ": " +
               ((changes < 0) ? "IMPOSSIBLE" : ("" + changes)));
         }
      } catch (Exception e) {
         e.printStackTrace();
      }
   }
}
