import java.io.*;
import java.util.*;


public class TrainTimetable {
	
	private static final int DAY_MINUTES = 24*60;
	
	private static class Trip {
		private int start;
		private int stop;
		
		Trip (int start, int stop) {
			this.start = start;
			this.stop = stop;
		}
	}

	private static int readNumber (BufferedReader reader)
			throws Exception {
		String line = reader.readLine();

		if (line == null) {
			throw new Exception (
				"End of file unexpected");
		}

		return Integer.parseInt(line.trim());
	}

	private static String readString (BufferedReader reader)
			throws Exception {
		String line = reader.readLine();
		
		if (line == null) {
			throw new Exception (
				"End of file unexpected");
		}
		
		return line.trim();
	}

	private static int parseTime (String time) {
		return
			(Character.digit(time.charAt(0), 10)*10+
		     Character.digit(time.charAt(1), 10))*60 +
		    (Character.digit(time.charAt(3), 10)*10+
		     Character.digit(time.charAt(4), 10));
	}

	private static final Comparator<Trip> SORT_BY_START
		= new Comparator<Trip> () {
			public int compare(Trip t1, Trip t2) {
				return t1.start - t2.start;
			}
		};
		
	private static void sumArray (int[] array, int start, int value) {
		for (int i = start; i < array.length; i++) {
			array[i] += value;
		}
	}

	private static int[] numTrains (int turnTime, Trip[] tripsA, Trip[] tripsB) {
		int nTripsA = tripsA.length;
		int nTripsB = tripsB.length;

		Arrays.sort (tripsA, SORT_BY_START);
		Arrays.sort (tripsB, SORT_BY_START);

		int[] nTrainsA = new int[DAY_MINUTES+turnTime];
		int[] nTrainsB = new int[DAY_MINUTES+turnTime];

		Arrays.fill (nTrainsA, 0);
		Arrays.fill (nTrainsB, 0);

		int startA = 0, startB = 0;
		int tripA = 0, tripB = 0;

		while ((tripA < nTripsA) &&
			   (tripB < nTripsB)) {
			int timeA = tripsA[tripA].start;
			int timeB = tripsB[tripB].start;

			if (timeA < timeB) {
				if (nTrainsA[timeA] > 0) {
					sumArray (nTrainsA, timeA, -1);
				} else {
					startA++;
				}
				sumArray (nTrainsB, tripsA[tripA].stop+turnTime, 1);
				tripA++;

			} else {
				if (nTrainsB[timeB] > 0) {
					sumArray (nTrainsB, timeB, -1);
				} else {
					startB++;
				}
				sumArray (nTrainsA, tripsB[tripB].stop+turnTime, 1);
				tripB++;
			}
		}

		for ( ; tripA < nTripsA; tripA++) {
			int timeA = tripsA[tripA].start;

			if (nTrainsA[timeA] > 0) {
				sumArray (nTrainsA, timeA, -1);
			} else {
				startA++;
			}
		}

		for ( ; tripB < nTripsB; tripB++) {
			int timeB = tripsB[tripB].start;

			if (nTrainsB[timeB] > 0) {
				sumArray (nTrainsB, timeB, -1);
			} else {
				startB++;
			}
		}
		
		int[] starts = {startA, startB};
		
		return starts;
	}
	
	public static void main(String[] args) {
		if (args.length == 0) {
			System.err.println ("Uso: TrainTimetable <fichero>");
			return;
		}
		
		try {
			BufferedReader reader
				= new BufferedReader (
					new FileReader (args[0]));
			
			int nCases = readNumber (reader);

			for (int i = 0; i < nCases; i++) {
				int turnTime = readNumber (reader);

				String[] nTripsAB = readString (reader).split(" ");

				int nTripsA = Integer.parseInt(nTripsAB[0]);
				int nTripsB = Integer.parseInt(nTripsAB[1]);

				Trip[] tripsA = new Trip[nTripsA];
				Trip[] tripsB = new Trip[nTripsB];

				for (int j = 0; j < nTripsA; j++) {
					String[] times = readString (reader).split(" ");

					tripsA[j] = new Trip (
						parseTime (times[0]), parseTime (times[1]));
				}

				for (int j = 0; j < nTripsB; j++) {
					String[] times = readString (reader).split(" ");

					tripsB[j] = new Trip (
						parseTime (times[0]), parseTime (times[1]));
				}

				int[] nTrains = numTrains (turnTime, tripsA, tripsB);

				System.out.println ("Case #" + (i+1) + ": " +
					nTrains[0] + " " + nTrains[1]);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
