import java.io.*;


public class SavingUniverse {

	private static int readNumber (BufferedReader reader)
			throws Exception {
		String line = reader.readLine();

		if (line == null) {
			throw new Exception (
				"End of file unexpected");
		}

		return Integer.parseInt(line.trim());
	}

	private static String readString (BufferedReader reader)
			throws Exception {
		String line = reader.readLine();
		
		if (line == null) {
			throw new Exception (
				"End of file unexpected");
		}
		
		return line.trim();
	}

	private static int arrayIndex (String[] strs, int begin, String str) {
		int nStrs = strs.length;

		if (begin >= nStrs) {
			throw new IllegalArgumentException (
				"Index out of range");
		}

		for (int i = begin; i < nStrs; i++) {
			if (str.equals (strs[i])){
				return i;
			}
		}

		return nStrs;
	}

	private static int arrayMax (int[] numbers) {
		int nNumbers = numbers.length;
		
		if (nNumbers == 0) {
			throw new IllegalArgumentException (
				"Array is empty");
		}
		
		int max = numbers[0];
		
		for (int i = 1; i < nNumbers; i++) {
			if (max < numbers[i]) {
				max = numbers[i];
			}
		}
		
		return max;
	}

	private static int minEngineSwitches (String[] engines, String[] queries) {
		int nEngines = engines.length;
		int nQueries = queries.length;

		if (nQueries == 0) {
			return 0;
		}

		int nSwitches = 0;
		int posQueries = 0;

		for ( ; ; ) {
			int[] distances = new int[nEngines];

			for (int i = 0; i < nEngines; i++) {
				distances[i] = arrayIndex (queries, posQueries, engines[i]);
			}

			posQueries = arrayMax (distances);

			if (posQueries == nQueries) {
				break;
			}

			nSwitches++;
		}

		return nSwitches;
	}

	public static void main(String[] args) {
		if (args.length == 0) {
			System.err.println ("Uso: SavingUniverse <fichero>");
			return;
		}
		
		try {
			BufferedReader reader
				= new BufferedReader (
					new FileReader (args[0]));
			
			int nCases = readNumber (reader);

			for (int i = 0; i < nCases; i++) {
				int nEngines = readNumber (reader);
				
				String[] engines = new String[nEngines];
				
				for (int j = 0; j < nEngines; j++) {
					engines[j] = readString (reader);
				}

				int nQueries = readNumber (reader);
				
				String[] queries = new String[nQueries];
				
				for (int j = 0; j < nQueries; j++) {
					queries[j] = readString (reader);
				}
				
				System.out.println ("Case #" + (i+1) + ": " +
					minEngineSwitches (engines, queries));
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
