import java.io.*;
import java.text.*;


public class FlySwatter {

	private static int readNumber (BufferedReader reader)
			throws Exception {
		String line = reader.readLine();
		
		if (line == null) {
			throw new Exception (
				"End of file unexpected");
		}
		
		return Integer.parseInt(line.trim());
	}

	private static String readString (BufferedReader reader)
			throws Exception {
		String line = reader.readLine();
		
		if (line == null) {
			throw new Exception (
				"End of file unexpected");
		}
		
		return line.trim();
	}

	private static double freeAreaHoriz (
			double f, double R, double r, double g, double h, double y) {
		double freeArea = 0;

		double rLong = Math.sqrt(R*R - y*y);
		double rShort = Math.sqrt(R*R - (y+h)*(y+h));

		double x = r + f;

		while ((x+h) <= rShort) {
			freeArea += h*h;
			x += 2*r + g;
		}

		double diffLong = rLong - x;
		double diffShort = rShort - x;

		if (diffShort <= 0) {
			if (diffLong <= 0) {
				return freeArea;
			}
		} else {
			if (diffLong <= h) {
				double diffLS = rLong - rShort;
				double ropeLength = Math.sqrt (diffLS*diffLS + h*h);
				double angleSector = 2*Math.asin((ropeLength/2)/R);
				double trianHeight = Math.sqrt(R*R - (ropeLength/2)*(ropeLength/2));
	
				freeArea += h*diffShort;
				freeArea += (h*diffLS)/2;
				freeArea += (angleSector*R*R)/2;
				freeArea -= (ropeLength*trianHeight)/2;
	
				return freeArea;
				
			} else {
				double diffXS = (x+h) - rShort;
				double rectHeight = Math.sqrt(R*R - (x+h)*(x+h)) - y;
				double angleSector = Math.acos (rShort/R) - Math.acos ((x+h)/R);
				double ropeLength = 2*R*Math.sin(angleSector/2);
				double ropeSine = Math.sqrt (ropeLength*ropeLength - diffXS*diffXS);
				double trianHeight = Math.sqrt(R*R - (ropeLength/2)*(ropeLength/2));
	
				freeArea += h*diffShort;
				freeArea += rectHeight*diffXS;
				freeArea += (diffXS*ropeSine)/2;
				freeArea += (angleSector*R*R)/2;
				freeArea -= (ropeLength*trianHeight)/2;
				
				x += 2*r + g;
			}
		}

		while ((x+h) <= rLong) {
			double rectHeight = Math.sqrt(R*R - (x+h)*(x+h)) - y;
			double angleSector = Math.acos (x/R) - Math.acos ((x+h)/R);
			double ropeLength = 2*R*Math.sin(angleSector/2);
			double ropeSine = Math.sqrt (ropeLength*ropeLength - h*h);
			double trianHeight = Math.sqrt(R*R - (ropeLength/2)*(ropeLength/2));

			freeArea += h*rectHeight;
			freeArea += (h*ropeSine)/2;
			freeArea += (angleSector*R*R)/2;
			freeArea -= (ropeLength*trianHeight)/2;
			
			x += 2*r + g;
		}

		diffLong = rLong - x;

		if (diffLong > 0) {
			double angleSector = Math.acos (x/R) - Math.acos (rLong/R);
			double ropeLength = 2*R*Math.sin(angleSector/2);
			double ropeCosine = Math.sqrt (ropeLength*ropeLength - diffLong*diffLong);
			double trianHeight = Math.sqrt(R*R - (ropeLength/2)*(ropeLength/2));

			freeArea += (ropeCosine*diffLong)/2;
			freeArea += (angleSector*R*R)/2;
			freeArea -= (ropeLength*trianHeight)/2;
		}

		return freeArea;
	}
	
	private static double freeAreaLast (
			double f, double R, double r, double g, double h, double y) {
		double freeArea = 0;
		
		double rLong = Math.sqrt(R*R - y*y);

		double x = r + f;

		while ((x+h) <= rLong) {
			double rectHeight = Math.sqrt(R*R - (x+h)*(x+h)) - y;
			double angleSector = Math.acos (x/R) - Math.acos ((x+h)/R);
			double ropeLength = 2*R*Math.sin(angleSector/2);
			double ropeSine = Math.sqrt (ropeLength*ropeLength - h*h);
			double trianHeight = Math.sqrt(R*R - (ropeLength/2)*(ropeLength/2));

			freeArea += h*rectHeight;
			freeArea += (h*ropeSine)/2;
			freeArea += (angleSector*R*R)/2;
			freeArea -= (ropeLength*trianHeight)/2;
			
			x += 2*r + g;
		}

		double diffLong = rLong - x;

		if (diffLong > 0) {
			double angleSector = Math.acos (x/R) - Math.acos (rLong/R);
			double ropeLength = 2*R*Math.sin(angleSector/2);
			double ropeCosine = Math.sqrt (ropeLength*ropeLength - diffLong*diffLong);
			double trianHeight = Math.sqrt(R*R - (ropeLength/2)*(ropeLength/2));

			freeArea += (ropeCosine*diffLong)/2;
			freeArea += (angleSector*R*R)/2;
			freeArea -= (ropeLength*trianHeight)/2;
		}

		return freeArea;
	}

	private static double freeAreaVert (
			double f, double R, double r, double g) {
		double freeArea = 0;

		double h = g - 2*f;
		double y = r + f;

		while ((y+h) <= R) {
			freeArea += freeAreaHoriz (f, R, r, g, h, y);
			y += 2*r + g;
		}
		
		if (y < R) {
			freeArea += freeAreaLast (f, R, r, g, h, y);
		}
		
		return freeArea;
	}

	private static double hitProbability (
			double f, double R, double t, double r, double g) {
		if (2*f >= g) {
			return 1.0;
		}

		double total = Math.PI*R*R;
		double free = 4*freeAreaVert (f, R-t-f, r, g);

		return (total-free)/total;
	}

	public static void main(String[] args) {
		if (args.length == 0) {
			System.err.println ("Uso: FlySwatter <fichero>");
			return;
		}
		
		try {
			BufferedReader reader
				= new BufferedReader (
					new FileReader (args[0]));

			int nCases = readNumber (reader);

			DecimalFormatSymbols dnf = new DecimalFormatSymbols ();
			dnf.setDecimalSeparator('.');

			DecimalFormat df = new DecimalFormat ("0.000000", dnf);

			for (int i = 0; i < nCases; i++) {
				String[] data = readString (reader).split(" ");

				double f = Double.parseDouble(data[0]);
				double R = Double.parseDouble(data[1]);
				double t = Double.parseDouble(data[2]);
				double r = Double.parseDouble(data[3]);
				double g = Double.parseDouble(data[4]);

				System.out.println ("Case #" + (i+1) + ": " +
					df.format (hitProbability (f, R, t, r, g)));
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
