package net.ujjwal.google.codejam.round1c;

import java.math.BigInteger;
import java.util.Scanner;


public class ChessBoards
{
    private class Square
    {
        boolean colour;
        boolean cut;
    }
    private final int  I;
    private int        m;
    private int        n;
    private Square[][] bark;

    public ChessBoards(Scanner in, int i)
    {
        this.I = i;
        this.m = in.nextInt();
        this.n = in.nextInt();
        in.nextLine();
        bark = new Square[m][n];
        for (int j = 0; j < m; ++j)
        {
            String line = in.nextLine();
            BigInteger integer = new BigInteger(line, 16);
            for (int k = 1; k <= n; ++k)
            {
                boolean set = integer.testBit(n - k);
                bark[j][k - 1] = new Square();
                bark[j][k - 1].colour = set;
                bark[j][k - 1].cut = false;
            }
        }
    }

    public static void main(String[] args)
    {
        Scanner in = new Scanner(System.in);
        int t = in.nextInt();
        for (int i = 1; i <= t; ++i)
        {
            ChessBoards boards = new ChessBoards(in, i);
            boards.solve();
        }
    }

    private void solve()
    {
        int maxSize = Math.min(m, n);
        int[] numSquares = new int[maxSize];
        // cut squares etc.
        for (int x = maxSize; x > 1; --x)
        {
            for (int i = 0; i < m; ++i)
            {
                if (i + x > m)
                    break; // no more looking in this column for this size
                for (int j = 0; j < n; ++j)
                {
                    if (j + x > n)
                        break; // no more looking in this row.
                    if (isChessBoard(i, j, x))
                    {
                        ++(numSquares[x - 1]);
                        cutChessBoard(i, j, x);
                    }
                }
            }
        }
        // count the singles
        for (int i = 0; i < m; ++i)
        {
            for (int j = 0; j < n; ++j)
            {
                if (!bark[i][j].cut)
                {
                    ++numSquares[0];
                    bark[i][j].cut = true;
                }
            }
        }
        // Count and output
        int numSizes = 0;
        for (int x : numSquares)
        {
            if (x > 0)
                ++numSizes;
        }
        System.out.printf("Case #%d: %d%n", I, numSizes);
        for (int j = maxSize - 1; j >= 0; --j)
        {
            if (numSquares[j] > 0)
            {
                System.out.printf("%d %d%n", j + 1, numSquares[j]);
            }
        }
    }

    private void cutChessBoard(int x, int y, int size)
    {
        for (int i = x; i < x + size; ++i)
        {
            for (int j = y; j < y + size; ++j)
            {
                bark[i][j].cut = true;
            }
        }
    }

    /**
     * Is there a chessboard of size size starting from x, y
     */
    private boolean isChessBoard(int x, int y, int size)
    {
        boolean start = bark[x][y].colour;
        boolean startRow = start;
        for (int i = x; i < x + size; ++i)
        {
            boolean test = startRow;
            for (int j = y; j < y + size; ++j)
            {
                if (bark[i][j].cut || bark[i][j].colour != test)
                    return false;
                test = !test;
            }
            startRow = !startRow;
        }
        return true;
    }
}
