package net.ujjwal.google.codejam.round2;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;


public class Bacteria
{

    public class Range
    {
        int x1, y1, x2, y2;

        public Range(int x1, int y1, int x2, int y2)
        {
            this.x1 = x1;
            this.y1 = y1;
            this.x2 = x2;
            this.y2 = y2;
        }

        /* (non-Javadoc)
         * @see java.lang.Object#toString()
         */
        @Override
        public String toString()
        {
            return String.format("%s %s %s %s%n", x1, x2, y1, y2);
        }

    }

    private List<BigInteger> grid;
    private int              xR;
    private int              yR;

    public Bacteria(Scanner in)
    {
        int r = in.nextInt();
        List<Range> ranges = new ArrayList<Range>();
        int minX = 1000001, maxX = 0;
        int minY = 1000001, maxY = 0;
        for (int i = 0; i < r; ++i)
        {
            int x1, y1, x2, y2;
            x1 = in.nextInt();
            y1 = in.nextInt();
            x2 = in.nextInt();
            y2 = in.nextInt();
            if (x1 < minX)
            {
                minX = x1;
            }
            if (x2 > maxX)
            {
                maxX = x2;
            }
            if (y1 < minY)
            {
                minY = y1;
            }
            if (y2 > maxY)
            {
                maxY = y2;
            }
            Range range = new Range(x1, y1, x2, y2);
            ranges.add(range);
        }
        xR = (maxX - minX) + 1;
        yR = (maxY - minY) + 1;
        this.grid = new ArrayList<BigInteger>(yR);
        for (int i = 0; i < yR; ++i)
        {
            this.grid.add(BigInteger.ZERO);
        }
        for (Range range : ranges)
        {
            int x1 = range.x1 - minX;
            int y1 = range.y1 - minY;
            int x2 = range.x2 - minX;
            int y2 = range.y2 - minY;
            for (int i = y1; i <= y2; ++i)
            {
                BigInteger value = grid.get(i);
                for (int j = x1; j <= x2; ++j)
                {
                    value = value.setBit(j);
                }
                grid.set(i, value);
            }
        }
    }

    /**
     * @param args
     */
    public static void main(String[] args)
    {
        Scanner in = new Scanner(System.in);
        int c = in.nextInt();
        for (int i = 1; i <= c; ++i)
        {
            Bacteria bacteria = new Bacteria(in);
            System.out.printf("Case #%d: %d%n", i, bacteria.getLife());
        }
    }

    private int getLife()
    {
        int secs = 0;
        while (countBacteria() > 0)
        {
            ++secs;
            evaluateSecond();
        }
        return secs;
    }

    private void evaluateSecond()
    {
        for (int i = yR - 1; i >= 0; --i)
        {
            for (int j = xR - 1; j >= 0; --j)
            {
                if (testBit(i, j))
                {
                    if (!testBit(i - 1, j) && !testBit(i, j - 1))
                    {
                        clearBit(i, j);
                    }
                }
                else
                {
                    if (testBit(i - 1, j) && testBit(i, j - 1))
                    {
                        setBit(i, j);
                    }
                }
            }
        }
    }

    private boolean testBit(int i, int j)
    {
        if (i < 0 || j < 0)
        {
            return false; // off the grid;
        }
        return grid.get(i).testBit(j);
    }

    private void setBit(int i, int j)
    {
        BigInteger row = grid.get(i);
        row = row.setBit(j);
        grid.set(i, row);
    }

    private void clearBit(int i, int j)
    {
        BigInteger row = grid.get(i);
        row = row.clearBit(j);
        grid.set(i, row);
    }

    private int countBacteria()
    {
        int count = 0;
        for (BigInteger integer : grid)
        {
            count += integer.bitCount();
        }
        return count;
    }

}
