package net.ujjwal.google.codejam.quals;

import java.io.PrintStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class Watersheds {

    /**
     * @param args
     */
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        int t = Integer.parseInt(scanner.nextLine());
        for (int i = 0; i < t; ++i) {
            int h = scanner.nextInt();
            int w = scanner.nextInt();
            Grid grid = new Grid(h, w);
            grid.readAltitudes(scanner);
            grid.labelBasins();
            System.out.printf("Case #%d:%n", i + 1);
            grid.printBasins(System.out);

        }
    }

}

enum FlowDirection {
    NORTH, WEST, EAST, SOUTH, SINK;
}

class Cell {

    public Cell(int alt, int x, int y) {
        this.altitude = alt;
        this.x = x;
        this.y = y;
    }

    final int     x;
    final int     y;
    int           altitude;
    FlowDirection flowDirection;
    Character     basin;
}

class Grid {
    public Grid(int h, int w) {
        this.h = h;
        this.w = w;
        cells = new ArrayList<List<Cell>>();
        for (int i = 0; i < h; ++i) {
            cells.add(new ArrayList<Cell>());
        }
    }

    public void printBasins(PrintStream out) {
        for (int i = 0; i < h; ++i) {
            for (int j = 0; j < w; ++j) {
                System.out.print(cells.get(i).get(j).basin + " ");
            }
            System.out.println();
        }

    }

    public void labelBasins() {
        evaluateFlowDirections();
        for (int i = 0; i < h; ++i) {
            for (int j = 0; j < w; ++j) {
                evaluateBasin(i, j);
            }
        }
    }

    private void evaluateBasin(int i, int j) {
        Cell cell = getCell(i, j);
        if (cell.basin != null) {
            return;
        }
        FlowDirection flowDirection = cell.flowDirection;
        if (flowDirection == FlowDirection.SINK) {
            cell.basin = nextBasin;
            nextBasin++;
        } else {
            Cell flowCell = getCell(i, j, flowDirection);
            evaluateBasin(flowCell.x, flowCell.y);
            cell.basin = flowCell.basin;
        }
    }

    private void evaluateFlowDirections() {
        for (int i = 0; i < h; ++i) {
            for (int j = 0; j < w; ++j) {
                Cell cell = getCell(i, j);
                Cell nCell = getCell(i, j, FlowDirection.NORTH);
                Cell wCell = getCell(i, j, FlowDirection.WEST);
                Cell eCell = getCell(i, j, FlowDirection.EAST);
                Cell sCell = getCell(i, j, FlowDirection.SOUTH);
                FlowDirection direction = FlowDirection.SINK;
                int lowestAltitude = cell.altitude;
                if (nCell != null && nCell.altitude < lowestAltitude) {
                    direction = FlowDirection.NORTH;
                    lowestAltitude = nCell.altitude;
                }
                if (wCell != null && wCell.altitude < lowestAltitude) {
                    direction = FlowDirection.WEST;
                    lowestAltitude = wCell.altitude;
                }
                if (eCell != null && eCell.altitude < lowestAltitude) {
                    direction = FlowDirection.EAST;
                    lowestAltitude = eCell.altitude;
                }
                if (sCell != null && sCell.altitude < lowestAltitude) {
                    direction = FlowDirection.SOUTH;
                    lowestAltitude = sCell.altitude;
                }
                cell.flowDirection = direction;
            }
        }
    }

    private Cell getCell(int i, int j, FlowDirection direction) {
        switch (direction) {
        case NORTH:
            if (i > 0)
                return getCell(i - 1, j);
            else
                return null;
        case WEST:
            if (j > 0)
                return getCell(i, j - 1);
            else
                return null;
        case EAST:
            if (j < w - 1)
                return getCell(i, j + 1);
            else
                return null;
        case SOUTH:
            if (i < h - 1)
                return getCell(i + 1, j);
            else
                return null;
        default:
            return null;
        }
    }

    private Cell getCell(int i, int j) {
        return cells.get(i).get(j);
    }

    public void readAltitudes(Scanner scanner) {
        for (int i = 0; i < h; ++i) {
            for (int j = 0; j < w; ++j) {
                cells.get(i).add(new Cell(scanner.nextInt(), i, j));
            }
        }
    }

    List<List<Cell>> cells;
    int              h;
    int              w;
    char             nextBasin = 'a';

}
