package net.ujjwal.google.codejam.quals;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.HashMap;
import java.util.Map;
import java.util.Scanner;

public class WelcomeToCodeJam {

    private static final String                 SEARCH_STRING = "welcome to code jam";
    private final int                           caseNumber;
    private final String                        line;
    private int                                 count;
    private Map<Integer, Map<Integer, Integer>> resultCache;

    public WelcomeToCodeJam(int caseNumber, String line) {
        this.caseNumber = caseNumber;
        this.line = line;
        this.resultCache = new HashMap<Integer, Map<Integer, Integer>>();
    }

    /**
     * @param args
     */
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        int n = Integer.parseInt(scanner.nextLine());
        for (int i = 0; i < n; ++i) {
            String nextLine = scanner.nextLine();
            WelcomeToCodeJam jam = new WelcomeToCodeJam(i + 1, nextLine);
            System.out.println(jam.output());
        }
    }

    private String output() {
        evaluate();
        StringWriter stringWriter = new StringWriter();
        PrintWriter writer = new PrintWriter(stringWriter);
        writer.printf("Case #%d: %04d", caseNumber, count);
        return stringWriter.toString();
    }

    private void evaluate() {
        this.count = 0;
        count = evaluate(0, 0);
        count %= 10000;
    }

    private int evaluate(int searchStringIndex, int currentStringIndex) {
        if (cacheContains(searchStringIndex, currentStringIndex)) {
            return readCache(searchStringIndex, currentStringIndex);
        }
        int returnValue = -1;
        if (currentStringIndex == line.length()) {
            returnValue = 0;
        } else if (searchStringIndex == SEARCH_STRING.length()) {
            returnValue = 0;
        } else if (searchStringIndex == SEARCH_STRING.length() - 1) {
            char searchCharacter = SEARCH_STRING.charAt(searchStringIndex);
            int moreCharOccurrences = evaluate(searchStringIndex,
                    currentStringIndex + 1);
            returnValue = moreCharOccurrences;
            if (line.charAt(currentStringIndex) == searchCharacter) {
                returnValue += 1;
            }
        } else {
            char searchCharacter = SEARCH_STRING.charAt(searchStringIndex);
            char currCharacter = line.charAt(currentStringIndex);
            int moreSubStringOccurrences = evaluate(searchStringIndex, currentStringIndex+1);
            returnValue = moreSubStringOccurrences;
            if(currCharacter == searchCharacter) {
                int moreLaterStringOcurrences = evaluate(searchStringIndex + 1, currentStringIndex + 1);
                returnValue += moreLaterStringOcurrences;
            }
        }
        putCache(searchStringIndex, currentStringIndex, returnValue);
        return returnValue;
    }

    private int readCache(int searchStringIndex, int currentStringIndex) {
        return resultCache.get(searchStringIndex).get(currentStringIndex);
    }

    private boolean cacheContains(int searchStringIndex, int currentStringIndex) {
        return resultCache.containsKey(searchStringIndex)
                && resultCache.get(searchStringIndex).containsKey(
                        currentStringIndex);
    }

    private void putCache(int searchStringIndex, int currentStringIndex,
            int returnValue) {
        if (!resultCache.containsKey(searchStringIndex)) {
            resultCache.put(searchStringIndex, new HashMap<Integer, Integer>());
        }
        resultCache.get(searchStringIndex).put(currentStringIndex, returnValue % 10000);
    }

}
