package net.ujjwal.codejam.gcj14.round1b;

import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class TheBoredTravellingSalesman implements Callable<String> {

	public static void main(String[] args) throws InterruptedException,
			ExecutionException {
		Scanner in = new Scanner(System.in);
		int t = in.nextInt();
		List<Future<String>> futures = new ArrayList<Future<String>>();
		ExecutorService executorService = Executors.newCachedThreadPool();
		for (int i = 0; i < t; ++i) {
			TheBoredTravellingSalesman salesman = new TheBoredTravellingSalesman();
			salesman.readInput(in);
			futures.add(executorService.submit(salesman));
		}

		for (int i = 0; i < t; ++i) {
			System.out.printf("Case #%d: %s%n", i + 1, futures.get(i).get());
		}

		executorService.shutdown();
		executorService.shutdownNow();
	}

	private int n; // number of cities
	private int m; // number of bidi flights (i.e. edges)
	private List<Integer> zipCodes = new ArrayList<Integer>();
	boolean[][] flights;
	private List<Integer> visitOrder;

	private void readInput(Scanner in) {
		this.n = in.nextInt();
		this.m = in.nextInt();
		for (int i = 0; i < n; ++i) {
			zipCodes.add(in.nextInt());
		}
		flights = new boolean[n][n];
		for (int i = 0; i < m; ++i) {
			int a = in.nextInt();
			int b = in.nextInt();
			flights[a - 1][b - 1] = flights[b - 1][a - 1] = true;
		}
	}

	@Override
	public String call() throws Exception {
		visitOrder = new ArrayList<Integer>();
		int current = -1;
		while (visitOrder.size() != n) {
			int next = findNext(current);
			if (next == -1) {
				// no more flights out of current.
				int cIndex = visitOrder.indexOf(current);
				current = visitOrder.get(cIndex - 1); // nothing gets added to visitOrder, and we backtrack to previous city.
			} else {
				visitOrder.add(next);
				current = next;
			}
		}

		StringBuilder builder = new StringBuilder();
		for (int i = 0; i < visitOrder.size(); ++i) {
			builder.append(zipCodes.get(visitOrder.get(i)));
		}
		return builder.toString();
	}

	private int findNext(int current) {
		int minZipcode = Integer.MAX_VALUE;
		int next = -1;
		for (int i = 0; i < n; ++i) {
			int zipCode = zipCodes.get(i);
			if (zipCode < minZipcode && !visitOrder.contains(i)) {
				if (current == -1 || flights[current][i]) {
					minZipcode = zipCode;
					next = i;
				}
			}
		}
		return next;
	}

}
