import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.*;

public class SolverA {

    private static final String fileName = "A-large-0";
    private Writer out;
    private Scanner in;
    private String chars;
    private int charsPos;
    private int T;
    private int case_;

    public static void main(String[] args) throws IOException {
        new SolverA().solve();
    }

    public void solve() throws IOException {
        in = new Scanner(new File(fileName + ".in"));
        out = new FileWriter(fileName + ".out");
        T = in.nextInt();

        int lastProgress = 0;
        for (case_ = 0; case_ < T; case_++) {
            int progress = case_ * 100 / T;
            if (progress > lastProgress) {
                System.out.println(progress + "%, " + case_ + "/" + T);
                lastProgress = progress;
            }

            long N = in.nextInt();
            short M = in.nextShort();
            List<Event> events = new ArrayList<Event>(M * 2);
            for (short m = 0; m < M; m++) {
                int o = in.nextInt();
                int e = in.nextInt();
                int p = in.nextInt();
                events.add(new Event(EventType.IN, o, e, p));
                events.add(new Event(EventType.OUT, o, e, p));
            }
            Collections.sort(events);

            long loss = 0;
            Stack<Ticket> tickets = new Stack<Ticket>();
            for (Event e : events) {
                if (e.type == EventType.IN) {
                    tickets.push(new Ticket(e.from, e.to, e.count));
                    continue;
                }
                int r = e.count;
                while (r > 0) {
                    Ticket t = tickets.peek();
                    int p = Math.min(r, t.count);
                    t.count -= p;
                    r -= p;
                    if (t.count == 0) {
                        tickets.pop();
                    }

                    long d = t.to - t.from;
                    long loss2 = 0;
                    if (d != 0) {
                        loss2 = d * N - d * (d + 1) / 2;
                    }
                    d = e.to - t.from;
                    if (d != 0) {
                        loss2 -= d * N - d * (d + 1) / 2;
                    }
                    loss = (loss + loss2 * p) % 1000002013;
                }
            }
            loss = (loss + 1000002013) % 1000002013;
            result(String.valueOf(loss));
        }
        out.close();
    }

    private void result(String res) throws IOException {
        out.write("Case #" + (case_ + 1) + ": " + res + "\n");
    }

    private char nextChar() {
        if (chars == null) {
            chars = in.next();
            charsPos = 0;
        } else {
            charsPos++;
        }
        return chars.charAt(charsPos);

    }

    private void endChars() {
        if (chars.length() > charsPos + 1) {
            throw new RuntimeException("String wasn't read fully: " + chars + ", pos: " + charsPos);
        }
        chars = null;
    }

    public static class Event implements Comparable<Event> {
        public final EventType type;
        public final int from;
        public final int to;
        public final int count;
        public final int station;

        public Event(EventType type, int from, int to, int count) {
            this.type = type;
            this.from = from;
            this.to = to;
            this.count = count;
            station = type == EventType.IN ? from : to;
        }

        @Override
        public String toString() {
            return "Event{" +
                    "type=" + type +
                    ", from=" + from +
                    ", to=" + to +
                    ", count=" + count +
                    ", station=" + station +
                    '}';
        }

        @Override
        public int compareTo(Event event) {
            if (station != event.station) {
                return station - event.station;
            }
            if (type == event.type) {
                return 0;
            }
            return type == EventType.IN ? -1 : 1;
        }
    }

    public static class Ticket {
        public final int from;
        public final int to;
        public int count;

        public Ticket(int from, int to, int count) {
            this.from = from;
            this.to = to;
            this.count = count;
        }

        @Override
        public String toString() {
            return "Ticket{" +
                    "from=" + from +
                    ", to=" + to +
                    ", count=" + count +
                    '}';
        }
    }

    public static enum EventType {
        IN, OUT
    }
}
