package challenge2017;

import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Iterator;
import java.util.List;
import java.util.PriorityQueue;

/**
 *
 * @author Bruno
 */
public class BathroomStalls {
    
    private static String directory = "data/challenge2017";
    private static String fileName = "C-small-2-attempt0";
    private static String inputFile = fileName + ".in";
    private static String outputFile = fileName + ".out";

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws IOException {
        Path path = Paths.get(directory, inputFile);
        List<String> lines = Files.readAllLines(path);
        PrintWriter out = new PrintWriter(new FileWriter(Paths.get(directory, outputFile).toString()));
        Iterator<String> it = lines.iterator();
        int numTests = Integer.parseInt(it.next());
        for (int i = 1; i <= numTests; ++i) {
            out.printf("Case #%d: %s%n", i, solve(it.next()));
        }
        out.close();
    }

    public static String solve(String line) {
        String[] tokens = line.split(" ");
        int n = Integer.parseInt(tokens[0]);
        int k = Integer.parseInt(tokens[1]);
        PriorityQueue<Interval> pq = new PriorityQueue<>();
        int start = 0;
        int end = n + 1;
        pq.add(new Interval(start, end));
        int middle = 0;
        for (int i = 0; i < k; ++i) {
            Interval interval = pq.remove();
            start = interval.getStart();
            end = interval.getEnd();
            middle = (start + end) >>> 1;
            pq.add(new Interval(start, middle));
            pq.add(new Interval(middle, end));
        }
        int left = middle - start - 1;
        int right = end - middle - 1;
        return Math.max(left, right) + " " + Math.min(left, right);
    }

}

class Interval implements Comparable<Interval> {
    
    private final int start;
    private final int end;

    public Interval(int start, int end) {
        this.start = start;
        this.end = end;
    }

    public int getStart() {
        return start;
    }

    public int getEnd() {
        return end;
    }

    @Override
    public int compareTo(Interval that) {
        int span1 = this.end - this.start;
        int span2 = that.end - that.start;
        if (span1 > span2) {
            return -1;
        }
        if (span1 < span2) {
            return 1;
        }
        return Integer.compare(this.start, that.start);
    }
    
}