package sandbox;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author rstoski
 */
public class Watersheds {
    public static void main(String[] args) {
        try {
            BufferedWriter writer = new BufferedWriter(new FileWriter("C:/output.txt"));
            BufferedReader reader = new BufferedReader(new FileReader("C:/B-small-attempt1.in"));
            int numMaps = Integer.parseInt(reader.readLine());
            for (int map = 0; map < numMaps; ++map) {
                processMap(map + 1, reader, writer);
            }
            writer.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private static void processMap(int mapNum, BufferedReader reader, BufferedWriter writer) throws Exception {
        String[] params = reader.readLine().split(" ");
        int H = Integer.parseInt(params[0]);
        int W = Integer.parseInt(params[1]);
        Cell[][] map = new Cell[H][W];

        // Build map
        for (int height = 0; height < H; ++height) {
            String[] row = reader.readLine().split(" ");
            for (int width = 0; width < W; ++width) {
                map[height][width] = new Cell(Integer.parseInt(row[width]), width, height);
            }
        }

        for (int height = 0; height < H; ++height) {
            for (int width = 0; width < W; ++width) {
                Cell cell = map[height][width];
                Cell lowestCell = null;
                int lowestNeighbor = cell.altitude;
                if (height > 0) {
                    if (map[height-1][width].altitude < lowestNeighbor) {
                        lowestNeighbor = map[height-1][width].altitude;
                        lowestCell = map[height-1][width];
                    }
                }
                if (width > 0) {
                    if (map[height][width-1].altitude < lowestNeighbor) {
                        lowestNeighbor = map[height][width-1].altitude;
                        lowestCell = map[height][width-1];
                    }
                }
                if (width < W - 1) {
                    if (map[height][width+1].altitude < lowestNeighbor) {
                        lowestNeighbor = map[height][width+1].altitude;
                        lowestCell = map[height][width+1];
                    }
                }
                if (height < H - 1) {
                    if (map[height+1][width].altitude < lowestNeighbor) {
                        lowestNeighbor = map[height+1][width].altitude;
                        lowestCell = map[height+1][width];
                    }
                }

                // cell flows to neighbor
                if (lowestNeighbor < cell.altitude) {
                    Basin neighborBasin = lowestCell.basin;
                    Basin cellBasin = cell.basin;
                    if (neighborBasin.size() < cellBasin.size()) {
                        cellBasin.addAll(neighborBasin);
                        for (Cell basinCell : neighborBasin) {
                            basinCell.basin = cellBasin;
                        }
                    } else {
                        neighborBasin.addAll(cellBasin);
                        for (Cell basinCell : cellBasin) {
                            basinCell.basin = neighborBasin;
                        }
                    }
                }
            }
        }

        List basins = new ArrayList();
        StringBuffer buffer = new StringBuffer();
            buffer.append("Case #");
            buffer.append(mapNum);
            buffer.append(":\n");
        for (int height = 0; height < H; ++height) {
            for (int width = 0; width < W; ++width) {
                Cell cell = map[height][width];
                if (!basins.contains(cell.basin.id)) {
                    basins.add(cell.basin.id);
                }
                buffer.append((char)(basins.indexOf(cell.basin.id) + 97));
                buffer.append(' ');
            }
            buffer.append('\n');
        }
        writer.write(buffer.toString());
    }

    public static class Cell {
        public Basin basin = new Basin();
        public int altitude = 0;
        public int width = 0;
        public int height = 0;

        public Cell(int altitude, int width, int height) {
            this.altitude = altitude;
            this.width = width;
            this.height = height;
            basin.add(this);
        }
    }

    public static class Basin extends ArrayList<Cell> {
        private static int seq = 0;
        public int id;

        public Basin() {
            id = seq++;
        }

        @Override
        public int hashCode() {
            return id;
        }

        @Override
        public boolean equals(Object obj) {
            if (obj == null || !(obj instanceof Basin)) {
                return false;
            }

            return ((Basin)obj).id == id;
        }
    }
}