package bacalhau;

import java.awt.Point;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.Set;

public class Watersheds {
    static class Node {
        Point value;
        Set<Node> neighbors;

        public Node(Point value) {
            this.value = value;
            neighbors  = new HashSet<Node>();
        }
    }

    static Map<Point, Node> graph = null;

    static class Direction implements Comparable<Direction> {
        public static final int NORTH = 0;
        public static final int WEST  = 1;
        public static final int EAST  = 2;
        public static final int SOUTH = 3;

        Point point;
        Point pointToFlow;
        int height;
        int direction;

        public Direction(Point point, Point pointToFlow, int height, int direction) {
            this.point = point;
            this.pointToFlow = pointToFlow;
            this.height = height;
            this.direction = direction;
        }

        @Override
        public int compareTo(Direction d) {
            if (height == d.height) {
                return direction - d.direction;
            }

            return height - d.height;
        }

    }

    static void buildBlobs(int[][] map, int w, int h) {
        for (int i = 0; i < w; i++) {
            for (int j = 0; j < h; j++) {
                List<Direction> possibilities = new ArrayList<Direction>();

                if (j > 0 && map[i][j] > map[i][j - 1]) {
                    //Check north
                    Point cell = new Point(i, j);
                    Point cellToFlow = new Point(i, j - 1);
                    possibilities.add(new Direction(cell, cellToFlow, map[i][j - 1], Direction.NORTH));
                    //addCell(cell, cellToFlow);
                }

                if (i > 0 && map[i][j] > map[i - 1][j]) {
                    //Check west
                    Point cell = new Point(i, j);
                    Point cellToFlow = new Point(i - 1, j);
                    //addCell(cell, cellToFlow);
                    possibilities.add(new Direction(cell, cellToFlow, map[i - 1][j], Direction.WEST));
                }

                if (i < w - 1 && map[i][j] > map[i + 1][j]) {
                    //Check east
                    Point cell = new Point(i, j);
                    Point cellToFlow = new Point(i + 1, j);
                    //addCell(cell, cellToFlow);
                    possibilities.add(new Direction(cell, cellToFlow, map[i + 1][j], Direction.EAST));
                }

                if (j < h - 1 && map[i][j] > map[i][j + 1]) {
                    //Check south
                    Point cell = new Point(i, j);
                    Point cellToFlow = new Point(i, j + 1);
                    //addCell(cell, cellToFlow);
                    possibilities.add(new Direction(cell, cellToFlow, map[i][j + 1], Direction.SOUTH));
                }

                if (!possibilities.isEmpty()) {
                    Collections.sort(possibilities);
                    Direction first = possibilities.get(0);
                    addCell(first.point, first.pointToFlow);
                } else {
                    //Is a sink !
                    Point cell = new Point(i, j);
                    addCell(cell, cell);
                }
            }
        }
    }

    private static void addCell(Point cell, Point cellToFlow) {
        Node origin      = null;
        Node destination = null;

        if (graph.containsKey(cell)) {
            origin = graph.get(cell);
        } else {
            origin = new Node(cell);
            graph.put(cell, origin);
        }

        if (graph.containsKey(cellToFlow)) {
            destination = graph.get(cellToFlow);
        } else {
            destination = new Node(cellToFlow);
            graph.put(cellToFlow, destination);
        }

        if (!origin.neighbors.contains(destination)) origin.neighbors.add(destination);
        if (!destination.neighbors.contains(origin)) destination.neighbors.add(origin);
    }

    static void removeConnected(Node root, List<Node> removed) {
        if (graph.containsKey(root.value)) {
            removed.add(root);
            graph.remove(root.value);
            for (Node neighbor : root.neighbors) {
                removeConnected(neighbor, removed);
            }
        }
    }

    public static void main(String[] args) {
        Scanner in = new Scanner(System.in);

        int n = in.nextInt();

        for (int idx = 0; idx < n; idx++) {
            int h = in.nextInt();
            int w = in.nextInt();

            int[][] map      = new int[w][h];
            char[][] charMap = new char[w][h];

            for (int j = 0; j < h; j++) {
                for (int i = 0; i < w; i++) {
                    map[i][j] = in.nextInt();
                }
            }

            graph = new HashMap<Point, Node>();
            buildBlobs(map, w, h);

            char currentChar = 'a';

            for (int j = 0; j < h; j++) {
                for (int i = 0; i < w; i++) {
                    Point cell = new Point(i, j);
                    if (graph.containsKey(cell)) {
                        List<Node> removed = new ArrayList<Node>();
                        removeConnected(graph.get(cell), removed);

                        for (Node node : removed) {
                            charMap[node.value.x][node.value.y] = currentChar;
                        }

                        currentChar++;
                    }
                }
            }

            System.out.println("Case #" + (idx + 1) + ":");

            for (int j = 0; j < h; j++) {
                StringBuilder str = new StringBuilder();
                for (int i = 0; i < w; i++) {
                    if (i > 0) str.append(" ");
                    str.append(charMap[i][j]);
                }

                System.out.println(str);
            }
        }
    }
}
