package problems.googlecodejam15;

import java.io.*;
import java.nio.file.FileSystems;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Created by sameerbhadouria on 4/11/15.
 */
public class InfiniteHouseOfPancakes {
    public static void main(String[] args) {
        StringBuilder basePath = new StringBuilder(System.getProperty("user.home"));

        basePath.append(File.separator)
                .append("code").append(File.separator)
                .append("test").append(File.separator)
                .append("inf-house-of-pancakes").append(File.separator);

        File inputFile = FileSystems.getDefault().getPath(basePath.toString() + "B-small-attempt1.in").toFile();
        File outputFile = FileSystems.getDefault().getPath(basePath.toString() + "B-small-attempt1  .out").toFile();
        run(inputFile, outputFile);
    }

    private static void run(File inputFileName, File outputFileName) {
        BufferedReader reader = null;
        BufferedWriter writer = null;

        try {
            reader = new BufferedReader(new FileReader(inputFileName));
            writer = new BufferedWriter(new FileWriter(outputFileName));

            String line = reader.readLine();
            int numTestCases = Integer.parseInt(line);

            for (int i = 1; i <= numTestCases; i++) {
                int D = Integer.parseInt(reader.readLine());
                String[] panCakesStr = reader.readLine().split(" ");
                List<Integer> panCakes = new ArrayList<>();
                for (int j = 0; j < D; j++) {
                    panCakes.add(Integer.parseInt(panCakesStr[j]));
                }
                String output = new StringBuilder("Case #").append(i).append(": ")
                        .append(getSmallestMinsToFinish(D, panCakes)).append("\n").toString();
                writer.write(output);
                System.out.print(output);

            }
        }
        catch (FileNotFoundException ex) {
            ex.printStackTrace();
        }
        catch (IOException e) {
            e.printStackTrace();
        }
        finally {
            try {
                if (reader != null) {
                    reader.close();
                }
                if (writer != null) {
                    writer.close();
                }
            }
            catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    private static int getSmallestMinsToFinish(int D, List<Integer> pancakes) {

        int elapsedMins = 0;

        if (pancakes.size() == 1) {

            if (pancakes.get(0)/2 >= 2) {
                // special min
                elapsedMins++;
                List<Integer> splitPancakes = new ArrayList<>();
                splitPancakes.add(0, pancakes.get(0) / 2);
                splitPancakes.add(pancakes.get(0) - splitPancakes.get(0));
                elapsedMins += getSmallestMinsToFinish(D, splitPancakes);
            }
            else {
                // regular min
                elapsedMins++;
                List<Integer> remainingPancakes = eatAndReturnRemainingPancakes(pancakes);
                if (remainingPancakes.isEmpty()) {
                    return elapsedMins;
                }
                elapsedMins += getSmallestMinsToFinish(D, remainingPancakes);
            }
        }
        else {
            // sort input pancakes and compare the with the previous entry for special min
            Collections.sort(pancakes);
            int length = pancakes.size();
            if (pancakes.get(length - 1)/2 >= pancakes.get(length -2))  {
                // special min, rebalance
                elapsedMins++;
                int maxPc = pancakes.get(length - 1);
                pancakes.remove(length -1);
                pancakes.add(length - 1, maxPc/2);
                List<Integer> newPancakeList = new ArrayList<>(pancakes);
                newPancakeList.add(maxPc - maxPc/2);

                elapsedMins += getSmallestMinsToFinish(D, newPancakeList);
            }
            else {
                // regular min
                elapsedMins++;
                List<Integer> remainingPancakes = eatAndReturnRemainingPancakes(pancakes);
                if (remainingPancakes.isEmpty()) {
                    return elapsedMins;
                }
                elapsedMins += getSmallestMinsToFinish(D, remainingPancakes);
            }
        }

        return elapsedMins;
    }

    // empty list means no pancakes left
    private static List<Integer> eatAndReturnRemainingPancakes(List<Integer> pancakes) {

        List<Integer> nonZeroPancakes = new ArrayList<>();
        for (int i = 0; i < pancakes.size(); i++) {
            int remainingPcs = pancakes.get(i);
            if (remainingPcs - 1 != 0) {
                nonZeroPancakes.add(remainingPcs - 1);
            }
        }

        return nonZeroPancakes;
    }
}
