package google.codejam14;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.nio.file.FileSystems;

public class CookieClickerAlpha {

	public static void main(String[] args) {
		File inputFile = FileSystems.getDefault().getPath(System.getProperty("user.home"), 
				"code/private/programing-puzzles/tests/cookieclicker/large-input.txt").toFile();
		File outputFile = FileSystems.getDefault().getPath(System.getProperty("user.home"), 
				"code/private/programing-puzzles/tests/cookieclicker/large-output.txt").toFile();
		run(inputFile, outputFile);
	}
	
	private static void run(File inputFileName, File outputFileName) {
		BufferedReader reader = null;
		BufferedWriter writer = null;
		
		try {
			reader = new BufferedReader(new FileReader(inputFileName));
			writer = new BufferedWriter(new FileWriter(outputFileName));
			
			String line = reader.readLine();
			int numTestCases = Integer.parseInt(line);
			
			for (int i = 1; i <= numTestCases; i++) {
				
				String[] vals = reader.readLine().split(" ");
				double C = Double.parseDouble(vals[0]);
				double F = Double.parseDouble(vals[1]);
				double X = Double.parseDouble(vals[2]);
				
				String prediction = Double.toString(getTimeToWin(C, F, X));
				writer.write(new StringBuilder("Case #").append(i).append(": ")
								.append(prediction).append("\n").toString());
				
			}
		}
		catch (FileNotFoundException ex) {
			ex.printStackTrace();
		} 
		catch (IOException e) {
			e.printStackTrace();
		}
		finally {
			try {
				if (reader != null) {
					reader.close();
				}
				if (writer != null) {
					writer.close();
				}
			}
			catch (IOException e) {
				e.printStackTrace();
			}
		}
		
	}
	
	private static double getTimeToWin(double C, double F, double X) {
		
		double time = 0.0;
		
		// num cookies per sec.
		double ncps = 2; // initial cookies/sec
		double cumulativeTimeToC = 0.0;
		double timeToX = X/ncps;
		
		while (true) {
			
			if (timeToX < cumulativeTimeToC) {
				time = timeToX;
				break;
			}

			// accumative C more cookies
			cumulativeTimeToC += C/ncps;
			ncps += F; // buying farm will increase cookies per sec

			// time after buying a farm
			double newTimeToX = cumulativeTimeToC + (X/ncps);
			if (newTimeToX > timeToX) {
				// previous iteration was a minima
				time = timeToX;
				break;
			}
			else {
				// new time will be time after buying farm
				timeToX = newTimeToX;
			}
		}

		return time;
	}

}
