package problemA.speakingintongues;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;

public class GoogleRese {

	private static final String INPUT_FILE = "/Users/sbhadour/dev/googlecodejam/A-small-attempt0.in";
	
	private static final String OUTPUT_FILE = "/Users/sbhadour/dev/googlecodejam/output.txt";
	
	// mapping of rese to humanEnglish Word
	private static final Map<Character, Character> singleLetterReseMap = new HashMap<Character, Character>();
	
	static {
		singleLetterReseMap.put('a', 'y');
		singleLetterReseMap.put('b', 'h');
		singleLetterReseMap.put('c', 'e');
		singleLetterReseMap.put('d', 's');
		singleLetterReseMap.put('e', 'o');
		singleLetterReseMap.put('f', 'c');
		singleLetterReseMap.put('g', 'v');
		singleLetterReseMap.put('h', 'x');
		singleLetterReseMap.put('i', 'd');
		singleLetterReseMap.put('j', 'u');
		singleLetterReseMap.put('k', 'i');
		singleLetterReseMap.put('l', 'g');
		singleLetterReseMap.put('m', 'l');
		singleLetterReseMap.put('n', 'b');
		singleLetterReseMap.put('o', 'k');
		singleLetterReseMap.put('p', 'r');
		singleLetterReseMap.put('q', 'z');
		singleLetterReseMap.put('r', 't');
		singleLetterReseMap.put('s', 'n');
		singleLetterReseMap.put('t', 'w');
		singleLetterReseMap.put('u', 'j');
		singleLetterReseMap.put('v', 'p');
		singleLetterReseMap.put('w', 'f');
		singleLetterReseMap.put('x', 'm');
		singleLetterReseMap.put('y', 'a');
		singleLetterReseMap.put('z', 'q');
		
	}
	
	// dictionary of known words
	private Map<String, String> dictonary = new HashMap<String, String>();
	
	/**
	 * Writes the results to the output file
	 * 
	 * @param results
	 */
	public void writeResults(String results) {
		try {
			Writer writer = new BufferedWriter(new FileWriter(OUTPUT_FILE));
			try {
				writer.write(results);
			}
			catch (IOException ex) {
				ex.printStackTrace();
			}
			finally {
				writer.close();
			}
		} 
		catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * Reads the input file and returns result. 
	 * 
	 * @return
	 */
	public String getResultsForInputFile() {
		StringBuilder result = new StringBuilder();
		
		try {
			BufferedReader input = new BufferedReader(new FileReader(INPUT_FILE));
			try {
				// first line is the number of test cases
				int numTestCases = Integer.parseInt(input.readLine());
				
				for (int i = 1; i <= numTestCases; i++) {
					result.append("Case #" + i + ": ");
					StringTokenizer words = new StringTokenizer(input.readLine(), " ");
					while (words.hasMoreTokens()) {
						result.append(translateWord(words.nextToken())).append(" ");
					}
					result.append(System.getProperty("line.separator"));
				}
				
			}
			catch (NumberFormatException nex) {
				nex.printStackTrace();
			} 
			catch (IOException e) {
				e.printStackTrace();
			}
			finally {
				
			}
		} 
		catch (FileNotFoundException e) {
			e.printStackTrace();
		}
		return result.toString();
	}
	
	/**
	 * Translates to human readable word.
	 * 
	 * @param reseWord
	 * @return
	 */
	private String translateWord(String reseWord) {
		
		// first lookup dictionary to see if word was repeated
		String translatedWord = dictonary.get(reseWord);
		if (translatedWord == null) {
			char[] characters = reseWord.toCharArray();
			int length = characters.length;
			char[] newChar = new char[length];

			for (int i = 0; i < length; i++) {
				newChar[i] = singleLetterReseMap.get(characters[i]);
			}

			translatedWord = new String(newChar);
		}
		
		return translatedWord;
	}
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		
		GoogleRese probA = new GoogleRese();
		
		long startTime = System.currentTimeMillis();
		String results = probA.getResultsForInputFile();
		probA.writeResults(results);
		long endTime = System.currentTimeMillis();
		
		System.out.println("Compute Time: " + (endTime - startTime) + " milliseconds");
	}
}
