package round1_2013;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;
import java.util.StringTokenizer;

public class Lawnmower {
	
	private static final String INPUT_FILE = "/Users/sbhadour/dev/googlecodejam/test/lawnmower-input.txt";
	
	private static final String OUTPUT_FILE = "/Users/sbhadour/dev/googlecodejam/test/lawnmower-output.txt";
	
	/**
	 * Reads the input file and returns result. 
	 * 
	 * @return
	 */
	public String getResultsForInputFile() {
		StringBuilder result = new StringBuilder();
		
		try {
			BufferedReader input = new BufferedReader(new FileReader(INPUT_FILE));
			try {
				// first line is the number of test cases
				int numTestCases = Integer.parseInt(input.readLine());
				
				for (int i = 1; i <= numTestCases; i++) {
					result.append("Case #" + i + ": ");
					StringTokenizer numLine = new StringTokenizer(input.readLine(), " ");
					int N = Integer.parseInt(numLine.nextToken());
					int M = Integer.parseInt(numLine.nextToken());
					int[][] lawn = new int[N][M];
					int[] maxRowWise = new int[N];
					for (int k = 0; k < N; k++) {
						maxRowWise[k] = 1;
						StringTokenizer lineTokens = new StringTokenizer(input.readLine(), " ");
						for (int r = 0; r < M; r++) {
							String numStr = lineTokens.nextToken();
							lawn[k][r] = Integer.parseInt(numStr);
							// also find max row wise
							if (lawn[k][r] > maxRowWise[k]) {
								maxRowWise[k] = lawn[k][r];
							}
						}
					}
					if (isMowingPossible(lawn, maxRowWise)) {
						result.append("YES");
					}
					else {
						result.append("NO");
					}
					result.append(System.getProperty("line.separator"));
				}
				
			}
			catch (NumberFormatException nex) {
				nex.printStackTrace();
			} 
			catch (IOException e) {
				e.printStackTrace();
			}
			finally {
				
			}
		} 
		catch (FileNotFoundException e) {
			e.printStackTrace();
		}
		return result.toString();
	}
	
	public boolean isMowingPossible (int[][] requiredLawn, int[] maxRowWise) {
		boolean possible = true;
		
		int n = requiredLawn.length;
		int m = requiredLawn[0].length;
		
		int[] minColWise = new int[m];
		int [] maxColWise = new int[m];
		
		int[][] initialLawn = new int[n][m];
		// create initial lawn
		// also find colwise min
		for (int j = 0; j < m; j++) {
			minColWise[j] = 100;
			maxColWise[j] = 1;
			for (int i = 0; i <n; i++) {
				initialLawn[i][j] = 100;
				if (requiredLawn[i][j] < minColWise[j]) {
					minColWise[j] = requiredLawn[i][j];
				}
				if (requiredLawn[i][j] > maxColWise[j]) {
					maxColWise[j] = requiredLawn[i][j];
				}
			}
				
		}
		
		// trim row wise first pass 
		// all trimmed uniformly to max row value
		for (int i = 0; i < n; i++) {
			// trim to maxRowWise
			for (int j = 0; j < m; j++) {
				initialLawn[i][j] = maxRowWise[i];
			}
		}
		
		// trim columnwise to min colwise
		for (int j = 0; j < m; j++) {
			int enterH = requiredLawn[0][j];
			if (enterH <= minColWise[j] && enterH >= maxColWise[j]) {
				for (int i =0; i < n; i++) {
					initialLawn[i][j] = minColWise[j];
				}
			}
		}
//		System.out.println();
//		for (int i = 0; i < n; i++) {
//			for (int j = 0; j < m; j++) {
//				System.out.print(initialLawn[i][j] + " ");
//			}
//			System.out.println();
//		}
		// compare initialLawn to requiredLawn
		for (int i = 0; i < n; i++) {
			for (int j = 0; j < m; j++) {
				if (initialLawn[i][j] != requiredLawn[i][j]) {
					possible = false;
					break;
				}
			}
		}
		
		return possible;
	}
	/**
	 * Writes the results to the output file
	 * 
	 * @param results
	 */
	public void writeResults(String results) {
		try {
			Writer writer = new BufferedWriter(new FileWriter(OUTPUT_FILE));
			try {
				writer.write(results);
			}
			catch (IOException ex) {
				ex.printStackTrace();
			}
			finally {
				writer.close();
			}
		} 
		catch (IOException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		Lawnmower probB = new Lawnmower();
		long startTime = System.currentTimeMillis();
		String results = probB.getResultsForInputFile();
		probB.writeResults(results);
		long endTime = System.currentTimeMillis();
		
		System.out.println("Compute Time: " + (endTime - startTime) + " milliseconds");
		
	}

}
