package google.codejam14;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.nio.file.FileSystems;
import java.util.HashSet;
import java.util.Set;
import java.util.SortedSet;
import java.util.TreeSet;

public class DeceitfulWar {

	public static void main(String[] args) {
		File inputFile = FileSystems.getDefault().getPath(System.getProperty("user.home"), 
				"code/private/programing-puzzles/tests/deceitfulwar/small-input.txt").toFile();
		File outputFile = FileSystems.getDefault().getPath(System.getProperty("user.home"), 
				"code/private/programing-puzzles/tests/deceitfulwar/small-output.txt").toFile();
		run(inputFile, outputFile);
	}
	
	private static void run(File inputFileName, File outputFileName) {
		BufferedReader reader = null;
		BufferedWriter writer = null;
		
		try {
			reader = new BufferedReader(new FileReader(inputFileName));
			writer = new BufferedWriter(new FileWriter(outputFileName));
			
			String line = reader.readLine();
			int numTestCases = Integer.parseInt(line);
			
			for (int i = 1; i <= numTestCases; i++) {
				
				int N = Integer.parseInt(reader.readLine());
				String[] naomiWtsRow = reader.readLine().split(" ");
				String[] kenWtsRow = reader.readLine().split(" ");
				
				TreeSet<Double> naomiWts = new TreeSet<>();
				TreeSet<Double> kenWts = new TreeSet<>();
				//sorted wts
				for (int w = 0; w< N; w++) {
					naomiWts.add(Double.parseDouble(naomiWtsRow[w]));
					kenWts.add(Double.parseDouble(kenWtsRow[w]));
				}
				String output = new StringBuilder("Case #").append(i).append(": ")
						.append(getScores(naomiWts, kenWts, N)).append("\n").toString();
				
				writer.write(output);
//				System.out.println(output);
			}
		}
		catch (FileNotFoundException ex) {
			ex.printStackTrace();
		} 
		catch (IOException e) {
			e.printStackTrace();
		}
		finally {
			try {
				if (reader != null) {
					reader.close();
				}
				if (writer != null) {
					writer.close();
				}
			}
			catch (IOException e) {
				e.printStackTrace();
			}
		}
		
	}
	
	// wts are sorted.
	private static String getScores(TreeSet<Double> naomiWts, TreeSet<Double> kenWts, int N) {
		StringBuilder score = new StringBuilder();
		int naomiDecitfulScore = getDeceitfulWarScore(new TreeSet(naomiWts), new TreeSet(kenWts), N);
		int naomiScore = getWarScore(new TreeSet(naomiWts), new TreeSet(kenWts), N);
		score.append(naomiDecitfulScore)
			 .append(" ")
			 .append(naomiScore);
		return score.toString();
		
	}
	
	private static int getDeceitfulWarScore(TreeSet<Double> naomiWts, TreeSet<Double> kenWts, int N) {
		int score = 0;
		for (int i = 0; i< N; i++) {
			double kWt = kenWts.pollFirst();
			Double nWt = naomiWts.higher(kWt);
			if (nWt != null) {
				naomiWts.remove(nWt);
				score++;
			}
			else {
				naomiWts.pollFirst();
			}
		}
		return score;
	}
	
	private static int getWarScore(TreeSet<Double> naomiWts, TreeSet<Double> kenWts, int N) {
		int naomiScore = 0;
		for (int i = 0; i < N; i++) {
			double nWt = naomiWts.pollFirst();
			
			Double kWt = kenWts.higher(nWt);
			if (kWt != null) {
				kenWts.remove(kWt);
			}
			else {
				kWt = kenWts.pollFirst();
				naomiScore++;
			}
		}
		return naomiScore;
	}

}
