package problems.googlecodejam15;

import java.io.*;
import java.nio.file.FileSystems;
import java.util.HashMap;
import java.util.Map;

/**
 * Created by sameerbhadouria on 4/11/15.
 */
public class DijkstraSpelling {

    // row key vs column key values
    private static Map<Character, Map<Character, String>> quaternions = new HashMap<>();
    static {
        Map<Character, String> oneChars = new HashMap<>();
        oneChars.put('1', "1");
        oneChars.put('i', "i");
        oneChars.put('j', "j");
        oneChars.put('k', "k");
        quaternions.put('1', oneChars);

        Map<Character, String> iChars = new HashMap<>();
        oneChars.put('1', "i");
        iChars.put('i', "-1");
        iChars.put('j', "k");
        iChars.put('k', "-j");
        quaternions.put('i', iChars);

        Map<Character, String> jChars = new HashMap<>();
        jChars.put('1', "j");
        jChars.put('i', "-k");
        jChars.put('j', "-1");
        jChars.put('k', "i");
        quaternions.put('j', jChars);

        Map<Character, String> kChars = new HashMap<>();
        kChars.put('1', "k");
        kChars.put('i', "j");
        kChars.put('j', "-i");
        kChars.put('k', "-1");
        quaternions.put('k', kChars);
    }

    public static void main(String[] args) {
        StringBuilder basePath = new StringBuilder(System.getProperty("user.home"));

        basePath.append(File.separator)
                .append("code").append(File.separator)
                .append("test").append(File.separator)
                .append("dijkstra").append(File.separator);

        File inputFile = FileSystems.getDefault().getPath(basePath.toString() + "C-small-attempt0.in").toFile();
        File outputFile = FileSystems.getDefault().getPath(basePath.toString() + "C-small-attempt0.out").toFile();
        run(inputFile, outputFile);
    }

    private static void run(File inputFileName, File outputFileName) {
        BufferedReader reader = null;
        BufferedWriter writer = null;

        try {
            reader = new BufferedReader(new FileReader(inputFileName));
            writer = new BufferedWriter(new FileWriter(outputFileName));

            String line = reader.readLine();
            int numTestCases = Integer.parseInt(line);

            for (int i = 1; i <= numTestCases; i++) {
                String[] LX = reader.readLine().split(" ");
                int L = Integer.parseInt(LX[0]);
                int X = Integer.parseInt(LX[1]);

                String pattern = reader.readLine();
                String output = new StringBuilder("Case #").append(i).append(": ")
                        .append(reducable(L, X, pattern)).append("\n").toString();
                writer.write(output);
                System.out.print(output);

            }
        }
        catch (FileNotFoundException ex) {
            ex.printStackTrace();
        }
        catch (IOException e) {
            e.printStackTrace();
        }
        finally {
            try {
                if (reader != null) {
                    reader.close();
                }
                if (writer != null) {
                    writer.close();
                }
            }
            catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    private static String reducable(int L, int X, String pattern) {

        if (pattern.length() * X < 3 || pattern.length() == 1) {
            return "NO";
        }

        StringBuilder extendedPattern = new StringBuilder();
        for (int i = 0; i < X; i++) {
            extendedPattern.append(pattern);
        }

        if (extendedPattern.length() == 3) {
            if (pattern.equals("ijk"))
                return "YES";
            else
                return "NO";
        }

        // more than 3 characters, traverse the string to make left, middle and right substrings to equal i, j and k respectively.

        char[] fullTextChars = extendedPattern.toString().toCharArray();
        String prod = "1";
        boolean foundI = false, foundJ = false, foundK = false;
        // try greedy first and then max substring match
        for (int i = 0; i < fullTextChars.length; i++) {
            if (foundK) {
                System.out.println("Found ijk with i=" + i + " length = " + fullTextChars.length);
            }
            if (prod.startsWith("-")) {
                String value = quaternions.get(prod.toCharArray()[1]).get(fullTextChars[i]);
                if (value.startsWith("-")) {
                    prod = value.substring(1, value.length());
                }
                else{
                    prod = "-" + value;
                }
            }
            else {
                prod = quaternions.get(prod.toCharArray()[0]).get(fullTextChars[i]);
            }

            // find i
            if (!foundI && prod.equals("i")) {
                // found i, reset prodChar to 1 for j
                prod = "1";
                foundI = true;
            }

            if (foundI && !foundJ && prod.equals("j")) {
                prod = "1";
                foundJ = true;
            }

            if (foundI && foundJ && !foundK && prod.equals("k")) {
                prod = "1";
                foundK = true;
            }
        }

        if (foundK) {
            return "YES";
        }
        else {
            // try max length substring
            return maxSubstring(fullTextChars, X);
        }

    }

    private static String maxSubstring(char[] fullTextChars, int X) {

        String prod = "1";
        boolean foundI = false, foundJ = false, foundK = false;
        int iLen = -1, jLen = -1;
        // try greedy first and then max substring match
        for (int i = 0; i < fullTextChars.length; i++) {
            if (foundK) {
                System.out.println("Found ijk with i=" + i + " length = " + fullTextChars.length);
            }
            if (prod.startsWith("-")) {
                String value = quaternions.get(prod.toCharArray()[1]).get(fullTextChars[i]);
                if (value.startsWith("-")) {
                    prod = value.substring(1, value.length());
                }
                else{
                    prod = "-" + value;
                }
            }
            else {
                prod = quaternions.get(prod.toCharArray()[0]).get(fullTextChars[i]);
            }

            if (!foundI && prod.equals("i")) {
                iLen = i + 1;
                // find max string to i
                if ((i + iLen) < X) {
                    i += iLen;
                    prod = "1";
                }
                else {
                    // found i, reset prodChar to 1 for j
                    prod = "1";
                    foundI = true;
                }
            }

            if (foundI && !foundJ && prod.equals("j")) {
                jLen = i - iLen;
                if ((i + jLen) < X) {
                    i += jLen;
                    prod = "1";
                }
                else {
                    prod = "1";
                    foundJ = true;
                }
            }

            if (foundI && foundJ && !foundK && prod.equals("k")) {
                prod = "1";
                foundK = true;
            }
        }

        if (foundK) {
            return "YES";
        }

        return "NO";
    }
}
