import java.io.*;
import java.nio.file.FileSystems;

public class StandingOvation {

    public static void main(String[] args) {
        StringBuilder basePath = new StringBuilder(System.getProperty("user.home"));
        basePath.append(File.separator)
                .append("code").append(File.separator)
                .append("test").append(File.separator)
                .append("standing-ovation").append(File.separator);

        File inputFile = FileSystems.getDefault().getPath(basePath.toString() + "A-small-attempt1.in").toFile();
        File outputFile = FileSystems.getDefault().getPath(basePath.toString() + "A-small-attempt1.out").toFile();
        run(inputFile, outputFile);
    }

    private static void run(File inputFileName, File outputFileName) {
        BufferedReader reader = null;
        BufferedWriter writer = null;

        try {
            reader = new BufferedReader(new FileReader(inputFileName));
            writer = new BufferedWriter(new FileWriter(outputFileName));

            String line = reader.readLine();
            int numTestCases = Integer.parseInt(line);

            for (int i = 1; i <= numTestCases; i++) {
                String[] vals = reader.readLine().split(" ");
                int sMax = Integer.parseInt(vals[0]);
                char[] shyPeopleCount = vals[1].toCharArray();
                String output = new StringBuilder("Case #").append(i).append(": ")
                        .append(getFriendsRequired(sMax, shyPeopleCount)).append("\n").toString();
                writer.write(output);
                System.out.print(output);

            }
        }
        catch (FileNotFoundException ex) {
            ex.printStackTrace();
        }
        catch (IOException e) {
            e.printStackTrace();
        }
        finally {
            try {
                if (reader != null) {
                    reader.close();
                }
                if (writer != null) {
                    writer.close();
                }
            }
            catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    private static int getFriendsRequired(int sMax, char[] shyPeopleCount) {

        int friendCnt = 0;

        int standiesSoFar = 0;
        for (int i = 0; i < sMax + 1 && standiesSoFar < sMax; i++) {
            int currCnt = Character.getNumericValue(shyPeopleCount[i]);
            if (currCnt == 0 && standiesSoFar <= i) {
                friendCnt++;
                standiesSoFar++;
            }
            else {
                standiesSoFar += currCnt;
            }
        }

        // add the difference to friendCnt
        if (standiesSoFar < sMax) {
            friendCnt += (sMax - standiesSoFar);
        }

        return friendCnt;
    }
}
