/**
 * TicTacToeTomek.java
 * 
 * Either use command line or first argument must be path of input file.
 */
import java.io.File;
import java.io.FileNotFoundException;
import java.util.Scanner;
import java.util.Set;

import org.apache.commons.lang3.ArrayUtils;

import com.google.common.collect.Sets;

/**
 * @author bsanghvi
 */
public class TicTacToeTomek {

    private enum Status {
        X_WON("X won"), O_WON("O won"), DRAW("Draw"), INCOMPLETE("Game has not completed");

        private final String message;

        private Status(final String message) {
            this.message = message;
        }

        @Override
        public String toString() {
            return this.message;
        }
    }

    /**
     * The main method.
     * 
     * @param args the arguments
     */
    public static void main(final String[] args) {
        try {
            final Scanner in;
            if (args.length >= 1) {
                in = new Scanner(new File(args[0]));
            } else {
                in = new Scanner(System.in);
            }

            final int T = in.nextInt();
            in.nextLine();

            for (int x = 1; x <= T; x++) {
                System.out.printf("Case #%d: %s", x, processCase(in)).println();
            }
        } catch (final FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    private static Status processCase(final Scanner in) {
        boolean incomplete = false;
        final Character[][] board = new Character[4][4];

        // read board and check if board is incomplete
        for (int i = 0; i < board.length; ++i) {
            board[i] = ArrayUtils.toObject(in.nextLine().toCharArray());
            incomplete |= ArrayUtils.contains(board[i], '.');
        }
        in.nextLine();      // empty new line

        // check rows to see if someone one
        for (int i = 0; i < board.length; ++i) {
            final Status status = check(board[i]);
            if (status != null) {
                return status;
            }
        }

        // check columns to see if someone one
        for (int i = 0; i < board.length; ++i) {
            final Status status = check(board[0][i], board[1][i], board[2][i], board[3][i]);
            if (status != null) {
                return status;
            }
        }

        // check diagonals to see if someone one
        final Status status = checkDiagonals(board);
        if (status != null) {
            return status;
        }

        return (incomplete ? Status.INCOMPLETE : Status.DRAW);
    }

    private static Status check(final Character... chars) {
        final Set<Character> set = Sets.newHashSet(chars);
        if (set.size() == 1 || (set.size() == 2 && set.contains('T'))) {
            if (set.contains('X')) {
                return Status.X_WON;
            }
            if (set.contains('O')) {
                return Status.O_WON;
            }
        }
        return null;
    }

    private static Status checkDiagonals(final Character[][] board) {
        final Character[] diag = new Character[board.length];
        for (int i = 0; i < board.length; ++i) {
            diag[i] = board[i][i];
        }
        final Status status = check(diag);
        if (status == null) {
            for (int i = 0; i < board.length; ++i) {
                diag[i] = board[i][board.length - i - 1];
            }
        }
        return check(diag);
    }

}
