/**
 * TrainTimetable.java
 *
 * Either use command line or first argument must be path of input file.
 */
import java.io.File;
import java.io.FileNotFoundException;
import java.util.Arrays;
import java.util.Scanner;

/**
 * @author bsanghvi
 */
public class TrainTimetable {

   /**
    * The main method.
    *
    * @param args the arguments
    */
   public static void main(String[] args) {
      try {
         final Scanner in;
         if (args.length >= 1) {
            in = new Scanner(new File(args[0]));
         } else {
            in = new Scanner(System.in);
         }

         // read cases
         final int N = in.nextInt();
         for (int x = 1; x <= N; x++) {
            int[] trains = processCase(in);
            System.out.println("Case #" + x + ": " + trains[0] + " " + trains[1]);
         }
      } catch (final FileNotFoundException e) {
         e.printStackTrace();
      }
   }

   /**
    * Processes a case.
    *
    * @param in the in
    *
    * @return the number of switches made
    */
   private static int[] processCase(final Scanner in) {
      // read turn around time
      final int T = in.nextInt();  // after this time train is ready
      final int NA = in.nextInt();
      final int NB = in.nextInt();

      final int[] departureA = new int[NA];
      final int[] arrivalB = new int[NA];
      final int[] departureB = new int[NB];
      final int[] arrivalA = new int[NB];

      for (int i = 0; i < NA; i++) {
         departureA[i] = readMinutes(in); // ready at A
         arrivalB[i] = readMinutes(in) + T; // ready at B
      }

      for (int i = 0; i < NB; i++) {
         departureB[i] = readMinutes(in); // ready at B
         arrivalA[i] = readMinutes(in) + T; // ready at A
      }

      // sort all timings
      Arrays.sort(departureA);
      Arrays.sort(arrivalB);
      Arrays.sort(departureB);
      Arrays.sort(arrivalA);

      return new int[] { compute(departureA, arrivalA), compute(departureB, arrivalB) };
   }

   /**
    * Compute.
    *
    * @param needToDepart the need to depart
    * @param readyToDepart the ready to depart
    *
    * @return the number of required trains
    */
   private static int compute(final int[] needToDepart, final int[] readyToDepart) {
      int i = 0;
      int n = 0;
      for (int j = 0; j < readyToDepart.length && i < needToDepart.length; i++) {
         if (readyToDepart[j] <= needToDepart[i]) {
            j++;
         } else {
            n++;
         }
      }

      return n + needToDepart.length - i;
   }

   /**
    * Read minutes.
    *
    * @param in the in
    *
    * @return the int
    */
   private static int readMinutes(final Scanner in) {
      final char[] charArray = in.next().toCharArray();


      int HH = (charArray[0] - '0') * 10 + (charArray[1] - '0');
      int MM = (charArray[3] - '0') * 10 + (charArray[4] - '0');
      return (HH * 60) + MM;
   }

}
