/**
 * BotTrust.java
 *
 * Either use command line or first argument must be path of input file.
 */
import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Scanner;

/**
 * @author bsanghvi
 */
public class BotTrust {

   /**
    * The main method.
    * 
    * @param args the arguments
    */
   public static void main(final String[] args) {
      try {
         final Scanner in;
         if (args.length >= 1) {
            in = new Scanner(new File(args[0]));
         } else {
            in = new Scanner(System.in);
         }

         // read cases
         final int T = in.nextInt();

         for (int x = 1; x <= T; ++x) {
            final long y = processCase(in);
            System.out.println("Case #" + x + ": " + y);
         }
      } catch (final FileNotFoundException e) {
         e.printStackTrace();
      }
   }

   /**
    * Processes a case.
    * 
    * @param in the in
    * 
    * @return the number of switches made
    */
   private static long processCase(final Scanner in) {
      final int N = in.nextInt();

      final BitSet bitSet = new BitSet(N);

      final List<Integer> oButtons = new ArrayList<Integer>();
      final List<Integer> bButtons = new ArrayList<Integer>();
      for (int i = 0; i < N; ++i) {
         final String next = in.next();
         if ("O".equals(next)) {
            bitSet.set(i);
            oButtons.add(in.nextInt());
         } else {
            bButtons.add(in.nextInt());
         }
      }

      int oPos = 1;
      int bPos = 1;
      int o = 0;
      int b = 0;

      int time = 0;
      int buttonsPressed = 0;
      while (buttonsPressed < N) {
         ++time;

         if (bitSet.get(buttonsPressed)) {
            // O needs to press button next
            final int oTo = oButtons.get(o);
            if (oTo == oPos) {
               ++o;
               ++buttonsPressed;
            } else if (oTo > oPos) {
               ++oPos;
            } else {
               --oPos;
            }
            if (b < bButtons.size()) {
               final int bTo = bButtons.get(b);
               if (bTo == bPos) {
                  // wait
               } else if (bTo > bPos) {
                  ++bPos;
               } else {
                  --bPos;
               }
            }
         } else {
            // B needs to press button next
            final int bTo = bButtons.get(b);
            if (bTo == bPos) {
               ++b;
               ++buttonsPressed;
            } else if (bTo > bPos) {
               ++bPos;
            } else {
               --bPos;
            }
            if (o < oButtons.size()) {
               final int oTo = oButtons.get(o);
               if (oTo == oPos) {
                  // wait
               } else if (oTo > oPos) {
                  ++oPos;
               } else {
                  --oPos;
               }
            }
         }
      }

      return time;
   }
}
