/**
 * ProbB.java
 * 
 * Either use command line or first argument must be path of input file.
 */
import java.io.File;
import java.io.FileNotFoundException;
import java.math.BigInteger;
import java.math.RoundingMode;
import java.util.Scanner;
import java.util.Set;

import com.google.common.collect.Sets;
import com.google.common.math.BigIntegerMath;

/**
 * @author bsanghvi
 */
public class FairAndSquare {

    private static final Set<BigInteger> FAIR_AND_SQUARE = Sets.newHashSet(BigInteger.ONE);

    private static final Set<BigInteger> NOT_FAIR_AND_SQUARE = Sets.newHashSet(BigInteger.ZERO);

    /**
     * The main method.
     * 
     * @param args the arguments
     */
    public static void main(final String[] args) {
        try {
            final Scanner in;
            if (args.length >= 1) {
                in = new Scanner(new File(args[0]));
            } else {
                in = new Scanner(System.in);
            }

            final int T = in.nextInt();
            for (int i = 1; i <= T; ++i) {
                System.out.printf("Case #%d: %d", i, processCase(in)).println();
            }
        } catch (final FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    /**
     * Processes a case.
     * 
     * @param in the in
     * 
     * @return the number of switches made
     */
    private static long processCase(final Scanner in) {
        final BigInteger A = new BigInteger(in.next());
        final BigInteger B = new BigInteger(in.next());

        final Set<BigInteger> fairAndSquare = Sets.newTreeSet();
        for (BigInteger i = A; i.compareTo(B) <= 0; i = i.add(BigInteger.ONE)) {
            if (FAIR_AND_SQUARE.contains(i)) {
                fairAndSquare.add(i);
            } else if (!NOT_FAIR_AND_SQUARE.contains(i)) {
                try {
                    final BigInteger sqrt = BigIntegerMath.sqrt(i, RoundingMode.UNNECESSARY);
                    if (isPalindrom(i) && isPalindrom(sqrt)) {
                        fairAndSquare.add(i);
                    } else {
                        NOT_FAIR_AND_SQUARE.add(i);
                    }
                } catch (final ArithmeticException e) {
                    // i does not have integral square root
                    NOT_FAIR_AND_SQUARE.add(i);
                }
            }
        }

        FAIR_AND_SQUARE.addAll(fairAndSquare);

        return fairAndSquare.size();
    }

    private static boolean isPalindrom(final BigInteger bigInteger) {
        final char[] array = bigInteger.toString().toCharArray();
        for (int i = 0; i < array.length; ++i) {
            if (array[i] != array[array.length - i - 1]) {
                return false;
            }
        }
        return true;
    }

}
