import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;


public class PermRLESolution {
	
	private static final String INPUT_FILE_NAME = "D-small-attempt0.in";
	private static final String OUTPUT_FILE_NAME = "D-small-attempt0.out";
	
	public static void main(String[] args) {
		Map<Integer, String> casesResult = new TreeMap<Integer, String>();
		
		List<String> lines = FileParser.readFile(INPUT_FILE_NAME);
		
		int numTestCases = Integer.parseInt(lines.get(0));
		
		int posBeginCase = 1;
		for(int caseNum = 1; caseNum <= numTestCases; caseNum++) {
			int sizePermutation = Integer.parseInt(lines.get(posBeginCase));
			String text = lines.get(posBeginCase + 1);
			
			Integer[] numbers = new Integer[sizePermutation];
			for(int i = 0; i < sizePermutation; i++) {
				numbers[i] = (i + 1);
			}
			
			List<Integer[]> permutations = getPermutations(numbers);
			
			List<String> textParts = generateTextParts(text, sizePermutation);
			int minimumSize = text.length(); 
			for(Integer[] permutation : permutations) {
				
				String permutedString = compressString(permutation, textParts);
				
				int size = calculateSize(permutedString);
				
				if(size < minimumSize) {
					minimumSize = size;
				}
			}
			
			casesResult.put(caseNum, String.valueOf(minimumSize));
			posBeginCase += 2;
		}
		
		
		FileParser.writeFile(OUTPUT_FILE_NAME, casesResult);
	}

	private static int calculateSize(String permutedString) {
		int size = 1;
		
		char[] characters = permutedString.toCharArray();
		
		for(int i = 1; i < characters.length; i++) {
			if(characters[i] != characters[i -1]) {
				size++;
			}
		}
		
		return size;
	}

	private static List<String> generateTextParts(String text, int sizePermutation) {
		List<String> parts = new ArrayList<String>();
		
		String auxText = text;
		if(auxText.length() > sizePermutation) {
			while(auxText.length() != sizePermutation) {
				String subText = auxText.substring(0, sizePermutation);
				parts.add(subText);
				auxText = auxText.substring(sizePermutation);
			}
			parts.add(auxText);
		} else {
			parts.add(text);
		}
		
		return parts;
	}

	private static String compressString(Integer[] permutation, List<String> parts) {
		StringBuffer result = new StringBuffer();
		
		for(String part : parts) {
			char[] chars = part.toCharArray();
			char[] permutedChars = new char[part.length()];
			
			for(int i = 0; i < part.length(); i++) {
				permutedChars[i] = chars[permutation[i] - 1];
			}
			
			result.append(String.valueOf(permutedChars));
		}
		
		return result.toString();
	}



	private static List<Integer[]> getPermutations(Integer[] numbers) {
		List<Integer[]> permutations = new ArrayList<Integer[]>();
		
		if(numbers.length == 1) {
			permutations.add(numbers);
			return permutations;
		}
		
		for(int number : numbers) {
		
			List<Integer[]> subPermutations = getPermutations(generateSubArray(numbers, number));
			
			for(Integer[] subPermutation : subPermutations) {
				Integer[] permutation = new Integer[numbers.length];
				permutation[0] = number;
				for(int i = 0; i < subPermutation.length; i++) {
					permutation[i + 1] = subPermutation[i];
				}
				
				permutations.add(permutation);
			}

		}
		
		
		return permutations;
	}
	
	private static Integer[] generateSubArray(Integer[] numbers, int numberToRemove) {
		Integer[] subArray = new Integer[numbers.length - 1];
		
		int i = 0;
		for(int number : numbers) {
			if(number != numberToRemove) {
				subArray[i] = number;
				i++;
			}
		}
		
		return subArray;
	}
}
