package qualification.bsevero.codejam;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;


public class SavingUniverse {
	
	private static final String TEST_FILE_NAME = "A-small-attempt1.in";
	private static final String OUT_EXTENSION = ".out";
	
	public static void main(String[] args) {
		List<Case> cases = parseFile(TEST_FILE_NAME);
		
		Map<Integer, Integer> caseSwitchs = new TreeMap<Integer, Integer>();
		
		int switchs;
		for(Case fileCase : cases) {
			switchs = 0;
			Map<String, Boolean> engineNameMatchs = new HashMap<String, Boolean>();
			for(String engineName : fileCase.getSearchEngines()) {
				engineNameMatchs.put(engineName, false);
			}
			
			for(String query : fileCase.getQuerys()) {
				if(fileCase.getSearchEngines().contains(query)) {
					engineNameMatchs.put(query, true);
					
					if(isAllEngineUsed(engineNameMatchs)) {
						switchs++;
						
						resetMatchs(engineNameMatchs);
						engineNameMatchs.put(query, true);
					}
				}
			}
			
			caseSwitchs.put(fileCase.getNumber(), switchs);
		}
		
		writeResult(caseSwitchs, TEST_FILE_NAME);
	}
	
	private static void writeResult(Map<Integer, Integer> caseSwitchs, String fileName) {
		
		try {
			String outputFileName = getFilePath(fileName);
			outputFileName =  (outputFileName.substring(0, outputFileName.length() - 3) + OUT_EXTENSION);
			File file = new File(outputFileName);
			if(file.exists()) {
				file.delete();
			}
			
			file.createNewFile();
			FileWriter fileWriter = new FileWriter(file);
			PrintWriter printWriter = new PrintWriter(fileWriter);
			
			StringBuffer result = new StringBuffer();
			
			for(int caseNum : caseSwitchs.keySet()) {
				result.append("Case #" + caseNum + ": " + caseSwitchs.get(caseNum) + "\n");
			}
			printWriter.print(result.toString().substring(0, result.length() - 1));
			
			printWriter.close();
			fileWriter.close();
		} catch(Exception e) {
			e.printStackTrace();
		}
	}
	
	private static void resetMatchs(Map<String, Boolean> engineNameMatchs) {
		for(String engineName : engineNameMatchs.keySet()) {
			engineNameMatchs.put(engineName, false);
		}
	}
	
	private static boolean isAllEngineUsed(Map<String, Boolean> engineNameMatchs) {
		return !engineNameMatchs.values().contains(false);
	}
	
	private static List<Case> parseFile(String fileName) {
		try {
			File file = new File(getFilePath(fileName));
			FileReader fileReader = new FileReader(file);
			BufferedReader bufferedReader = new BufferedReader(fileReader);
			
			List<String> fileLines = new ArrayList<String>();
			for(String line = bufferedReader.readLine(); line != null; line = bufferedReader.readLine()) {
				fileLines.add(line);
			}

			
			int numberCases = Integer.valueOf(fileLines.get(0));
			
			List<Case> cases = new ArrayList<Case>(numberCases);
			
			int posCaseBegin = 1;
			for(int i = 0; i < numberCases; i++) {
				Case fileCase = new Case();
				fileCase.setNumber(i + 1);
				
				int numberSearchEngines =  Integer.valueOf(fileLines.get(posCaseBegin));
				List<String> searchEngines = new ArrayList<String>();
				for(int j = posCaseBegin + 1; j < numberSearchEngines + (posCaseBegin + 1); j++) {
					searchEngines.add(fileLines.get(j));
				}
				fileCase.setSearchEngines(searchEngines);
				
				
				int numberQuerys =  Integer.valueOf(fileLines.get(posCaseBegin + numberSearchEngines + 1));
				List<String> querys = new ArrayList<String>();
				for(int j = (posCaseBegin + numberSearchEngines + 2); j < (posCaseBegin + numberSearchEngines + 2) + numberQuerys; j++) {
					querys.add(fileLines.get(j));
				}
				fileCase.setQuerys(querys);
				
				cases.add(fileCase);
				
				posCaseBegin = posCaseBegin + numberSearchEngines + 1 + numberQuerys + 1;
			}
			
			bufferedReader.close();
			
			return cases;
		} catch(Exception e) {
			e.printStackTrace();
			return Collections.emptyList();
		}
	}
	
	private static String getFilePath(String fileName) {
		return new SavingUniverse().getClass().getResource(fileName).getFile();
	}
}
