/**
 * @(#)RoundQB.java
 *
 * RoundQB application
 *
 * @author Brian Tagiku
 * @version 1.00 2009/9/2
 */

import java.util.*;
import java.io.*;
 
public class RoundQB {
    
    public static String filename = "B-small-attempt0";
    
    public static void main(String[] args) {
    	
    	// Load input
    	try {
	    	Scanner filein = new Scanner(new File(filename+".in"));
	    	
	    	int T = filein.nextInt();
	    	
	    	PrintWriter fileout = new PrintWriter(new FileWriter(filename+".out"));
	    	
	    	for(int mapNum=0; mapNum<T; mapNum++) {
	    	
				int H = filein.nextInt();
	    		int W = filein.nextInt();
	    	
		    	// Read in map
		    	int[][] elevmap = new int[H][W];
		    	for(int i=0; i<H; i++)
		    		for(int j=0; j<W; j++)
		    			elevmap[i][j] = filein.nextInt();
		    	
		    	// Generate adjacency lists (forward and backwards)
		    	int[] fwdAdjList = new int[H*W];
		    	Vector< Vector<Integer> > bckAdjList = new Vector< Vector<Integer> >();
		    	for(int i=0; i<H*W; i++)
		    		bckAdjList.add(new Vector<Integer>());
		    	
		    	for(int i=0; i<H; i++) {
		    		for(int j=0; j<W; j++) {
		    			
		    			// Find the smallest neighbor (priority NWES)
		    			int minalt=elevmap[i][j];
		    			int minx=0,miny=0;
		    			for(int y=-1; y<=1; y++) {
		    				for(int x=-1; x<=1; x++) {
		    					// Only horizontal/vertical neighbors
		    					if ((x+y)%2 != 0) {
		    						// Boundary conditions
		    						if ((0 <= i+y) && (i+y < H) && (0 <= j+x) && (j+x < W)) {
		    							// If lower altitude, update
		    							if(elevmap[i+y][j+x] < minalt) {
		    								minalt = elevmap[i+y][j+x];
		    								minx = x;
		    								miny = y;
		    							}
		    						}
		    					}
		    				}
		    			}
		    			
		    			// Update adjlists (-1 indicates sink)
		    			if((minx==0) && (miny==0)) {
		    				fwdAdjList[i*W+j] = -1;
		    			}
		    			else {
		    				fwdAdjList[i*W+j] = (i+miny)*W+(j+minx);
		    				bckAdjList.elementAt((i+miny)*W+(j+minx)).add(i*W+j);
		    			}
		    		}
		    	}
		    	
		    	// Calculate basins using reverse BFS
		    	Vector<Integer> queue = new Vector<Integer>();
		    	int[] sinkOf = new int[H*W];
		    	
		    	// Enqueue sinks
		    	for(int i=0; i<H*W; i++)
		    		if (fwdAdjList[i]==-1) {
		    			queue.add(i);
		    			sinkOf[i]=i;
		    			fwdAdjList[i]=i;
		    		}
		    	
		    	// Run backwards BFS
		    	while(!queue.isEmpty()) {
		    		int curr = queue.remove(0);
		    		
		    		sinkOf[curr] = sinkOf[fwdAdjList[curr]];
		    		
		    		for(int i : bckAdjList.elementAt(curr))
		    			queue.add(i);
		    	}
		    	
		    	// Now assign labels
		    	char[] labelOf = new char[H*W];
		    	char label = 'a';
		    	for(int i=0; i<H*W; i++) {
		    		if(labelOf[sinkOf[i]]==0) {
		    			labelOf[sinkOf[i]]=label;
		    			label++;
		    		}
		    		labelOf[i] = labelOf[sinkOf[i]];
		    	}
		    	
		    	// Print out answer
		    	fileout.println("Case #" + (mapNum+1) + ":");
		    	for(int i=0; i<H; i++){
		    		for(int j=0; j<W; j++) {
		    			fileout.print(labelOf[i*W+j] + " ");
		    		}
		    		fileout.println();
		    	}
	    	}
	    	
	    	filein.close();
	    	fileout.close();
       	}
       	catch(IOException e) {
       		System.out.println("Error loading input or output file");
       	}
    }
}
