/**
 * @(#)Round1BA.java
 *
 * Round1BA application
 *
 * @author Brian Tagiku
 * @version 1.00 2009/9/12
 */

import java.util.*;
import java.io.*;
import java.text.*;
 
public class Round1BA {
    
    //public static String filename = "A-test";
    public static String filename = "A-small-attempt0";
    //public static String filename3= "A-large";
    
    public static Scanner fin;
    public static String treestr;
    
    public static void main(String[] args) {
    	
    	// Load input
    	try {
	    	fin = new Scanner(new File(filename+".in"));
	    	PrintWriter fout = new PrintWriter(new FileWriter(filename+".out"));
	    	
	    	// Load the number of cases
	    	int N = fin.nextInt();
	    	
	    	for(int casenum=0; casenum<N; casenum++) {
	    		
	    		// Read in input
	    		int L = fin.nextInt();
	    		fin.nextLine();
	    		treestr = "";
	    		for(int i=0; i<L; i++)
	    			treestr += fin.nextLine();
	    		Tree t = parseTree();
	    			
	    		// Read in animals
	    		int A = fin.nextInt();
	    		fin.nextLine();
	    		Animal[] animals = new Animal[A];
	    		for(int i=0; i<A; i++)
	    			animals[i] = new Animal(fin.nextLine());
	    		
	    		// Print out solution
	    		fout.println("Case #" + (casenum+1) + ": ");
	    		
	    		DecimalFormat df = new DecimalFormat("#.######");
	    		for(int i=0; i<A; i++)
	    			fout.println(df.format(t.getProb(animals[i])));

	    	}
	    	
    		// Close up shop
    		fin.close();
    		fout.close();

       	}
       	catch(IOException e) {
       		System.out.println("Error loading input or output file");
       	}
    }
    
    public static class Tree {
    	
    	public double weight;
    	public String feature;
    	public Tree left;
    	public Tree right;
    	
    	public Tree(double weight) {
    		this.weight = weight;
    		feature = null;
    		left = null;
    		right = null;
    	}
    	
    	public Tree(double weight, String feature, Tree l, Tree r) {
    		this.weight = weight;
    		this.feature = feature;
    		this.left = l;
    		this.right = r;
    	}
    	
    	public boolean isLeaf() {
    		return ((left==null) && (right==null));
    	}
    	
    	public double getProb(Animal a) {
    		if (isLeaf())
    			return weight;
    		
    		if (a.hasFeat(feature))
    			return weight * right.getProb(a);
    		return weight*left.getProb(a);
    	}
    	
    	public String toString() {
    		String leftstr = null;
    		String rightstr = null;
    		if(left != null)
    			leftstr = left.toString();
    		if(right != null)
    			rightstr = right.toString();
    		
    		return "(" + weight + " " + feature + " " + leftstr + " " + rightstr + ")";
    	}
    }
    
	public static Tree parseTree() {

		treestr = treestr.trim();	
		
		// If we're at a leaf
		if (treestr.matches("\\(\\s*[\\.0-9]+\\s*\\).*")) {
			int end = 0;
			while(treestr.charAt(end) != ')')
				end++;
			double weight = Double.parseDouble(treestr.substring(1,end));
			treestr = treestr.substring(end+1);
			return new Tree(weight);
		}
		
		// Else recurse
		
		String[] tokens = treestr.trim().substring(1).split("\\s");
		
		double weight = Double.parseDouble(tokens[0]);
		String feat = tokens[1];
		treestr = "";
		for(int i=2; i<tokens.length; i++)
			treestr += tokens[i]+" ";
		
		Tree r = parseTree();
		Tree l = parseTree();
		
		// Remove end paren
		int beg = 0;
		while(treestr.charAt(beg) != ')')
			beg++;
		treestr = treestr.substring(beg+1);
		
		return new Tree(weight,feat,l,r);
	}
	
	public static class Animal {
		String name;
		PriorityQueue<String> features;
		
		public Animal(String line) {
			String[] tokens = line.split("\\s");
			
			name = tokens[0];
			features = new PriorityQueue<String>();
			for(int i=0; i<Integer.parseInt(tokens[1]); i++)
				features.add(tokens[i+2]);
		}
		
		public boolean hasFeat(String feature) {
			for(String s:features)
				if (s.equals(feature))
					return true;
			return false;
		}
	}
}