package codejam.two.zero.one.seven;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

import com.google.common.base.MoreObjects;
import com.google.common.base.Preconditions;

public class AmpleSyrup {
    public static void main(String[] args) {
        try (Scanner sc = new Scanner(System.in)) {
            int numTests = sc.nextInt();
            for (int numTest = 0; numTest < numTests; numTest++) {
                int n = sc.nextInt();
                int k = sc.nextInt();
                List<Pancake> pancakes = new ArrayList<>(n);
                for (int i = 0; i < n; i++) {
                    pancakes.add(new Pancake(sc.nextInt(), sc.nextInt()));
                }
                System.out.format("Case #%s: %s%n", (numTest + 1), solve(pancakes, k));
            }
        }
        System.exit(0);
    }

    private static String solve(List<Pancake> pancakes, int finalNumPancakes) {
        Collections.sort(pancakes);
        // f(k,i) = max area with pancake p_k and at least i pancakes
        // f(k,0) = 0
        // f(k,1) = area + side area of pancake
        // if k < i - 1: 0
        // if k == i - 1: include all pancakes
        // if k > i - 1: check all stacks f(0...k, i-1)
        Double[][] memoized = new Double[pancakes.size()][finalNumPancakes + 1];
        for (int currPancake = 0; currPancake < pancakes.size(); currPancake++) {
            memoized[currPancake][0] = 0.0;
            // just currPancake
            memoized[currPancake][1] = area(pancakes.get(currPancake));
        }

        for (int numPancake = 2; numPancake <= finalNumPancakes; numPancake++) {
            for (int currIndex = 0; currIndex < numPancake - 1; currIndex++) {
                memoized[currIndex][numPancake] = 0.0;
            }
        }

        for (int numPancake = 2; numPancake <= finalNumPancakes; numPancake++) {
            double area = area(pancakes.get(0));
            for (int currIndex = 1; currIndex <= numPancake - 1; currIndex++) {
                area += stackArea(pancakes.get(currIndex - 1), pancakes.get(currIndex));
            }
            memoized[numPancake - 1][numPancake] = area;
        }

        for (int numPancakes = 2; numPancakes <= finalNumPancakes; numPancakes++) {
            for (int currIndex = numPancakes; currIndex < pancakes.size(); currIndex++) {
                Pancake currPancake = pancakes.get(currIndex);
                double max = 0.0;
                for (int prevPancakeIndex = 0; prevPancakeIndex < currIndex; prevPancakeIndex++) {
                    double currArea = memoized[prevPancakeIndex][numPancakes - 1] +
                            stackArea(pancakes.get(prevPancakeIndex), currPancake);
                    max = Math.max(max, currArea);
                }
                memoized[currIndex][numPancakes] = max;
            }
        }
//        System.out.println(Arrays.deepToString(memoized));
        double max = 0.0;
        for (int currIndex = 0; currIndex < pancakes.size(); currIndex++) {
            max = Math.max(max, memoized[currIndex][finalNumPancakes]);
        }
        return String.valueOf(max);
    }

    private static double area(Pancake pancake) {
        return Math.PI * (pancake.radius * pancake.radius) + 2 * Math.PI * pancake.radius * pancake.height;
    }

    private static double stackArea(Pancake smaller, Pancake larger) {
        Preconditions.checkArgument(smaller.compareTo(larger) <= 0);
        return (Math.PI * ((larger.radius * larger.radius) - (smaller.radius * smaller.radius))) +
                (2 * Math.PI * larger.radius * larger.height);
    }

    private static class Pancake implements Comparable<Pancake> {
        private final long radius;
        private final long height;

        private Pancake(int radius, int height) {
            this.radius = radius;
            this.height = height;
        }

        @Override
        public int compareTo(Pancake o) {
            if (radius < o.radius) {
                return -1;
            } else if (radius == o.radius) {
                return 0;
            } else {
                return 1;
            }
        }

        @Override
        public String toString() {
            return MoreObjects.toStringHelper(this).add("radius", radius).add("height", height).toString();
        }
    }
}
