package qualification;

import java.math.BigInteger;
import java.util.*;

public class CoinJam {
    //private static final int NUM_JAM_COINS_TO_FIND = 3;
    private static final int NUM_JAM_COINS_TO_FIND = 50;
    //private static final int NUM_JAM_COINS_TO_FIND = 500;

    public static void main(String[] args) {
        System.out.println("Case #1: ");
        SortedMap<Integer, BigInteger> baseToCurr = new TreeMap<>();
        for (int i = 2; i <= 10; i++) {
            //baseToCurr.put(i, new BigInteger("100001", i));
            baseToCurr.put(i, new BigInteger("1000000000000001", i));
            //baseToCurr.put(i, new BigInteger("10000000000000000000000000000001", i));
        }

        long prevGrayCode = 0;
        long currGrayCode = 0;
        int numFound = 0;
        for (long numGrayCode = 1; ; numGrayCode++) {
            if (numFound >= NUM_JAM_COINS_TO_FIND) {
                break;
            }

            currGrayCode = getNumGrayCode(numGrayCode);
            int exponent = computeExponentToFlip(prevGrayCode, currGrayCode);
            boolean shouldAddPower = (currGrayCode & (1 << exponent)) != 0;
            /*
            System.out.println("prev code: " + Long.toBinaryString(prevGrayCode));
            System.out.println("new code: " + Long.toBinaryString(currGrayCode));
            System.out.println("exponent: " + exponent);
            System.out.println("should add power: " + shouldAddPower);
            */

            // Shift exponent by one since the lowest bit must be on
            updateMap(baseToCurr, exponent + 1, shouldAddPower);
            //System.out.println(baseToCurr);

            SortedMap<Integer, Integer> divisors = findDivisors(baseToCurr);
            if (divisors.size() == 9) {
                StringBuilder jamCoin = new StringBuilder();
                jamCoin.append(baseToCurr.get(2).toString(2));
                for (int divisor : divisors.values()) {
                    jamCoin.append(" ");
                    jamCoin.append(divisor);
                }
                System.out.println(jamCoin.toString());
                numFound++;
            }

            prevGrayCode = currGrayCode;
        }
    }

    private static int computeExponentToFlip(long prevGrayCode, long currGrayCode) {
        return Long.numberOfTrailingZeros(prevGrayCode ^ currGrayCode);
    }

    private static long getNumGrayCode(long numGrayCode) {
        return numGrayCode ^ (numGrayCode >> 1);
    }

    private static void updateMap(Map<Integer, BigInteger> baseToCurr, int exponent, boolean shouldAddPower) {
        for (Map.Entry<Integer, BigInteger> entry : baseToCurr.entrySet()) {
            int base = entry.getKey();
            BigInteger prevValue = entry.getValue();
            BigInteger newValue = computeNewValue(exponent, shouldAddPower, base, prevValue);
            //System.out.println("prev: " + prevValue.toString(2));
            //System.out.println("new: " + newValue.toString(2));
            baseToCurr.put(base, newValue);
        }
    }

    private static BigInteger computeNewValue(int exponent, boolean shouldAddPower, int base, BigInteger prevValue) {
        BigInteger difference = BigInteger.valueOf(base).pow(exponent);
        if (shouldAddPower) {
            return prevValue.add(difference);
        } else {
            return prevValue.subtract(difference);
        }
    }

    // This is just an estimate for speed
    private static SortedMap<Integer, Integer> findDivisors(SortedMap<Integer, BigInteger> baseToCurr) {
        SortedMap<Integer, Integer> baseToDivisor = new TreeMap<>();
        for (Map.Entry<Integer, BigInteger> entry : baseToCurr.entrySet()) {
            int base = entry.getKey();
            // No need to do square root (it's hard anyways, because of big integer) since they should all be larger
            // than 10000^2
            for (int divisor = 2; divisor < 10000; divisor++) {
                if (entry.getValue().mod(BigInteger.valueOf(divisor)) == BigInteger.ZERO) {
                    //System.out.println("\t" + divisor + " divides " + num);
                    baseToDivisor.put(base, divisor);
                    break;
                }
            }
            if (!baseToDivisor.containsKey(base)) {
                // Return whatever we have so far
                //System.out.println("couldn't find divisor for " + num);
                break;
            }
        }
        return baseToDivisor;
    }
}
