import java.util.*;

public class DGA {

      public static final int POPULATION_SIZE = 150,
                              ITERATION_LIMIT = 100,
                              SURVIVE         = 40,
                              MUTATE          = 5;

      public static int N;

      public static Solution[] population    = new Solution[POPULATION_SIZE],
                               newPopulation = new Solution[POPULATION_SIZE];

      public static Chest[] chests = new Chest[200];
      
      public static Bag initial;

      public static Random R = new Random(System.currentTimeMillis());

      public static void main (String[] args) {
            
            Scanner S = new Scanner(System.in);
            int T = S.nextInt(), K, c, ki;
            
            for (c = 1 ; T-- > 0 ; c++) {
                  K = S.nextInt();
                  N = S.nextInt();
                  initial = new Bag();
                  while (K-- > 0)
                        initial.add(S.nextInt()-1);
                  for (K = 0 ; K < N ; K++) {
                        chests[K] = new Chest(S.nextInt()-1);
                        ki = S.nextInt();
                        while (ki-- > 0)
                              chests[K].addContent(S.nextInt()-1);
                  }
                  for (K = 0 ; K < POPULATION_SIZE ; K++)
                        population[K] = new Solution(N, true);
                  Arrays.sort(population);
                  for (K = 0 ; K < ITERATION_LIMIT ; K++) {
                        for (ki = 0 ; ki < SURVIVE ; ki++)
                              newPopulation[ki] = population[ki];
                        for ( ; ki < POPULATION_SIZE ; ki += 2) {
                              int a, b;
                              a = R.nextInt(POPULATION_SIZE);
                              b = R.nextInt(POPULATION_SIZE);
                              newPopulation[ki] = population[a].cross(population[b]);
                              newPopulation[ki+1] = population[b].cross(population[a]);
                        }
                        for (ki = 0 ; ki < MUTATE ; ki++) {
                              int a;
                              a = R.nextInt(POPULATION_SIZE);
                              newPopulation[a].mutate();
                        }
                        for (ki=0 ; ki < POPULATION_SIZE ; ki++)
                              population[ki] = newPopulation[ki];
                        Arrays.sort(population);
                  }
                  if (population[0].fitness == 0)
                        System.out.println("Case #" + c + ":" + population[0]);
                  else
                        System.out.println("Case #" + c + ": IMPOSSIBLE");
            }
            
      }

}

class Solution implements Comparable<Solution> {

      int[] perm;
      
      int fitness;

      public Solution(int tam, boolean randomize) {
            
            int i;
            
            perm = new int[tam];
            for (i = 0 ; i < tam ; i++)
                  perm[i] = i;
            if (randomize) {
                  for (i = 0 ; i < tam ; i++) {
                        int a, tmp;
                        a = i + DGA.R.nextInt(tam - i);
                        tmp = perm[a];
                        perm[a] = perm[i];
                        perm[i] = tmp;
                  }
                  findFitness();
            }
            
      }

      public void findFitness() {
            
            fitness = 0;
            Bag actual = new Bag(DGA.initial);
            for (int i = 0 ; i < perm.length ; i++) {
                  if (actual.contains(DGA.chests[perm[i]].keyType))
                        actual.remove(DGA.chests[perm[i]].keyType);
                  else
                        fitness++;
                  actual.addAll(DGA.chests[perm[i]].contents);
            }
            
      }

      public boolean lexSmaller(Solution other) {
            
            for (int i = 0 ; i < perm.length ; i++) {
                  if (perm[i] < other.perm[i])
                        return true;
                  if (perm[i] > other.perm[i])
                        return false;
            }
            return true;
            
      }

      public Solution cross(Solution b) {
            
            Solution ret = new Solution(perm.length, false);
            
            for (int i = 0 ; i < perm.length ; i++)
                  ret.perm[i] = perm[b.perm[i]];
            ret.findFitness();
            
            return ret;
            
      }

      public void mutate() {
            
            int a, b, tmp;
            a = DGA.R.nextInt(perm.length);
            b = DGA.R.nextInt(perm.length);
            for ( ; a < b ; a++, b--) {
                  tmp = perm[a];
                  perm[a] = perm[b];
                  perm[b] = tmp;
            }
            findFitness();
            
      }

      public int compareTo(Solution other) {
            
            if (fitness < other.fitness)
                  return -1;
            if (fitness > other.fitness)
                  return 1;
            return toString().compareTo(other.toString());
            /*
            if (lexSmaller(other))
                  return -1;
            return 0;
            */
            
      }

      public String toString() {
            
            String ret = "";
            
            for (int i = 0 ; i < perm.length ; i++)
                  ret += " " + (perm[i] + 1);
            
            return ret;
            
      }

}

class Chest {

      int keyType;

      Bag contents;

      public Chest(int keyType) {
            
            this.keyType = keyType;
            contents = new Bag();
            
      }

      public void addContent(int key) {
            
            contents.add(key);
            
      }

}

class Bag {

      int[] contents;

      public Bag () {
            
            contents = new int[200];
            
      }

      public Bag (Bag ks) {
            
            this();
            addAll(ks);
            
      }

      public void add(int k) {
            
            contents[k]++;
            
      }

      public void addAll(Bag ks) {
            
            for (int i = 0 ; i < 200 ; i++)
                  contents[i] += ks.contents[i];
            
      }

      public void remove(int k) {
            
            contents[k]--;
            
      }

      public boolean contains(int k) {
            
            return contents[k] > 0;
            
      }

}