import java.io.*;
import java.util.*;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Scanner;

// @SuppressWarnings("all")
@SuppressWarnings("unchecked")
public class Solution {
	private static final String FILE_NAME = "A-small-attempt3";	

	/**************************** 
	 * 		   Solution
	 ****************************/

	private void solve() {
		int rows = nextInt();
		int cols = nextInt();
		char[][] grid = new char[rows][cols];

		for (int i = 0; i < rows; i++) {
			String row = next();
			grid[i] = row.toCharArray();
		}

		// solve
		HashSet<Character> lettersSet = new HashSet<>();
		LinkedList<Character> letters = new LinkedList<>();
		int emptyCount = 0;
		for (int i = 0; i < rows; i++) {
			for (int j = 0; j < cols; j++) {
				if (grid[i][j] == '?') {
					emptyCount++;
				}
				if (grid[i][j] != '?' && !lettersSet.contains(grid[i][j])) {
					lettersSet.add(grid[i][j]);
					letters.add(grid[i][j]);
				}
			}
		}

		if (lettersSet.size() > 0) {
			grid = findSolution(grid, letters, emptyCount);
		}

		if (grid == null) {
			print("Error");
			return;
		}

		for (int i = 0; i < rows; i++) {
			println();
			for (int j = 0; j < cols; j++) {
				print(grid[i][j]);
			}
		}
	}

	private char[][] findSolution(char[][] grid, LinkedList<Character> letters, int emptyCount) {
		// System.out.println(letters);
		if (emptyCount == 0) {
			return grid;
		} else if (letters.isEmpty() && emptyCount > 0) {
			return null;
		} else {
			char currentChar = letters.removeLast();
			int[] startingRegion = getStartingRegion(grid, currentChar);
			ArrayList<int[]> validEdges = findAllValidRegions(grid, startingRegion);
			validEdges.add((new int[]{0, 0, -1, -1}));

			for (int[] edges : validEdges) {
				// System.out.println(Arrays.toString(edges));
				char[][] newGrid = cloneArray(grid);
				int painted = paintRegion(newGrid, edges, currentChar);
				newGrid = findSolution(newGrid, letters, emptyCount - painted);

				if (newGrid != null) {
					return newGrid;
				}
			}

			letters.addLast(currentChar);

			return null;
		}
	}

	private int[] getStartingRegion(char[][] grid, char curr) {
		for (int row = 0; row < grid.length; row++) {
			for (int col = 0; col < grid[0].length; col++) {
				if (grid[row][col] == curr) {
					return (new int[]{col, row, col, row});
				}
			}
		}
		return null;
	}

	private ArrayList<int[]> findAllValidRegions(char[][] grid, int[] region) {
		HashSet<String> foundRegions = new HashSet<>();
		ArrayList<int[]> validRegions = new ArrayList<>();
		findAllValidRegions(grid, region, validRegions, foundRegions);
		return validRegions;
	}

	private void findAllValidRegions(char[][] grid, int[] region, ArrayList<int[]> validRegions, HashSet<String> foundRegions) {
		// Try all directions
		// left
		if (region[0] > 0 && regionEmpty(grid, (new int[]{region[0] - 1, region[1], region[0] - 1, region[3]}))) {
			int [] newRegion = (new int[]{region[0] - 1, region[1], region[2], region[3]});
			String regionStr = regionToStr(newRegion);
			if (!foundRegions.contains(regionStr)) {
				foundRegions.add(regionStr);
				validRegions.add(newRegion);
				findAllValidRegions(grid, newRegion, validRegions, foundRegions);
			}
		}

		// top
		if (region[1] > 0 && regionEmpty(grid, (new int[]{region[0], region[1] - 1, region[2], region[1] - 1}))) {
			int [] newRegion = (new int[]{region[0], region[1] - 1, region[2], region[3]});
			String regionStr = regionToStr(newRegion);
			if (!foundRegions.contains(regionStr)) {
				foundRegions.add(regionStr);
				validRegions.add(newRegion);
				findAllValidRegions(grid, newRegion, validRegions, foundRegions);
			}
		}

		// right
		if (region[2] + 1 < grid[0].length && regionEmpty(grid, (new int[]{region[2] + 1, region[1], region[2] + 1, region[3]}))) {
			int [] newRegion = (new int[]{region[0], region[1], region[2] + 1, region[3]});
			String regionStr = regionToStr(newRegion);
			if (!foundRegions.contains(regionStr)) {
				foundRegions.add(regionStr);
				validRegions.add(newRegion);
				findAllValidRegions(grid, newRegion, validRegions, foundRegions);
			}
		}

		// bottom
		if (region[3] + 1 < grid.length && regionEmpty(grid, (new int[]{region[0], region[3] + 1, region[2], region[3] + 1}))) {
			int [] newRegion = (new int[]{region[0], region[1], region[2], region[3] + 1});
			String regionStr = regionToStr(newRegion);
			if (!foundRegions.contains(regionStr)) {
				foundRegions.add(regionStr);
				validRegions.add(newRegion);
				findAllValidRegions(grid, newRegion, validRegions, foundRegions);
			}
		}
	}

	private String regionToStr(int[] region) {
		return "" + region[0] + '-' +  region[1] + '-' + region[2] + '-' + region[3];
	}

	private boolean regionEmpty(char[][] grid, int[] edges) {
		for (int row = edges[1]; row <= edges[3]; row++) {
			for (int col = edges[0]; col <= edges[2]; col++) {
				if (grid[row][col] != '?') {
					return false;
				}
			}
		}
		return true;
	}

	private int paintRegion(char[][] grid, int[] edges, char c) {
		int painted = 0;
		for (int row = edges[1]; row <= edges[3]; row++) {
			for (int col = edges[0]; col <= edges[2]; col++) {
				if (grid[row][col] == '?') {
					grid[row][col] = c;
					painted++;
				}
			}
		}
		return painted;
	}

	public static char[][] cloneArray(char[][] src) {
		int length = src.length;
		char[][] target = new char[length][src[0].length];
		for (int i = 0; i < length; i++) {
			System.arraycopy(src[i], 0, target[i], 0, src[i].length);
		}
		return target;
	}
	
	/**************************** 
	 * 		Set-up
	 ****************************/
	
	private Scanner in;
	private PrintStream out;

	public Solution () throws FileNotFoundException {
		in = new Scanner(new File(FILE_NAME + ".in"));	
		out = new PrintStream(FILE_NAME + ".out"); 

		int cases = nextInt();	
		for (int i = 1; i <= cases; i++) {
			print("Case #" + i + ":");
			solve();
			println();
		}	

		out.close();
	}
	
	/**************************** 
	 * 		Manage input
	 ****************************/
	private int[] nextArray(int length) {
		int[] arr = new int[length];
		for (int i = 0; i < length; i++) {
			arr[i] = nextInt();
		}
		return arr;
	}
	
	private int[][] nextMatrix(int rows, int columns) {
		int[][] mat = new int[rows][columns];
		for (int r = 0; r < rows; r++) {
			for (int c = 0; c < columns; c++) {
				mat[r][c] = nextInt();
			}
		}
		return mat;
	}
	
	private String nextLine() {
		return in.nextLine();
	}
	private String next() {
		return in.next();
	}
	private int nextInt() {
		return in.nextInt();
	}
	private long nextLong() {
		return in.nextLong();
	}

	/**************************** 
	 * 		Manage output
	 ****************************/
	private void print(String s) { 
		System.out.print(s);
		out.print(s); 
	}	
	private void print(char c) { 
		System.out.print(c);
		out.print(c); 
	}	
	private void print(int i) { 
		System.out.print(i);
		out.print(i); 
	}
	private void print(long l) {
		System.out.println(l);
		out.print(l);
	}
	private void print(Object o) {
		System.out.print(o);
		print(o);
	}
	private void println() { 
		System.out.println();
		out.println(); 
	}
	
	public static void main(String[] args) {
		try {
			new Solution();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}