import java.io.*;
import java.util.*;
import java.text.*;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Scanner;

// @SuppressWarnings("all")
@SuppressWarnings("unchecked")
public class Solution {
	class Horse {
		int position;
		int speed;
		public Horse(int position, int speed) {
			this.position = position;
			this.speed = speed;
		}
		public String toString() {
			return "p: " + position + " s:" + speed;
		}
	}

	private static final String FILE_NAME = "A-large";	

	/**************************** 
	 * 		   Solution
	 ****************************/

	private void solve() {
		int distance = nextInt();
		int horsesCount = nextInt();
		ArrayList<Horse> horses = new ArrayList<>(horsesCount);
		// System.out.println(distance);
		for (int i = 0; i < horsesCount; i++) {
			horses.add(new Horse(nextInt(), nextInt()));
			// System.out.println(horses.get(horses.size() - 1).position + " - " + horses.get(horses.size() - 1).speed);
		}

		horses.sort((h1, h2) -> h2.position - h1.position);
		// System.out.println(horses);

		double time = getTime(distance, horses);
		// System.out.println("Time: " + time);

		DecimalFormat df = new DecimalFormat("0.000000");
		if (time == 0) {
			print(df.format(0.0));
		} else {
			print(df.format(distance / time));
		}
		// System.out.println(distance + " - " + time);
		// print(distance / time);
	}

	private double getTime(int distance, ArrayList<Horse> horses) {
		Horse slowest = horses.get(0);
		for (int i = 1; i < horses.size(); i++) {
			Horse curr = horses.get(i);

			if (slowest.speed >= curr.speed) {
				slowest = curr;
				// System.out.println("Curr has slower speed " + i);
			} else {
				double[] intersection = getIntersection(slowest, curr);
				double time = intersection[0];
				double position = intersection[1];

				if (position < distance) {
					// slow will be the bottlneck
				} else {
					// fast will be the bottleneck as slow will get first to the end
					slowest = curr;
					// System.out.println("Curr is the bottleck " + i);
				}
			}
		}

		// System.out.println("Slowest: " + slowest.speed);
		// System.out.println("speed: " + slowest.speed + " p:" + slowest.position + " d:" + distance);
		return (distance - slowest.position) / (double)slowest.speed;
	}

	private double[] getIntersection(Horse h1, Horse h2) {
		double time = (h1.position - h2.position) / (double)(h2.speed - h1.speed);
		double position = h1.position + h1.speed * time;
		return (new double[]{time, position});
	}
	
	/**************************** 
	 * 		Set-up
	 ****************************/
	
	private Scanner in;
	private PrintStream out;

	public Solution () throws FileNotFoundException {
		in = new Scanner(new File(FILE_NAME + ".in"));	
		out = new PrintStream(FILE_NAME + ".out"); 

		int cases = nextInt();	
		for (int i = 1; i <= cases; i++) {
			print("Case #" + i + ": ");
			solve();
			println();
		}	

		out.close();
	}
	
	/**************************** 
	 * 		Manage input
	 ****************************/
	private int[] nextArray(int length) {
		int[] arr = new int[length];
		for (int i = 0; i < length; i++) {
			arr[i] = nextInt();
		}
		return arr;
	}
	
	private int[][] nextMatrix(int rows, int columns) {
		int[][] mat = new int[rows][columns];
		for (int r = 0; r < rows; r++) {
			for (int c = 0; c < columns; c++) {
				mat[r][c] = nextInt();
			}
		}
		return mat;
	}
	
	private String nextLine() {
		return in.nextLine();
	}
	private String next() {
		return in.next();
	}
	private int nextInt() {
		return in.nextInt();
	}
	private long nextLong() {
		return in.nextLong();
	}

	/**************************** 
	 * 		Manage output
	 ****************************/
	private void print(String s) { 
		System.out.print(s);
		out.print(s); 
	}	
	private void print(int i) { 
		System.out.print(i);
		out.print(i); 
	}
	private void print(long l) {
		System.out.println(l);
		out.print(l);
	}
	private void print(double l) {
		System.out.println(l);
		out.print(l);
	}
	private void print(Object o) {
		System.out.print(o);
		print(o);
	}
	private void println() { 
		System.out.println();
		out.println(); 
	}
	
	public static void main(String[] args) {
		try {
			new Solution();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**************************** 
	 * 		Utils
	 ****************************/
	private static char[] cloneArray(char[] src) {
		return Arrays.copyOf(src, src.length);
	}

	private static int[] cloneArray(int[] src) {
		return Arrays.copyOf(src, src.length);
	}

	public static char[][] cloneArray(char[][] src) {
		int length = src.length;
		char[][] target = new char[length][src[0].length];
		for (int i = 0; i < length; i++) {
			System.arraycopy(src[i], 0, target[i], 0, src[i].length);
		}
		return target;
	}

	public static int[][] cloneArray(int[][] src) {
		int length = src.length;
		int[][] target = new int[length][src[0].length];
		for (int i = 0; i < length; i++) {
			System.arraycopy(src[i], 0, target[i], 0, src[i].length);
		}
		return target;
	}
}