import java.io.*;
import java.util.*;
import java.text.*;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Scanner;

// @SuppressWarnings("all")
@SuppressWarnings("unchecked")
public class Solution {
	class City {
		int max;
		int speed;
		public City(int max, int speed) {
			this.max = max;
			this.speed = speed;
		}
	}
	private static final String FILE_NAME = "C-small-attempt0";	

	/**************************** 
	 * 		   Solution
	 ****************************/

	private void solve() {
		int citiesCount = nextInt();
		int pairsCount = nextInt();
		ArrayList<City> cities = new ArrayList<>(citiesCount);
		for (int i = 0; i < citiesCount; i++) {
			cities.add(new City(nextInt(), nextInt()));
		}
		int[][] distances = new int[citiesCount][citiesCount];
		for (int i = 0; i < citiesCount; i++) {
			distances[i] = new int[citiesCount];
			for (int j = 0; j < citiesCount; j++) {
				distances[i][j] = nextInt();
			}
		}
		int[][] pairs = new int[pairsCount][2];
		for (int i = 0; i < pairsCount; i++) {
			pairs[i] = new int[]{nextInt(), nextInt()};
		}

		double times[] = getTimes(cities, distances, pairs);
		DecimalFormat df = new DecimalFormat("0.000000");
			
		for (double time : times) {
			print(df.format(time));
			print(" ");
		}
	}

	private double[] getTimes(ArrayList<City> cities, int[][] distances, int[][] pairs) {
		double[] times = new double[pairs.length];
		int[] linearDistance = new int[distances.length];
		linearDistance[0] = -1;
		for (int i = 1; i < distances.length; i++) {
			linearDistance[i] = distances[i - 1][i];
		}
		for (int i = 0; i < times.length; i++) {
			times[i] = getTimes(cities, linearDistance);
		}
		return times;
	}

	private double getTimes(ArrayList<City> cities, int[] distances) {
		// System.out.println(Arrays.toString(distances));
		double[] best = new double[distances.length];
		for (int i = 0; i < best.length; i++) {best[i] = Double.MAX_VALUE;}
		best[best.length - 1] = 0;
		// System.out.println(Arrays.toString(best));
		for (int i = best.length - 2; i >= 0; i--) {
			int speed = cities.get(i).speed;
			int max = cities.get(i).max;
			int currIndex = i + 1;
			double time = 0;

			// System.out.println(i + "b: " + Arrays.toString(best));
			while (max > 0 && currIndex < distances.length && max >= distances[currIndex]) {
				// time to next city
				time += distances[currIndex] / (double) speed;
				max -= distances[currIndex];
				if (time + best[currIndex] < best[i]) {
					// System.out.println("C:" + currIndex + " t" + time + Arrays.toString(best));
					best[i] = time + best[currIndex];
				}
				currIndex++;
			}

			// System.out.println(i + ": " + Arrays.toString(best));
		}

		return best[0];
	}
	
	/**************************** 
	 * 		Set-up
	 ****************************/
	
	private Scanner in;
	private PrintStream out;

	public Solution () throws FileNotFoundException {
		in = new Scanner(new File(FILE_NAME + ".in"));	
		out = new PrintStream(FILE_NAME + ".out"); 

		int cases = nextInt();	
		for (int i = 1; i <= cases; i++) {
			print("Case #" + i + ": ");
			solve();
			println();
		}	

		out.close();
	}
	
	/**************************** 
	 * 		Manage input
	 ****************************/
	private int[] nextArray(int length) {
		int[] arr = new int[length];
		for (int i = 0; i < length; i++) {
			arr[i] = nextInt();
		}
		return arr;
	}
	
	private int[][] nextMatrix(int rows, int columns) {
		int[][] mat = new int[rows][columns];
		for (int r = 0; r < rows; r++) {
			for (int c = 0; c < columns; c++) {
				mat[r][c] = nextInt();
			}
		}
		return mat;
	}
	
	private String nextLine() {
		return in.nextLine();
	}
	private String next() {
		return in.next();
	}
	private int nextInt() {
		return in.nextInt();
	}
	private long nextLong() {
		return in.nextLong();
	}

	/**************************** 
	 * 		Manage output
	 ****************************/
	private void print(String s) { 
		System.out.print(s);
		out.print(s); 
	}	
	private void print(int i) { 
		System.out.print(i);
		out.print(i); 
	}
	private void print(long l) {
		System.out.println(l);
		out.print(l);
	}
	private void print(Object o) {
		System.out.print(o);
		print(o);
	}
	private void println() { 
		System.out.println();
		out.println(); 
	}
	
	public static void main(String[] args) {
		try {
			new Solution();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**************************** 
	 * 		Utils
	 ****************************/
	private static char[] cloneArray(char[] src) {
		return Arrays.copyOf(src, src.length);
	}

	private static int[] cloneArray(int[] src) {
		return Arrays.copyOf(src, src.length);
	}

	public static char[][] cloneArray(char[][] src) {
		int length = src.length;
		char[][] target = new char[length][src[0].length];
		for (int i = 0; i < length; i++) {
			System.arraycopy(src[i], 0, target[i], 0, src[i].length);
		}
		return target;
	}

	public static int[][] cloneArray(int[][] src) {
		int length = src.length;
		int[][] target = new int[length][src[0].length];
		for (int i = 0; i < length; i++) {
			System.arraycopy(src[i], 0, target[i], 0, src[i].length);
		}
		return target;
	}
}