package codejam.qualification;

import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Locale;
import java.util.Scanner;
import java.util.Set;
import java.util.TreeSet;


public class War {
	
	
	private static final String FILE_IN = "resources/D-large.in";
	private static final String FILE_OUT = "resources/D-large.out";
	
	
	private static final String OUT_FORMAT = "Case #%d: %d %d";
	
	public static void main(String[] args) throws IOException {
		Scanner in = new Scanner ( new File ( FILE_IN ) );
		Path outPath = Paths.get(FILE_OUT);
		Charset charset = Charset.forName("US-ASCII");
		List<String> outLines = new ArrayList<>();
		
		int testCount = in.nextInt();

		long allStart = System.currentTimeMillis();
		for ( int test = 0; test < testCount; ++test ) {
			InputData inputData = new InputData(in);
			int[] points = calculatePoints(inputData);
//			System.err.println("test: " + (test+1) + "; " + inputData + " ; points: " + Arrays.toString(points));
			outLines.add(String.format(Locale.ENGLISH, OUT_FORMAT, (test+1), points[0], points[1]));
		}
		in.close();
		long allEnd = System.currentTimeMillis();
		
		System.out.printf ( "%dms\n", allEnd-allStart );
		Files.write(outPath, outLines, charset, StandardOpenOption.WRITE, StandardOpenOption.CREATE, StandardOpenOption.TRUNCATE_EXISTING);
	}
	
	


	private static int[] calculatePoints(InputData inputData) {
		int wrongWar = calculateWrongWar(inputData);
		int war = calculateWar(inputData);
		
		return new int[]{wrongWar, war};
	}


	
	
	private static int calculateWrongWar(InputData inputData) {
		List<Double> naomies = new ArrayList<>(inputData.naomies);
		List<Double> kens = new ArrayList<>(inputData.kens);
		
		Collections.sort(naomies);
		Collections.sort(kens);
		
//		System.err.println(naomies);
//		System.err.println(kens);
		
		int points = 0;
		int size = naomies.size();
		for (int i = 0; i < size; i++){
			Double nBlock = naomies.get(i);
			Double kBlock = kens.get(i);
			if (Double.compare(nBlock, kBlock) > 0){
				points++;
			}else{
				kens.add(i, kens.get(size-1));
			}
		}
		
		return points;
	}


	private static int calculateWar(InputData inputData) {
		List<Double> naomies = new ArrayList<>(inputData.naomies);
		Set<Double> kens = new TreeSet<>(inputData.kens);
		int points = 0;
		for (Double nBlock : naomies){
			boolean struck = false;
			for (Double kBlock : kens){
				if (Double.compare(nBlock, kBlock) < 0){
					kens.remove(kBlock);
					struck = true;
					break;
				}
			}
			if (!struck){
				points++;
			}
		}
		return points;
	}






	private static class InputData {
		private int blocks;
		private List<Double> naomies;
		private List<Double> kens;
		
		public InputData(Scanner in){
			naomies = new ArrayList<>();
			kens = new ArrayList<>();
			blocks = in.nextInt();	
			for (int i = 0; i < blocks; i++){
				naomies.add(Double.valueOf(in.next()));
			}
			for (int i = 0; i < blocks; i++){
				kens.add(Double.valueOf(in.next()));
			}
		}

		@Override
		public String toString() {
			return "InputData [blocks=" + blocks + ", naomies=" + naomies
					+ ", kens=" + kens + "]";
		}
	}
}








