package codejam.qualification;

import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Scanner;


public class MagicTrick {
	
	
	private static final String FILE_IN = "resources/A-small-attempt0.in";
	private static final String FILE_OUT = "resources/A-small-attempt0.out";
	
	
	private static final String BAD = "Bad magician!";
	private static final String CHEATED = "Volunteer cheated!";

	
	
	private static final String OUT_FORMAT = "Case #%d: %s";
	
	public static void main(String[] args) throws IOException {
		Scanner in = new Scanner ( new File ( FILE_IN ) );
		Path outPath = Paths.get(FILE_OUT);
		Charset charset = Charset.forName("US-ASCII");
		List<String> outLines = new ArrayList<>();
		
		int testCount = in.nextInt();

		long allStart = System.currentTimeMillis();
		for ( int test = 0; test < testCount; ++test ) {
			Arrangement arrangement1 = new Arrangement(in);
			Arrangement arrangement2 = new Arrangement(in);
			String result = checkAnswers(arrangement1, arrangement2);
			outLines.add(String.format(Locale.ENGLISH, OUT_FORMAT, (test+1), result));
		}
		in.close();
		long allEnd = System.currentTimeMillis();
		
		System.out.printf ( "%dms\n", allEnd-allStart );
		Files.write(outPath, outLines, charset, StandardOpenOption.WRITE, StandardOpenOption.CREATE, StandardOpenOption.TRUNCATE_EXISTING);
	}
	
	
	private static String checkAnswers(Arrangement arrangement1, Arrangement arrangement2) {
		int[] row1 = arrangement1.getRow();
		int[] row2 = arrangement2.getRow();
		Map<Integer, Integer> intersection = new HashMap<>();
		for (int i = 0; i < row1.length; i++){
			intersection.put(row1[i], 0);
		}
		for (int i = 0; i < row2.length; i++){
			int card = row2[i];
			if (intersection.containsKey(card)){
				int count = intersection.get(card);
				intersection.put(card, ++count);
			}
		}
		String result = null;
		for (Map.Entry<Integer, Integer> entry : intersection.entrySet()){
			if (entry.getValue() == 1){
				if (result != null){
					return BAD;
				}
				result = entry.getKey().toString();
			}
		}
		if (result == null){
			result = CHEATED;
		}
		return result;
	}


	private static class Arrangement{
		private int row;
		private int[][] grid = new int[4][4];
		
		public Arrangement(Scanner in){
			row = in.nextInt();
			for (int i = 0; i < 4; i++){
				for (int j = 0; j < 4; j++){
					grid[i][j] = in.nextInt();
				}
			}
		}
		
		public int[] getRow(){
			return grid[row-1];
		}

		@Override
		public String toString() {
			StringBuilder sb = new StringBuilder(System.lineSeparator());
			for (int i = 0; i < 4; i++){
				for (int j = 0; j < 4; j++){
					sb.append(" ").append(grid[i][j]);
				}
				sb.append(System.lineSeparator());
			}
			return "Arrangement" + System.lineSeparator() + "[row=" + row +", " + System.lineSeparator() +  "grid=" +
					sb.toString() + "]";
		}
	}
}








