package codejam.round.one.b;

import java.io.File;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Locale;
import java.util.Scanner;
import java.util.SortedMap;
import java.util.TreeMap;
import java.util.concurrent.Future;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;


public class B {
	
	
	private static final String FILE_IN = "resources/B-small-attempt0.in";
	private static final String FILE_OUT = "resources/B-small-attempt0.out";
	
	private long allStart;
	
	private static final String OUT_FORMAT = "Case #%d: %s";
	
	
	private SortedMap<Integer, String> outputLines = Collections.synchronizedSortedMap(new TreeMap<Integer, String>());

    private ThreadPoolExecutor executor = new ThreadPoolExecutor(8, 8, 5, TimeUnit.DAYS, new LinkedBlockingQueue<Runnable>(), new ThreadFactory() {
        @Override
        public Thread newThread(Runnable r) {
            Thread thread = new Thread(r);
            thread.setDaemon(true);
            return thread;
        }
    });
	
	
	public static void main(String[] args) throws Exception {
		Scanner in = new Scanner ( new File ( FILE_IN ) );
		
		int testCount = in.nextInt();
		List<InputData> inputDataList = new ArrayList<>();
		for ( int test = 0; test < testCount; ++test ) {
			InputData inputData = new InputData(in);
			inputDataList.add(inputData);
		}
		in.close();
		B template = new B();
		template.run(inputDataList);
	}
	
	
	private void run(List<InputData> inputDataList) throws Exception {
		allStart = System.currentTimeMillis();
		
		Path outPath = Paths.get(FILE_OUT);
		Charset charset = Charset.forName("US-ASCII");

		List<Future<?>> tasks = new ArrayList<>(inputDataList.size());
		int i = 0;
		for (final InputData inputData : inputDataList){
			final int fi = i++;
			tasks.add(executor.submit(new Runnable() {
                @Override
                public void run() {
                    try {
                        runCase((fi+1), inputData);
                    } catch (Throwable t) {
                        t.printStackTrace();
                    }
                }
            }));
		}
		for (Future<?> task : tasks) {
            task.get();
        }
		long allEnd = System.currentTimeMillis();
		
		System.out.printf ( "%dms\n", allEnd-allStart );
		Files.write(outPath, outputLines.values(), charset, StandardOpenOption.WRITE, StandardOpenOption.CREATE, StandardOpenOption.TRUNCATE_EXISTING);
	}

	 public void runCase(int caseNumber, InputData inputData) {
		 long result = 0;
		 for (long ai = 0; ai < inputData.a; ai++){
			 for (long bi = 0; bi < inputData.b; bi++){
				 long and = ai & bi;
				 if (and < inputData.k){
					 result++;
				 }
			 }
		 }
		 outputLines.put(caseNumber, String.format(Locale.ENGLISH, OUT_FORMAT, caseNumber, result));
	 }

	private static class InputData {
		private long a;
		private long b;
		private long k;
		
		
		public InputData(Scanner in){
			a = in.nextLong();
			b = in.nextLong();
			k = in.nextLong();
		}


		@Override
		public String toString() {
			return "InputData [a=" + a + ", b=" + b + ", k=" + k + "]";
		}
	}
}








