package codejam.qualification;

import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Scanner;


public class CopyOfMinesweeper {
	
	
//	private static final String FILE_IN = "resources/minesweeper.in";
//	private static final String FILE_OUT = "resources/minesweeper.out";

	private static final String FILE_IN = "resources/C-small-attempt2.in";
	private static final String FILE_OUT = "resources/C-small-attempt2.out";

//	private static final String FILE_IN = "resources/minesweeper1.in";
//	private static final String FILE_OUT = "resources/minesweeper1.out";

	

	private static final String OUT_FORMAT = "Case #%d:";
	
	private static final String IMP = "Impossible";
	
	private static final char c = 'c';
	private static final char m = '*';
	private static final char e = '.';
	
	public static void main(String[] args) throws IOException {
		Scanner in = new Scanner ( new File ( FILE_IN ) );
		Path outPath = Paths.get(FILE_OUT);
		Charset charset = Charset.forName("US-ASCII");
		List<String> outLines = new ArrayList<>();
		
		int testCount = in.nextInt();

		long allStart = System.currentTimeMillis();
		for ( int test = 0; test < testCount; ++test ) {
			InputData inputData = new InputData(in);
//			System.err.println("Test Case # = " + (test+1) + " , input: " + inputData);
			List<String> result = findSolution(inputData);
			System.err.println("------------------------------");
			System.err.println("Test Case # = " + (test+1) + " , input: " + inputData + " and result: " );
			for (String entry : result){
				System.err.println(entry);
			}
			outLines.add(String.format(Locale.ENGLISH, OUT_FORMAT, (test+1)));
			for (String entry : result){
				outLines.add(entry);
			}
		}
		in.close();
		long allEnd = System.currentTimeMillis();
		
		System.out.printf ( "%dms\n", allEnd-allStart );
		Files.write(outPath, outLines, charset, StandardOpenOption.WRITE, StandardOpenOption.CREATE, StandardOpenOption.TRUNCATE_EXISTING);
	}
	
	
	
	
	private static List<String> findSolution(InputData inputData) {
		int rows 	= inputData.rows;
		int columns = inputData.columns;
		int mines	= inputData.mines;
		int size    = rows * columns;
		
		List<String> solution = new ArrayList<>();
		
			char[][] grid = new char[rows][columns];
			
			// fill by empty cells
			for (int i = 0; i < rows; i++){
				for (int j = 0; j < columns; j++){
					grid[i][j] = e;
				}
			}
			if (mines > 0){
				if (mines == (size-1)){
					// only 1 cell is not mined, fill all cells by mines
					for (int i = 0; i < rows; i++){
						for (int j = 0; j < columns; j++){
							grid[i][j] = m;
						}
					}
				}else{
					int minesToPlace = mines;
					if ((rows == 1) || (columns == 1)){
						// if only 1 row or column
						if (rows == 1){
							// only one row
							for (int i = (columns-1); minesToPlace > 0; minesToPlace--, i-- ){
								grid[0][i] = m;
							}
						}else{
							// only one column
							for (int i = (rows-1); minesToPlace > 0; minesToPlace--, i-- ){
								grid[i][0] = m;
							}
						}
					}
					else if ((size - mines) < 4){
						// if grid size - mines less than 4 it's impossible
						solution.add(IMP);
						return solution;
					}else{
						// place mines on grid (if possible)
						boolean possible = placeMinesOnGrid(grid, minesToPlace);
						if (!possible){
							solution.add(IMP);
							return solution;
						}
					}
					
				}
			}
			grid[0][0] = c;
			
			
			for (int i = 0; i < rows; i++){
				StringBuilder sb = new StringBuilder();
				for (int j = 0; j < columns; j++){
					sb.append(grid[i][j]);
				}
				solution.add(sb.toString());
			}
		return solution;
	}
	
	
	private static boolean placeMinesOnGrid(char[][] grid, int minesToPlace){
		boolean possible = false;
		int rows = grid.length;
		int columns = grid[0].length;
		
		// check rows
		possible = checkRows(rows, columns, minesToPlace);
		if (possible){
			placeMinesByRows(grid, rows, columns, minesToPlace);
		}else{
			possible = checkColumns(rows, columns, minesToPlace);
			if (possible){
				placeMinesByColumns(grid, rows, columns, minesToPlace);
			}else{
				int currentRow = rows-1;
				int currentColumn = columns-1;
				possible = checkRowsColumns(currentRow, currentColumn, minesToPlace);
				if (possible){
					placeMinesRowsColumns(grid, minesToPlace, currentRow, currentColumn);
				}else{
					possible = checkColumnsRows(currentRow, currentColumn, minesToPlace);
					if (possible){
						placeMinesColumnsRows(grid, minesToPlace, currentRow, currentColumn);
					}
				}
			}
		}
		
		return possible;
	}

	

	private static void placeMinesColumnsRows(char[][] grid, int minesToPlace, 	int currentRow, int currentColumn) {
		if (minesToPlace == 0){
			return;
		}
		// go through rows
		for (int i = (currentRow); i >= 0 && minesToPlace > 0; i--, minesToPlace--){
			if (minesToPlace == 1 && i == 1){
				break;
			}
			grid[i][currentColumn] = m;
		}
		
		if (minesToPlace == 0){
			return;
		}
		// go through columns
		for (int i = (currentColumn-1); i >= 0 && minesToPlace > 0; i--, minesToPlace--){
			grid[currentRow][i] = m;
		}
		
		if (minesToPlace > 0){
			placeMinesColumnsRows(grid, minesToPlace, currentRow-1, currentColumn-1);
		}
		
	}




	private static boolean checkColumnsRows(int currentRow, int currentColumn, int minesToPlace) {
		if ((currentRow < 2) || (currentColumn < 2)){
			return false;
		}
		// go through rows
		if (currentColumn > 1){
			minesToPlace -= (currentRow+1);
			if (minesToPlace ==0){
				return true;
			}else if (minesToPlace < 0){
				if (Math.abs(minesToPlace) > 1){
					return true;
				}else{
					minesToPlace = 1;
				}
			} 
		}
		
		// go through columns
		if (currentRow > 1){
			minesToPlace -= (currentColumn);
			if (minesToPlace ==0){
				return true;
			}else if (minesToPlace < 0){
				return (Math.abs(minesToPlace) > 1);
			} 
		}
		if (minesToPlace > 0){
			return checkColumnsRows(currentRow-1, currentColumn-1, minesToPlace);
		}else{
			return true;
		}
	}





	private static void placeMinesRowsColumns(char[][] grid, int minesToPlace, int currentRow, int currentColumn){
		if (minesToPlace == 0){
			return;
		}
		// go through columns
		for (int i = (currentColumn); i >= 0 && minesToPlace > 0; i--, minesToPlace--){
			if (minesToPlace == 1 && i == 1){
				break;
			}
			grid[currentRow][i] = m;
		}
		
		if (minesToPlace == 0){
			return;
		}
		// go through rows
		for (int i = (currentRow-1); i >= 0 && minesToPlace > 0; i--, minesToPlace--){
			grid[i][currentColumn] = m;
		}
		
		if (minesToPlace > 0){
			placeMinesRowsColumns(grid, minesToPlace, currentRow-1, currentColumn-1);
		}
	}




	private static boolean checkRowsColumns(int currentRow, int currentColumn, int minesToPlace) {
		if ((currentRow < 2) || (currentColumn < 2)){
			return false;
		}
		// go through columns
		if (currentRow > 1){
			minesToPlace -= (currentColumn+1);
			if (minesToPlace ==0){
				return true;
			}else if (minesToPlace < 0){
				if (Math.abs(minesToPlace) > 1){
					return true;
				}else{
					minesToPlace = 1;
				}
			} 
		}
		
		// go through rows
		if (currentColumn > 1){
			minesToPlace -= (currentRow);
			if (minesToPlace ==0){
				return true;
			}else if (minesToPlace < 0){
				return (Math.abs(minesToPlace) > 1);
			} 
		}
		if (minesToPlace > 0){
			return checkRowsColumns(currentRow-1, currentColumn-1, minesToPlace);
		}else{
			return true;
		}
	}




	private static void placeMinesByColumns(char[][] grid, int rows,
			int columns, int minesToPlace) {
		for (int column = (columns-1); (column >= 2 && minesToPlace > 0); column--){
			for (int row = (rows-1); (row >= 0 && minesToPlace > 0); row--, minesToPlace--){
				grid[row][column] = m;
			}
		}
		if (minesToPlace > 0){
			for (int row = (rows-1); (row >= 2 && minesToPlace > 0); row--){
				for (int column = 1; (column >= 0 && minesToPlace > 0); column--, minesToPlace--){
					grid[row][column] = m;
				}
			}
		}
		
	}




	private static void placeMinesByRows(char[][] grid, int rows, int columns, int minesToPlace) {
		for (int row = (rows-1); (row >= 2 && minesToPlace > 0); row--){
			for (int column = (columns-1); (column >= 0 && minesToPlace > 0); column--, minesToPlace--){
				grid[row][column] = m;
			}
		}
		if (minesToPlace > 0){
			for (int column = (columns-1); (column >= 2 && minesToPlace > 0); column--){
				for (int row = 1; (row >= 0 && minesToPlace > 0); row--, minesToPlace--){
					grid[row][column] = m;
				}
			}
		}
	}




	private static boolean checkColumns(int rows, int columns, int minesToPlace) {
		if (columns <=2){
			return false;
		}
		for (int column = (columns-1); (column >= 2 && minesToPlace > 0); column--){
			minesToPlace -= rows;
			if (minesToPlace ==0){
				return true;
			}else if (minesToPlace < 0){
				return (Math.abs(minesToPlace) > 1);
			}
		}
		int rowsTofilled = minesToPlace / 2;
		int reminder = minesToPlace % 2;
		if ((reminder > 0) || (rowsTofilled > ( rows-2))){
			return false;
		}
		return true;
	}




	private static boolean checkRows(int rows, int columns, int minesToPlace) {
		if (rows<=2){
			return false;
		}
		for (int row = (rows-1); (row >= 2 && minesToPlace > 0); row--){
			minesToPlace -= columns;
			if (minesToPlace ==0){
				return true;
			}else if (minesToPlace < 0){
				return (Math.abs(minesToPlace) > 1);
			}
		}
		int columnsTofilled = minesToPlace / 2;
		int reminder = minesToPlace % 2;
		if ((reminder > 0) || (columnsTofilled > ( columns-2))){
			return false;
		}
		return true;
	}

	private static class InputData {
		private int rows;
		private int columns;
		private int mines;
		
		public InputData(Scanner in){
			rows = in.nextInt();			
			columns = in.nextInt();	
			mines = in.nextInt();	
		}

		@Override
		public String toString() {
			return "InputData [rows=" + rows + ", columns=" + columns
					+ ", mines=" + mines + "]";
		}
	}
}








