package codejam.qualification;

import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Scanner;


public class Cookie {
	
	
	private static final String FILE_IN = "resources/B-small-attempt0.in";
	private static final String FILE_OUT = "resources/B-small-attempt0.out";
	
	private static final String OUT_FORMAT = "Case #%d: %.7f";
	
	private static double rate = 2d;
	
	public static void main(String[] args) throws IOException {
		Scanner in = new Scanner ( new File ( FILE_IN ) );
		Path outPath = Paths.get(FILE_OUT);
		Charset charset = Charset.forName("US-ASCII");
		List<String> outLines = new ArrayList<>();
		
		int testCount = in.nextInt();

		long allStart = System.currentTimeMillis();
		for ( int test = 0; test < testCount; ++test ) {
			InputData inputData = new InputData(in);
			double result = findSolution(inputData);
			outLines.add(String.format(Locale.ENGLISH, OUT_FORMAT, (test+1), result));
		}
		in.close();
		long allEnd = System.currentTimeMillis();
		
		System.out.printf ( "%dms\n", allEnd-allStart );
		Files.write(outPath, outLines, charset, StandardOpenOption.WRITE, StandardOpenOption.CREATE, StandardOpenOption.TRUNCATE_EXISTING);
	}
	
	
	
	
	private static double findSolution(InputData inputData) {
		
		double currentTime = inputData.targetCookies / rate;
		return find(inputData, rate, currentTime, 0);
	}
	
	
	private static double find(InputData inputData, double currentRate, double currentTime, double farmTotalTime){
		double farmTime = inputData.farmCost/currentRate;
		double newRate = currentRate + inputData.farmRate;
		farmTotalTime += farmTime;
		double newTime = (farmTotalTime + inputData.targetCookies/newRate);
		if (Double.compare(currentTime, newTime) < 0){
			return currentTime;
		}
		return find(inputData, newRate, newTime, farmTotalTime);
	}




	private static class InputData {
		private double farmCost;
		private double farmRate;
		private double targetCookies;
		
		public InputData(Scanner in){
			farmCost = Double.valueOf(in.next());			// in.nextDouble() ?
			farmRate = Double.valueOf(in.next());
			targetCookies = Double.valueOf(in.next());
		}

		@Override
		public String toString() {
			return "InputData [farmCost=" + farmCost + ", farmRate=" + farmRate
					+ ", targetCookies=" + targetCookies + "]";
		}
	}
}








