package bathroomstalls;

import common.Solver;

import java.io.PrintWriter;
import java.util.Scanner;

public class BathroomStallsCalculator implements Solver {
    @Override
    public void solveAllTests(Scanner in, PrintWriter out) {
        int noOfTests = Integer.valueOf(in.nextLine());
        for (int i = 1; i <= noOfTests; i++) {
            String[] testData = in.nextLine().split(" ");
            long noOfStalls = Long.valueOf(testData[0]);
            long noOfUsers = Long.valueOf(testData[1]);

            Solution solution = solve(noOfStalls, noOfUsers);

            out.println("Case #" + i + ": " + solution.max + " " + solution.min);
        }
    }

    private Solution solve(long noOfStalls, long noOfUsers) {
        return new Solver(noOfStalls, noOfUsers).solve();
    }

    private static class Solver {
        private final long noOfStalls;
        private final long totalUsers;


        private Solver(long noOfStalls, long totalUsers) {
            this.noOfStalls = noOfStalls;
            this.totalUsers = totalUsers;
        }

        private Solution solve() {
            if (noOfStalls == totalUsers) {
                return new Solution(0, 0);
            }

            OwnLinkedList linkedList = new OwnLinkedList();
            OwnNode firstNode = new OwnNode(1, noOfStalls);
            linkedList.add(firstNode);



            for (long i = 0; i < totalUsers - 1;) {
                OwnNode ownNode;
                if (linkedList.head.numberOfEntries + i > totalUsers - 1) {
                    ownNode = linkedList.popFirst(totalUsers - 1);
                } else {
                    ownNode = linkedList.popFirst();
                }
                i = i + ownNode.numberOfEntries;


                long lValue = (ownNode.totalArea - 1) / 2;
                if (lValue != 0) {
                    OwnNode leftNode = new OwnNode(ownNode.numberOfEntries, lValue);
                    linkedList.add(leftNode);
                }

                long rValue = ownNode.totalArea - 1 - lValue;
                if (rValue != 0) {
                    OwnNode rightNode = new OwnNode(ownNode.numberOfEntries, rValue);
                    linkedList.add(rightNode);
                }
            }

            OwnNode fin = linkedList.popFirst(1);
            long finLValue = (fin.totalArea - 1) / 2;
            long finRValue = fin.totalArea - 1 - finLValue;
            return new Solution(Math.max(finLValue, finRValue), Math.min(finLValue, finRValue));
        }
    }

    private final static class OwnLinkedList {
        private OwnNode head;
        private OwnNode tail;

        private OwnNode popFirst() {
            if (head.after == null) {
                OwnNode tempHead = head;
                head = null;
                tail = null;
                return tempHead;
            } else {
                OwnNode tempHead = head;
                head = tempHead.after;
                head.previous = null;
                return tempHead;
            }
        }

        private OwnNode popFirst(long numberToPop) {
            if (head.numberOfEntries > numberToPop) {
                return popFirst();
            } else {
                head.numberOfEntries = head.numberOfEntries - numberToPop;
                return new OwnNode(numberToPop, head.totalArea);
            }
        }

        private void add(OwnNode nodeToAdd) {
            if (head == null && tail == null) {
                head = nodeToAdd;
                tail = nodeToAdd;
            } else {
                OwnNode prev = tail;
                OwnNode after = null;
                while (prev != null && nodeToAdd.totalArea > prev.totalArea) {
                    after = prev;
                    prev = prev.previous;
                }

                if (prev != null && prev.totalArea == nodeToAdd.totalArea) {
                    prev.numberOfEntries = prev.numberOfEntries + nodeToAdd.numberOfEntries;
                } else if (after != null && after.totalArea == nodeToAdd.totalArea) {
                    after.numberOfEntries = after.numberOfEntries + nodeToAdd.numberOfEntries;
                } else {
                    nodeToAdd.after = after;
                    nodeToAdd.previous = prev;

                    if (prev != null) {
                        prev.after = nodeToAdd;
                    } else {
                        head = nodeToAdd;
                    }

                    if (after != null) {
                        after.previous = nodeToAdd;
                    } else {
                        tail = nodeToAdd;
                    }
                }
            }
        }
    }

    private final static class OwnNode {
        private long numberOfEntries;
        private long totalArea;

        private OwnNode previous;
        private OwnNode after;

        private OwnNode(long numberOfEntries, long totalArea) {
            this.numberOfEntries = numberOfEntries;
            this.totalArea = totalArea;
        }

        private boolean isBefore(OwnNode tail) {
            return tail.totalArea < totalArea;
        }
    }

    private static class Solution {
        private final long max;
        private final long min;

        private Solution(long max, long min) {
            this.max = max;
            this.min = min;
        }
    }
}
