package bathroomstalls;

import common.Solver;

import java.io.PrintWriter;
import java.util.Scanner;

public class BathroomStallsCalculator2 implements Solver {
    @Override
    public void solveAllTests(Scanner in, PrintWriter out) {
        int noOfTests = Integer.valueOf(in.nextLine());
        for (int i = 1; i <= noOfTests; i++) {
            String[] testData = in.nextLine().split(" ");
            long noOfStalls = Long.valueOf(testData[0]);
            long noOfUsers = Long.valueOf(testData[1]);

            BathroomStallsCalculator2.Solution solution = solve(noOfStalls, noOfUsers);

            out.println("Case #" + i + ": " + solution.max + " " + solution.min);
        }
    }

    private BathroomStallsCalculator2.Solution solve(long noOfStalls, long noOfUsers) {
        return new BathroomStallsCalculator2.Solver(noOfStalls, noOfUsers).solve();
    }

    private static class Solver {
        private final long noOfStalls;
        private final long totalUsers;


        private Solver(long noOfStalls, long totalUsers) {
            this.noOfStalls = noOfStalls;
            this.totalUsers = totalUsers;
        }

        private BathroomStallsCalculator2.Solution solve() {
            if (noOfStalls == totalUsers) {
                return new BathroomStallsCalculator2.Solution(0, 0);
            }

            BathroomStallsCalculator2.OwnLinkedList linkedList = new BathroomStallsCalculator2.OwnLinkedList();
            BathroomStallsCalculator2.OwnNode firstNode = new BathroomStallsCalculator2.OwnNode((noOfStalls - 1) / 2, (noOfStalls - 1) / 2, (noOfStalls - 1) - (noOfStalls - 1) / 2);
            linkedList.add(firstNode);

            for (int i = 0; i < totalUsers - 1; i++) {
                BathroomStallsCalculator2.OwnNode ownNode = linkedList.popFirst();

                if (ownNode.lValue != 0) {
                    BathroomStallsCalculator2.OwnNode leftNode = new BathroomStallsCalculator2.OwnNode(ownNode.id - (ownNode.lValue - 1) - (ownNode.lValue - 1) / 2 - 1,
                                                                                                     (ownNode.lValue - 1) / 2,
                                                                                                     (ownNode.lValue - 1) - (ownNode.lValue - 1) / 2);
                    linkedList.add(leftNode);
                }

                if (ownNode.rValue != 0) {
                    BathroomStallsCalculator2.OwnNode rightNode = new BathroomStallsCalculator2.OwnNode(ownNode.id + (ownNode.rValue - 1) - (ownNode.rValue - 1) / 2 + 1,
                                                                                                      (ownNode.rValue - 1) / 2,
                                                                                                      (ownNode.rValue - 1) - (ownNode.rValue - 1) / 2);
                    linkedList.add(rightNode);
                }
            }

            BathroomStallsCalculator2.OwnNode fin = linkedList.popFirst();
            return new BathroomStallsCalculator2.Solution(Math.max(fin.lValue, fin.rValue), Math.min(fin.lValue, fin.rValue));
        }
    }

    private final static class OwnLinkedList {
        private BathroomStallsCalculator2.OwnNode head;
        private BathroomStallsCalculator2.OwnNode tail;

        private BathroomStallsCalculator2.OwnNode popFirst() {
            if (head.after == null) {
                BathroomStallsCalculator2.OwnNode tempHead = head;
                head = null;
                tail = null;
                return tempHead;
            } else {
                BathroomStallsCalculator2.OwnNode tempHead = head;
                head = tempHead.after;
                head.previous = null;
                return tempHead;
            }
        }

        private void add(BathroomStallsCalculator2.OwnNode nodeToAdd) {
            if (head == null && tail == null) {
                head = nodeToAdd;
                tail = nodeToAdd;
            } else {
                BathroomStallsCalculator2.OwnNode prev = tail;
                BathroomStallsCalculator2.OwnNode after = null;
                while (prev != null && nodeToAdd.isBefore(prev)) {
                    after = prev;
                    prev = prev.previous;
                }

                nodeToAdd.after = after;
                nodeToAdd.previous = prev;

                if (prev != null) {
                    prev.after = nodeToAdd;
                } else {
                    head = nodeToAdd;
                }

                if (after != null) {
                    after.previous = nodeToAdd;
                } else {
                    tail = nodeToAdd;
                }
            }
        }
    }

    private final static class OwnNode {
        private long id;
        private long lValue;
        private long rValue;

        private BathroomStallsCalculator2.OwnNode previous;
        private BathroomStallsCalculator2.OwnNode after;

        private OwnNode() {

        }

        private OwnNode(long id, long lValue, long rValue) {
            this.id = id;
            this.lValue = lValue;
            this.rValue = rValue;
        }

        private boolean isBefore(BathroomStallsCalculator2.OwnNode tail) {
            long tailMin = Math.min(tail.lValue, tail.rValue);
            long nodeMin = Math.min(lValue, rValue);

            if (tailMin > nodeMin) {
                return false;
            } else if (tailMin == nodeMin) {
                long tailMax = Math.max(tail.lValue, tail.rValue);
                long nodeMax = Math.max(lValue, rValue);

                if (tailMax > nodeMax) {
                    return false;
                } else if (tailMax == nodeMax) {
                    return id < tail.id;
                } else {
                    return true;
                }
            } else {
                return true;
            }
        }
    }

    private static class Solution {
        private final long max;
        private final long min;

        private Solution(long max, long min) {
            this.max = max;
            this.min = min;
        }
    }
}
