package oneb;

import common.Solver;

import java.io.PrintWriter;
import java.util.*;
import java.util.stream.Collectors;

public class Calculator implements Solver {
    @Override
    public void solveAllTests(Scanner in, PrintWriter out) {
        int noOfTests = Integer.valueOf(in.nextLine());
        for (int i = 1; i <= noOfTests; i++) {
            String[] testData = in.nextLine().split(" ");
            long noOfKm = Long.valueOf(testData[0]);
            long noOfHorses = Long.valueOf(testData[1]);

            Collection<HorseData> horseDatas = new ArrayList<>();
            for (int j = 0; j < noOfHorses; j++) {
                String[] horseData = in.nextLine().split(" ");
                horseDatas.add(new HorseData(Long.valueOf(horseData[0]), Long.valueOf(horseData[1])));
            }

            double solution = solve(noOfKm, horseDatas);

            out.println("Case #" + i + ": " + solution);
        }
    }

    private double solve(double noOfKm, Collection<HorseData> horseDatas) {
        Comparator<HorseData> comparing = Comparator.comparing(h -> (h.startPosition));
        List<HorseData> orderedByLastFirst = horseDatas.stream()
                                                       .sorted(comparing.reversed())
                                                       .collect(Collectors.toList());
        HorseData prev = orderedByLastFirst.get(0);
        orderedByLastFirst.remove(0);


        // x, v, y, u
        // x + d1 = y + d2
        // x + vt = y + ut
        //

        for (HorseData data : orderedByLastFirst) {
            if (data.maxSpeed <= prev.maxSpeed) {
                return noOfKm / (noOfKm - data.startPosition) * (data.maxSpeed);
            }

            double t0 = (prev.startPosition - data.startPosition) / (data.maxSpeed - prev.maxSpeed);
            double d = t0 * data.maxSpeed;
            if (noOfKm - d >= data.startPosition) {
                // only consider first one
                return noOfKm / (noOfKm - prev.startPosition) * (prev.maxSpeed);
            } else {
                // only consider the last one
                return noOfKm / (noOfKm - data.startPosition) * (data.maxSpeed);
            }
        }

        return noOfKm / (noOfKm - prev.startPosition) * (prev.maxSpeed);
    }

    private static class HorseData {
        private final long startPosition;
        private final long maxSpeed;

        private HorseData(long startPosition, long maxSpeed) {
            this.startPosition = startPosition;
            this.maxSpeed = maxSpeed;
        }
    }
}
