package oversizedpancakeflipper;

import common.Solver;

import java.io.PrintWriter;
import java.util.Scanner;

public class PancakeCalculator implements Solver {
    private static class PancakeScenario {
        private final boolean[] pancakeConfiguration;
        private final int flipperSize;

        private PancakeScenario(boolean[] pancakeConfiguration, int flipperSize) {
            this.pancakeConfiguration = pancakeConfiguration;
            this.flipperSize = flipperSize;
        }

        private void flipFrom(int leftMostPosition) {
            for (int i = leftMostPosition; i < leftMostPosition + flipperSize; i++) {
                pancakeConfiguration[i] = !pancakeConfiguration[i];
            }
        }

        private boolean solved() {
            for (boolean config : pancakeConfiguration) {
                if (!config) {
                    return false;
                }
            }

            return true;
        }
    }

    @Override
    public void solveAllTests(Scanner in, PrintWriter out) {
        int noOfTests = Integer.valueOf(in.nextLine());
        for (int i = 1; i <= noOfTests; i++) {
            PancakeScenario pancakeScenario = readSingleTest(in);
            PancakeSolution solution = solve(pancakeScenario);
            out.println("Case #" + i + ": " + solution.toString());
        }
    }

    private static PancakeScenario readSingleTest(Scanner in) {
        String s = in.nextLine();
        String[] split = s.split(" ");

        boolean[] pancakeConfig = new boolean[split[0].length()];
        for (int i = 0; i < split[0].length(); i++) {
            pancakeConfig[i] = split[0].charAt(i) == '+';
        }

        int flipperSize = Integer.valueOf(split[1]);

        return new PancakeScenario(pancakeConfig, flipperSize);
    }

    private static PancakeSolution solve(PancakeScenario pancakeScenario) {
        int flips = 0;

        for (int i = 0; i <= pancakeScenario.pancakeConfiguration.length - pancakeScenario.flipperSize; i++) {
            if (!pancakeScenario.pancakeConfiguration[i]) {
                pancakeScenario.flipFrom(i);
                flips++;
            }
        }

        if (pancakeScenario.solved()) {
            return new PancakeSolution(flips);
        } else {
            return PancakeSolution.impossible();
        }
    }

    private static class PancakeSolution {
        private final int minFlips;

        private PancakeSolution(int minFlips) {
            this.minFlips = minFlips;
        }

        private static PancakeSolution impossible() {
            return new PancakeSolution(-1);
        }


        @Override
        public String toString() {
            return minFlips == -1 ? "IMPOSSIBLE" : "" + minFlips;
        }
    }
}
