package gcj.b;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Scanner;

public class BTest {

    public static void main(String[] args) {
        new SolveProblem().solve();
    }

    public static class SolveProblem {

        private Scanner sc = null;
        private StringBuilder sb = new StringBuilder();

        public SolveProblem() {
            loadInput();
        }

        private void loadInput() {
            try {
                sc = new Scanner(new FileReader("in.txt"));
            } catch (FileNotFoundException ex) {
                ex.printStackTrace();
                System.exit(-1);
            }
        }

        private void saveSolution() {
            try {
                PrintWriter pw = new PrintWriter("out.txt");
                pw.append(sb.toString());
                pw.flush();
                pw.close();
            } catch (FileNotFoundException ex) {
                ex.printStackTrace();
                System.exit(-1);
            }
        }

        public void solve() {
            int T = sc.nextInt();
            sc.nextLine();
            for (int caseNumber = 1; caseNumber <= T; caseNumber++) {
                sb.append("Case #").append(caseNumber).append(": ");
                sb.append(solveTestCase(sc)).append("\n");
            }

            System.out.print(sb.toString());
            saveSolution();
        }

        private String solveTestCase(Scanner sc) {
            Integer m = 0;
            Integer D = Integer.parseInt(sc.nextLine());
            String[] dinners = sc.nextLine().trim().split(" ");
            m = calculateEatingTime(sortDinners(dinners));
            return m.toString();
        }

        private List<Integer> sortDinners(String[] dinners) {
            List<Integer> list = new ArrayList();
            for (String str : Arrays.asList(dinners)) {
                list.add(Integer.parseInt(str));
            }
            list.sort(Collections.reverseOrder());
            return list;
        }

        private Integer calculateEatingTime(List<Integer> ds) {
            return shufflePancakes(ds);
        }

        private int shufflePancakes(List<Integer> ds) {
            int currentCost = Collections.max(ds);
            int shuffleCost = 0;
            for (Integer n : ds) {
                if (shuffleCost == 0) {
                    Node node = getNode(n);
                    if (node.cost < currentCost) {
                        shuffleCost = node.cost;
                    } else {
                        shuffleCost = currentCost;
                    }
                } else if(n>shuffleCost) {
                   shuffleCost++;
                }
                if(shuffleCost>=currentCost){
                    return currentCost;
                }
            }
            return shuffleCost;
        }

        private static Map<Integer, Node> shuffleCost = new HashMap();

        public static Node getNode(int n) {
            if (!shuffleCost.containsKey(n)) {
                shuffleCost.put(n, new Node(n));
            }
            return shuffleCost.get(n);
        }

        private static class Node {

            public int cost, a, b;

            public Node(int n) {
                if (n > 2) {
                    a = n / 2;
                    b = n - a;
                    cost = Math.max(a, b) + 1;
                } else {
                    a = 1;
                    b = 1;
                    cost = 2;
                }
            }

        }

        @Override
        protected void finalize() {
            sc.close();
        }

    }

}
