package googleCodeJam2014;

import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;
import java.util.Scanner;

public class Minesweeper {
	final static String WORK_DIR = "/home/cae/code/googleCodeJam/";

	public static void main(String[] args) throws IOException {
		// TODO Auto-generated method stub
		Scanner sc = new Scanner(new FileReader(WORK_DIR + "minesweeper.txt"));
		PrintWriter pw = new PrintWriter(
				new FileWriter(WORK_DIR + "output.txt"));
		int caseCnt = sc.nextInt();
		sc.nextLine();
		long ini = Calendar.getInstance().getTimeInMillis();
		for (int caseNum = 0; caseNum < caseCnt; caseNum++) {
			System.out.println("Processing test case " + (caseNum + 1));
			pw.print("Case #" + (caseNum + 1) + ": ");
			new Minesweeper().solve(sc, pw);
			pw.println();
		}
		System.out.println(Calendar.getInstance().getTimeInMillis() - ini);
		pw.flush();
		pw.close();
		sc.close();
	}

	private void solve(Scanner sc, PrintWriter pw) {
		String line = sc.nextLine();
		String[] split = line.split(" ");
		int inputRows = Integer.parseInt(split[0]);
		int inputColumns = Integer.parseInt(split[1]);
		int inputMines = Integer.parseInt(split[2]);

		boolean bidimensional = inputRows > 1 && inputColumns > 1
				&& (inputRows * inputColumns) - inputMines >= 4;
		boolean unidimensional = (inputRows == 1 || inputColumns == 1)
				&& (inputRows * inputColumns) - inputMines >= 2;
		boolean zero = (inputRows == 1 && inputColumns == 1 && inputMines == 0);
		boolean oneEmpty = (inputRows * inputColumns - inputMines == 1);
		List<List<Cell>> board = new ArrayList<List<Cell>>();

		if (unidimensional || bidimensional || zero || oneEmpty) {
			fillSolutionBoard(inputRows, inputColumns, inputMines, board);
			if (unidimensional || oneEmpty || isValidBoard(board, inputRows, inputColumns, inputMines)) {
				printSolutionBoard(pw, inputRows, inputColumns, board);
			} else {
				pw.println();
				pw.print("Impossible");
			}
		} else {
			pw.println();
			pw.print("Impossible");
		}
	}

	private boolean isValidBoard(List<List<Cell>> board, int inputRows,
			int inputColumns, int inputMines) {
		int validatedMines = 0;
		for (int i = 0; i < inputRows; i++) {
			for (int j = 0; j < inputColumns; j++) {
				if (!board.get(i).get(j).isMine()) {
					if (countProxMines(board, i, j) == 0) {
						validatedMines += getValidatedCloseCells(board, i, j);
					}
				}
			}
		}
		return validatedMines == inputRows * inputColumns - inputMines;
	}

	private int getValidatedCloseCells(List<List<Cell>> board, int i, int j) {
		int count = 0;
		for (int desvi = -1; desvi < 2; desvi++) {
			for (int desvj = -1; desvj < 2; desvj++) {
				if (i + desvi >= 0 && i + desvi < board.size()
						&& j + desvj >= 0 && j + desvj < board.get(0).size()) {
					if (!board.get(i + desvi).get(j + desvj).isMine()
							&& !board.get(i + desvi).get(j + desvj).valid) {
						board.get(i + desvi).get(j + desvj).valid = true;
						count++;
					}
				}
			}
		}
		return count;
	}

	private int countProxMines(List<List<Cell>> board, int i, int j) {
		int count = 0;
		for (int desvi = -1; desvi < 2; desvi++) {
			for (int desvj = -1; desvj < 2; desvj++) {
				if (i + desvi >= 0 && i + desvi < board.size()
						&& j + desvj >= 0 && j + desvj < board.get(0).size()) {
					if (board.get(i + desvi).get(j + desvj).isMine()) {
						count++;
					}
				}
			}
		}
		if(!board.get(i).get(j).valid && board.get(i).get(j).render.equals("c")){
			count++;
		}
		return count;
	}

	private void fillSolutionBoard(int inputRows, int inputColumns,
			int inputMines, List<List<Cell>> board) {
		createSolutionBoard(inputRows, inputColumns, board);
		int count = 0;
		int mines = 0;
		int row=0;
		int col=0;
		boolean rowtry=inputRows>inputColumns;
		while (mines < inputMines) {
			if (inputRows == inputColumns) {
				if (rowtry) {
					for (int i = 0; i < inputColumns && mines < inputMines; i++) {
						if(!board.get(row).get(i).isMine()){
							board.get(row).set(i, new Cell("*"));
							mines++;
						}
					}
					row++;
				}
				if (!rowtry) {
					for (int i = 0; i < inputRows && mines < inputMines; i++) {
						if(!board.get(i).get(col).isMine()){
							board.get(i).set(col, new Cell("*"));
							mines++;
						}
					}
					col++;
				}
				rowtry=!rowtry;
			} else if (inputRows > inputColumns) {
				for (int i = 0; mines < inputMines; i++) {
					if(!board.get(i / inputRows).get(i % inputColumns).isMine()){
						board.get(i / inputRows).set(i % inputColumns, new Cell("*"));
						mines++;	
					}
				}
			} else if (inputRows < inputColumns) {
				for (int i = 0;mines < inputMines; i++) {
					if(!board.get(i % inputRows).get(i / inputColumns).isMine()){
						board.get(i % inputRows).set(i / inputColumns,new Cell("*"));
						mines++;
					}
				}
			}
			count++;
		}
		board.get(inputRows - 1).set(inputColumns - 1, new Cell("c"));
	}

	private void createSolutionBoard(int inputRows, int inputColumns,
			List<List<Cell>> board) {
		for (int i = 0; i < inputRows; i++) {
			List<Cell> row = new ArrayList<Cell>();
			board.add(row);
			for (int j = 0; j < inputColumns; j++) {
				row.add(new Cell("."));
			}
		}
	}

	private void printSolutionBoard(PrintWriter pw, int m, int r,
			List<List<Cell>> board) {
		for (int i = 0; i < m; i++) {
			pw.println();
			for (int j = 0; j < r; j++) {
				pw.print(board.get(i).get(j).render);
			}
		}
	}

	private class Cell {
		public Cell(String render) {
			this.render = render;
		}

		public boolean isMine() {
			return render.equals("*");
		}

		public String render = "";
		public int closeMines = 0;
		public boolean valid = false;

	}
}
