import java.io.BufferedReader;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.PrintStream;
import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;


public class PalindromeApp {

    private static int numberOfTestCases = 0;
    private static ArrayList<String> fileStrings = new ArrayList<String>();


    public static void main(String[] args) throws Exception {
        PrintStream out = new PrintStream(new FileOutputStream("fair_square_small_output.txt"));
        System.setOut(out);
        //System.err.println("starting the palindrome game from " + System.getProperty("user.dir"));
        //System.out.println("parsing the file..." + args[0]);
        parseFile(args[0]);
        verifyNumberOfTestCases();
        //System.err.println("number of test cases found: " + fileStrings.size());
        analyzeTestCases();
    }

    private static void analyzeTestCases() {
        int min = Integer.MIN_VALUE;
        int max = Integer.MAX_VALUE;

        int testIndex = 0;

        for (String testCase : fileStrings) {
            testIndex++;
            String[] testRange = testCase.split(" ");
            min = Integer.parseInt(testRange[0]);
            max = Integer.parseInt(testRange[1]);
            assert (min <= max);
            ArrayList candidatePalindromes = findCandidatePalindromes(min, max);
            int numberFairAndSquare = 0;
            if (candidatePalindromes.isEmpty() == false) {
                numberFairAndSquare = findFairAndSquare(candidatePalindromes);
                //System.out.println("Case #" + testIndex + ": " + numberFairAndSquare);
            }
            System.out.println("Case #" + testIndex + ": " + numberFairAndSquare);

        }

    }

    private static boolean isAPalindrome(int number) {
        String firstWay = "" + number;
        String secondWay = new StringBuilder(firstWay).reverse().toString();
        return firstWay.equals(secondWay);
    }

    private static int findFairAndSquare(ArrayList<Integer> candidatePalindromes) {
        ArrayList<Integer> fairAndSquares = new ArrayList<Integer>();
        //System.out.println("Reviewing " + candidatePalindromes.size() + " Candidate Palindromes.");
        for (Integer candidate : candidatePalindromes) {
            if (isAnIntegerSquare(candidate) && isAPalindrome((int) Math.sqrt(candidate))) {
                fairAndSquares.add(candidate);
            }
        }

        return fairAndSquares.size();
    }

    private static boolean isAnIntegerSquare(Integer candidate) {
        if (candidate < 0) {
            return false;
        }
        long sqrt = (long) (Math.sqrt(candidate));
        return sqrt * sqrt == candidate;
    }

    private static ArrayList<Integer> findCandidatePalindromes(int min, int max) {
        //System.out.println("searching for palindromes between " + min + " and " + max);
        ArrayList<Integer> holding = new ArrayList();
        for (int i = min; i <= max; i++) {
            if (isAPalindrome(i)) {
                holding.add(i);
            }
        }

        return holding;
    }

    private static void parseFile(String fileName) throws Exception {
        FileReader input = new FileReader(fileName);
        BufferedReader bufRead = new BufferedReader(input);
        String myLine = bufRead.readLine();
        calculateNumberOfTestCases(myLine);

        while ((myLine = bufRead.readLine()) != null) {
            if (myLine.isEmpty() == false) {
                fileStrings.add(myLine);
            }
        }
    }

    private static void calculateNumberOfTestCases(String myLine) {
        PalindromeApp.numberOfTestCases = Integer.parseInt(myLine);
    }

    private static void verifyNumberOfTestCases() {
        if (fileStrings.size() != numberOfTestCases) {
            throw new IllegalStateException();
        }
    }
}
