import java.io.BufferedReader;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class MagicTrick {

    private static int numberOfTestCases;
    private static ArrayList<TestCase> tests = new ArrayList<TestCase>();
    private static ArrayList<String> fileStrings = new ArrayList<String>();

    public static void main(String[] args) throws Exception {
        //System.err.println("Hello Magician World!");
        //System.err.println("starting the game from " + System.getProperty("user.dir"));
        String fileName =  args[0];
        //System.err.println("parsing the file..." + fileName);
        parseFile(fileName);
        //System.out.println("file strings contains " + fileStrings.size());
        generateTestCases();
        evaluateTestCases();
        printTestResults();
        //System.err.println("magic show completed");
    }

    private static void printTestResults() throws Exception {
        PrintStream out = new PrintStream(new FileOutputStream("magicresults.txt"));
        System.setOut(out);
        for (TestCase testCase : tests) {
            String testResult = null;
            if (testCase.result == 100) {
                testResult = "Bad magician!";
            } else if (testCase.result == -99) {
                testResult= "Volunteer cheated!";
            }  else {
                testResult = "" + testCase.result;
            }

            System.out.println("Case #" + testCase.testCaseNumber +": " + testResult);
        }
    }

    private static void evaluateTestCases() {
        for (TestCase testCase : tests) {
            String result;
            int foundCount = 0;

            //System.out.println("Test Case " + testCase.testCaseNumber);

            for (int number : testCase.secondArray) {
                //System.out.println("checking for second row char: " + number);
                for (int k = 0; k < testCase.firstArray.length; k++)
                    //System.out.println("first row: contains " + number + " : " + testCase.firstRow);
                    if (testCase.firstArray[k] == number) {
                        testCase.result = number;
                        foundCount++;
                    }
            }

            if (foundCount == 0) {
                testCase.result = -99;
            } else if (foundCount > 1) {
                testCase.result = 100;
            }
            //System.out.println("Test Case " + testCase.testCaseNumber + " result: " + testCase.result );
        }

    }


    private static void parseFile(String fileName) throws Exception {
        FileReader input = new FileReader(fileName);
        BufferedReader bufRead = new BufferedReader(input);
        String myLine = bufRead.readLine();
        calculateNumberOfTestCases(myLine);

        while ((myLine = bufRead.readLine()) != null) {
            //System.out.println("line: " + myLine);
                fileStrings.add(myLine);

        }
    }

    private static void generateTestCases() {
        ArrayList<String> individualTest = new ArrayList<String>(10);
        TestCase testCase;
        int numberOfTest = 1;
        for (int i = 0, j=0; i < fileStrings.size(); i++,j++) {
            //System.out.println("file string: " + i + " " + fileStrings.get(i));
            individualTest.add(fileStrings.get(i));
            if (individualTest.size() == 10) {
                testCase = new TestCase(numberOfTest, individualTest);
                tests.add(testCase);
                individualTest = new ArrayList<String>(10);
                numberOfTest++;
                j = 0;
            }
        }
        //System.out.println("number of tests generated: " + tests.size());
    }

    private static void calculateNumberOfTestCases(String myLine) {
        MagicTrick.numberOfTestCases = Integer.parseInt(myLine);
        //System.err.println("number of test cases expected: " + MagicTrick.numberOfTestCases);
    }

    private static void verifyNumberOfTestCases() {
        if (numberOfTestCases != tests.size() ) {
            //System.err.println("failed number of tests found: " + tests.size());
            throw new IllegalStateException();
        }
    }

    static class TestCase {
        int testCaseNumber;
        int firstGuess;
        int secondGuess;

        String firstRow;
        String secondRow;

        int[] firstArray = new int[4];
        int[] secondArray = new int[4];

        int result = -1;

        public TestCase(int numberOfTest, ArrayList<String> individualTest) {
            testCaseNumber = numberOfTest;
            //System.out.println("creating test: " + numberOfTest);

            firstGuess = Integer.parseInt(individualTest.get(0));
            //System.out.println("firstguess = " + firstGuess);
            firstRow = individualTest.get(firstGuess);
            secondGuess = Integer.parseInt(individualTest.get(5));
            //System.out.println("secondguess = " + secondGuess);
            secondRow = individualTest.get(5 + secondGuess);
            String[] firstSplit=firstRow.split(" ");
            String[] secondSplit=secondRow.split(" ");
            for (int i = 0; i < 4; i++) {
                firstArray[i] = Integer.parseInt(firstSplit[i]);
            }
            for (int i = 0; i < 4; i++) {
                secondArray[i] = Integer.parseInt(secondSplit[i]);
            }
            //System.out.println("test case: " + testCaseNumber + " first row: " + firstRow + " second row: " + secondRow);
        }
    }
}
