package com.company;

import java.math.BigInteger;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.IntStream;

public class Fractiles {

    public static void main(final String[] args){
        final Scanner s = new Scanner(System.in);
        final int T = s.nextInt();
        for(int i = 0; i < T; i++) {
            final int K = s.nextInt();
            final int C = s.nextInt();
            final int S = s.nextInt();
            System.out.printf("Case #%d: %s\n", i + 1, solve(K, C, S));
        }
    }

    public static String solve(final int K, final int C, final int S) {
        if (K == 1) {
            if (S < 1) {
                return "IMPOSSIBLE";
            }
            else{
                return "1";
            }
        }

        if (C == 1){
            if (S < K) {
                return "IMPOSSIBLE";
            }
            else return IntStream.rangeClosed(1, K).mapToObj(String::valueOf).collect(Collectors.joining(" "));
        }

        if (((K + 1)/ 2) > S) {
            return "IMPOSSIBLE";
        }

        // A known index of the original fractal position is given by an AOP_C-1(K) * (index)
        final BigInteger gap = aop(C - 1, K);
        final Queue<BigInteger> results = new LinkedList<>();

        for (int i = 0; i < (K + 1)/2; i++) {
            if (i == K/2) {
                results.add(gap.multiply(BigInteger.valueOf(i)));
            }
            else {
                results.add(gap.multiply(BigInteger.valueOf(i)).add(BigInteger.ONE));
                results.add(gap.multiply(BigInteger.valueOf(K - 1 - i)).subtract(BigInteger.ONE));
            }
        }
        return results.stream().limit(S).map(BigInteger.ONE::add).map(BigInteger::toString).collect(Collectors.joining(" "));
    }

    /**
     * Get the AOP value for a given c, k
     * https://en.wikipedia.org/wiki/All_one_polynomial
     *
     * @param c complexity
     * @param k set size
     */
    public static BigInteger aop(final int c, final int k) {
        return BigInteger.valueOf(k).pow(c + 1).subtract(BigInteger.ONE).divide(BigInteger.valueOf(k - 1));
    }

}
