package firstRound;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;

public class RobotTrust {
	private class StepEntry {
		
		private String robot;
		private int pos;
		
		public StepEntry(String robot, int pos) {
			this.robot = robot;
			this.pos = pos;
		}
		
		public String getRobot() {
			return robot;
		}
		
		public int getPos() {
			return pos;
		}
		
	}
	public ArrayList<ArrayList<StepEntry>> readInput(String filename) throws IOException {
		
		ArrayList<ArrayList<StepEntry>> res = new ArrayList<ArrayList<StepEntry>>();
		
		BufferedReader in = new BufferedReader(new FileReader(filename));
		in.readLine();
		String line = in.readLine();
		
		while (line != null) {
			String[] chunks = line.split(" ");
			ArrayList<StepEntry> newTestCase = new ArrayList<StepEntry>();
			for (int i = 1; i < chunks.length; i = i + 2) {
				newTestCase.add(new StepEntry(chunks[i], Integer.parseInt(chunks[i + 1])));
			}
			res.add(newTestCase);
			line = in.readLine();
		}
		
		return res;
	}
	
	public int calculateTime(ArrayList<StepEntry> sequence) {
		
		int res = 0;
		int curMove = 0;
		
		int orangeNext = findNext(sequence, "O", curMove);
		int blueNext = findNext(sequence, "B", curMove);
		int orangePos = 1;
		int bluePos = 1;
		boolean someonePushes = false;
		while (curMove < sequence.size()) {
			
			someonePushes = false;
			System.out.println("	=== " + Integer.toString(res) + " ===");
			// For Orange
			if (orangeNext >= 0) {
				if (sequence.get(orangeNext).pos == orangePos) {
					
					if (orangeNext == curMove) {
						System.out.println("	Orange pushes button " + Integer.toString(orangePos));
						someonePushes = true;
						
					} else {
						System.out.println("	Orange stays at button " + Integer.toString(orangePos));
					}
					
				} else if (sequence.get(orangeNext).pos > orangePos) {
					
					orangePos ++;
					System.out.println("	Orange moves to the right to button " + Integer.toString(orangePos));
				} else {
					orangePos --;
					System.out.println("	Orange moves to the left to button " + Integer.toString(orangePos));
				}
			} else {
				System.out.println("	Orange stays at button " + Integer.toString(orangePos) + " (FINISHED)");
			}
			
			// For Blue
			if (blueNext >= 0) {
				if (sequence.get(blueNext).pos == bluePos) {
					
					if (blueNext == curMove) {
						System.out.println("	Blue pushes button " + Integer.toString(bluePos));
						someonePushes = true;
					} else {
						System.out.println("	Blue stays at button " + Integer.toString(bluePos));
					}
					
				} else if (sequence.get(blueNext).pos > bluePos) {
					
					bluePos ++;
					System.out.println("	Blue moves to the right to button " + Integer.toString(bluePos));
				} else {
					bluePos --;
					System.out.println("	Blue moves to the left to button " + Integer.toString(bluePos));
				}
			} else {
				System.out.println("	Blue stays at button " + Integer.toString(bluePos) + " (FINISHED)");
			}
			
			if (someonePushes) {
				curMove ++;
				blueNext = findNext(sequence, "B", curMove);
				orangeNext = findNext(sequence, "O", curMove);
				
			}
			res ++;
		}
		return res;
	}
	
	private int findNext(ArrayList<StepEntry> sequence, String robot, int curPos) {
		
		int i = curPos;
		int res = -1;
		while (i < sequence.size()) {
			if (sequence.get(i).robot.equals(robot)) {
				res = i;
				break;
			}
			i ++;
		}
		
		return res;
	}
	
	public static void main(String[] args) throws IOException {
		RobotTrust r = new RobotTrust();
		ArrayList<ArrayList<StepEntry>> testCases = r.readInput("D:\\A-small-attempt0.in");
		
		int i = 0;
		int totalTime = 0;
		PrintWriter out = new PrintWriter(new FileWriter("D:\\output.txt"));
		while (i < testCases.size()) {
			System.out.println("*** Test Case " + Integer.toString(i) + " ***");
			totalTime = r.calculateTime(testCases.get(i));
			System.out.println("Total Time: " + Integer.toString(totalTime));
			i ++;
			out.println("Case #" + Integer.toString(i) + ": " + Integer.toString(totalTime) + "\n");
			
		}
		out.close();
	}
}
