
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.InputStreamReader;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.PriorityQueue;

import java.util.StringTokenizer;

public class AA {

    private Pipe pipe = null;

    public AA(String args[]) throws FileNotFoundException, IOException {
        this.pipe = new Pipe(args);
    }

    public static void main(String args[]) throws FileNotFoundException, IOException {
        new AA(args).start();
    }

    public void start() throws FileNotFoundException, IOException {
        int roundCount = pipe.ni();
        for (int round = 1; round <= roundCount; round++) {
            String result = solve();
            String outStr = "Case #" + round + ": " + result + "\n";
            pipe.print(outStr);
//            pipe.nline();
        }
        pipe.close();
    }

    public String solve() throws IOException {
        int N = pipe.ni();
        String[] strs = new String[N];
        for (int i = 0; i < N; i++) {
            strs[i] = pipe.nline();
        }

        int result = possible(strs);
        if (result == -1) {
            return "Fegla Won";
        }
        //
        PriorityQueue<Edge> edges = new PriorityQueue<Edge>();
        for (int i = 0; i < strs.length; i++) {
            for (int j = 0; j < strs.length; j++) {
                if (i != j) {
                    int dis = compute(strs[i], strs[j]);
                    edges.add(new Edge(i, j, dis));
                }
            }
        }

        int dd = 0;
        UF uf = new UF(strs.length);
        while (!edges.isEmpty()) {
            Edge edge = edges.poll();
            int root1 = uf.find(edge.u);
            int root2 = uf.find(edge.v);
            if (root1 != root2) {
                uf.union(root1, root2);
                dd += edge.weight;
            }
        }
        return "" + dd;
    }

    class UF {

        int s[];
        int rank[];

        public UF(int size) {
            s = new int[size];
            rank = new int[size];
            for (int i = 0; i < size; i++) {
                s[i] = i;
            }
        }

        public int find(int k) {
            while (s[k] != k) {
                k = s[k];
            }
            return k;
        }

        public void union(int p, int q) {
            int i = p;
            int j = q;
            if (i == j) {
                return;
            }

            // make root of smaller rank point to root of larger rank
            if (rank[i] < rank[j]) {
                s[i] = j;
            } else if (rank[i] > rank[j]) {
                s[j] = i;
            } else {
                s[j] = i;
                rank[i]++;
            }
        }

    }

    private int possible(String[] strs) {
        String compress0 = compress(strs[0]);
        for (int i = 1; i < strs.length; i++) {
            String comp = compress(strs[i]);
            if (!comp.equals(compress0)) {
                return -1;
            }
        }
        return 1;
    }

    private String compress(String str) {
        String stt = "";
        char ch = '*';
        for (int i = 0; i < str.length(); i++) {
            if (str.charAt(i) != ch) {
                stt += str.charAt(i);
                ch = str.charAt(i);
            }
        }
        return stt;
    }

    private int compute(String st1, String st2) {
        int d = 0;
        char ch = '*';
        int i = 0;
        int j = 0;

        while (i < st1.length() && j < st2.length()) {
            if (st1.charAt(i) == st2.charAt(j)) {
                ch = st1.charAt(i);
                i++;
                j++;
            } else {
                if (st1.charAt(i) == ch) {
                    i++;
                } else {
                    j++;
                }
                d++;
            }
        }
        if (i < st1.length()) {
            d += st1.length() - i;
        } else if (j < st2.length()) {
            d += st2.length() - j;
        }
        return d;
    }

    class Edge implements Comparable<Edge> {

        int weight, u, v;

        Edge(int u, int v, int weight) {
            this.u = u;
            this.v = v;
            this.weight = weight;
        }

        Edge() {
        }

        @Override
        public int compareTo(Edge o) {
            return this.weight - o.weight;
        }
    }

    private class Pipe {

        private BufferedReader reader;
        private BufferedWriter writer;
        private StringTokenizer tokenizer;

        public Pipe(String args[]) throws FileNotFoundException, IOException {
            if (args != null && args.length >= 1) {
                reader = new BufferedReader(new FileReader(args[0]));
                if (args.length == 2) {
                    writer = new BufferedWriter(new FileWriter(args[1]));
                }
            } else {
                reader = new BufferedReader(new InputStreamReader(System.in));
            }
        }

        public String nline() throws IOException {
            tokenizer = null;
            return reader.readLine();
        }

        public String ns() throws IOException {
            while (tokenizer == null || !tokenizer.hasMoreTokens()) {
                tokenizer = new StringTokenizer(reader.readLine());
            }
            return tokenizer.nextToken();
        }

        public int ni() throws IOException {
            return Integer.parseInt(ns());
        }

        public long nl() throws IOException {
            return Long.parseLong(ns());
        }

        public float nf() throws IOException {
            return Float.parseFloat(ns());
        }

        public double nd() throws IOException {
            return Double.parseDouble(ns());
        }

        public void print(String str) throws IOException {
            System.out.print(str);
            if (writer != null) {
                writer.write(str, 0, str.length());
            }
        }

        public void close() throws IOException {
            if (writer != null) {
                writer.close();
            }
        }
    }
}
