/**
 * 
 * Copyright 2016 RSVP Technologies Inc. All rights reserved. RevengeOfThePancakes.java
 * 
 */
package qual;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.math.BigInteger;
import java.util.HashSet;
import java.util.Scanner;
import java.util.Set;
import java.util.zip.GZIPInputStream;

/**
 * @author Anqi Cui (caq@rsvptech.ca)
 * @date Apr 9, 2016
 */
public class CoinJam {
  static final String PROB = "C", SIZE = "large", NUMTRY = "1";
  static final String FILENAME = PROB + "-" + SIZE
      + (SIZE.equals("large") ? "" : "-attempt" + NUMTRY);

  static final int CERTAINTY = 100;

  static Set<String> primeSet;
  static {
    primeSet = new HashSet<>();
    /*
     * https://primes.utm.edu/lists/small/millions/
     */
    for (File fl : new File(".").listFiles()) {
      String filename = fl.getAbsolutePath();
      if (!filename.endsWith(".gz"))
        continue;
      if (!filename.contains("primes"))
        continue;
      System.out.println(filename);
      try (BufferedReader br =
          new BufferedReader(new InputStreamReader(new GZIPInputStream(
              new FileInputStream(filename))))) {
        String line;
        line = br.readLine();
        while ((line = br.readLine()) != null) {
          line = line.trim();
          if (line.length() == 0)
            continue;
          String[] fields = line.split("\\s+");
          for (String f : fields) {
            primeSet.add(f);
          }
          // if (primeSet.size() > 10000)
          // break;
        }
      } catch (FileNotFoundException e) {
        e.printStackTrace();
      } catch (IOException e) {
        e.printStackTrace();
      }
    }
    System.out.println("Prime set: " + primeSet.size());
  }

  static BufferedWriter bw;
  static {
    try {
      bw = new BufferedWriter(new FileWriter("output/" + FILENAME + ".out"));
    } catch (IOException e) {
      e.printStackTrace();
    }
  }

  static void print(String s) throws IOException {
    // System.out.print(s);
    bw.write(s);
  }

  static void println() throws IOException {
    // System.out.println();
    bw.newLine();
  }

  public static void main(String[] args) throws Exception {
    try (Scanner scanner = new Scanner(new File("input/" + FILENAME + ".in"))) {
      int T = scanner.nextInt();
      for (int t = 0; t < T; t++) {
        print("Case #" + (t + 1) + ": ");
        println();
        int N = scanner.nextInt();
        int J = scanner.nextInt();

        /*
         * Init the number byte array.
         */
        char[] num = new char[N];
        num[0] = '1';
        for (int i = 1; i < N - 1; i++)
          num[i] = '0';
        num[N - 1] = '1';

        Set<String> outputResults = new HashSet<>();

        /*
         * Traverse each possibility.
         */
        int count = 0;
        while (count < J) {
          String numS = new String(num);
          // System.out.println("Trying " + numS);
          if (!outputResults.contains(numS)) {
            boolean isJamcoin = true;
            for (int radix = 2; radix <= 10; radix++) {
              BigInteger n = new BigInteger(numS, radix);
              if (n.isProbablePrime(CERTAINTY)) {
                /*
                 * Is prime, not a jamcoin.
                 */
                // System.out.println(n + " is prime.");
                isJamcoin = false;
                break;
              }
            }

            if (isJamcoin) {
              /*
               * Output this solution.
               */
              print(numS);
              int c = 0;
              for (int radix = 2; radix <= 10; radix++) {
                // System.out.print("(" + numS + ")" + radix + " = ");
                BigInteger n = new BigInteger(numS, radix);
                // System.out.print(n + " = ");
                for (String p : primeSet) {
                  if (n.mod(new BigInteger(p)).equals(BigInteger.ZERO)) {
                    // System.out.println(p + " * " + n.divide(new BigInteger(p)));
                    print(" ");
                    print(p);
                    c++;
                    break;
                  }
                }
              }
              if (c < 9) {
                System.err.println(numS + ": No enough primes!");
                print(" ERROR");
                count--;
              }
              println();
              count++;
              outputResults.add(numS);
            }
          }
          /*
           * Increment the num.
           */
          int i = N - 2;
          boolean carry = true;
          while (carry && i > 0) {
            if (num[i] == '1') {
              num[i] = '0';
              carry = true;
            } else {
              num[i] = '1';
              carry = false;
            }
            i--;
          }
          if (carry && i == 0) {
            /*
             * Reach the biggest possible.
             */
            break;
          }
        }

      }
    }
    bw.close();
  }
}
