package codejam;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.text.DecimalFormat;
import java.util.*;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * Created by carlos on 12/04/14.
 */
public class CookieClickerAlpha {

    public static void main(String args[]) {
        new CookieClickerAlpha().execute();
    }

    public void execute() {
        new Executor(new CookieClickerAlphaInputParser(), new CookieClickerAlphaSolver()).readAndExecute(System.in);
    }

    class CookieClickerAlphaCase extends AbstractCase {
        double c;
        double f;
        double x;
    }

    class CookieClickerAlphaSolver implements Solver<CookieClickerAlphaCase> {
        @Override
        public String solve(CookieClickerAlphaCase c) {

            double cookies = 0;
            double currentRatePerSecond = 2;
            final double farmPrice = c.c;
            final double farmProductionPerSecond = c.f;
            final double creditToWin = c.x;
            double secondsSpent = 0;
            while(cookies < creditToWin) {
                double secondsToWinIfWaiting =
                        (creditToWin - cookies) / currentRatePerSecond;
                double secondsToWinIfWaitingToBuyAFarm =
                        (creditToWin / (currentRatePerSecond + farmProductionPerSecond))
                        + (farmPrice / currentRatePerSecond);

                if (secondsToWinIfWaiting > secondsToWinIfWaitingToBuyAFarm) {
                    double secondsSpentToBuyAFarm = farmPrice / currentRatePerSecond;
                    secondsSpent += secondsSpentToBuyAFarm;
                    currentRatePerSecond += farmProductionPerSecond;
                } else {
                    secondsSpent += secondsToWinIfWaiting;
                    cookies += secondsToWinIfWaiting * currentRatePerSecond;
                }
            }

            return ""+secondsSpent;
        }

    }

    class CookieClickerAlphaInputParser extends AbstractInputParser {
        @Override
        protected AbstractCase parseCase() {
            CookieClickerAlphaCase c = new CookieClickerAlphaCase();
            c.c = scanner.nextDouble();
            c.f = scanner.nextDouble();
            c.x = scanner.nextDouble();
            return c;
        }
    }

    abstract class AbstractCase {
        public String solve(Solver solver) {
            return solver.solve(this);
        }
    }

    interface Solver<T extends AbstractCase> {
        public String solve(T c);
    }

    abstract class AbstractInputParser {

        protected Scanner scanner;

        public AbstractCase[] parse(Reader reader) {
            scanner = new Scanner(reader);
            scanner.useLocale(Locale.US);
            int numberOfCases = scanner.nextInt();
            scanner.nextLine();
            AbstractCase[] cases = new AbstractCase[numberOfCases];
            for (int i = 0; i < numberOfCases; i++) {
                cases[i] = parseCase();
            }
            return cases;
        }

        protected abstract AbstractCase parseCase();
    }

    class Executor {

        private AbstractInputParser inputParser;
        private Solver solver;

        private AbstractCase[] cases;
        private String[] results;
        private Map<AbstractCase, Integer> caseToIndex;

        private boolean casesLeft = true;

        private AtomicInteger threadsBusy = new AtomicInteger(0);

        public Executor(AbstractInputParser inputParser, Solver solver) {
            this.inputParser = inputParser;
            this.solver = solver;
        }

        public void readAndExecute(InputStream in) {
            cases = inputParser.parse(new InputStreamReader(in));
            results = new String[cases.length];
            caseToIndex = new HashMap<AbstractCase, Integer>();

            int cores = Runtime.getRuntime().availableProcessors();

            System.err.println("Spawning "+cores+" threads...");

            BlockingQueue<AbstractCase> caseQueue = new LinkedBlockingQueue<AbstractCase>(cores);

            LinkedList<ExecutorThread> runningThreads = new LinkedList<ExecutorThread>();
            for (int i = 0; i < cores; i++) {
                ExecutorThread executorThread = new ExecutorThread(caseQueue);
                runningThreads.add(executorThread);
                executorThread.start();
            }

            for (int i = 0; i < cases.length; i++) {
                caseToIndex.put(cases[i], i);
                try {
                    caseQueue.put(cases[i]);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            while(caseQueue.size() > 0) {
                try {
                    Thread.sleep(500);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            casesLeft = false;

            System.err.println("Waiting for "+runningThreads.size()+" threads to finish...");
            while (runningThreads.size() > 0) {
                try {
                    runningThreads.peek().interrupt();
                    runningThreads.peek().join();
                    runningThreads.remove();
                    System.err.println(runningThreads.size()+" remaining threads...");
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }


            for (int i = 0; i < results.length; i++) {
                System.out.println(String.format(("Case #%d: %s"), i+1, results[i]));
            }

            System.err.println("Finished.");
        }

        class ExecutorThread extends Thread {

            BlockingQueue<AbstractCase> blockingQueue;

            ExecutorThread(BlockingQueue<AbstractCase> blockingQueue) {
                this.blockingQueue = blockingQueue;
            }

            @Override
            public void run() {
                while(casesLeft) {
                    try {
                        AbstractCase c = blockingQueue.take();
                        threadsBusy.incrementAndGet();
                        String result = c.solve(solver);
                        results[caseToIndex.get(c)] = result;
                        System.err.println(String.format("Solved case #%d: %s", caseToIndex.get(c), result));
                        threadsBusy.decrementAndGet();
                    } catch (InterruptedException e) {
                    }
                }
            }
        }
    }


}
