package codejam;

import java.io.*;
import java.util.*;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.atomic.AtomicInteger;

import static java.lang.Math.abs;

/**
 * Created by carlos on 3/05/14.
 */
    public class Dijkstra {

    public static void main(String args[]) throws FileNotFoundException {
        new Dijkstra().execute(args[0]);
    }

    public void execute(String filename) throws FileNotFoundException {
        new Executor(new DijkstraInputParser(), new DijkstraSolver()).readAndExecute(
                // System.in
                new FileInputStream(filename)
        );
    }

    class DijkstraCase extends AbstractCase {
        long l, x;
        String s;
    }


    class DijkstraSolver implements Solver<DijkstraCase> {

        int i = 2;
        int j = 3;
        int k = 4;

        int table[][] = new int[][] {
            {0, 0,  0,  0,  0},
            {0, 1,  i,  j,  k},
            {0, i, -1,  k, -j},
            {0, j, -k, -1,  i},
            {0, k,  j, -i, -1}
        };

        int sign(int x) {
            return x >= 0 ? 1 : -1;
        }

        int reduce(int a, int b) {
            int value = table[abs(a)][abs(b)];
            return value * sign(a) * sign(b);
        }

        int convert(char c) {
            switch (c) {
                case 'i':
                    return i;
                case 'j':
                    return j;
                case 'k':
                    return k;
                default:
                    throw new RuntimeException();
            }
        }

        @Override
        public String solve(DijkstraCase c) {

            int reduced = 1;
            if (c.x * c.l >= 3) {
                for (int x = 0; x < c.x; x++) {
                    for (int y = 0; y < c.s.length(); y++) {
                        reduced = reduce(reduced, convert(c.s.charAt(y)));
                    }
                }
            }

            boolean canBeDone = false;
            if (reduced == -1) {
                reduced = 1;
                boolean i_found = false;
                boolean j_found = false;
                for (int x = 0; x < c.x; x++) {
                    for (int y = 0; y < c.s.length(); y++) {
                        if (reduced == i && !i_found) {
                            reduced = 1;
                            i_found = true;
                        }
                        if (reduced == j && i_found && !j_found) {
                            reduced = 1;
                            j_found = true;
                        }
                        reduced = reduce(reduced, convert(c.s.charAt(y)));
                    }
                }
                canBeDone = i_found && j_found && reduced == k;
            }


            return canBeDone? "YES" : "NO";
        }

    }

    class DijkstraInputParser extends AbstractInputParser {
        @Override
        protected AbstractCase parseCase() {
            DijkstraCase c = new DijkstraCase();
            c.l = scanner.nextLong();
            c.x = scanner.nextLong();
            c.s = scanner.next();
            return c;
        }
    }

    abstract class AbstractCase {
        public String solve(Solver solver) {
            return solver.solve(this);
        }
    }

    interface Solver<T extends AbstractCase> {
        public String solve(T c);
    }

    abstract class AbstractInputParser {

        protected Scanner scanner;

        public AbstractCase[] parse(Reader reader) {
            scanner = new Scanner(reader);
            scanner.useLocale(Locale.US);
            int numberOfCases = scanner.nextInt();
            scanner.nextLine();
            AbstractCase[] cases = new AbstractCase[numberOfCases];
            for (int i = 0; i < numberOfCases; i++) {
                cases[i] = parseCase();
            }
            return cases;
        }

        protected abstract AbstractCase parseCase();
    }

    class Executor {

        private AbstractInputParser inputParser;
        private Solver solver;

        private AbstractCase[] cases;
        private String[] results;
        private Map<AbstractCase, Integer> caseToIndex;

        private boolean casesLeft = true;

        private AtomicInteger threadsBusy = new AtomicInteger(0);

        public Executor(AbstractInputParser inputParser, Solver solver) {
            this.inputParser = inputParser;
            this.solver = solver;
        }

        public void readAndExecute(InputStream in) {
            cases = inputParser.parse(new InputStreamReader(in));
            results = new String[cases.length];
            caseToIndex = new HashMap<AbstractCase, Integer>();

            int cores = Runtime.getRuntime().availableProcessors();
//            cores = 1;

            System.err.println("Spawning "+cores+" threads...");

            BlockingQueue<AbstractCase> caseQueue = new LinkedBlockingQueue<AbstractCase>(cores);

            LinkedList<ExecutorThread> runningThreads = new LinkedList<ExecutorThread>();
            for (int i = 0; i < cores; i++) {
                ExecutorThread executorThread = new ExecutorThread(caseQueue);
                runningThreads.add(executorThread);
                executorThread.start();
            }

            for (int i = 0; i < cases.length; i++) {
                caseToIndex.put(cases[i], i);
                try {
                    caseQueue.put(cases[i]);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            while(caseQueue.size() > 0) {
                try {
                    Thread.sleep(500);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            casesLeft = false;

            System.err.println("Waiting for "+runningThreads.size()+" threads to finish...");
            while (runningThreads.size() > 0) {
                try {
                    runningThreads.peek().interrupt();
                    runningThreads.peek().join();
                    runningThreads.remove();
                    System.err.println(runningThreads.size()+" remaining threads...");
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }


            for (int i = 0; i < results.length; i++) {
                System.out.println(String.format(("Case #%d: %s"), i+1, results[i]));
            }

            System.err.println("Finished.");
        }

        class ExecutorThread extends Thread {

            BlockingQueue<AbstractCase> blockingQueue;

            ExecutorThread(BlockingQueue<AbstractCase> blockingQueue) {
                this.blockingQueue = blockingQueue;
            }

            @Override
            public void run() {
                while(casesLeft) {
                    try {
                        AbstractCase c = blockingQueue.take();
                        threadsBusy.incrementAndGet();
                        String result = c.solve(solver);
                        results[caseToIndex.get(c)] = result;
                        System.err.println(String.format("Solved case #%d: %s", caseToIndex.get(c), result));
                        threadsBusy.decrementAndGet();
                    } catch (InterruptedException e) {
                    }
                }
            }
        }
    }

}
