package codejam;

import java.io.*;
import java.util.*;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.atomic.AtomicInteger;

import static java.lang.Math.*;
import static java.lang.Math.abs;

/**
 * Created by carlos on 3/05/14.
 */
public class InfiniteHouseOfPancakes {

    public static void main(String args[]) throws FileNotFoundException {
        new InfiniteHouseOfPancakes().execute(args[0]);
    }

    public void execute(String filename) throws FileNotFoundException {
        new Executor(new InfiniteHouseOfPancakesInputParser(), new InfiniteHouseOfPancakesSolver()).readAndExecute(
                // System.in
                new FileInputStream(filename)
        );
    }

    class InfiniteHouseOfPancakesCase extends AbstractCase {
        int[] pancakesPerDiner;
    }

    class Diner implements Comparable<Diner>{
        int pancakes;

        @Override
        public String toString() {
            return ""+pancakes;
        }

        @Override
        public int compareTo(Diner o) {
            return new Integer(pancakes).compareTo(o.pancakes);
        }
    }

    class DinerComparator implements Comparator<Integer> {
        @Override
        public int compare(Integer o1, Integer o2) {
            return o1.compareTo(o2) * - 1;
        }
    }

    class InfiniteHouseOfPancakesSolver implements Solver<InfiniteHouseOfPancakesCase> {

        int minutes(PriorityQueue<Integer> diners) {
            if (diners.size() == 0)
                return 0;

            int minutesIfSpecial = Integer.MAX_VALUE;

            if (diners.peek() >= diners.size()/3) {
                PriorityQueue<Integer> dinersSpecial = new PriorityQueue<Integer>(diners);
                Integer pancakes = dinersSpecial.poll();
                dinersSpecial.add(pancakes / 2);
                dinersSpecial.add(pancakes - (pancakes / 2));
                minutesIfSpecial = minutes(dinersSpecial);
            }

            PriorityQueue<Integer> dinersNormal = new PriorityQueue<Integer>(diners.size());
            for (Iterator<Integer> iterator = diners.iterator(); iterator.hasNext();) {
                Integer diner = iterator.next() - 1;
                if (diner > 0) {
                    dinersNormal.add(diner);
                }
            }
            int minutesIfNormal = minutes(dinersNormal);

            return min(minutesIfSpecial, minutesIfNormal) + 1;
        }

        @Override
        public String solve(InfiniteHouseOfPancakesCase c) {
            PriorityQueue<Integer> diners = new PriorityQueue<Integer>(c.pancakesPerDiner.length, new DinerComparator());
            for (int i : c.pancakesPerDiner) {
                diners.add(i);
            }

            int minutes =  minutes(diners);

            return "" + minutes;
        }

    }

    class InfiniteHouseOfPancakesInputParser extends AbstractInputParser {
        @Override
        protected AbstractCase parseCase() {
            InfiniteHouseOfPancakesCase c = new InfiniteHouseOfPancakesCase();
            c.pancakesPerDiner = new int[scanner.nextInt()];
            for (int i = 0; i < c.pancakesPerDiner.length; i++) {
                c.pancakesPerDiner[i] = scanner.nextInt();
            }
            return c;
        }
    }

    abstract class AbstractCase {
        public String solve(Solver solver) {
            return solver.solve(this);
        }
    }

    interface Solver<T extends AbstractCase> {
        public String solve(T c);
    }

    abstract class AbstractInputParser {

        protected Scanner scanner;

        public AbstractCase[] parse(Reader reader) {
            scanner = new Scanner(reader);
            scanner.useLocale(Locale.US);
            int numberOfCases = scanner.nextInt();
            scanner.nextLine();
            AbstractCase[] cases = new AbstractCase[numberOfCases];
            for (int i = 0; i < numberOfCases; i++) {
                cases[i] = parseCase();
            }
            return cases;
        }

        protected abstract AbstractCase parseCase();
    }

    class Executor {

        private AbstractInputParser inputParser;
        private Solver solver;

        private AbstractCase[] cases;
        private String[] results;
        private Map<AbstractCase, Integer> caseToIndex;

        private boolean casesLeft = true;

        private AtomicInteger threadsBusy = new AtomicInteger(0);

        public Executor(AbstractInputParser inputParser, Solver solver) {
            this.inputParser = inputParser;
            this.solver = solver;
        }

        public void readAndExecute(InputStream in) {
            cases = inputParser.parse(new InputStreamReader(in));
            results = new String[cases.length];
            caseToIndex = new HashMap<AbstractCase, Integer>();

            int cores = Runtime.getRuntime().availableProcessors();
//            cores = 1;

            System.err.println("Spawning "+cores+" threads...");

            BlockingQueue<AbstractCase> caseQueue = new LinkedBlockingQueue<AbstractCase>(cores);

            LinkedList<ExecutorThread> runningThreads = new LinkedList<ExecutorThread>();
            for (int i = 0; i < cores; i++) {
                ExecutorThread executorThread = new ExecutorThread(caseQueue);
                runningThreads.add(executorThread);
                executorThread.start();
            }

            for (int i = 0; i < cases.length; i++) {
                caseToIndex.put(cases[i], i);
                try {
                    caseQueue.put(cases[i]);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            while(caseQueue.size() > 0) {
                try {
                    Thread.sleep(500);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            casesLeft = false;

            System.err.println("Waiting for "+runningThreads.size()+" threads to finish...");
            while (runningThreads.size() > 0) {
                try {
                    runningThreads.peek().interrupt();
                    runningThreads.peek().join();
                    runningThreads.remove();
                    System.err.println(runningThreads.size()+" remaining threads...");
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }


            for (int i = 0; i < results.length; i++) {
                System.out.println(String.format(("Case #%d: %s"), i+1, results[i]));
            }

            System.err.println("Finished.");
        }

        class ExecutorThread extends Thread {

            BlockingQueue<AbstractCase> blockingQueue;

            ExecutorThread(BlockingQueue<AbstractCase> blockingQueue) {
                this.blockingQueue = blockingQueue;
            }

            @Override
            public void run() {
                while(casesLeft) {
                    try {
                        AbstractCase c = blockingQueue.take();
                        threadsBusy.incrementAndGet();
                        String result = c.solve(solver);
                        results[caseToIndex.get(c)] = result;
                        System.err.println(String.format("Solved case #%d: %s", caseToIndex.get(c), result));
                        threadsBusy.decrementAndGet();
                    } catch (InterruptedException e) {
                    }
                }
            }
        }
    }

}
