package codejam;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.*;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * Created by carlos on 12/04/14.
 */
public class MineSweeperMaster {

    public static void main(String args[]) {
        new MineSweeperMaster().execute();
    }

    public void execute() {
        new Executor(new MineSweeperMasterInputParser(), new MineSweeperMasterSolver()).readAndExecute(System.in);
    }

    class MineSweeperMasterCase extends AbstractCase {
        int r, c, m;
    }

    class MineSweeperMasterSolver implements Solver<MineSweeperMasterCase> {

        class Coordinate {
            int x,y;
            Coordinate(int x, int y) {
                this.x = x;
                this.y = y;
            }
        }

        @Override
        public String solve(MineSweeperMasterCase c) {
            boolean possible =
                    c.r * c.c - c.m == 1 || c.r * c.c - c.m >= 4
                    || (c.r == 1 && c.c - c.m >= 2)
                    || (c.c == 1 && c.r - c.m >= 2);


            if (!possible) {
                return "\nImpossible";
            }

            Character[][] grid = new Character[c.r][c.c];
            grid[0][0] = 'c';

            if (c.r * c.c - c.m == 1) {
                fillUp(grid, '*');
            } else {
                if (c.r > 1) {
                    grid[1][0] = '.';
                }
                if (c.c > 1) {
                    grid[0][1] = '.';
                }
                if (c.r > 1 && c.c > 1) {
                    grid[1][1] = '.';
                }
                Queue<Coordinate> queue = new LinkedList<Coordinate>();
                queue.add(new Coordinate(c.r - 1, c.c - 1));
                layMines(grid, queue, c.m);
                fillUp(grid, '.');
            }

            return generateOutput(grid);
        }

        private void layMines(Character[][] grid, Queue<Coordinate> queue, int minesLeft) {
            while (!queue.isEmpty() && minesLeft > 0) {
                Coordinate c = queue.poll();
                if (grid[c.x][c.y] == null) {
                    grid[c.x][c.y] = '*';
                    minesLeft--;

                    if (minesLeft > 0) {
                        if (c.x - 1 >= 0) {
                            queue.add(new Coordinate(c.x - 1, c.y));
                        }
                        if (c.y - 1 >= 0) {
                            queue.add(new Coordinate(c.x, c.y - 1));
                        }
                    }
                }
            }
        }

        private void fillUp(Character[][] grid, Character c) {
            for (int i = 0; i < grid.length; i++) {
                for (int j = 0; j < grid[i].length; j++) {
                    if (grid[i][j] == null) {
                        grid[i][j] = c;
                    }
                }
            }
        }

        private String generateOutput(Character[][] grid) {
            String output = "";

            for (Character[] row: grid) {
                output += "\n";
                for (Character c : row) {
                    output += c;
                }
            }

            return output;
        }

    }

    class MineSweeperMasterInputParser extends AbstractInputParser {
        @Override
        protected AbstractCase parseCase() {
            MineSweeperMasterCase c = new MineSweeperMasterCase();
            c.r = scanner.nextInt();
            c.c = scanner.nextInt();
            c.m = scanner.nextInt();
            return c;
        }
    }

    abstract class AbstractCase {
        public String solve(Solver solver) {
            return solver.solve(this);
        }
    }

    interface Solver<T extends AbstractCase> {
        public String solve(T c);
    }

    abstract class AbstractInputParser {

        protected Scanner scanner;

        public AbstractCase[] parse(Reader reader) {
            scanner = new Scanner(reader);
            scanner.useLocale(Locale.US);
            int numberOfCases = scanner.nextInt();
            scanner.nextLine();
            AbstractCase[] cases = new AbstractCase[numberOfCases];
            for (int i = 0; i < numberOfCases; i++) {
                cases[i] = parseCase();
            }
            return cases;
        }

        protected abstract AbstractCase parseCase();
    }

    class Executor {

        private AbstractInputParser inputParser;
        private Solver solver;

        private AbstractCase[] cases;
        private String[] results;
        private Map<AbstractCase, Integer> caseToIndex;

        private boolean casesLeft = true;

        private AtomicInteger threadsBusy = new AtomicInteger(0);

        public Executor(AbstractInputParser inputParser, Solver solver) {
            this.inputParser = inputParser;
            this.solver = solver;
        }

        public void readAndExecute(InputStream in) {
            cases = inputParser.parse(new InputStreamReader(in));
            results = new String[cases.length];
            caseToIndex = new HashMap<AbstractCase, Integer>();

            int cores = Runtime.getRuntime().availableProcessors();

            System.err.println("Spawning "+cores+" threads...");

            BlockingQueue<AbstractCase> caseQueue = new LinkedBlockingQueue<AbstractCase>(cores);

            LinkedList<ExecutorThread> runningThreads = new LinkedList<ExecutorThread>();
            for (int i = 0; i < cores; i++) {
                ExecutorThread executorThread = new ExecutorThread(caseQueue);
                runningThreads.add(executorThread);
                executorThread.start();
            }

            for (int i = 0; i < cases.length; i++) {
                caseToIndex.put(cases[i], i);
                try {
                    caseQueue.put(cases[i]);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            while(caseQueue.size() > 0) {
                try {
                    Thread.sleep(500);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            casesLeft = false;

            System.err.println("Waiting for "+runningThreads.size()+" threads to finish...");
            while (runningThreads.size() > 0) {
                try {
                    runningThreads.peek().interrupt();
                    runningThreads.peek().join();
                    runningThreads.remove();
                    System.err.println(runningThreads.size()+" remaining threads...");
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }


            for (int i = 0; i < results.length; i++) {
                System.out.println(String.format(("Case #%d:%s"), i+1, results[i]));
            }

            System.err.println("Finished.");
        }

        class ExecutorThread extends Thread {

            BlockingQueue<AbstractCase> blockingQueue;

            ExecutorThread(BlockingQueue<AbstractCase> blockingQueue) {
                this.blockingQueue = blockingQueue;
            }

            @Override
            public void run() {
                while(casesLeft) {
                    try {
                        AbstractCase c = blockingQueue.take();
                        threadsBusy.incrementAndGet();
                        String result = c.solve(solver);
                        results[caseToIndex.get(c)] = result;
                        System.err.println(String.format("Solved case #%d: %s", caseToIndex.get(c), result));
                        threadsBusy.decrementAndGet();
                    } catch (InterruptedException e) {
                    }
                }
            }
        }
    }


}
