package codejam;

import java.io.*;
import java.util.*;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.atomic.AtomicInteger;

import static java.lang.Math.abs;

/**
 * Created by carlos on 3/05/14.
 */
public class StandingOvation {

    public static void main(String args[]) throws FileNotFoundException {
        new StandingOvation().execute(args[0]);
    }

    public void execute(String filename) throws FileNotFoundException {
        new Executor(new StandingOvationInputParser(), new StandingOvationSolver()).readAndExecute(
                // System.in
                new FileInputStream(filename)
        );
    }

    class StandingOvationCase extends AbstractCase {
        int[] audiencePerShynessLevel;
        int totalPeople;
    }

    class StandingOvationSolver implements Solver<StandingOvationCase> {

        @Override
        public String solve(StandingOvationCase c) {

            int peopleStanding = c.audiencePerShynessLevel[0];
            int requiredPeopleToStandUp = 1;
            int invitedFriends = 0;
            int totalPeople = c.totalPeople;
            while(peopleStanding < totalPeople) {
                if (c.audiencePerShynessLevel[requiredPeopleToStandUp] > 0) {
                    if (peopleStanding < requiredPeopleToStandUp) {
                        int friendsToInvite = requiredPeopleToStandUp - peopleStanding;
                        invitedFriends += friendsToInvite;
                        peopleStanding += friendsToInvite;
                        totalPeople += friendsToInvite;
                    }
                    peopleStanding += c.audiencePerShynessLevel[requiredPeopleToStandUp];
                }
                requiredPeopleToStandUp++;
            }

            return ""+invitedFriends;
        }

    }

    class StandingOvationInputParser extends AbstractInputParser {
        @Override
        protected AbstractCase parseCase() {
            StandingOvationCase c = new StandingOvationCase();
            int Smax = scanner.nextInt();
            c.audiencePerShynessLevel = new int[Smax + 1];
            c.totalPeople = 0;
            String digits = scanner.next();
            for (int i = 0; i < c.audiencePerShynessLevel.length; i++) {
                int people = Integer.parseInt(""+digits.charAt(i));
                c.audiencePerShynessLevel[i] = people;
                c.totalPeople += people;
            }
            return c;
        }
    }

    abstract class AbstractCase {
        public String solve(Solver solver) {
            return solver.solve(this);
        }
    }

    interface Solver<T extends AbstractCase> {
        public String solve(T c);
    }

    abstract class AbstractInputParser {

        protected Scanner scanner;

        public AbstractCase[] parse(Reader reader) {
            scanner = new Scanner(reader);
            scanner.useLocale(Locale.US);
            int numberOfCases = scanner.nextInt();
            scanner.nextLine();
            AbstractCase[] cases = new AbstractCase[numberOfCases];
            for (int i = 0; i < numberOfCases; i++) {
                cases[i] = parseCase();
            }
            return cases;
        }

        protected abstract AbstractCase parseCase();
    }

    class Executor {

        private AbstractInputParser inputParser;
        private Solver solver;

        private AbstractCase[] cases;
        private String[] results;
        private Map<AbstractCase, Integer> caseToIndex;

        private boolean casesLeft = true;

        private AtomicInteger threadsBusy = new AtomicInteger(0);

        public Executor(AbstractInputParser inputParser, Solver solver) {
            this.inputParser = inputParser;
            this.solver = solver;
        }

        public void readAndExecute(InputStream in) {
            cases = inputParser.parse(new InputStreamReader(in));
            results = new String[cases.length];
            caseToIndex = new HashMap<AbstractCase, Integer>();

            int cores = Runtime.getRuntime().availableProcessors();
//            cores = 1;

            System.err.println("Spawning "+cores+" threads...");

            BlockingQueue<AbstractCase> caseQueue = new LinkedBlockingQueue<AbstractCase>(cores);

            LinkedList<ExecutorThread> runningThreads = new LinkedList<ExecutorThread>();
            for (int i = 0; i < cores; i++) {
                ExecutorThread executorThread = new ExecutorThread(caseQueue);
                runningThreads.add(executorThread);
                executorThread.start();
            }

            for (int i = 0; i < cases.length; i++) {
                caseToIndex.put(cases[i], i);
                try {
                    caseQueue.put(cases[i]);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            while(caseQueue.size() > 0) {
                try {
                    Thread.sleep(500);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            casesLeft = false;

            System.err.println("Waiting for "+runningThreads.size()+" threads to finish...");
            while (runningThreads.size() > 0) {
                try {
                    runningThreads.peek().interrupt();
                    runningThreads.peek().join();
                    runningThreads.remove();
                    System.err.println(runningThreads.size()+" remaining threads...");
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }


            for (int i = 0; i < results.length; i++) {
                System.out.println(String.format(("Case #%d: %s"), i+1, results[i]));
            }

            System.err.println("Finished.");
        }

        class ExecutorThread extends Thread {

            BlockingQueue<AbstractCase> blockingQueue;

            ExecutorThread(BlockingQueue<AbstractCase> blockingQueue) {
                this.blockingQueue = blockingQueue;
            }

            @Override
            public void run() {
                while(casesLeft) {
                    try {
                        AbstractCase c = blockingQueue.take();
                        threadsBusy.incrementAndGet();
                        String result = c.solve(solver);
                        results[caseToIndex.get(c)] = result;
                        System.err.println(String.format("Solved case #%d: %s", caseToIndex.get(c), result));
                        threadsBusy.decrementAndGet();
                    } catch (InterruptedException e) {
                    }
                }
            }
        }
    }

}
