package codejam;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.*;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.atomic.AtomicInteger;

import static java.lang.Math.abs;
import static java.lang.Math.min;

/**
 * Created by carlos on 3/05/14.
 */
public class Repeater {

    public static void main(String args[]) {
        new Repeater().execute();
    }

    public void execute() {
        new Executor(new RepeaterInputParser(), new RepeaterSolver()).readAndExecute(System.in);
    }

    class RepeaterCase extends AbstractCase {
        String[] strings;
    }

    class RepeaterSolver implements Solver<RepeaterCase> {

        @Override
        public String solve(RepeaterCase c) {

            String min = minimize(c.strings[0]);
            boolean equal = true;
            {
                int i = 1;
                while (equal && i < c.strings.length) {
                    equal &= min.equals(minimize(c.strings[i++]));
                }
            }

            int movements = 0;
            if (equal) {
                // There is a solution
                int groupsOfChars = countGroupsOfChars(c.strings[0]);
                int [][] charPerGroupMatrix = new int[c.strings.length][groupsOfChars];
                for (int i = 0; i < c.strings.length; i++) {
                    populateMatrix(c.strings[i], charPerGroupMatrix[i]);
                }
                movements = calculateMovements(charPerGroupMatrix);
            }

            return " " + (equal? "" + movements : "Fegla Won");
        }

        private int calculateMovements(int[][] charPerGroupMatrix) {
            int movements = 0;
            int rows = charPerGroupMatrix.length;
            int cols = charPerGroupMatrix[0].length;
            for (int i = 0; i < cols; i++) {
                int accumulated = 0;
                int mean = 0;
                for (int j = 0; j < rows; j++) {
                    accumulated += charPerGroupMatrix[j][i];
                }
                mean += (accumulated / rows);

                int rowMovements = 0;
                for (int j = 0; j < rows; j++) {
                    rowMovements += abs(mean - charPerGroupMatrix[j][i]);
                }
                movements += rowMovements;
            }
            return movements;
        }

        private void populateMatrix(String s, int[] row) {
            if (s.length() == 0) {
                return;
            }
            Character previous = s.charAt(0);
            int x = 0;
            row[x] = 0;
            for(int i = 0; i < s.length(); i++) {
                Character current = s.charAt(i);
                if (previous == current) {
                    row[x]++;
                } else {
                    x++;
                    if (x < row.length) {
                        row[x] = 1;
                    }
                }
                previous = current;
            }
        }

        String minimize(String s) {
            return s.replaceAll("(.)\\1{1,}", "$1");
        }

        int countGroupsOfChars(String s) {
            int groups = 0;
            Character previous = null;
            for(int i = 0; i < s.length(); i++) {
                Character current = s.charAt(i);
                if (previous != current) {
                    groups++;
                }
                previous = current;
            }
            return groups;
        }

    }

    class RepeaterInputParser extends AbstractInputParser {
        @Override
        protected AbstractCase parseCase() {
            RepeaterCase c = new RepeaterCase();
            c.strings = new String[scanner.nextInt()];
            for (int i = 0; i < c.strings.length; i++) {
                c.strings[i] = scanner.next();
            }
            return c;
        }
    }

    abstract class AbstractCase {
        public String solve(Solver solver) {
            return solver.solve(this);
        }
    }

    interface Solver<T extends AbstractCase> {
        public String solve(T c);
    }

    abstract class AbstractInputParser {

        protected Scanner scanner;

        public AbstractCase[] parse(Reader reader) {
            scanner = new Scanner(reader);
            scanner.useLocale(Locale.US);
            int numberOfCases = scanner.nextInt();
            scanner.nextLine();
            AbstractCase[] cases = new AbstractCase[numberOfCases];
            for (int i = 0; i < numberOfCases; i++) {
                cases[i] = parseCase();
            }
            return cases;
        }

        protected abstract AbstractCase parseCase();
    }

    class Executor {

        private AbstractInputParser inputParser;
        private Solver solver;

        private AbstractCase[] cases;
        private String[] results;
        private Map<AbstractCase, Integer> caseToIndex;

        private boolean casesLeft = true;

        private AtomicInteger threadsBusy = new AtomicInteger(0);

        public Executor(AbstractInputParser inputParser, Solver solver) {
            this.inputParser = inputParser;
            this.solver = solver;
        }

        public void readAndExecute(InputStream in) {
            cases = inputParser.parse(new InputStreamReader(in));
            results = new String[cases.length];
            caseToIndex = new HashMap<AbstractCase, Integer>();

            int cores = Runtime.getRuntime().availableProcessors();
            cores = 1;

            System.err.println("Spawning "+cores+" threads...");

            BlockingQueue<AbstractCase> caseQueue = new LinkedBlockingQueue<AbstractCase>(cores);

            LinkedList<ExecutorThread> runningThreads = new LinkedList<ExecutorThread>();
            for (int i = 0; i < cores; i++) {
                ExecutorThread executorThread = new ExecutorThread(caseQueue);
                runningThreads.add(executorThread);
                executorThread.start();
            }

            for (int i = 0; i < cases.length; i++) {
                caseToIndex.put(cases[i], i);
                try {
                    caseQueue.put(cases[i]);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            while(caseQueue.size() > 0) {
                try {
                    Thread.sleep(500);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }

            casesLeft = false;

            System.err.println("Waiting for "+runningThreads.size()+" threads to finish...");
            while (runningThreads.size() > 0) {
                try {
                    runningThreads.peek().interrupt();
                    runningThreads.peek().join();
                    runningThreads.remove();
                    System.err.println(runningThreads.size()+" remaining threads...");
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }


            for (int i = 0; i < results.length; i++) {
                System.out.println(String.format(("Case #%d:%s"), i+1, results[i]));
            }

            System.err.println("Finished.");
        }

        class ExecutorThread extends Thread {

            BlockingQueue<AbstractCase> blockingQueue;

            ExecutorThread(BlockingQueue<AbstractCase> blockingQueue) {
                this.blockingQueue = blockingQueue;
            }

            @Override
            public void run() {
                while(casesLeft) {
                    try {
                        AbstractCase c = blockingQueue.take();
                        threadsBusy.incrementAndGet();
                        String result = c.solve(solver);
                        results[caseToIndex.get(c)] = result;
                        System.err.println(String.format("Solved case #%d: %s", caseToIndex.get(c), result));
                        threadsBusy.decrementAndGet();
                    } catch (InterruptedException e) {
                    }
                }
            }
        }
    }

}
