import java.io.File;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

/**
 * Created by Catalin on 4/8/2017.
 */
public class ProblemA {
    private final Scanner in;
    private final PrintStream out;
    private final int instanceCount;

    public ProblemA(Scanner in, PrintStream out) {
        this.in = in;
        this.out = out;
        instanceCount = in.nextInt();
    }

    public static void main(String[] args) throws Exception {
        ProblemA problem = new ProblemA(new Scanner(new File("A-small-attempt2.in")), new PrintStream("src/syrup.out"));
        problem.solve();
    }

    public void solve() {
        for (int testCase = 1; testCase <= instanceCount; testCase++) {
            int n, k;
            n = in.nextInt();
            k = in.nextInt();
            List<Pancake> pancakes = new ArrayList<>();
            for (int i = 0; i < n; i++) {
                pancakes.add(new Pancake(in));
            }
            Collections.sort(pancakes);
            double max = -1;
            for (int i = 0; i < n; i++) {
                double current = largestStackArea(k - 1, pancakes, i);
                if (current > max) {
                    max = current;
                }
            }
            out.printf("Case #%d: %.9f\n", testCase, max);
        }
    }

    private double largestStackArea(int count, List<Pancake> pancakes, int except) {
        Pancake exceptPancake = pancakes.get(except);
        double result = exceptPancake.lateralArea + exceptPancake.topArea;
        List<Pancake> selection = new ArrayList<>();
        for (int i = pancakes.size() - 1; i >= 0 && selection.size() < count; i--) {
            if (i != except && pancakes.get(i).radius <= exceptPancake.radius) {
                selection.add(pancakes.get(i));
            }
        }
        if (selection.size() < count) {
            return 0.0;
        }
        for (Pancake pancake : selection) {
            result += pancake.lateralArea;
        }
        return result;
    }

    private static final double PI = Math.PI;

    private class Pancake implements Comparable<Pancake> {
        final int radius;
        final int height;
        final double lateralArea;
        final double topArea;

        private Pancake(Scanner in) {
            this.radius = in.nextInt();
            this.height = in.nextInt();
            lateralArea = 2 * PI * radius * height;
            topArea = PI * radius * radius;
        }

        @Override
        public int compareTo(Pancake o) {
            int compare = Double.compare(lateralArea, o.lateralArea);
            if (compare == 0) {
                compare = Integer.compare(height, o.height);
            }
            if (compare == 0) {
                compare = Integer.compare(radius, o.radius);
            }
            return compare;
        }

        @Override
        public String toString() {
            return "Pancake{" + radius + ", " + height + '}';
        }
    }
}
