package com.test.codejam;

import java.io.BufferedReader;
import java.io.DataInputStream;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.math.BigInteger;
import java.util.TreeSet;

/**
 * @author Igor Konoplyanko <ikonopyanko@xsolut.de>
 *         Date: 13.04.13
 *         Time: 12:58
 */
public class P3 {

  private static TreeSet<BigInteger> founded = new TreeSet<BigInteger>();
  private static TreeSet<Integer> solvedSet = new TreeSet<Integer>();

  public static void main(String... args) throws Exception {
    final InputStream resourceAsStream = P3.class.getClassLoader().getResourceAsStream("C-large-1.in");

    DataInputStream in = new DataInputStream(resourceAsStream);
    BufferedReader br = new BufferedReader(new InputStreamReader(in));

    String strLine;
    int casenum = 1;

    founded.add(new BigInteger("1"));
    founded.add(new BigInteger("4"));
    founded.add(new BigInteger("9"));

    strLine = br.readLine();

    while ((strLine = br.readLine()) != null) {

      final String[] split = strLine.split("\\s");
      BigInteger min = new BigInteger(split[0]);
      BigInteger max = new BigInteger(split[1]);

      System.out.print("Case #" + casenum + ": ");
      System.out.print(solve(min, max) + "\n");

      casenum++;
    }
    in.close();
  }

  private static String solve(BigInteger min, BigInteger max) {

    int minLen = min.toString().length();
    int maxLen = max.toString().length() + 1;

    int currLen = minLen;
    if (currLen == 1) {
      currLen = 2;
    }

    while (currLen < maxLen) {
      if (solvedSet.contains(currLen)) {
        currLen++;
        continue;
      }
      int halfSize = currLen / 2;

      if (currLen % 2 == 0) {

        BigInteger start = BigInteger.TEN.pow(halfSize);
        BigInteger end = BigInteger.TEN.pow(halfSize + 1).subtract(BigInteger.ONE);

        BigInteger curInt = start;
        while (curInt.compareTo(end) == -1) {
          final BigInteger palindrome = makePalindrome(curInt);
          final double sqrt1 = Math.sqrt(palindrome.doubleValue());
          final double floor = Math.floor(sqrt1);
          if (sqrt1 != floor) {
            curInt = curInt.add(BigInteger.ONE);
            continue;
          }

          final BigInteger sqrt = BigInteger.valueOf((long) floor);
          if (isPalindrome(sqrt.toString())) {
            founded.add(palindrome);
          }
          curInt = curInt.add(BigInteger.ONE);
        }

      } else {

        BigInteger start = BigInteger.TEN.pow(halfSize - 1);
        BigInteger end = BigInteger.TEN.pow(halfSize).subtract(BigInteger.ONE);

        BigInteger curInt = start;
        while (curInt.compareTo(end) == -1) {
          int middle;
          for (middle = 0; middle < 10; middle++) {
            final BigInteger palindrome = makePalindrome(curInt, middle);
            final double sqrt1 = Math.sqrt(palindrome.doubleValue());
            final double floor = Math.floor(sqrt1);
            if (sqrt1 != floor) {
              continue;
            }

            final BigInteger sqrt = BigInteger.valueOf((long) floor);
            if (isPalindrome(sqrt.toString())) {
              founded.add(palindrome);
            }
          }
          curInt = curInt.add(BigInteger.ONE);
        }
      }
      solvedSet.add(currLen);
      currLen++;
    }

    int solutions = 0;
    for (BigInteger i : founded) {
      final int i1 = i.compareTo(min);
      final int i2 = i.compareTo(max);
      if (((i1 == 0) || (i1 == 1)) && ((i2 == 0) || (i2 == -1))) {
        solutions++;
      }
    }

    return String.valueOf(solutions);
  }

  private static boolean isPalindrome(String s) {
    final char[] chars = s.toCharArray();
    if (chars.length == 1) {
      return true;
    }
    for (int i = 0; i < (chars.length / 2) + 1; i++) {
      if (chars[i] != chars[chars.length - 1 - i]) {
        return false;
      }
    }
    return true;
  }

  private static BigInteger makePalindrome(BigInteger curInt, int middle) {
    final String s = curInt.toString();

    final char[] chars = s.toCharArray();
    char[] reverse = new char[chars.length];
    for (int j = 0; j < chars.length; j++) {
      char aChar = chars[j];
      reverse[chars.length - 1 - j] = aChar;
    }

    return new BigInteger(s.concat(String.valueOf(middle)).concat(new String(reverse)));

  }

  static BigInteger makePalindrome(BigInteger i) {
    final String s = i.toString();

    final char[] chars = s.toCharArray();
    char[] reverse = new char[chars.length];
    for (int j = 0; j < chars.length; j++) {
      char aChar = chars[j];
      reverse[chars.length - 1 - j] = aChar;
    }

    return new BigInteger(s.concat(new String(reverse)));
  }
}
