package com.test.codejam2;

import java.io.*;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.*;

/**
 * @author Igor Konoplyanko <konoplianko@me.com>
 *         Date: 12.04.14
 *         Time: 14:22
 */
public class ProblemDWar {

  public static final DecimalFormatSymbols OTHER_SYMBOLS;
  public static final DecimalFormat df;

  static {
    OTHER_SYMBOLS = new DecimalFormatSymbols(new Locale("EN"));
    OTHER_SYMBOLS.setDecimalSeparator('.');
    df = new DecimalFormat("0.0000000", OTHER_SYMBOLS);
  }

  public static void main(String[] args) throws IOException {

    PrintStream out = new PrintStream(new FileOutputStream("solution.txt"));
    System.setOut(out);

    final InputStream resourceAsStream = ProblemDWar.class.getClassLoader().getResourceAsStream("D-small-attempt0.in");

    DataInputStream in = new DataInputStream(resourceAsStream);
    BufferedReader br = new BufferedReader(new InputStreamReader(in));

    String strLine;
    int casenum = 1;

    strLine = br.readLine();
    int numOfCases = Integer.parseInt(strLine);
//    System.out.println("num of: " + numOfCases);

    while ((strLine = br.readLine()) != null) {

      Integer numBlocks = Integer.parseInt(strLine);

      List<Double> naomiBlocks = parse(br.readLine());
      List<Double> kensBlocks = parse(br.readLine());

      System.out.print("Case #" + casenum + ": ");
      System.out.println(solve(numBlocks, naomiBlocks, kensBlocks));

      casenum++;
    }
    in.close();
  }

  private static String solve(Integer numBlocks, List<Double> naomiBlocks, List<Double> kenBlocks) {

    int lieScore = 0;
    int honestScore = 0;

    TreeSet<Double> naomi = new TreeSet<Double>(naomiBlocks);
    TreeSet<Double> ken = new TreeSet<Double>(kenBlocks);

    // Honest game
    for (int i = 0; i < numBlocks; i++) {
      Double naomiBlock = naomi.pollLast();

      Double higher = ken.higher(naomiBlock);
      if (higher == null) {
        ken.pollFirst();
        honestScore++;
      } else {
        ken.remove(higher);
      }
    }

    naomi = new TreeSet<Double>(naomiBlocks);
    ken = new TreeSet<Double>(kenBlocks);

    //Lie game
    for (int i = 0; i < numBlocks; i++) {
      if (naomi.last().compareTo(ken.last()) > 0) {
        Double kenSurrenders = ken.pollFirst();
        Double naomiWins = naomi.higher(kenSurrenders);

        naomi.remove(naomiWins);
        lieScore++;

      } else {
        ken.pollLast();
        naomi.pollFirst();
      }

    }

    return lieScore + " " + honestScore;
  }

  private static List<Double> parse(String line) {
    ArrayList<Double> result = new ArrayList<Double>();

    String[] split = line.split("\\s");
    for (String aSplit : split) {
      result.add(Double.parseDouble(aSplit));
    }
    return result;
  }

}
