import java.io.File;
import java.util.Stack;


public class Main {

	private final static int SIZE = 'Z'-'A'+1;

	public class LineWrapper {
		private String[]pieces;
		private int currentPiece;
		private int insidePiece;
		
		LineWrapper(String line) {
			pieces = line.trim().split(" ");
			currentPiece = 0;
			insidePiece = 0;
		}
		
		public int readInt() {
			insidePiece = 0;
			return Integer.parseInt(pieces[currentPiece++]);
		}
		
		public char readChar() {
			char r = pieces[currentPiece].charAt(insidePiece++);
			if (pieces[currentPiece].length() == insidePiece) {
				currentPiece ++;
				insidePiece = 0;
			}
			return r;
		}
	}
	
	public static void main(String[] args) {
		new Main().start();
	}

	private void start() {
		String contents = FileUtil.getContents(new File("in.txt"));
		String[] lines = contents.split("\n");
		String result = "";
		int T = new LineWrapper(lines[0]).readInt();
		for(int i=1; i<=T; i++) {
			LineWrapper line = new LineWrapper(lines[i]);
			
			int[][] CC = newMatrix(-1);
			int[][] DD = newMatrix(0);
			
			int C = line.readInt();
			for(int j=1; j<=C; j++) {
				int src1 = line.readChar() - 'A';
				int src2 = line.readChar() - 'A';
				int dst = line.readChar() - 'A';
				CC[src1][src2] = dst;
				CC[src2][src1] = dst;
			}
			
			int D = line.readInt();
			for(int j=1; j<=D; j++) {
				int src1 = line.readChar() - 'A';
				int src2 = line.readChar() - 'A';
				DD[src1][src2] = 1;
				DD[src2][src1] = 1;
			}
			
			result += "Case #" + i + ": " + stackAsString(solve(CC, DD, line)) + "\n";
		}
		FileUtil.setContents(new File("out.txt"), result);
		//System.out.println(result);
	}
	
	private int[][] newMatrix(int def) {
		int[][] r = new int[SIZE][SIZE];
		for(int i=0; i<SIZE; i++) {
			for(int j=0; j<SIZE; j++) {
				r[i][j] = def;
			}
		}
		return r;
	}
	
	private void wipeOut(int[] contains) {
		for (int i=0; i<contains.length; i++) {
			contains[i] = 0;
		}
	}
	
	private String stackAsString(Stack<Integer> stack) {
		String result = "[";
		boolean first = true;
		for (int j=0; j<stack.size(); j++) {
			if (first) {
				first = false;
			} else {
				result += ", ";
			}
			result += (char)('A'+stack.get(j));
		}
		result += "]";
		return result;
	}
	
	private Stack<Integer> solve(int[][] C, int[][] D, LineWrapper line) {
		int N = line.readInt();
		int[] contains = new int[SIZE];
		wipeOut(contains);
		
		Stack<Integer> stack = new Stack<Integer>();
		
		for (int i=1; i<=N; i++) {
			int el = line.readChar() - 'A';
			
//			System.out.println("---------------");
//			System.out.print("Adding " + (char)('A' + el) + " to ");
//			System.out.println(stackAsString(stack));
			
			// Combine
			while (stack.size() > 0 && C[stack.peek()][el] != -1) {
				contains[stack.peek()] --;
				el = C[stack.pop()][el];
			}
//			System.out.print("After reducing "+(char)('A' + el) + " and ");
//			System.out.println(stackAsString(stack));
			
			// Explode
			boolean exploded = false;
			for(int j=0; j<SIZE&&!exploded; j++) {
				if (D[el][j] != 0) {
//					System.out.println("INTERACTING WITH " + j);
					if (contains[j] > 0) {
						exploded = true;
						wipeOut(contains);
						stack.clear();
					}
				}
			}
			
			if (!exploded) {
				contains[el] ++;
				stack.push(el);
			}
			
//			System.out.println("At the end: " + stackAsString(stack));
		}
		
		return stack;
	}
}
