package candy;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.LineNumberReader;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

import javax.swing.plaf.basic.BasicInternalFrameTitlePane.MaximizeAction;


public class Main {
	
	private long testSum;
	
	public static void main(String[] args) {
		try {
			Main m = new Main();
			m.run(args[0]);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private void run(String filename) throws Exception {
		List<List<Integer>> tests = readTests(filename);
		long[] results = new long[tests.size()];
		for(int i=0; i<tests.size(); ++i) {
			List<Integer> test = tests.get(i);
			results[i] = runTest(test);
		}
		createOutput(results);
	}

	private void createOutput(long[] results) throws Exception {
		FileWriter writer = new FileWriter("output.txt");
		for(int i=0; i<results.length; ++i) {
			writer.write("Case #"+(i+1)+": "+(results[i] == -1 ? "NO" : results[i])+"\n");
		}
		writer.close();
	}

	private List<List<Integer>> readTests(String filename) throws Exception {
		LineNumberReader reader = null;
		try {
			reader = new LineNumberReader(new FileReader(filename));
		} catch (FileNotFoundException e) {
			System.out.println("File not found");
			e.printStackTrace();
			throw e;
		}
		int testCount = Integer.parseInt(reader.readLine().trim());
		List<List<Integer>> tests = new ArrayList<List<Integer>>(testCount);
		for(int i=0; i<testCount; ++i) {
			int count = Integer.parseInt(reader.readLine().trim());
			String testStr = reader.readLine().trim();
			List<Integer> test = parseTest(count, testStr);
			tests.add(test);
		}
		reader.close();
		return tests;
	}

	private List<Integer> parseTest(int count, String testStr) {
		StringTokenizer tokenizer = new StringTokenizer(testStr);
		List<Integer> test = new ArrayList<Integer>(count);
		for(int i=0; i < count; ++i) {
			int candy = Integer.parseInt(tokenizer.nextToken().trim());
			test.add(new Integer(candy));
		}
		return test;
	}

	private long runTest(List<Integer> test) {
		testSum = realSum(test);
		long testXorSum = calculateSum(test);
		return divide(0, 0, testXorSum, test);
	}
	
	private long divide(long sum, long realsum, long listXorSum, List<Integer> list) {
		long total = -1L;
		if(list.size() <= 1)
			return -1L;
		for(int i=0; i<list.size(); ++i) {
			List<Integer> copy = new ArrayList<Integer>(list);
			for(int j = i; j>=0; --j)
				copy.remove(j);
			long newSum = sum ^ list.get(i).longValue();
			long realSum1 = realsum + list.get(i).longValue();
			long newXorSum = listXorSum ^ list.get(i).longValue();
			if(newSum == newXorSum) {
				long realSumOfCopy = testSum - realSum1;
				long max = Math.max(realSum1, realSumOfCopy);
				total = Math.max(total, max);
			}
			long combinationsum = divide(newSum, realSum1, newXorSum, copy);
			total = Math.max(total, combinationsum);
		}
		return total;
	}
	
	private long calculateSum(List<Integer> list) {
		long sum = 0;
		for(Integer i : list) {
			sum ^= i.longValue();
		}
		return sum;
	}
	
	private long realSum(List<Integer> list) {
		long sum = 0;
		for(Integer i : list) {
			sum += i.longValue();
		}
		return sum;
	}
	
}
