package sort;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.LineNumberReader;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Locale;
import java.util.StringTokenizer;

public class Main {

	
	public static void main(String[] args) {
		try {
			Main m = new Main();
			m.run(args[0]);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private void run(String filename) throws Exception {
		List<List<Integer>> tests = readTests(filename);
		long[] results = new long[tests.size()];
		for(int i=0; i<tests.size(); ++i) {
			List<Integer> test = tests.get(i);
			results[i] = runTest(test);
		}
		createOutput(results);
	}

	private void createOutput(long[] results) throws Exception {
		FileWriter writer = new FileWriter("output.txt");
		DecimalFormat formatter = new DecimalFormat("0.000000");
		formatter.setDecimalFormatSymbols(new DecimalFormatSymbols(Locale.ENGLISH));
		for(int i=0; i<results.length; ++i) {
			writer.write("Case #"+(i+1)+": "+formatter.format(results[i])+"\n");
		}
		writer.close();
	}

	private List<List<Integer>> readTests(String filename) throws Exception {
		LineNumberReader reader = null;
		try {
			reader = new LineNumberReader(new FileReader(filename));
		} catch (FileNotFoundException e) {
			System.out.println("File not found");
			e.printStackTrace();
			throw e;
		}
		int testCount = Integer.parseInt(reader.readLine().trim());
		List<List<Integer>> tests = new ArrayList<List<Integer>>(testCount);
		for(int i=0; i<testCount; ++i) {
			int count = Integer.parseInt(reader.readLine().trim());
			String testStr = reader.readLine().trim();
			List<Integer> test = parseTest(count, testStr);
			tests.add(test);
		}
		reader.close();
		return tests;
	}

	private List<Integer> parseTest(int count, String testStr) {
		StringTokenizer tokenizer = new StringTokenizer(testStr);
		List<Integer> test = new ArrayList<Integer>(count);
		for(int i=0; i < count; ++i) {
			int candy = Integer.parseInt(tokenizer.nextToken().trim());
			test.add(new Integer(candy));
		}
		return test;
	}

	@SuppressWarnings("unchecked")
	private long runTest(List<Integer> test) {
		List sortedList = new ArrayList<Integer>(test);
		Collections.sort(sortedList);
		// Find correct placed elements
		int unorderedCount = 0;
		for(int i=0; i< test.size(); ++i) {
			if(!test.get(i).equals(sortedList.get(i)))
				++unorderedCount;
		}
		if(unorderedCount == 0)
			return 0;
		long min = Long.MAX_VALUE;
		for(int i = 1; i<=unorderedCount; ++i) {
			long result = calculateOrderCount(unorderedCount, i);
			min = Math.min(min, result);
		}
		return min;
	}
	
	private long calculateOrderCount(int total, int group) {
		long groupFactorial = 1;
		for(int i=2; i<= group; ++i)
			groupFactorial *= i;
		long result = (long)Math.floor(total/group) * groupFactorial;
		if( (total % group) > 0) {
			groupFactorial = 1;
			for(int i=2; i<= (total % group); ++i)
				groupFactorial *= i;
			result += groupFactorial;
		}
		return result;
	}
	
	
	
}
