package robot;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.LineNumberReader;
import java.io.StringWriter;
import java.io.Writer;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

public class Main {
	
	public static void main(String[] args) {
		try {
			Main m = new Main();
			m.run(args[0]);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private void run(String filename) throws Exception {
		List<List<Command>> tests = readTests(filename);
		long[] results = new long[tests.size()];
		for(int i=0; i<tests.size(); ++i) {
			List<Command> test = tests.get(i);
			results[i] = runTest(test);
		}
		createOutput(results);
	}

	private void createOutput(long[] results) throws Exception {
		FileWriter writer = new FileWriter("output.txt");
		for(int i=0; i<results.length; ++i) {
			writer.write("Case #"+(i+1)+": "+results[i]+"\n");
		}
		writer.close();
	}

	private List<List<Command>> readTests(String filename) throws Exception {
		LineNumberReader reader = null;
		try {
			reader = new LineNumberReader(new FileReader(filename));
		} catch (FileNotFoundException e) {
			System.out.println("File not found");
			e.printStackTrace();
			throw e;
		}
		int testCount = Integer.parseInt(reader.readLine().trim());
		List<List<Command>> tests = new ArrayList<List<Command>>(testCount);
		for(int i=0; i<testCount; ++i) {
			String testStr = reader.readLine().trim();
			List<Command> test = parseTest(testStr);
			tests.add(test);
		}
		reader.close();
		return tests;
	}

	private List<Command> parseTest(String testStr) {
		StringTokenizer tokenizer = new StringTokenizer(testStr);
		int commandCount = Integer.parseInt(tokenizer.nextToken().trim());
		List<Command> test = new ArrayList<Command>(commandCount);
		for(int i=0; i < commandCount; ++i) {
			String robot = tokenizer.nextToken();
			int button = Integer.parseInt(tokenizer.nextToken().trim());
			test.add(new Command(robot, button));
		}
		return test;
	}

	private long runTest(List<Command> test) {
		Robot orange = new Robot(Robot.ROBOT_O);
		Robot blue = new Robot(Robot.ROBOT_B);
		long step = 0;
		while(!test.isEmpty()) {
			boolean o = orange.action(test);
			boolean b = blue.action(test);
			if(o || b)
				test.remove(0); // Remove first command
			++step;
		}
		return step;
	}
	
	
	

}
