import javafx.scene.control.Cell;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

/**
 * Created by cesarterrazas on 4/8/17.
 */
public class BathroomStalls {
    public static void main(String[] args) throws IOException {
        String INPUT_FILE = "C-small-1-attempt2.in";
        String OUTPUT_FILE = "C-small-1-attempt2.out";
        try (Scanner scanner = new Scanner(new File(INPUT_FILE)); FileWriter fw = new FileWriter(new File(OUTPUT_FILE))) {
            StringBuilder stringBuilder = new StringBuilder();
            int t = scanner.nextInt();
            for (long i = 1; i <= t; i++) {
                int n = scanner.nextInt();
                long k = scanner.nextLong();
                Result result = calculateResult(n, k);
                stringBuilder.append(String.format("Case #%d: %d %d\n", i, result.x, result.y));
            }
            fw.write(stringBuilder.toString());
        }
    }

    private static Result calculateResult(int n, long k) {
        Cell[] cells = new Cell[n + 2];
        for (int i = 0; i < cells.length; i++) {
            cells[i] = new Cell(i);
        }
        cells[0].isBusy = true;
        cells[cells.length - 1].isBusy = true;
        initializeLR(cells);
        Cell last = null;
        for (int i = 0; i < k; i++) {
            last = selectACell(cells);
            updateLR(cells, last.index);
        }
        Result result = new Result();
        result.x = last.maximal();
        result.y = last.minimal();
        return result;
    }


    private static Cell selectACell(Cell[] cells) {
        int max = -1;
        List<Cell> cellsWithMax = new ArrayList<>();
        for (int i = 1; i < cells.length - 1; i++) {
            int a = cells[i].minimal();
            if (!cells[i].isBusy && a > max) {
                max = a;
                cellsWithMax.clear();
                cellsWithMax.add(cells[i]);
            } else if (!cells[i].isBusy && a == max) {
                cellsWithMax.add(cells[i]);
            }
        }
        if (cellsWithMax.size() > 1) {
            int p = -1;
            int maxCount = 0;
            Cell s = null;
            for (int i = 0; i < cellsWithMax.size(); i++) {
                if (cellsWithMax.get(i).maximal() > p) {
                    maxCount = 1;
                    s = cellsWithMax.get(i);
                    p = cellsWithMax.get(i).maximal();
                } else if (cellsWithMax.get(i).maximal() == p) {
                    maxCount++;
                }
            }
            if (maxCount == 1) {
                s.isBusy = true;
                return s;
            }
        }
        cellsWithMax.get(0).isBusy = true;
        return cellsWithMax.get(0);
    }

    private static void initializeLR(Cell[] cells) {
        for (int i = 1; i < cells.length - 1 ; i++) {
            cells[i].ls = i - 1;
            cells[i].rs = cells.length - 3 - cells[i].ls;
        }
    }

    private static void updateLR(Cell[] cells, int index) {
        int i = index - 1;
        int j = 0;
        while(i >= 1 && !cells[i].isBusy) {
            cells[i].rs = j;
            j++;
            i--;
        }
        i = index + 1;
        j = 0;
        while (i < cells.length && !cells[i].isBusy) {
            cells[i].ls = j;
            j++;
            i++;
        }
    }

    private static class Cell {
        boolean isBusy;
        int ls;
        int rs;
        int index;

        Cell(int index) {
            this.index = index;
        }

        int maximal() {
            return Math.max(ls, rs);
        }

        int minimal() {
            return Math.min(ls, rs);
        }
    }

//    private static Result calculateResult1(long n, long k) {
//        Result result = new Result();
//        if (k == 1) {
//            result.x = n / 2;
//            result.y = (n - 1) / 2;
//            return result;
//        }
//        if (k == 2) {
//            result.x = n / 4;
//            result.y = (n / 2 - 1) - result.x;
//            return result;
//        }
//        if (k == 3) {
//            long m = (calculateResult(n, 1)).y;
//            result.x = m / 2;
//            result.y = m - 1 - result.x;
//            return result;
//        }
//        long m;
//        if (k % 2 == 0) {
//            Result result1 = calculateResult(n, (k / 2));
//            m = middle(result1.x, result1.y, calculateResult(n, (k / 2) - 1).y);
//        } else {
//            Result result1 = calculateResult(n, (k / 2));
//            m = middle(calculateResult(n, (k + 1)/ 2).x, result1.x, result1.y);
//        }
//        result.x = m / 2;
//        if (result.x < 1) {
//            result.x = 0;
//        }
//        result.y = (m - 1) - result.x;
//        if (result.y < 1) {
//            result.y = 0;
//        }
//        return result;
//    }

    private static long middle(long a, long b, long c) {
        if ((a <= b && b <= c) || (c <= b && b <= a)) {
            return b;
        }
        if ((b <= a && a <= c) || (c <= a && a <= c)) {
            return a;
        }
        return c;
    }

    private static class Result {
        long x;
        long y;
    }
}
