
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Scanner;


/**
 *
 * @author Charles
 */
public class CodeJam
{
    //input/output file name
    static final String FILE_NAME = "C-large-1";
    static long[] perfectSquares = new long[40];

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws FileNotFoundException
    {
        ArrayList<String> values = readFile(FILE_NAME + ".in");
        int count = 1;

        PrintWriter outFile = new PrintWriter(new File(FILE_NAME + ".out"));
        
        long square;
        int index = 0;
        for(long start = 0; start < 1000001; start++)
        {
            if(isPalendrone(Long.toString(start)))
            {
                square = start * start;
                if(isPalendrone(Long.toString(square)))
                {
                    perfectSquares[index++] = square;
                    
                }
            }
        }
          
        for (String line : values)
        {
            String output = processAlgorithm(line, count++);
            System.out.println(output);
            outFile.println(output);
        }
        outFile.close();
    }

    /**
     * Reads the CodeJam files and returns the input as a List of String. Should
     * be adjusted for each individual file inputs.
     *
     * @param fileName The name of the file to be read
     * @return the list containing the contents of the file.
     */
    public static ArrayList<String> readFile(String fileName)
    {
        ArrayList<String> results = new ArrayList<String>();
        try
        {
            Scanner inFile = new Scanner(new File(fileName));
            int numberOfLines = Integer.parseInt(inFile.nextLine());
            while (inFile.hasNextLine())
            {
                results.add(inFile.nextLine());
            }

            if (numberOfLines != results.size())
            {
                System.err.println("File size does not match...");
                System.exit(0);
            }

        } catch (FileNotFoundException ex)
        {
            System.err.println("File not found...");
            System.exit(0);
        }
        return results;
    }

    /**
     * Work the magic here.
     * @param line
     * @param count
     * @return 
     */
    private static String processAlgorithm(String line, int count)
    {
        StringBuilder result = new StringBuilder("Case #" + count + ": ");

        int countFairs = 0;
        
        String[] parts = line.split(" ");
        long start = Long.parseLong(parts[0]);
        long stop = Long.parseLong(parts[1]);
        
        for(int index = 0; index < perfectSquares.length; index++)
        {
            if(perfectSquares[index] >= start && perfectSquares[index] <= stop)
            {
                countFairs++;
            }
        }
        result.append(countFairs);
        return result.toString();
    }
    
    private static  boolean isPalendrone(String in)
    {
        for(int index = 0; index < in.length(); index++)
        {
            if(in.charAt(index) != in.charAt(in.length() - index - 1))
            {
                return false;
            }
        }
        
        return true;
    }

    /**
     * Possible helper, in certain cases, (long) Math.pow(base, exponent) does 
     * NOT return a correct long value. Use this method instead when dealing
     * with large numbers.
     * 
     * @param base
     * @param exponent
     * @return base base raised to the exponent power, base ^ exponent
     */
    private static long pow(int base, int exponent)
    {
        long result = 1;
        for (int count = 1; count <= exponent; count++)
        {
            result *= base;
        }
        return result;
    }
    
    /**
     * This method will, with limited accuracy, check to see if the floating
     * point number passed in as an argument can be considered a whole
     * number with minimal loss of precision. 
     * 
     * @param number
     * @return 
     */
    private static boolean isDoubleWhole(double number)
    {
        long numberAsInteger = (long) number;
        
        double diff = number - numberAsInteger;
        
        if(diff > .00000001)
        {
            return false;
        }
        else
        {
            return true;
        }
    }
}
