
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Scanner;

/**
 *
 * @author Charles
 */
public class CodeJam {

    //input/output file name
    static final String FILE_NAME = "A-small";

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws FileNotFoundException {
        ArrayList<Integer> values = readFile(FILE_NAME + ".in");
        int count = 1;

        PrintWriter outFile = new PrintWriter(new File(FILE_NAME + ".out"));
        for (Integer line : values) {
            String output = processAlgorithm(line, count++);
            System.out.println(output);
            outFile.println(output);
        }
        outFile.close();
    }

    /**
     * Reads the CodeJam files and returns the input as a List of String. Should
     * be adjusted for each individual file inputs.
     *
     * @param fileName The name of the file to be read
     * @return the list containing the contents of the file.
     */
    public static ArrayList<Integer> readFile(String fileName) {
        ArrayList<Integer> results = new ArrayList<>();
        try {
            Scanner inFile = new Scanner(new File(fileName));
            int numberOfLines = Integer.parseInt(inFile.nextLine());
            while (inFile.hasNextLine()) {
                results.add(Integer.parseInt(inFile.nextLine()));
            }

            if (numberOfLines != results.size()) {
                System.err.println("File size does not match...");
                System.exit(0);
            }

        } catch (FileNotFoundException ex) {
            System.err.println("File not found...");
            System.exit(0);
        }
        return results;
    }

    /**
     * Work the magic here.
     *
     * @param line
     * @param count
     * @return
     */
    private static String processAlgorithm(final Integer line, final int count) {
       if (line == 0) {
           return "Case #" + count + ": INSOMNIA";
       }
        int[] digits = new int[10];
       
        int i = 2;
        int n = line;
       while (!isAllUsed(digits)) {
           int currentN = n;
           while (currentN > 0) {
                digits[currentN % 10]++;
                currentN /= 10;
           }
           
           n = line * i;
           i++;
       }
        i -= 2;
        n = line * i;
        return "Case #" + count + ": " + String.valueOf(n);
    }
    
    private static boolean isAllUsed(final int[] digits) {
        boolean result = true;
        for(int digit : digits) {
            result &= digit > 0;
        }
        return result;
    }

    /**
     * Possible helper, in certain cases, (long) Math.pow(base, exponent) does
     * NOT return a correct long value. Use this method instead when dealing
     * with large numbers.
     *
     * @param base
     * @param exponent
     * @return base base raised to the exponent power, base ^ exponent
     */
    private static long pow(int base, int exponent) {
        long result = 1;
        for (int count = 1; count <= exponent; count++) {
            result *= base;
        }
        return result;
    }

    /**
     * This method will, with limited accuracy, check to see if the floating
     * point number passed in as an argument can be considered a whole number
     * with minimal loss of precision.
     *
     * @param number
     * @return
     */
    private static boolean isDoubleWhole(double number) {
        long numberAsInteger = (long) number;

        double diff = number - numberAsInteger;

        if (diff > .00000001) {
            return false;
        } else {
            return true;
        }
    }
}
