
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Scanner;

/**
 *
 * @author Charles
 */
public class CodeJamA
{
    //input/output file name

    static final String FILE_NAME = "A";

    /**
     * @param args the command line arguments
     * @throws FileNotFoundException
     */
    public static void main(String[] args) throws FileNotFoundException
    {
        ArrayList<int[][]> values = readFile(FILE_NAME + ".in");
        int count = 1;

        PrintWriter outFile = new PrintWriter(new File(FILE_NAME + ".out"));
        for (int[][] square : values)
        {
            String output = processAlgorithm(square, count++);
            System.out.println(output);
            outFile.println(output);
        }
        outFile.close();
    }

    /**
     * Reads the CodeJam files and returns the input as a List of String. Should
     * be adjusted for each individual file inputs.
     *
     * @param fileName The name of the file to be read
     * @return the list containing the contents of the file.
     */
    public static ArrayList<int[][]> readFile(String fileName)
    {
        ArrayList<int[][]> results = new ArrayList<int[][]>();
        try
        {
            Scanner inFile = new Scanner(new File(fileName));
            int numberOfLines = Integer.parseInt(inFile.nextLine());
            for (int count = 0; count < numberOfLines; count++)
            {
				int[][] square = new int[4][4];
				for(int row = 0; row < 4; row++)
				{
					String line = inFile.nextLine();
					for(int col = 0; col < 4; col++)
					{
						square[row][col] = getValue(line.charAt(col));
					}
				}
				if(count < numberOfLines - 1)
				{
					inFile.nextLine();
				}
				results.add(square);
            }

            if (numberOfLines != results.size())
            {
                System.err.println("File size does not match...");
                System.exit(0);
            }

        }
        catch (FileNotFoundException ex)
        {
            System.err.println("File not found...");
            System.exit(0);
        }
        return results;
    }

    /**
     * Work the magic here.
     * @param line
     * @param count
     * @return
     */
    private static String processAlgorithm(int[][] square, int count)
    {
        StringBuilder result = new StringBuilder("Case #" + count + ": ");

		boolean containsBlank = false;

		String winner = "";

		for(int row = 0; row < 4; row++)
		{
			int rowSum = 0;
			for(int col = 0; col < 4; col++)
			{
				rowSum += square[row][col];
				containsBlank |= square[row][col] == 0;
			}
			winner = whoWins(rowSum);
			if(!winner.isEmpty())
			{
				result.append(winner);
				return result.toString();
			}
		}
		for(int row = 0; row < 4; row++)
		{
			int colSum = 0;
			for(int col = 0; col < 4; col++)
			{
				colSum += square[col][row];
			}
			winner = whoWins(colSum);
			if(!winner.isEmpty())
			{
				result.append(winner);
				return result.toString();
			}
		}
		int xSum = square[0][0] + square[1][1] + square[2][2] + square[3][3];
		winner = whoWins(xSum);
		if(!winner.isEmpty())
		{
			result.append(winner);
			return result.toString();
		}
		xSum = square[0][3] + square[1][2] + square[2][1] + square[3][0];
		winner = whoWins(xSum);
		if(!winner.isEmpty())
		{
			result.append(winner);
			return result.toString();
		}

		if(containsBlank)
		{
				result.append("Game has not completed");
				return result.toString();
		}
		result.append("Draw");
        return result.toString();
    }

    private static int getValue(char c)
    {
		switch(c)
		{
			case 'X':
				return 1;
			case 'O':
				return -1;
			case '.':
				return 0;
			case 'T':
				return 10;
		}
		return 9000;
	}

	private static String whoWins(int value)
	{
		if(value == 4 || value == 13)
		{
			return "X won";
		}
		else if(value == -4 || value == 7)
		{
			return "O won";
		}
		else
		{
			return "";
		}
	}

}

