
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Scanner;

/**
 *
 * @author Charles
 */
public class CodeJam {

    //input/output file name
    static final String FILE_NAME = "B-large";

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws FileNotFoundException {
        ArrayList<String> values = readFile(FILE_NAME + ".in");
        int count = 1;

        PrintWriter outFile = new PrintWriter(new File(FILE_NAME + ".out"));
        for (String line : values) {
            String output = processAlgorithm(line, count++);
            System.out.println(output);
            outFile.println(output);
        }
        outFile.close();
    }

    /**
     * Reads the CodeJam files and returns the input as a List of String. Should
     * be adjusted for each individual file inputs.
     *
     * @param fileName The name of the file to be read
     * @return the list containing the contents of the file.
     */
    public static ArrayList<String> readFile(String fileName) {
        ArrayList<String> results = new ArrayList<String>();
        try {
            Scanner inFile = new Scanner(new File(fileName));
            int numberOfLines = Integer.parseInt(inFile.nextLine());
            while (inFile.hasNextLine()) {
                results.add(inFile.nextLine());
            }

            if (numberOfLines != results.size()) {
                System.err.println("File size does not match...");
                System.exit(0);
            }

        } catch (FileNotFoundException ex) {
            System.err.println("File not found...");
            System.exit(0);
        }
        return results;
    }

    /**
     * Work the magic here.
     *
     * @param line
     * @param count
     * @return
     */
    private static String processAlgorithm(String line, int count) {
        DecimalFormat fmt = new DecimalFormat("0.00000000");
        StringBuilder result = new StringBuilder("Case #" + count + ": ");
        Scanner tokens = new Scanner(line);
        double costToBuy = tokens.nextDouble();
        double additionalCookies = tokens.nextDouble();
        double goal = tokens.nextDouble();
        double noFactoryTime = 0.0, factoryTime = 0.0, estimateNoFactoryTime = 0.0, estimateFactoryTime = 0;

        double cookieCount = 2.0;

        do {
            noFactoryTime += goal / cookieCount;
            double buyFactory = factoryTime + costToBuy / cookieCount;
            cookieCount += additionalCookies;
            factoryTime = buyFactory + goal / cookieCount;
            if(noFactoryTime > factoryTime) {
                noFactoryTime = factoryTime = buyFactory;
            }
            else if(noFactoryTime == factoryTime) {
                break;
            }
        } while (factoryTime <= noFactoryTime);
        result.append(fmt.format(noFactoryTime));
        return result.toString();
    }

    /**
     * Possible helper, in certain cases, (long) Math.pow(base, exponent) does
     * NOT return a correct long value. Use this method instead when dealing
     * with large numbers.
     *
     * @param base
     * @param exponent
     * @return base base raised to the exponent power, base ^ exponent
     */
    private static long pow(int base, int exponent) {
        long result = 1;
        for (int count = 1; count <= exponent; count++) {
            result *= base;
        }
        return result;
    }

    /**
     * This method will, with limited accuracy, check to see if the floating
     * point number passed in as an argument can be considered a whole number
     * with minimal loss of precision.
     *
     * @param number
     * @return
     */
    private static boolean isDoubleWhole(double number) {
        long numberAsInteger = (long) number;

        double diff = number - numberAsInteger;

        if (diff > .00000001) {
            return false;
        } else {
            return true;
        }
    }
}
