
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Scanner;


/*
 * To change this template, choose Tools | Templates and open the template in
 * the editor.
 */
/**
 *
 * @author Charles
 */
public class CodeJam2015C {

    static final String FILE_NAME = "C-small-attempt1";
//    static final String FILE_NAME = "A-small";

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws FileNotFoundException {
        ArrayList<Case> values = readFile(FILE_NAME + ".in");
        int count = 1;

        PrintWriter outFile = new PrintWriter(new File(FILE_NAME + ".out"));
        for (Case c : values) {
            String output = processAlgorithm(c, count++);
            System.out.println(output);
            outFile.println(output);
        }
        outFile.close();
    }

    /**
     * Reads the CodeJam files and returns the input as a List of String.
     *
     * @param fileName The name of the file to be read
     * @return the list containing the contents of the file.
     */
    private static ArrayList<Case> readFile(String fileName) {
        ArrayList<Case> results = new ArrayList<Case>();
        try {
            Scanner inFile = new Scanner(new File(fileName));
            int numberOfLines = inFile.nextInt();

            //inFile.nextLine();  //  If reading strings uncomment....
            while (inFile.hasNextInt()) {

                Case c = new Case(inFile.nextInt(), inFile.nextInt(), inFile.next());

                results.add(c);
            }

            if (numberOfLines != results.size()) {
                System.err.println("File size does not match...");
                System.exit(0);
            }

        }
        catch (FileNotFoundException ex) {
            System.err.println("File not found...");
            System.exit(0);
        }
        return results;
    }

    private static String processAlgorithm(Case c, int caseNumber) {
        StringBuilder result = new StringBuilder("Case #" + caseNumber + ": ");

        result.append(c.findIjk() ? "YES" : "NO");

        return result.toString();
    }

    /**
     * Possible helper, in certain cases, (long) Math.pow(base, exponent) does
     * NOT return a correct long value. Use this method instead when dealing
     * with large numbers.
     *
     * @param base
     * @param exponent
     * @return base base raised to the exponent power, base ^ exponent
     */
    private static long pow(int base, int exponent) {
        long result = 1;
        for (int count = 1; count <= exponent; count++) {
            result *= base;
        }
        return result;
    }

    /**
     * This method will, with limited accuracy, check to see if the floating
     * point number passed in as an argument can be considered a whole number
     * with minimal loss of precision.
     *
     * @param number
     * @return
     */
    private static boolean isDoubleWhole(double number) {
        return (number - (long) number) <= .00000001;
    }

}

class Case {

    String line, frag;
    int fragLength;

    Case(int length, int repeat, String frag) {
        StringBuilder text = new StringBuilder(frag);
        for (int i = 1; i < repeat; i++) {
            text.append(frag);
        }
        line = text.toString();
        this.frag = frag;
        this.fragLength = length;
    }

    boolean findIjk() {
        if (fragLength == 1) {
            return false;
        }
        else {
            ArrayList<Integer> iIndicies = getIIndexes();
            ArrayList<Integer> kIndicies = getKIndexes();
            int[][] jays = buildJArray();

            for (int i = iIndicies.size() - 1; i >= 0; i--) {
                for (int k = 0; k < kIndicies.size(); k++) {
                    int iIndex = iIndicies.get(i);
                    int kIndex = kIndicies.get(k);
                    if (iIndex < kIndex && jays[iIndex + 1][kIndex - 1] == 3) {
                        return true;
                    }
                }
            }
        }
        return false;
    }
    
    boolean isJ(int iIndex, int kIndex) {
        int currentMulti = 1;
        for (int i = iIndex + 1; i < kIndex; i++) {
            int current = line.charAt(i) - 103;
            currentMulti = multiplyQuanternion(currentMulti, current);
        }
        return currentMulti == 3;
    }

    ArrayList<Integer> getIIndexes() {
        ArrayList<Integer> indexes = new ArrayList<Integer>();

        int currentMulti = 1;
        for (int i = 0; i < line.length(); i++) {
            int current = line.charAt(i) - 103;
            currentMulti = multiplyQuanternion(currentMulti, current);
            if (currentMulti == 2) {
                indexes.add(i);
            }
        }
        return indexes;
    }
    
    int[][] buildJArray() {
        int[][] jays = new int[line.length()][line.length()];
        
        for(int i = 0; i < line.length(); i++) {
            int currentMulti = 1;
            for(int j = i; j < line.length(); j++) {
                int current = line.charAt(j) - 103;
                jays[i][j] = currentMulti = multiplyQuanternion(currentMulti, current);
            }
        }
        
        
        return jays;
        
    }

    ArrayList<Integer> getKIndexes() {
        ArrayList<Integer> indexes = new ArrayList<Integer>();

        for (int i = 0; i < line.length(); i++) {
            int currentMulti = 1;
            for (int j = i; j < line.length(); j++) {
                int current = line.charAt(j) - 103;
                currentMulti = multiplyQuanternion(currentMulti, current);
            }
            if (currentMulti == 4) {
                indexes.add(i);
            }
        }
        return indexes;
    }

    private int multiplyQuanternion(int first, int second) {
        int result = MULTIPLICIATIVE_STRUCTURE[Math.abs(first) - 1][Math.abs(second) - 1];
        if (first * second < 0) { //one of these is -
            result *= -1;
        }
        return result;
    }

    static final int[][] MULTIPLICIATIVE_STRUCTURE = {
        {1, 2, 3, 4},
        {2, -1, 4, -3},
        {3, -4, -1, 2},
        {4, 3, -2, -1}
    };

    static final char[] CONVERSION = {'X', '1', 'i', 'j', 'k'};
}

class Node<T> {

    T data;
    ArrayList<Node> leaves = new ArrayList<Node>();

    Node(T name) {
        this.data = name;
    }

    Node getChildNode(T target) {
        for (Node n : leaves) {
            if (n.data.equals(target)) {
                return n;
            }
        }
        return null;
    }

    Node makeChildNode(T target) {
        Node n = new Node(target);
        leaves.add(n);
        return n;
    }
}
