
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Scanner;


/**
 *
 * @author Charles
 */
public class CodeJam
{
    //input/output file name
    static final String FILE_NAME = "B-small-attempt0";

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws FileNotFoundException
    {
        ArrayList<int[][]> values = readFile(FILE_NAME + ".in");
        int count = 1;

        PrintWriter outFile = new PrintWriter(new File(FILE_NAME + ".out"));
        for (int[][] lawn : values)
        {
            String output = processAlgorithm(lawn, count++);
            System.out.println(output);
            outFile.println(output);
        }
        outFile.close();
    }

    /**
     * Reads the CodeJam files and returns the input as a List of String. Should
     * be adjusted for each individual file inputs.
     *
     * @param fileName The name of the file to be read
     * @return the list containing the contents of the file.
     */
    public static ArrayList<int[][]> readFile(String fileName)
    {
        ArrayList<int[][]> results = new ArrayList<int[][]>();
        try
        {
            Scanner inFile = new Scanner(new File(fileName));
            int numberOfLines = Integer.parseInt(inFile.nextLine());
            for(int count = 0; count < numberOfLines; count++)
            {
                String line = inFile.nextLine();
                String[] parts = line.split(" ");
                int rows = Integer.parseInt(parts[0]);
                int cols = Integer.parseInt(parts[1]);
                int[][] lawn = new int[rows][cols];
                for(int row = 0; row < rows; row++)
                {
                    line = inFile.nextLine();
                    parts = line.split(" ");
                    for(int col = 0; col < cols; col++)
                    {
                        lawn[row][col] = Integer.parseInt(parts[col]);
                    }
                }
                results.add(lawn);
            }

            if (numberOfLines != results.size())
            {
                System.err.println("File size does not match...");
                System.exit(0);
            }

        } catch (FileNotFoundException ex)
        {
            System.err.println("File not found...");
            System.exit(0);
        }
        return results;
    }

    /**
     * Work the magic here.
     * @param line
     * @param count
     * @return 
     */
    private static String processAlgorithm(int[][] lawn, int count)
    {
        StringBuilder result = new StringBuilder("Case #" + count + ": ");
        
        //create boolean array for results
        boolean[][] table = new boolean[lawn.length][lawn[0].length];
        
        
        //get the max of all rows and cols
        int[] rowHighs = new int[lawn.length];
        int[] colHighs = new int[lawn[0].length];
        
        for(int row = 0; row < lawn.length; row++)
        {
            for(int col = 0; col < lawn[0].length; col++)
            {
                if(lawn[row][col] > rowHighs[row])
                {
                    rowHighs[row] = lawn[row][col];
                }
                if(lawn[row][col] > colHighs[col])
                {
                    colHighs[col] = lawn[row][col];
                }
            }
        }
        
        //look at each spot in each row, see if it could be bad
        for(int row = 0; row < lawn.length; row++)
        {
            for(int col = 0; col < lawn[0].length; col++)
            {
                table[row][col] |= (lawn[row][col] >= rowHighs[row]);
            }
            
        }
        
        //look at each spot in each col, see if it could be bad
        for(int row = 0; row < lawn.length; row++)
        {
            for(int col = 0; col < lawn[0].length; col++)
            {
                 table[row][col] |= (lawn[row][col] >= colHighs[col]);               
            }
            
        }
        
        //look at the boolean array, any false???
        boolean valid = true;
        for(int row = 0; row < lawn.length; row++)
        {
            for(int col = 0; col < lawn[0].length; col++)
            {
                valid &= table[row][col];
            }
        }
        
        if(valid)
        {
            result.append("YES");
        }
        else
        {
            result.append("NO");            
        }

        return result.toString();
    }
    


    /**
     * Possible helper, in certain cases, (long) Math.pow(base, exponent) does 
     * NOT return a correct long value. Use this method instead when dealing
     * with large numbers.
     * 
     * @param base
     * @param exponent
     * @return base base raised to the exponent power, base ^ exponent
     */
    private static long pow(int base, int exponent)
    {
        long result = 1;
        for (int count = 1; count <= exponent; count++)
        {
            result *= base;
        }
        return result;
    }
    
    /**
     * This method will, with limited accuracy, check to see if the floating
     * point number passed in as an argument can be considered a whole
     * number with minimal loss of precision. 
     * 
     * @param number
     * @return 
     */
    private static boolean isDoubleWhole(double number)
    {
        long numberAsInteger = (long) number;
        
        double diff = number - numberAsInteger;
        
        if(diff > .00000001)
        {
            return false;
        }
        else
        {
            return true;
        }
    }
}
