
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Scanner;

/**
 *
 * @author Charles
 */
public class CodeJam
{
    //input/output file name

    static final String FILE_NAME = "A";

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws FileNotFoundException
    {
        ArrayList<Osmos> values = readFile(FILE_NAME + ".in");
        int count = 1;

        PrintWriter outFile = new PrintWriter(new File(FILE_NAME + ".out"));
        for (Osmos line : values)
        {
            String output = processAlgorithm(line, count++);
            System.out.println(output);
            outFile.println(output);
        }
        outFile.close();
    }

    /**
     * Reads the CodeJam files and returns the input as a List of String. Should
     * be adjusted for each individual file inputs.
     *
     * @param fileName The name of the file to be read
     * @return the list containing the contents of the file.
     */
    public static ArrayList<Osmos> readFile(String fileName)
    {
        ArrayList<Osmos> results = new ArrayList<Osmos>();
        try
        {
            Scanner inFile = new Scanner(new File(fileName));
            int numberOfLines = Integer.parseInt(inFile.nextLine());
            for (int count = 0; count < numberOfLines; count++)
            {
                Osmos current = new Osmos();
                String[] parts = inFile.nextLine().split(" ");
                current.myMote = Integer.parseInt(parts[0]);
                parts = inFile.nextLine().split(" ");
                for (int index = 0; index < parts.length; index++)
                {
                    int temp = Integer.parseInt(parts[index]);
                    if (current.myMote > temp)
                    {
                        current.myMote += temp;
                    }
                    else
                    {
                        current.otherMotes.add((long) temp);
                    }
                }
                results.add(current);
            }
            if (numberOfLines != results.size())
            {
                System.err.println("File size does not match...");
                System.exit(0);
            }

        }
        catch (FileNotFoundException ex)
        {
            System.err.println("File not found...");
            System.exit(0);
        }
        return results;
    }

    /**
     * Work the magic here.
     *
     * @param line
     * @param count
     * @return
     */
    private static String processAlgorithm(Osmos line, int count)
    {
        StringBuilder result = new StringBuilder("Case #" + count + ": ");

        Collections.sort(line.otherMotes);

        long[] numChanges = new long[line.otherMotes.size()];
        int index = 0;
        if (line.myMote == 1)
        {
            line.changes = line.otherMotes.size();
        }
        else
        {
            if (count == 7)
            {
                int x = 0;
            }
            while (!line.otherMotes.isEmpty())
            {
                if (line.myMote > line.otherMotes.get(0))
                {
                    line.myMote += line.otherMotes.remove(0);
                    index++;
                }
                else if (line.myMote * 2 - 1 > line.otherMotes.get(0))
                {
                    line.myMote += (line.myMote - 1 + line.otherMotes.remove(0));
                    numChanges[index++]++;
                }
                else
                {
                    line.myMote += line.myMote - 1;
                    numChanges[index]++;
                }
            }
        }

        for (index = 0; index < numChanges.length; index++)
        {
            if (numChanges[index] < numChanges.length - index)
            {
                line.changes += numChanges[index];
            }
            else
            {
                line.changes += numChanges.length - index;
                index = Integer.MAX_VALUE - 1;
            }
        }
        if(line.changes > numChanges.length)
        {
            line.changes = numChanges.length;
        }

        result.append(line.changes);

        return result.toString();
    }

    /**
     * Possible helper, in certain cases, (long) Math.pow(base, exponent) does
     * NOT return a correct long value. Use this method instead when dealing
     * with large numbers.
     *
     * @param base
     * @param exponent
     * @return base base raised to the exponent power, base ^ exponent
     */
    private static long pow(int base, int exponent)
    {
        long result = 1;
        for (int count = 1; count <= exponent; count++)
        {
            result *= base;
        }
        return result;
    }

    /**
     * This method will, with limited accuracy, check to see if the floating
     * point number passed in as an argument can be considered a whole number
     * with minimal loss of precision.
     *
     * @param number
     * @return
     */
    private static boolean isDoubleWhole(double number)
    {
        long numberAsInteger = (long) number;

        double diff = number - numberAsInteger;

        if (diff > .00000001)
        {
            return false;
        }
        else
        {
            return true;


        }
    }
}

class Osmos
{

    long myMote;
    ArrayList<Long> otherMotes = new ArrayList<Long>();
    int changes = 0;
}
