import java.io.*;
import java.util.*;

public class Watersheds {

	private ArrayList<String> input = new ArrayList<String>();
	//private static ArrayList<int[][]> maps = new ArrayList<int[][]>();
	private ArrayList<int[][]> basins = new ArrayList<int[][]>();
	private ArrayList<Square[][]> maps = new ArrayList<Square[][]>();
	private ArrayList<Square> sinks = new ArrayList<Square>();
	
	private enum Direction {
		North,
		West,
		East,
		South

	}
	
	private class Square {
		int x,y,altitude;
		Square drainsTo;
		ArrayList<Square> drainsFrom = new ArrayList<Square>();
		char basin = '0';
		
		public Square(int altitude, int x, int y) {
			this.altitude = altitude;
			this.x = x;
			this.y = y;
		}
	}

	/**
	 * Prints number of words matching each test case for given input file
	 */
	public void printBasins() {
		
		try {
			// Read lines into an array
			String filename = "wsinput.txt";
			File currentDirectory = new File( "." );
			filename = currentDirectory.getCanonicalPath() + "/src/" + filename;
			BufferedReader br = new BufferedReader(new FileReader(filename));
			while (true) {
				String line = br.readLine();
				if (line == null) break;
				input.add(line);
			}
			
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		parseInput();
		for (int i = 0; i < maps.size(); ++i) {
			drainMap(maps.get(i));
			System.out.println("Case #" + (i+1) + ":");
			assignBasins(maps.get(i));
		}
	}

	private void assignBasins(Square[][] map) {
		char ch = 'a';
		for (int i = 0; i < map.length; ++i) {
			for (int j = 0; j < map[0].length; ++j) {
				if ((i == 0 && j == 0 ) || map[i][j].basin == '0') {
					map[i][j].basin = ch;
					drainTo(map[i][j].drainsTo,ch);
					drainUpstream(map[i][j],ch);
					//System.out.println(j + " " + i);
					//System.out.println("old basin: " + ch);
					ch++;
					//System.out.println("new basin: " + ch);
				}
			} 
		}
		for (int i = 0; i < map.length; ++i) {
			String row = "";
			for (int j = 0; j < map[0].length; ++j) {
				row = row + map[i][j].basin;
				if (j < (map[0].length - 1)) row = row + " ";
			}
			System.out.println(row);
		}
	}
	
	private void drainTo(Square sq, char basin) {
		if (sq == null) return;
		sq.basin = basin;
		drainUpstream(sq, basin);
		drainTo(sq.drainsTo,basin);
	}
	
	private void drainUpstream(Square sq, char basin) {
		ArrayList<Square> squares = sq.drainsFrom;
		if (squares.size() == 0) return;
		Iterator<Square> iter = squares.iterator();
		while (iter.hasNext()) {
			Square source = iter.next();
			if (source.basin == '0') {
				source.basin = basin;
				drainUpstream(source,basin);
			}
		}
	}

	private void drainMap(Square[][] map) {
		int height = map.length;
		int width = map[0].length;
		for (int i = 0; i < height; ++i) {
			for (int j = 0; j < width; ++j) {
				int currAlt = map[i][j].altitude;
				int lowestAlt = currAlt;
				Direction lowestDir = null;
				// north
				if (i != 0) {
					if (map[i-1][j].altitude < lowestAlt) {
						lowestAlt = map[i-1][j].altitude; 
						lowestDir = Direction.North;
					}
				}
				// west
				if (j != 0) {
					if (map[i][j-1].altitude < lowestAlt ) {
						lowestAlt = map[i][j-1].altitude; 
						lowestDir = Direction.West;
					}
				}
				// east
				if (j != (width - 1)) {
					if (map[i][j+1].altitude < lowestAlt ) {
						lowestAlt = map[i][j+1].altitude; 
						lowestDir = Direction.East;
					}
				}
				// south
				if (i != (height-1)) {
					if (map[i+1][j].altitude < lowestAlt ) {
						lowestAlt = map[i+1][j].altitude; 
						lowestDir = Direction.South;
					}
				}
				if (lowestDir != null) {
					Square sq = getSquare(map,map[i][j],lowestDir);
					map[i][j].drainsTo = sq;
					sq.drainsFrom.add(map[i][j]);
				//	System.out.println("Square at " + j + " " + i + " drains to " + sq.x + " " + sq.y);
				} else {
					// it is a sink
					sinks.add(map[i][j]);
					map[i][j].drainsTo = null;
					//System.out.println("Square at " +j+ " " +i+ " is a sink.");
				}
			}
		}
	}
	
	
	public Square getSquare(Square[][] map, Square curr, Direction dir) {
		int x = curr.x;
		int y = curr.y;
		if (dir == Direction.North) {
			return map[y-1][x];
		} else if (dir == Direction.West) {
			return map[y][x-1];
		} else if (dir == Direction.East) {
			return map[y][x+1];
		} else if (dir == Direction.South) {
			return map[y+1][x];
		}
		return null;
	}

	private void parseInput() {
		
		int numMaps = Integer.parseInt(input.get(0));
		int lineNo = 0;

		for (int i = 0; i < numMaps; ++i) {
			lineNo++;
			int spaceIndex = input.get(lineNo).indexOf(' ');
			int height = Integer.parseInt(input.get(lineNo).substring(0,spaceIndex));
			int width = Integer.parseInt(input.get(lineNo).substring(spaceIndex+1));
			String[][] mapStrings = new String[height][width];
			Square[][] map = new Square[height][width];
			for (int j = 0; j < height; ++j) {
				lineNo++;
				mapStrings[j] = input.get(lineNo).split(" ");
				
			}
			// convert from string array to int array
			for (int j = 0; j < height; ++j) {
				for (int k = 0; k < mapStrings[j].length; ++k) {
					map[j][k] = new Square(Integer.parseInt(mapStrings[j][k]),k,j);
				}
			}
			maps.add(map);
		}
		
	}
}
