import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.util.*;

public class Bathroom {
    public static void main(String[] args) throws FileNotFoundException {
        TestCase[] testCases;

        String inputFile = "C-small-1-attempt0.in";
        String outputFile = inputFile.replace(".in", ".out");

        try(Scanner sc = new Scanner(new File(inputFile))) {
            testCases = new TestCase[sc.nextInt()];

            for (int i = 0; i < testCases.length; i++) {
                testCases[i] = new TestCase();
                testCases[i].stalls = sc.nextInt();
                testCases[i].peopleCount = sc.nextInt();
            }
        }

        TestCaseResult[] results = new TestCaseResult[testCases.length];

        for (int i = 0; i < testCases.length; i++) {
            results[i] = solve(testCases[i]);
        }

        display(results, outputFile);
    }

    private static TestCaseResult solve(TestCase testCase) {
        int stallCount = testCase.stalls + 2;
        int peopleCount = testCase.peopleCount;

        Stalls stalls = new Stalls(stallCount);

        for (int i = 0; i < peopleCount; i++) {
            int index = stalls.insertPerson();

            if (i == peopleCount - 1) {
                TestCaseResult testCaseResult = new TestCaseResult();
                testCaseResult.max = stalls.computeMax(index);
                testCaseResult.min = stalls.computeMin(index);

                return testCaseResult;
            }
        }

        throw new IllegalStateException();
    }

    private static void display(TestCaseResult[] results, String outputFile) throws FileNotFoundException {
        try(PrintWriter pw = new PrintWriter(new FileOutputStream(outputFile))) {
            for (int i = 0; i < results.length; i++) {
                TestCaseResult result = results[i];
                pw.println("Case #" + (i + 1) + ": " + result.max + " " + result.min);
            }
        }
    }

    private static class TestCase {
        int stalls;
        int peopleCount;
    }

    private static class TestCaseResult {
        int max;
        int min;
    }

    private static class Stalls {
        private final byte[] stallsArray;
        private final Set<Gap> gaps;

        public Stalls(int stallCount) {
            this.stallsArray = new byte[stallCount];
            this.stallsArray[0] = 1;
            this.stallsArray[stallCount - 1] = 1;
            this.gaps = new HashSet<>();
            this.gaps.add(new Gap(1, stallCount - 2));
        }

        public int insertPerson() {
            Gap gap = gaps.stream().sorted(Comparator.comparing(Gap::size, Comparator.reverseOrder()).thenComparing(Gap::getFirst)).findFirst().get();

            int index = gap.first + (gap.last - gap.first) / 2;
            stallsArray[index] = 1;

            gaps.remove(gap);

            Gap gapBefore = new Gap(gap.first, index - 1);
            Gap gapAfter = new Gap(index + 1, gap.last);

            if (gapBefore.isValid()) {
                gaps.add(gapBefore);
            }

            if (gapAfter.isValid()) {
                gaps.add(gapAfter);
            }

            return index;
        }

        public int computeMin(int index) {
            int ls = computeLs(index);
            int rs = computeRs(index);

            return Math.min(ls, rs);
        }

        public int computeMax(int index) {
            int ls = computeLs(index);
            int rs = computeRs(index);

            return Math.max(ls, rs);
        }

        private int computeLs(int index) {
            int count = 0;
            int start = index - 1;
            while (stallsArray[start] == 0) {
                count++;
                start--;
            }
            return count;
        }

        private int computeRs(int index) {
            int count = 0;
            int start = index + 1;
            while (stallsArray[start] == 0) {
                count++;
                start++;
            }
            return count;
        }
    }

    private static class Gap {
        private final int first;
        private final int last;

        public Gap(int first, int last) {
            this.first = first;
            this.last = last;
        }

        public int getFirst() {
            return first;
        }

        public int size() {
            return last - first;
        }

        public boolean isValid() {
            return first <= last;
        }
    }
}

