import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.atomic.DoubleAccumulator;

public class Problem {

    public static void main(String[] args) throws FileNotFoundException {
        TestCase[] testCases;

        String inputFile = "A-small-attempt0.in";
        String outputFile = inputFile.replace(".in", ".out");

        try (Scanner sc = new Scanner(new File(inputFile))) {
            testCases = new TestCase[sc.nextInt()];

            for (int i = 0; i < testCases.length; i++) {
                testCases[i] = parseTestCase(sc);
            }
        }

        TestCaseResult[] results = new TestCaseResult[testCases.length];

        for (int i = 0; i < testCases.length; i++) {
            System.out.println("Solving case #" + (i+1));
            results[i] = solve(testCases[i]);
        }

        try (PrintWriter pw = new PrintWriter(new FileOutputStream(outputFile))) {
            for (int i = 0; i < results.length; i++) {
                TestCaseResult result = results[i];
                pw.println("Case #" + (i + 1) + ": " + result.toOutput());
            }
        }
    }

    private static TestCase parseTestCase(Scanner sc) {

        int km = sc.nextInt();
        int count = sc.nextInt();

        List<Opponent> opponentList = new ArrayList<>();

        for (int i = 0; i < count; i++) {
            int pos = sc.nextInt();
            int speed = sc.nextInt();

            opponentList.add(new Opponent(pos, speed));
        }

        return new TestCase(km, opponentList);
    }

    private static TestCaseResult solve(TestCase testCase) {
        DoubleAccumulator da = new DoubleAccumulator(Double::max, -1);

        for (Opponent opponent : testCase.opponentList) {
            da.accumulate((testCase.km - opponent.pos) / (double) opponent.speed );
        }

        double maxTime = da.get();

        return new TestCaseResult(testCase.km / maxTime);
    }

    private static class TestCase {

        final int km;
        final List<Opponent> opponentList;

        public TestCase(int km, List<Opponent> opponentList) {
            this.km = km;
            this.opponentList = opponentList;
        }
    }

    private static class TestCaseResult {
        private final double result;

        public TestCaseResult(double result) {
            this.result = result;
        }

        public String toOutput() {
            DecimalFormat df = new DecimalFormat("0.000000");

            StringBuilder out = new StringBuilder();
            out.append(df.format(result));
            return out.toString();
        }
    }

    private static class Opponent {

        final int pos;
        final int speed;

        public Opponent(int pos, int speed) {
            this.pos = pos;
            this.speed = speed;
        }
    }

}

