
import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Comparator;

public class AmpleSyrup {
		private BufferedReader br;
		private PrintWriter writer;

		public AmpleSyrup(String pathToReadFile, String pathToWriteFile) {
			openReadFile(pathToReadFile);
			openWriteFile(pathToWriteFile);
		}
		
		private void openReadFile(String path) {
			try {
				br = new BufferedReader(new FileReader(path));
			} catch (FileNotFoundException e) {
				System.err.println("Can't read the input.");
			}
		}
		
		private String [] getInput() {
			String[] inputs = null;
			try {
				inputs = br.readLine().split(" ");
			} catch (IOException e) {
				System.err.println("Can't read lines.");
			}
			return inputs;
		}
		
		private void openWriteFile(String path) {
			try{
			    writer = new PrintWriter(path, "UTF-8");
			} catch (IOException e) {
				System.err.println("Can't open write file.");
			}
		}
		
		private void writeFile(String str) {
			writer.println(str);
		}
		
		private void closeAllFiles() {
			writer.close();
			try {
				br.close();
			} catch (IOException e) {
				System.err.println("Can't close files.");
			}
		}
		
		private void work() {
			int T;
			T = Integer.parseInt(getInput()[0]);
			for(int q = 0; q < T; ++q) {
				String[] inputs = getInput();
				int N = Integer.parseInt(inputs[0]);
				int K = Integer.parseInt(inputs[1]);
				
				double[][] table = new double[N+1][K+1];
				int[][] radius = new int[N+1][K+1];
				
				info[] data = new info[N];
				for(int a = 0; a < N; ++a) {
					inputs = getInput();
					int R = Integer.parseInt(inputs[0]);
					int H = Integer.parseInt(inputs[1]);
					data[a] = new info();
					data[a].R = R;
					data[a].H = H;
				}
				
				Arrays.sort(data, aComparator);
//				System.out.println(Arrays.toString(data));

				for(int a = 1; a <= N; ++a) {
					int R = data[a-1].R;
					int H = data[a-1].H;
					
					double additionH = 2.0 * R * H;
					for(int b = 1; b <= K; ++b) {
						table[a][b] = table[a-1][b];
						radius[a][b] = radius[a-1][b];

						double additionR = getArea(R, radius[a-1][b-1]);
						if(table[a][b] < additionR + additionH + table[a-1][b-1]) {
							table[a][b] = additionR + additionH + table[a-1][b-1];
							radius[a][b] = getMax(R, radius[a-1][b-1]);
						}
						else if(table[a][b] == additionR + additionH + table[a-1][b-1]) {
							radius[a][b] = getMin(radius[a][b], getMax(R, radius[a-1][b-1]));
						}
//						System.out.println("-------------------------");
//						System.out.println(R);System.out.println(H);
//						System.out.println(additionH);
//						System.out.println(additionR);
//						System.out.println(table[a][b]);
					}
				}
				double answer = table[N][K] * Math.PI;
				
				writeFile("Case #"+(q+1)+": "+answer);
			}
			
			closeAllFiles();
		}
		
		private int getMin(int r, int i) {
			if(r <= i) return r;
			return i;
		}

		private int getMax(int r, int i) {
			if(r >= i) return r;
			return i;
		}

		private double getArea(int r, int i) {
			if(r > i) {
				return 1.0 * r*r - 1.0 *i*i;
			}
			return 0.0;
		}

		public static void main(String[] args) {
//			String inputPath = "input.in";
			String inputPath = "A-large (1).in";
			AmpleSyrup p = new AmpleSyrup(inputPath, "a_output.txt");
			p.work();
		}
		
		private class info {
			int R;
			int H;
		}

		public static Comparator<info> aComparator
	                          = new Comparator<info>() {

		    public int compare(info j, info i) {
		    	if(j.R == i.R) {
					return - j.H + i.H;
				}

				return - j.R + i.R;
		    }

		};
	}
