/**
 * @author chang
 * created on 11/04/15
 */

import java.util.*;
import java.io.*;

public class Pancakes {
    public static void main(String[] args) throws IOException {
        new PancakesSolver();
    }
}

class PancakesSolver {

    BufferedReader br;
    PrintWriter out;
    StringTokenizer st;
    boolean eof;

    int[][] dp; // dp[i][k], i = no of pancakes, k = allowed steps excluding chef special move
    boolean[][] valid; // to check whether it can be done or not
    int size;

    void compute(){
        size = 1001;
        dp = new int[size][size];
        valid = new boolean[size][size];

        dp[1][1] = 0;
        valid[1][1] = true;
        for(int i = 2; i < size; ++i){
            dp[1][i] = dp[2][i] = 0;
            valid[1][i] = valid[2][i] = true;
        }

        for(int i = 3; i < size; ++i){
            for(int k = 2; k < size; ++k){
                if (valid[i-1][k-1]){
                    valid[i][k] = true;
                    dp[i][k] = dp[i-1][k-1];
                }

                for(int v1 = i-1; v1 > 0; --v1) {
                    int v2 = i-v1;
                    if (valid[v1][k] && valid[v2][k]) {
                        int res = dp[v1][k] + dp[v2][k] + 1;
                        if (valid[i][k])
                            dp[i][k] = Math.min(dp[i][k], res);
                        else
                            dp[i][k] = res;
                        valid[i][k] = true;
                    }
                }
            }
        }
    }

    void solve(int ts) throws IOException {
        int n = nextInt();
        int[] cakes = new int[n];

        for(int i = 0; i < n; ++i)
            cakes[i] = nextInt();

        int ans = 1000000;
        for(int i = 1; i < size; ++i){
            int count = 0;
            boolean flag = true;
            for(int k = 0; k < n; ++k){
                int num = cakes[k];
                if (!valid[num][i]){
                    flag = false;
                    break;
                }
                count += dp[num][i];
            }

            if (flag)
                ans = Math.min(count+i,ans);
        }

        out.println("Case #"+ts+": "+ans);
    }

    PancakesSolver() throws IOException {
        br = new BufferedReader(new FileReader("../../Downloads/B-large.in"));
        out = new PrintWriter(new FileWriter("PancakesOutput.txt"));
        //br = new BufferedReader(new InputStreamReader(System.in));
        //out = new PrintWriter(System.out);
        Thread t = new Thread(null, () -> {
            try {
                int ts = 1;
                ts = nextInt();

                compute();
                for(int i = 1; i <= ts; ++i){
                    solve(i);
                }
            } catch (Exception e) {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
        }, "a", 1 << 24);
        t.start();
        try {
            t.join();
        } catch (InterruptedException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        out.close();
    }

    String nextToken() {
        while (st == null || !st.hasMoreTokens()) {
            try {
                st = new StringTokenizer(br.readLine());
            } catch (Exception e) {
                eof = true;
                return null;
            }
        }
        return st.nextToken();
    }

    String nextString() {
        try {
            return br.readLine();
        } catch (IOException e) {
            eof = true;
            return null;
        }
    }

    int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }
}