import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Arrays;

import org.jgrapht.alg.flow.PushRelabelMFImpl;
import org.jgrapht.graph.DefaultWeightedEdge;
import org.jgrapht.graph.SimpleDirectedWeightedGraph;

public class Bsmall {
	
	static int[] splitToInts(String s) {
		return Arrays.stream(s.split("\\s")).mapToInt(Integer::parseInt).toArray();
	}
	
	static long[] splitToLongs(String s) {
		return Arrays.stream(s.split("\\s")).mapToLong(Long::parseLong).toArray();
	}
	
	static class Ingre {
		int r;
		int amount;
		int min;
		int max;
		
		public Ingre(int r, int amount) {
			this.r = r;
			this.amount = amount;
			max = (int)(amount/(r*0.9));
			if(1.0*amount/max >  r*1.1) {
				max -= 1;
			}
			min = (int)(amount/(r*1.1));
			if(1.0*amount/min > r*1.1) {
				min += 1;
			}
			if(max < min) {
				min = max = 0;
			}
		}
	}
	
	static double solve(int N, int[] R, int[][] ps) {
		SimpleDirectedWeightedGraph<Ingre, DefaultWeightedEdge> g = new SimpleDirectedWeightedGraph<>(DefaultWeightedEdge.class);
		Ingre[][] ingre = new Ingre[N][ps[0].length];
		for(int i=0; i<N; i++) {
			for(int j=0; j<ps[0].length; j++) {
				ingre[i][j] = new Ingre(R[i], ps[i][j]);
			}
		}
		Ingre src = new Ingre(1,1);
		Ingre dest = new Ingre(1,1);
		g.addVertex(src);
		g.addVertex(dest);
		for(int j=0; j<ingre[0].length; j++) {
			Ingre in = ingre[0][j];
			if(in.max == 0) continue;
			g.addVertex(in);
			DefaultWeightedEdge edge = g.addEdge(src, in);
			g.setEdgeWeight(edge, 1.0);
		}
		for(int i=1; i<N; i++) {
			for(int j=0; j<ingre[i].length; j++) {
				Ingre to = ingre[i][j];
				if(to.max == 0) continue;
				g.addVertex(to);
				for(int k=0; k<ingre[i-1].length; k++) {
					Ingre from = ingre[i-1][k];
					if(from.max == 0) continue;
					if(!(from.max < to.min || to.max < from.min)) {
						DefaultWeightedEdge edge = g.addEdge(from, to);
						g.setEdgeWeight(edge, 1.0);
					}
				}
			}
		}
		for(int j=0; j<ingre[0].length; j++) {
			Ingre in = ingre[N-1][j];
			if(in.max == 0) continue;
			g.addVertex(in);
			DefaultWeightedEdge edge = g.addEdge(in, dest);
			g.setEdgeWeight(edge, 1.0);
		}
		
		PushRelabelMFImpl flow = new PushRelabelMFImpl(g);
		double ret = flow.calculateMaximumFlow(src, dest);
		System.out.println(ret);
		return ret;
	}

	public static void main(String[] args) throws IOException{
		Ingre a = new Ingre(100, 10000);
		System.out.println(a.min+" "+a.max);
		
		BufferedReader input = new BufferedReader(new FileReader(args[0]));
		FileWriter output = new FileWriter(args[0].substring(0, args[0].length()-2)+"out");
		final int tn = Integer.parseInt(input.readLine());
		
		for(int t=1; t<= tn; t++) {
			int[] tmp = splitToInts(input.readLine());
			int N = tmp[0];
			int P = tmp[1];
			int[] R = splitToInts(input.readLine());
			int[][] ps = new int[N][];
			for(int i=0; i<N; i++) {
				ps[i] = splitToInts(input.readLine());
			}
			Integer ret = (int)solve(N, R, ps);
			System.out.println(String.format("Case #%d: %s", t, ret.toString()));
			output.write(String.format("Case #%d: %s\n", t, ret.toString()));
		}
		
		input.close();
		output.close();
	}

}
