package round1c.a;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.Scanner;

/**
 * Square Tiles
 * Problem
You are selling beautiful geometric pictures. Each one consists of 1x1 square tiles arranged into a non-overlapping grid. For example:
    .##..
    .####
    .####
    .##..
Blue tiles are represented by '#' characters, and white tiles are represented by '.' characters. You do not use other colors.
Not everybody likes blue though, and some customers want you to replace all the blue tiles in your picture with red tiles. Unfortunately, red tiles only come in the larger 2x2 size, which makes this tricky.

You can cover any 2x2 square of blue tiles with a single red tile, and then repeat until finished. A red tile cannot overlap another red tile, it cannot cover white tiles, and it cannot go outside the picture. For example, you could add red tiles to the previous picture as follows:

    ./\..
    .\//\
    ./\\/
    .\/..
Each red tile is represented here by a pair of '/' characters in the top-left and bottom-right corners, and a pair of '\' characters in the other two corners.
Given a blue and white picture, can you transform it into a red and white picture in this way?

Input
The first line of the input gives the number of test cases, T. T test cases follow.
Each test case begins with a line containing R and C, the number of rows and columns in a picture. The next R lines each contain exactly C characters, describing the picture. As above, '#' characters represent blue tiles, and '.' characters represent white tiles.

Output
For each test case, first output one line containing "Case #x:" where x is the case number (starting from 1).
If it is possible to cover the blue tiles with non-overlapping red tiles, output R lines each containing C characters, describing the resulting red and white picture. As above, red tiles should be represented by '/' and '\' characters, while white tiles are represented by '.' characters. If multiple solutions are possible, you may output any of them.
If the task is impossible, output a single line containing the text "Impossible" instead.

Limits
Small dataset
1 ≤ T ≤ 20.
1 ≤ R ≤ 6.
1 ≤ C ≤ 6.

Large dataset
1 ≤ T ≤ 50.
1 ≤ R ≤ 50.
1 ≤ C ≤ 50.

Sample
Input 
3
2 3
###
###
1 1
.
4 5
.##..
.####
.####
.##..	 
Output 
Case #1:
Impossible
Case #2:
.
Case #3:
./\..
.\//\
./\\/
.\/.. 

 * 2011.05.22. 12:07 - 12:25
 * @author Chei
 */
public class SquareTiles {
	Scanner scanner;

	public static void main(String[] args) throws FileNotFoundException {
		new SquareTiles().solve();
	}
	
	void solve() throws FileNotFoundException {
		scanner = new Scanner(new File("resources/round1c/A-large.in"));
		int numberOfTestCases = scanner.nextInt();
		for (int testCaseIndex = 1; testCaseIndex <= numberOfTestCases; testCaseIndex++) {
			char[][] result = solveTestCase();
			System.out.format("Case #%d:%n", testCaseIndex);
			if (result == null) {
				System.out.println("Impossible");
			} else {
				for (char[] row: result) {
					for (char tile: row) {
						System.out.print(tile);
					}
					System.out.println();
				}
			}
		}
	}

	char[][] solveTestCase() {
		int rows = scanner.nextInt();
		int columns = scanner.nextInt();
		
		char[][] tiles = new char[rows][];
		for (int row = 0; row < rows; row++) {
			String rowString = scanner.next();
			tiles[row] = rowString.toCharArray();
		}
		
		for (int row = 0; row < rows; row++) {
			for (int column = 0; column < columns; column++) {
				if (tiles[row][column] == '#') {
					tiles[row][column] = '/';
					if (column + 1 < columns && tiles[row][column + 1] == '#') {
						tiles[row][column + 1] = '\\';
					} else {
						return null;
					}
					if (row + 1 < rows && tiles[row + 1][column] == '#') {
						tiles[row + 1][column] = '\\';
					} else {
						return null;
					}
					if (row + 1 < rows && column + 1 < columns && tiles[row + 1][column + 1] == '#') {
						tiles[row + 1][column + 1] = '/';
					} else {
						return null;
					}
				}
			}
		}
		return tiles;
	}
}
