package qualification.a;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.AbstractMap;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Scanner;

/**
 *
Problem

Blue and Orange are friendly robots. An evil computer mastermind has locked them up in separate hallways to test them, and then possibly give them cake.
Each hallway contains 100 buttons labeled with the positive integers {1, 2, ..., 100}. Button k is always k meters from the start of the hallway, and the robots both begin at button 1. Over the period of one second, a robot can walk one meter in either direction, or it can press the button at its position once, or it can stay at its position and not press the button. To complete the test, the robots need to push a certain sequence of buttons in a certain order. Both robots know the full sequence in advance. How fast can they complete it?
For example, let's consider the following button sequence:
   O 2, B 1, B 2, O 4
Here, O 2 means button 2 in Orange's hallway, B 1 means button 1 in Blue's hallway, and so on. The robots can push this sequence of buttons in 6 seconds using the strategy shown below:

Time | Orange           | Blue
-----+------------------+-----------------
  1  | Move to button 2 | Stay at button 1
  2  | Push button 2    | Stay at button 1
  3  | Move to button 3 | Push button 1
  4  | Move to button 4 | Move to button 2
  5  | Stay at button 4 | Push button 2
  6  | Push button 4    | Stay at button 2
Note that Blue has to wait until Orange has completely finished pushing O 2 before it can start pushing B 1.

Input
The first line of the input gives the number of test cases, T. T test cases follow.
Each test case consists of a single line beginning with a positive integer N, representing the number of buttons that need to be pressed. This is followed by N terms of the form "Ri Pi" where Ri is a robot color (always 'O' or 'B'), and Pi is a button position.

Output
For each test case, output one line containing "Case #x: y", where x is the case number (starting from 1) and y is the minimum number of seconds required for the robots to push the given buttons, in order.

Limits
1 ≤ Pi ≤ 100 for all i.

Small dataset
1 ≤ T ≤ 20.
1 ≤ N ≤ 10.

Large dataset
1 ≤ T ≤ 100.
1 ≤ N ≤ 100.

Sample

Input 
3
4 O 2 B 1 B 2 O 4
3 O 5 O 8 B 100
2 B 2 B 1
Output 
Case #1: 6
Case #2: 100
Case #3: 4
 * 
 * 2011.05.07. 7:45 - 9:43
 * @author Chei
 */
public class BotTrust {
	Scanner scanner;
	
	
	public static void main(String[] args) throws FileNotFoundException {
		new BotTrust().solve();
	}


	void solve() throws FileNotFoundException {
		scanner = new Scanner(new File("resources/A-small-attempt0.in"));
		int numberOfTestCases = scanner.nextInt();
		for (int testCaseIndex = 1; testCaseIndex <= numberOfTestCases; testCaseIndex++) {
			int result = solveTestCase();
			System.out.format("Case #%d: %d%n", testCaseIndex, result);
		}
	}

	int solveTestCase() {
		List<Map.Entry<Bot, Integer>> commands = readCommands();
		//System.out.println(commands);
		
		int steps = 0;
		Map<Bot, Integer> botPositions = new HashMap<Bot, Integer>();
		for (Bot bot: Bot.values()) {
			botPositions.put(bot, 1);
		}

		for (; commands.size() > 0; steps++) {
			Bot nextBotToPush = commands.get(0).getKey();
			boolean someonePushedAButton = false;
			// calculate next step of bots
			for (Bot bot: Bot.values()) {
				int nextButton = nextButtonForBot(commands, bot);
				int currentPosition = botPositions.get(bot);
				// System.out.format("%s %d -> %d%n", bot, currentPosition, nextButton);
				if (currentPosition < nextButton) {
					// move forward
					botPositions.put(bot, currentPosition + 1);
				} else if (currentPosition > nextButton) {
					// move backward
					botPositions.put(bot, currentPosition - 1);
				} else if (bot == nextBotToPush) {
					//push button
					someonePushedAButton = true;
				} // else stay at button
			}
			if (someonePushedAButton) {
				commands.remove(0);
			}
			
		}
		return steps;
	}

	int nextButtonForBot(List<Map.Entry<Bot, Integer>> remainingCommands, Bot bot) {
		for(Map.Entry<Bot, Integer> command: remainingCommands) {
			if (command.getKey() == bot) {
				return command.getValue();
			}
		}
		// no more buttons for this bot
		return 0;
	}

	List<Entry<Bot, Integer>> readCommands() {
		int numberOfCommands = scanner.nextInt();
		List<Map.Entry<Bot, Integer>> commands = new ArrayList<Map.Entry<Bot,Integer>>();
		for (int commandIndex = 0; commandIndex < numberOfCommands; commandIndex++) {
			Bot bot = Bot.valueOf(scanner.next());
			int button = scanner.nextInt();
			Map.Entry<Bot, Integer> command = new AbstractMap.SimpleImmutableEntry<Bot, Integer>(bot, button);
			commands.add(command);
		}
		return commands;
	}
}

enum Bot {
	O,
	B;
}