package qualification.b;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

/**
 * Problem B. Magicka

Magicka™ is an action-adventure game developed by Arrowhead Game Studios. In Magicka you play a wizard, invoking and combining elements to create Magicks. This problem has a similar idea, but it does not assume that you have played Magicka.
Note: "invoke" means "call on." For this problem, it is a technical term and you don't need to know its normal English meaning.

Problem
As a wizard, you can invoke eight elements, which are the "base" elements. Each base element is a single character from {Q, W, E, R, A, S, D, F}. When you invoke an element, it gets appended to your element list. For example: if you invoke W and then invoke A, (we'll call that "invoking WA" for short) then your element list will be [W, A].
We will specify pairs of base elements that combine to form non-base elements (the other 18 capital letters). For example, Q and F might combine to form T. If the two elements from a pair appear at the end of the element list, then both elements of the pair will be immediately removed, and they will be replaced by the element they form. In the example above, if the element list looks like [A, Q, F] or [A, F, Q] at any point, it will become [A, T].
We will specify pairs of base elements that are opposed to each other. After you invoke an element, if it isn't immediately combined to form another element, and it is opposed to something in your element list, then your element list will be cleared.
For example, suppose Q and F combine to make T. R and F are opposed to each other. Then invoking the following things (in order, from left to right) will have the following results:
QF → [T] (Q and F combine to form T)
QEF → [Q, E, F] (Q and F can't combine because they were never at the end of the element list together)
RFE → [E] (F and R are opposed, so the list is cleared; then E is invoked)
REF → [] (F and R are opposed, so the list is cleared)
RQF → [R, T] (QF combine to make T, so the list is not cleared)
RFQ → [Q] (F and R are opposed, so the list is cleared)
Given a list of elements to invoke, what will be in the element list when you're done?

Input
The first line of the input gives the number of test cases, T. T test cases follow. Each test case consists of a single line, containing the following space-separated elements in order:
First an integer C, followed by C strings, each containing three characters: two base elements followed by a non-base element. This indicates that the two base elements combine to form the non-base element. Next will come an integer D, followed by D strings, each containing two characters: two base elements that are opposed to each other. Finally there will be an integer N, followed by a single string containing N characters: the series of base elements you are to invoke. You will invoke them in the order they appear in the string (leftmost character first, and so on).

Output
For each test case, output one line containing "Case #x: y", where x is the case number (starting from 1) and y is a list in the format "[e0, e1, ...]" where ei is the ith element of the final element list. Please see the sample output for examples.

Limits
1 ≤ T ≤ 100.
Each pair of base elements may only appear together in one combination, though they may appear in a combination and also be opposed to each other.
No base element may be opposed to itself.
Unlike in the computer game Magicka, there is no limit to the length of the element list.

Small dataset
0 ≤ C ≤ 1.
0 ≤ D ≤ 1.
1 ≤ N ≤ 10.

Large dataset
0 ≤ C ≤ 36.
0 ≤ D ≤ 28.
1 ≤ N ≤ 100.

Sample
Input 
5
0 0 2 EA
1 QRI 0 4 RRQR
1 QFT 1 QF 7 FAQFDFQ
1 EEZ 1 QE 7 QEEEERA
0 1 QW 2 QW

Output 
Case #1: [E, A]
Case #2: [R, I, R]
Case #3: [F, D, T]
Case #4: [Z, E, R, A]
Case #5: []

Magicka™ is a trademark of Paradox Interactive AB. Paradox Interactive AB does not endorse and has no involvement with Google Code Jam.

 * 2011.05.07. 10:07 - 11:40
 * @author Chei
 */
public class Magicka {
	Scanner scanner;
	
	public static void main(String[] args) throws FileNotFoundException {
		new Magicka().solve();
	}

	void solve() throws FileNotFoundException {
		scanner = new Scanner(new File("resources/B-small-attempt0.in"));
		int numberOfTestCases = scanner.nextInt();
		for (int testCaseIndex = 1; testCaseIndex <= numberOfTestCases; testCaseIndex++) {
			List<Character> result = solveTestCase();
			System.out.format("Case #%d: %s%n", testCaseIndex, result.toString());
		}
	}

	List<Character> solveTestCase() {
		char[][] combiners = readElementList(); 
		char[][] opposers = readElementList();
		int elementCount = scanner.nextInt();
		List<Character> elements = new ArrayList<Character>();
		char[] elementArray = scanner.next().toCharArray();
		for (char c : elementArray) {
			elements.add(c);
		}
		
		List<Character> result = new ArrayList<Character>();
		// insert first element
		for (int i = 0; i < elementCount; i++) {
			// put new element in list
			Character nextElement = elements.get(i);
			if (!result.isEmpty()) {
				Character lastElement = result.get(result.size() - 1);
				// check for combination
				Character combinedElement = combine(lastElement, nextElement, combiners); 
				if (combinedElement != null) {
					// overwrite last element with newly combined element
					result.set(result.size() - 1, combinedElement);
				} else if (opposed(result, nextElement, opposers)) {
					result.clear();
				} else {
					result.add(nextElement);
				}
			} else {
				// no element in list yet, insert at first position
				result.add(nextElement);
			}
		}
		return result;
	}
	
	Character combine(Character e1, Character e2, char[][] combiners) {
		for (char[] combinerPair : combiners) {
			if ((e1.equals(combinerPair[0]) && e2.equals(combinerPair[1])) ||
					(e1.equals(combinerPair[1]) && e2.equals(combinerPair[0]))) {
				return combinerPair[2];
			}
		}
		return null;
	}

	boolean opposed(List<Character> elements, Character e, char[][] opposers) {
		for (char[] opposedPair : opposers) {
			if ((elements.contains(opposedPair[0]) && e.equals(opposedPair[1])) ||
					(elements.contains(opposedPair[1]) && e.equals(opposedPair[0]))) {
				return true;
			}
		}
		return false;
	}

	char[][] readElementList() {
		int numberOfElementLists = scanner.nextInt();
		char[][] elements = new char[numberOfElementLists][];
		for (int elementIndex = 0; elementIndex < numberOfElementLists; elementIndex++) {
			elements[elementIndex] = scanner.next().toCharArray();
		}
		return elements;
	}
}
