package org.ater.cheilman.puzzles.codejam.cj2016;

import lombok.Data;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import sun.util.PreHashedMap;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.math.BigInteger;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.IntStream;

/**
 * Code Jam 2016, Problem B
 */
@RequiredArgsConstructor
public class CJ2016ProblemB {
    // Initial number
    private final String initialPancakes;
    private final Set<String> visited = new HashSet<>();

    @Data
    private class Node {
        private final String cakes;
        private final int level;
    }

    /**
     * Execute the test and return the printed output.
     */
    public String run() {
        return Integer.toString(solve(initialPancakes));
    }

    private int solve(final String pancakes) {
        // Do a breadth-first search
        final Queue<Node> working = new ArrayDeque<>();
        working.add(new Node(pancakes, 0));

        while (!working.isEmpty()) {
            final Node cur = working.poll();
            final String curCakes = cur.getCakes();

            final Optional<Integer> degenerateCase = isDegenerateCase(curCakes);

            if (degenerateCase.isPresent()) {
                return degenerateCase.get() + cur.getLevel();
            }

            // string contains both
            if (curCakes.charAt(curCakes.length() - 1) == '+') {
                // Ignore ones already happy
                final int lastMinus = curCakes.lastIndexOf('-');
                final String subCakes = curCakes.substring(0, lastMinus + 1);

                // Put new list on at same level
                working.add(new Node(subCakes, cur.getLevel()));
            } else {
                final List<String> nextLevel = generateNextLevel(curCakes);

                nextLevel.forEach(s -> working.add(new Node(s, cur.getLevel() + 1)));
            }
        }

        throw new RuntimeException("blah");
    }

    private String flipAt(final String pancackes, final int flipIndex) {
        final char[] flipped = new char[pancackes.length()];

        for (int i = flipIndex - 1; i >= 0; i--) {
            final int newIndex = (flipIndex - 1) - i;

            if (pancackes.charAt(i) == '+') {
                flipped[newIndex] = '-';
            } else {
                flipped[newIndex] = '+';
            }
        }

        for (int i = flipIndex; i < pancackes.length(); i++) {
            flipped[i] = pancackes.charAt(i);
        }

        return new String(flipped);
    }

    private List<String> generateNextLevel(final String pancakes) {
        final List<String> results = IntStream.range(1, pancakes.length())
                .mapToObj(operand -> flipAt(pancakes, operand))
                .filter(value -> !visited.contains(value))
                .collect(Collectors.toList());
        visited.addAll(results);
        return results;
    }

    private Optional<Integer> isDegenerateCase(final String pancakes) {
        boolean foundPlus = false;
        boolean foundMinus = false;

        for (final char c : pancakes.toCharArray()) {
            if (c == '+') {
                foundPlus = true;
            } else {
                foundMinus = true;
            }
        }

        if (foundPlus && !foundMinus) {
            // all plusses, we're done
            return Optional.of(0);
        } else if (foundMinus && !foundPlus) {
            // all minuses, flip once
            return Optional.of(1);
        } else if ((!foundMinus) && (!foundPlus)) {
            // empty string
            return Optional.of(0);
        }

        return Optional.empty();
    }

    @SneakyThrows
    public static void main(String[] args) {

        final String inputFile = args[0];
        final String outputFile;

        if (inputFile.contains(".in")) {
            outputFile = inputFile.replace(".in", ".out");
        } else {
            outputFile = args[0] + ".out";
        }

        try (final BufferedWriter writer = new BufferedWriter(new FileWriter(outputFile, false))) {
            // Read from the file
            int i = 0;
            try (final BufferedReader reader = new BufferedReader(new FileReader(inputFile))) {
                String line = reader.readLine();

                if ((line == null) || (line.trim().isEmpty())) {
                    return;
                }

                final BigInteger t = new BigInteger(line.trim());

                System.out.println(t + " cases");

                for (line = reader.readLine(); line != null; line = reader.readLine()) {
                    final String cleanLine = line.trim();

                    if (cleanLine.isEmpty()) {
                        continue;
                    }

                    i++;

                    final String result = new CJ2016ProblemB(cleanLine).run();

                    final String output = String.format("Case #%d: %s", i, result);

                    System.out.println(output);
                    writer.write(output);
                    writer.newLine();
                }
            }
        }
    }
}
