package org.ater.cheilman.puzzles.codejam.cj2016;

import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/**
 * Code Jam 2016, Problem A.
 */
@RequiredArgsConstructor
public class CJ2016ProblemA {
    // Initial number
    private final BigInteger n;
    private final Set<Character> digitSet = new HashSet<>(10);

    /**
     * Execute the test and return the printed output.
     */
    public String run() {

        if (n.equals(BigInteger.ZERO)) {
            return "INSOMNIA";
        }

        BigInteger cur = n;
        int i = 1000000;

        do {
//            System.out.println(cur);

            if (addDigitsToSetAndCheck(cur)) {
                return cur.toString();
            }

            cur = cur.add(n);
            i++;
        } while (i > 0);

        return "POSSIBLE?";
    }

    private boolean addDigitsToSetAndCheck(@NonNull final BigInteger num) {
        // who cares about digits, use characters
        for (final char c : num.toString().toCharArray()) {
            digitSet.add(c);
        }

        return digitSet.size() == 10;
    }

    @SneakyThrows
    public static void main(String[] args) {

        final String inputFile = args[0];
        final String outputFile;

        if (inputFile.contains(".in")) {
            outputFile = inputFile.replace(".in", ".out");
        } else {
            outputFile = args[0] + ".out";
        }

        try (final BufferedWriter writer = new BufferedWriter(new FileWriter(outputFile, false))) {
            // Read from the file
            int i = 0;
            try (final BufferedReader reader = new BufferedReader(new FileReader(inputFile))) {
                String line = reader.readLine();

                if ((line == null) || (line.trim().isEmpty())) {
                    return;
                }

                final BigInteger t = new BigInteger(line.trim());

                System.out.println(t + " cases");

                for (line = reader.readLine(); line != null; line = reader.readLine()) {
                    final String cleanLine = line.trim();

                    if (cleanLine.isEmpty()) {
                        continue;
                    }

                    i++;

                    final BigInteger n = new BigInteger(cleanLine);

                    final String result = new CJ2016ProblemA(n).run();

                    final String output = String.format("Case #%d: %s", i, result);

                    System.out.println(output);
                    writer.write(output);
                    writer.newLine();
                }
            }
        }
    }
}
