package org.ater.cheilman.puzzles.codejam.cj2016;

import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.math.BigInteger;
import java.util.*;

/**
 * Code Jam 2016, Problem C.
 */
@RequiredArgsConstructor
public class CJ2016ProblemC {
    // Initial number
    private final int n;
    private final int j;

    private final SortedSet<Integer> primes = buildPrimeSet((int) Math.pow(10, 8));

    private SortedSet<Integer> buildPrimeSet(final int max) {
        final SortedSet<Integer> retval = new TreeSet<>();

        final boolean[] primes = new boolean[max];

        for (int i = 0; i < max; i++) {
            primes[i] = (i % 2) != 0;
        }

        primes[0] = false;
        primes[1] = false;
        primes[2] = true;
        primes[3] = true;

        retval.add(2);

        for (int i = 3; i < max; i++) {
            // Find first prime
            if (primes[i]) {
                retval.add(i);

                for (int j = i * 2; j < max; j += i) {
                    primes[j] = false;
                }
            }
        }

//        retval.forEach(System.out::println);

        return retval;
    }

    /**
     * Execute the test and return the printed output.
     */
    private String run() {
        final Map<String, List<Integer>> jamcoins = new HashMap<>();    // coins to their proofs

        long num = 0;

        while (true) {
            if (jamcoins.size() > j) {
                break;
            }

            final String candidate = generateCandidate(num);

            if (candidate.length() > n) {
                break;
            }

            // Check candidate
            final Optional<List<Integer>> proofs = proveCandidate(candidate);

            if (proofs.isPresent()) {
                System.out.println("Found '" + candidate + "', proof: '" +
                        proofs.get().stream().map(Object::toString).reduce((s, s2) -> s + " " + s2) +
                        "'");
                jamcoins.put(candidate, proofs.get());
            }

            num++;
        }

        final StringBuilder builder = new StringBuilder();

        jamcoins.forEach((s, integers) -> {
            builder.append(s);
            builder.append(" ");

            integers.forEach(integer -> {
                builder.append(integer);
                builder.append(" ");
            });

            builder.append("\n");
        });

        return builder.toString();
    }

    private Optional<List<Integer>> proveCandidate(final String candidate) {
        final List<Integer> proofs = new ArrayList<>(10);

        // Interpret in different bases
        for (int base = 2; base <= 10; base++) {
            final long value = Long.parseLong(candidate, base);

            if (primes.contains((int) value)) {
                // Failure
                return Optional.empty();
            }

            // Generate proof
            final Optional<Integer> proof = primes.stream().filter(integer -> (value % integer) == 0).findFirst();

            if (proof.isPresent()) {
//                System.out.println("candidate '" + candidate + "', base '" + base + "', value '" + value + "', proof '" + proof.get() + "'");
                proofs.add(proof.get());
            } else {
                // Must have been prime after all!
                return Optional.empty();
            }
        }

        return Optional.of(proofs);
    }

    private String generateCandidate(final long num) {
        final String bin = Long.toBinaryString(num);
        final int zeros = (n - 2) - bin.length();

        final String middle;

        if (zeros > 0 ) {
            char[] chars = new char[zeros];
            Arrays.fill(chars, '0');
            middle = new String(chars) + bin;
        } else {
            middle = bin;
        }

        return "1" + middle + "1";
    }

    @SneakyThrows
    public static void main(String[] args) {

        final String inputFile = args[0];
        final String outputFile;

        if (inputFile.contains(".in")) {
            outputFile = inputFile.replace(".in", ".out");
        } else {
            outputFile = args[0] + ".out";
        }

        try (final BufferedWriter writer = new BufferedWriter(new FileWriter(outputFile, false))) {
            // Read from the file
            int i = 0;
            try (final BufferedReader reader = new BufferedReader(new FileReader(inputFile))) {
                String line = reader.readLine();

                if ((line == null) || (line.trim().isEmpty())) {
                    return;
                }

                final BigInteger t = new BigInteger(line.trim());

                System.out.println(t + " cases");

                for (line = reader.readLine(); line != null; line = reader.readLine()) {
                    final String cleanLine = line.trim();

                    if (cleanLine.isEmpty()) {
                        continue;
                    }

                    i++;

                    final String[] parts = cleanLine.split(" ");

                    final int n = Integer.parseInt(parts[0]);
                    final int j = Integer.parseInt(parts[1]);

                    final String result = new CJ2016ProblemC(n, j).run();

                    final String output = String.format("Case #%d", i);

                    System.out.println(output);
                    writer.write(output);
                    writer.newLine();

                    System.out.println(result);
                    writer.write(result);
                    writer.newLine();
                }
            }
        }
    }
}
