package codejam2010.round1c;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

public class MakingChessBoards {
	int noOfTests;
	int m,n;
	char[][] board;
	Map<Integer,Integer> sizeMap;
	List<Cont> sizeList;
	
	BufferedReader in;
	BufferedWriter out;
	
	public static void main(String[] args) throws Exception {
		new MakingChessBoards(args[0]);
    }
	
	public MakingChessBoards(String fn) throws Exception {
		in = new BufferedReader(new FileReader(fn+".in"));
		out = new BufferedWriter(new FileWriter(fn + ".out"));
		readInput();
		out.flush();
        out.close();
	}
	
	public void readInput() throws Exception {
        String line = null;
        line = in.readLine();
        noOfTests = Integer.parseInt(line.trim());
        
        for(int i=0; i<noOfTests; i++) {
            line = in.readLine();
            String[] parts = line.split(" ");
            m = Integer.parseInt(parts[0]);
            n = Integer.parseInt(parts[1]);
            board = new char[m][n];
            sizeMap = new HashMap<Integer,Integer>();
            sizeList = new ArrayList<Cont>();
            
            for(int j=0;j<m;j++) {
            	line = in.readLine().trim();
            	fillRow(line, j);
            }
            
            process();
            getOutput();
            
        	writeOutput(i+1);
        }
        System.out.println();
    }
	
	public void getOutput() {
		int coverage = 0;
		for (Iterator<Entry<Integer, Integer>> iterator = sizeMap.entrySet().iterator(); iterator.hasNext();) {
			Entry<Integer, Integer> entry = iterator.next();
			int size = entry.getKey();
			int value = entry.getValue();
			
			coverage += (size*size*value);
			sizeList.add(new Cont(size, value));
		}
		
		if(coverage < m*n) {
			sizeList.add(new Cont(1, m*n - coverage));
		}
		Collections.sort(sizeList);
	}
	
	public void process() {
		boolean bigBoardExists = true;
		
		while(bigBoardExists) {
			int biggestSize = -1, biggestI = -1, biggestJ = -1;
			
			
			for(int i=0;i<board.length;i++) {
				for(int j=0;j<board[i].length;j++) {
					if('-' == board[i][j])
						continue;
					
					int size = 1;
					boolean flag = true;
					while(flag) {
						int rowIndex = i+size;
						int colIndex = j+size;
						
						if( rowIndex >= board.length || colIndex >= board[rowIndex].length ) {
							break;
						}
						
						char prev = board[i][colIndex-1];
						char cur;
						for(int k=i;k<=rowIndex;k++) {
							cur = board[k][colIndex];
							if(!areOpposite(prev, cur)) {
								flag = false;
								break;
							}
							prev = cur;
						}
						
						if(!flag)
							break;
						
						prev = board[rowIndex-1][j];
						for(int k=j;k<=colIndex;k++) {
							cur = board[rowIndex][k];
							if(!areOpposite(prev, cur)) {
								flag = false;
								break;
							}
							prev = cur;
						}
						
						if(!flag)
							break;
						
//						board[i][j] = '-';
//						for(int k=i;k<=rowIndex;k++) {
//							board[k][colIndex] = '-';
//						}
//						for(int k=j;k<=colIndex;k++) {
//							board[rowIndex][k] = '-';
//						}
						size++;
					}
					
					if( size > biggestSize ) {
						biggestSize = size;
						biggestI = i;
						biggestJ = j;
					}
//					if(size>1) {
//						if( sizeMap.containsKey(size) ) {
//							int value = sizeMap.get(size);
//							sizeMap.put(size, value+1);
//						} else {
//							sizeMap.put(size, 1);
//						}
//					}
				}
			}
			
			
			if(biggestSize<=1) {
				bigBoardExists = false;
			} else {
				for(int i=biggestI;i<biggestI+biggestSize;i++) {
					for(int j=biggestJ;j<biggestJ+biggestSize;j++) {
						board[i][j] = '-';
					}
				}
				
				if( sizeMap.containsKey(biggestSize) ) {
					int value = sizeMap.get(biggestSize);
					sizeMap.put(biggestSize, value+1);
				} else {
					sizeMap.put(biggestSize, 1);
				}
			}
		}
	}
	
	public boolean areOpposite(char ch1, char ch2) {
		if( (ch1 == 'W' && ch2 == 'B') || (ch1 == 'B' && ch2 == 'W'))
			return true;
		return false;
	}
	
	public void fillRow(String line, int rowIndex) {
		int columnIndex = board[rowIndex].length - 1;
		for(int i=line.length()-1;i>=0;i--) {
			int value = getInt(line.charAt(i));
			for(int j=0;j<4;j++) {
				if( (value & 1) == 1 )
					board[rowIndex][columnIndex--] = 'W';
				else
					board[rowIndex][columnIndex--] = 'B';
				value = value >> 1;
			}
		}
	}
	
	public int getInt(char ch) {
		if( Character.isDigit(ch) ) {
			return ch - '0';
		} else if( ch == 'A' || ch == 'a' ) {
			return 10;
		} else if( ch == 'B' || ch == 'b' ) {
			return 11;
		} else if( ch == 'C' || ch == 'c' ) {
			return 12;
		} else if( ch == 'D' || ch == 'd' ) {
			return 13;
		} else if( ch == 'E' || ch == 'e' ) {
			return 14;
		} else if( ch == 'F' || ch == 'f' ) {
			return 15;
		}
		return 0;
	}
	
	public void writeOutput(long inputNumber) throws Exception {
        String str = String.format("Case #%s: %s\n", inputNumber, sizeList.size());
        out.write(str);
        for(int i=sizeList.size()-1;i>=0;i--) {
        	Cont cont = sizeList.get(i);
        	out.write(cont.size + " " + cont.number + "\n");
        }
    }
	
	public static class Cont implements Comparable<Cont> {
		int size;
		int number;
		
		public Cont(int size, int number) {
			this.size = size;
			this.number = number;
		}
		
		public int compareTo(Cont cont) {
			return this.size - cont.size;
		}
	}
}
