package gcj2014.qualification;


import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;

public class MinesweeperMaster {
	BufferedReader br;
	BufferedWriter bw;
	int noOfTestCases;
	int currentCase;
	
	int r, c, m;
	int total;
	int nonM;
	char[][] grid;
	boolean possible;
	
	public MinesweeperMaster(String filename) throws Exception {
		br = new BufferedReader(new FileReader(filename));
		bw = new BufferedWriter(new FileWriter(filename + ".out"));
		
		noOfTestCases = Integer.parseInt(br.readLine());
		currentCase = 1;
		for(int i=0;i<noOfTestCases;i++) {
			readInput();
			process();
			writeOutput();
			currentCase++;
		}
		
		br.close();
		bw.flush();
		bw.close();
	}
	
	public void readInput() throws Exception {
		String str = br.readLine();
		String[] strArr = str.split(" ");
		
		r = Integer.parseInt(strArr[0]);
		c = Integer.parseInt(strArr[1]);
		m = Integer.parseInt(strArr[2]);

		total = r * c;
		nonM = total - m;
		grid = new char[r][c];
	}
	
	public void process() {
		for(int i=0;i<r;i++)
			for(int j=0;j<c;j++)
				grid[i][j] = '*';
		possible = true;
		
		if(nonM == total) {
			// No mines
			for(int i=0;i<r;i++)
				for(int j=0;j<c;j++)
					grid[i][j] = '.';
			return;
		}
		
		if(nonM == 1) {
			// All mines but 1
			grid[0][0] = 'c';
			return;
		}
		
		if(r == 1 || c == 1) {
			// When row or column is 1, we always have a solution
			int nonMLeft = nonM;
			for(int i=0;i<r && nonMLeft != 0;i++)
				for(int j=0;j<c && nonMLeft != 0;j++) {
					grid[i][j] = '.';
					nonMLeft--;
				}
			return;
		}
		
		if(r == 2 || c == 2) {
			// When rows or columns is 2
			
			if(nonM == 2 || (nonM % 2 == 1)) {
				// 2 or odd non mines is not possible
				possible = false;
				return;
			} else if(nonM % 2 == 0) {
				// Even non mines > 2
				int nonMLeft = nonM;
				
				if(r == 2) {
					// Fill columns of 2 rows
					for(int i=0;i<c && nonMLeft != 0;i++) {
						grid[0][i] = grid[1][i] = '.';
						nonMLeft -= 2;
					}
				} else if(c == 2) {
					// Fill rows of 2 columns
					for(int i=0;i<r && nonMLeft != 0; i++) {
						grid[i][0] = grid[i][1] = '.';
						nonMLeft -= 2;
					}
				}
				return;
			}
		}
		
		// Atleast 3x3 grid from here on
		
		if(nonM < 4) {
			possible = false;
			return;
		}
		
		if(nonM == 4) {
			// 4 Non mines
			fillSquare(2);
			return;
		}
		
		// Non mines in [5,8]
		if(nonM < 9) {
			if(nonM % 2 == 1) {
				// Odd number is impossible
				possible = false;
				return;
			} else {
				if(nonM == 6) {
					fillSquare(2);
					grid[0][2] = '.';
					grid[1][2] = '.';
					return;
				} else if(nonM == 8) {
					fillSquare(3);
					grid[2][2] = '*';
					return;
				}
			}
		}
		
		int biggestSquareSize = (int)Math.floor(Math.sqrt(nonM));
		
//		if(biggestSquareSize * biggestSquareSize == nonM){
//			// Perfect square of non mines
//			fillSquare(biggestSquareSize);
//			return;
//		}
		
		int nonMLeft = nonM;
		if(r > biggestSquareSize && c > biggestSquareSize) {
			// Square possible and grid is big on both sides
			fillSquare(biggestSquareSize);
			nonMLeft = nonMLeft - (biggestSquareSize * biggestSquareSize);
			
			if(nonMLeft == 0) {
				// Done
				return;
			}else if(nonMLeft == 1) {
				// Fill columns
				grid[0][biggestSquareSize] = '.';
				grid[1][biggestSquareSize] = '.';
				grid[biggestSquareSize-1][biggestSquareSize-1] = '*';
				return;
			} else if(nonMLeft == 2) {
				grid[0][biggestSquareSize] = '.';
				grid[1][biggestSquareSize] = '.';
				return;
			} else if(nonMLeft == 3) {
				// Fill columns
				grid[0][biggestSquareSize] = '.';
				grid[1][biggestSquareSize] = '.';
				grid[2][biggestSquareSize] = '.';
				return;
			} else {
				// Simultaneously fill rows & columns
				int i = 0;
				while(nonMLeft != 0) {
					grid[biggestSquareSize][i] = '.';
					nonMLeft--;
					if(nonMLeft == 0)
						break;
					
					grid[i][biggestSquareSize] = '.';
					nonMLeft--;
					
					i++;
				}
				return;
			}
		} else {
			// After completing the square, either rows or columns are done
			// The square might be smaller than biggestSquareSize
			int maxSquareSizePossible = Math.min(biggestSquareSize, Math.min(r, c));
			
			fillSquare(maxSquareSizePossible);
			nonMLeft = nonMLeft - (maxSquareSizePossible * maxSquareSizePossible);
			
			if(nonMLeft == 0) {
				// We are done
				return;
			}
			
			if(r == maxSquareSizePossible) {
				// No extra rows available
				int colBeingFilled = maxSquareSizePossible;
				while(nonMLeft >= r) {
					for(int i=0;i<r;i++)
						grid[i][colBeingFilled] = '.';

					nonMLeft = nonMLeft - r;
					colBeingFilled++;
				}
				
				if(nonMLeft == 0) {
					// We are done
					return;
				} else if(nonMLeft == 1) {
					grid[0][colBeingFilled] = '.';
					grid[1][colBeingFilled] = '.';
					grid[maxSquareSizePossible-1][colBeingFilled-1] = '*';
					return;
				} else {
					for(int i=0;i<r && nonMLeft != 0;i++) {
						grid[i][colBeingFilled] = '.';
						nonMLeft--;
					}
					return;
				}
			} else if(c == maxSquareSizePossible) {
				// No extra columns available
				int rowBeingFilled = maxSquareSizePossible;
				while(nonMLeft >= c) {
					for(int i=0;i<c;i++)
						grid[rowBeingFilled][i] = '.';

					nonMLeft = nonMLeft - c;
					rowBeingFilled++;
				}
				
				if(nonMLeft == 0) {
					// We are done
					return;
				} else if(nonMLeft == 1) {
					grid[rowBeingFilled][0] = '.';
					grid[rowBeingFilled][1] = '.';
					grid[rowBeingFilled-1][maxSquareSizePossible-1] = '*';
					return;
				} else {
					for(int i=0;i<c && nonMLeft != 0;i++) {
						grid[rowBeingFilled][i] = '.';
						nonMLeft--;
					}
					return;
				}
			}
		}
//		
//		
//		if ((r == biggestSquareSize && c > biggestSquareSize) || 
//				(r > biggestSquareSize && c == biggestSquareSize)) {
//			// Square possible and grid is not big
//			for(int i=0;i<biggestSquareSize;i++)
//				for(int j=0;j<biggestSquareSize;j++)
//					grid[i][j] = '.';
//			nonMLeft = nonMLeft - (biggestSquareSize * biggestSquareSize);
//			
//			if(r == biggestSquareSize) {
//				int colBeingFilled = biggestSquareSize;
//				// No extra rows
//				while(nonMLeft >= r) {
//					for(int i=0;i<r;i++) {
//						grid[i][colBeingFilled] = '.';
//						nonMLeft--;
//					}
//					colBeingFilled++;
//				}
//				
//				if(nonMLeft == 0) {
//					grid[0][0] = 'c';
//					possible = true;
//					return;
//				} else if(nonMLeft == 1) {
//					grid[0][colBeingFilled] = '.';
//					grid[1][colBeingFilled] = '.';
//					grid[biggestSquareSize-1][colBeingFilled-1] = '*';
//					grid[0][0] = 'c';
//					possible = true;
//					return;
//				} else {
//					for(int i=0;i<r && nonMLeft != 0;i++) {
//						grid[i][colBeingFilled] = '.';
//						nonMLeft--;
//					}
//					grid[0][0] = 'c';
//					possible = true;
//					return;
//				}
//			}
//			
//			if(c == biggestSquareSize) {
//				int rowBeingFilled = biggestSquareSize;
//				// No extra columns
//				while(nonMLeft >= c) {
//					for(int i=0;i<c;i++) {
//						grid[rowBeingFilled][i] = '.';
//						nonMLeft--;
//					}
//					rowBeingFilled++;
//				}
//				
//				if(nonMLeft == 0) {
//					grid[0][0] = 'c';
//					possible = true;
//					return;
//				} else if(nonMLeft == 1) {
//					grid[rowBeingFilled][0] = '.';
//					grid[rowBeingFilled][1] = '.';
//					grid[rowBeingFilled-1][biggestSquareSize-1] = '*';
//					grid[0][0] = 'c';
//					possible = true;
//					return;
//				} else {
//					for(int i=0;i<c && nonMLeft != 0;i++) {
//						grid[rowBeingFilled][i] = '.';
//						nonMLeft--;
//					}
//					grid[0][0] = 'c';
//					possible = true;
//					return;
//				}
//			}
//		} else {
//			// Square not possible
//			int maxSquareSize = Math.min(r, c);
//			for(int i=0;i<maxSquareSize;i++)
//				for(int j=0;j<maxSquareSize;j++)
//					grid[i][j] = '.';
//			
//			nonMLeft = nonMLeft - (maxSquareSize * maxSquareSize);
//			if(r == maxSquareSize) {
//				// Row is the limiting factor, fill columns
//			} else {
//				
//			}
//		}
	}
	
	private void fillSquare(int squareSize) {
		for(int i=0;i<squareSize;i++)
			for(int j=0;j<squareSize;j++)
				grid[i][j] = '.';
	}
	
	public void writeOutput() throws Exception {
		if(possible)
			grid[0][0] = 'c';

		StringBuffer buf = new StringBuffer();
		buf.append("Case #").append(currentCase).append(":\n");
		if(possible) {
			for(int i=0;i<r;i++)
				buf.append(new String(grid[i]) + "\n");
		} else {
			buf.append("Impossible\n");
		}
		bw.write(buf.toString());
	}
	
	public static void main(String[] args) throws Exception {
		new MinesweeperMaster("input/gcj2014/qualification/C-large.in");
	}
}
