
import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.LinkedList;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class ThemeParkSmall
{

    private BufferedReader d;
    private DataOutputStream dos = null;
    private Logger logger = Logger.getLogger(ThemePark.class.getName());
    private long k, r;
    private int n, t;
    private static final String outputPrefix = "Case #";
    private static final Pattern numericPattern = Pattern.compile("(\\d+)");
    private static final Pattern rknPattern = Pattern.compile("(\\d+)\\s*(\\d+)\\s*(\\d+)");


    public ThemeParkSmall() throws IOException
    {
        try
        {
            d = new BufferedReader(new InputStreamReader(new FileInputStream(new File("C-small.in"))));
            dos = new DataOutputStream(new FileOutputStream(new File("C-small.out")));
        }
        catch (FileNotFoundException ex)
        {
            logger.log(Level.SEVERE, "Could not find file");
        }
        try
        {
            Matcher m = numericPattern.matcher(d.readLine().trim());
            if (m.matches())
            {
                t = Integer.parseInt(m.group(1));
            }
            else
            {
                logger.log(Level.SEVERE, "Invalid value for T");
                t = 0;
            }
        }
        catch (NullPointerException e)
        {
            //file could not be opened, already logged, so nothing to do
            throw e;
        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file");
            throw e;
        }
        for (int i = 0; i < t; i++)
        {
            startTest(i + 1);
        }
    }

    private void startTest(int testCase)
    {
        LinkedList<Long> groups = new LinkedList<Long>();
        long sum;
        try
        {
            Matcher m = rknPattern.matcher(d.readLine().trim());
            if (m.matches())   
            {
                r = Long.parseLong(m.group(1));
                k = Long.parseLong(m.group(2));
                n = Integer.parseInt(m.group(3));
            }
            else
            {
                logger.log(Level.SEVERE, "Invalid values for R, K and N");
                return;
            }
            groups.clear();
            sum =0;
            String[] groupStrings = d.readLine().trim().split("\\s");
            for (int i = 0; i < n; i++)
            {
                groups.add(Long.parseLong(groupStrings[i]));
                    sum += groups.peekLast();
            }
            if (sum <= k)
            {
                writeResponse(testCase, "" + r * sum + (testCase < t ? "\n" : ""));
            }
            else
            {
                int runs = 0;
                int currentGroup = 0;
                int groupNo = 0;
                long solution = 0;
                while (runs<r)
                {
                    int current =0;
                    for (int i=0; i<n && current+groups.peek()<=k; i++)
                    {
                        current += groups.peek();
                        groups.addLast(groups.pollFirst());
                    }
                    runs++;
                    solution+=current;
                }
                writeResponse(testCase, ""+solution + (testCase < t ? "\n" : ""));
            }
        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file test #" + testCase);
            return;
        }
        catch (NullPointerException e)
        {
            return;
            // already logged;
        }
    }

    private void writeResponse(int testCase, String value)
    {
        try
        {
            dos.write((outputPrefix + testCase + ": " + value).getBytes());
        }
        catch (IOException ex)
        {
            logger.log(Level.SEVERE, "Could not write output for testcase #" + testCase);
        }
    }

    public static void main(String args[]) throws IOException
    {
        ThemeParkSmall t = new ThemeParkSmall();
    }
}
