
import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Iterator;
import java.util.Map.Entry;
import java.util.SortedMap;
import java.util.TreeMap;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * @author Adrian Buturuga
 */
public class Intranet
{

    private BufferedReader d;
    private DataOutputStream dos = null;
    private Logger logger = Logger.getLogger(this.getClass().getName());
    private int n, t;
    private SortedMap<Integer, Integer> lines;
    private SortedMap<Integer, Integer> reverseLines;
    private static final String outputPrefix = "Case #";
    private static final String inputFileName = "A-large.in";
    private static final String outputFileName = "A-large.out";

    public Intranet() throws IOException
    {
        try
        {
            d = new BufferedReader(new InputStreamReader(new FileInputStream(new File(inputFileName))));
            dos = new DataOutputStream(new FileOutputStream(new File(outputFileName)));
        }
        catch (FileNotFoundException ex)
        {
            logger.log(Level.SEVERE, "Could not find file");
        }
        try
        {
            t = Integer.parseInt(d.readLine().trim());
//            System.out.println(t);
        }
        catch (NullPointerException e)
        {
            //file could not be opened, already logged, so nothing to do
            throw e;
        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file");
            throw e;
        }
        lines = new TreeMap<Integer, Integer>();
        reverseLines = new TreeMap<Integer, Integer>();
        for (int i = 0; i < t; i++)
        {
//            System.out.println("test "+i);
            startTest(i + 1);
        }
    }

    public void startTest(int testCase)
    {
        try
        {
            n = Integer.parseInt(d.readLine().trim());
            lines.clear();
            reverseLines.clear();
            for (int i = 0; i < n; i++)
            {
                String temp = d.readLine();
//                System.out.println(temp);
                while(temp == null || temp.isEmpty()) temp = d.readLine();
                String line[] = temp.trim().split("\\s");
                
                    lines.put(Integer.parseInt(line[0]), Integer.parseInt(line[1]));
                    reverseLines.put(Integer.parseInt(line[1]), Integer.parseInt(line[0]));
            }
//            System.out.println("Testcase "+testCase);
            int intersects = 0;
            Iterator<Entry<Integer, Integer>> iterator = lines.entrySet().iterator();
            while (iterator.hasNext())
            {
                Entry<Integer, Integer> line = iterator.next();
                Iterator<Entry<Integer, Integer>> reverseIterator = reverseLines.entrySet().iterator();
                while (reverseIterator.hasNext())
                {
                    Entry<Integer, Integer> otherLine = reverseIterator.next();
//                    System.out.println("Comparing "+line.getKey()+", "+line.getValue()+" with "+otherLine.getValue()+", "+otherLine.getKey());
                    if (line.getValue() <= otherLine.getKey())
                    {
                        break;
                    }
//                    System.out.println(line.getKey()+", "+line.getValue()+" hits "+otherLine.getValue()+", "+otherLine.getKey());
                    intersects++;
                    
                }
                reverseLines.remove(line.getValue());
            }
            writeResponse(testCase, "" + intersects);

        }
        catch (IOException e)
        {
            return;
        }
        catch (NullPointerException e)
        {
            return;
            // already logged;
        }
    }

    private void writeResponse(int testCase, String value)
    {
        try
        {
            dos.write((outputPrefix + testCase + ": " + value + "\n").getBytes());
        }
        catch (IOException ex)
        {
            logger.log(Level.SEVERE, "Could not write output for testcase #" + testCase);
        }
    }

    public static void main(String args[]) throws IOException
    {
        Intranet intranet = new Intranet();
    }
}

