
import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Adrian Buturuga
 */
public class FixIt
{

    private BufferedReader d;
    private DataOutputStream dos = null;
    private Logger logger = Logger.getLogger(SnapperChain.class.getName());
    private int t, n, m;
    private HashMap<String, Integer> folders;
    private static final String outputPrefix = "Case #";
    private static final Pattern nmPattern = Pattern.compile("(\\d+)\\s*(\\d+)");
    private static final String inputFileName = "A-small.in";
    private static final String outputFileName = "A-small.out";

    public FixIt() throws IOException
    {
        folders = new HashMap<String, Integer>();
        folders.put("/", 0);

        try
        {
            d = new BufferedReader(new InputStreamReader(new FileInputStream(new File(inputFileName))));
            dos = new DataOutputStream(new FileOutputStream(new File(outputFileName)));
        }
        catch (FileNotFoundException ex)
        {
            logger.log(Level.SEVERE, "Could not find file");
        }
        try
        {
            t = Integer.parseInt(d.readLine().trim());
        }
        catch (NullPointerException e)
        {
            //file could not be opened, already logged, so nothing to do
            throw e;
        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file");
            throw e;
        }
        for (int i = 0; i < t; i++)
        {
            startTest(i + 1);
        }
    }

    public void startTest(int testCase)
    {
        folders.clear();
        try
        {
            Matcher matcher = nmPattern.matcher(d.readLine().trim());
            if (matcher.matches())
            {
                n = Integer.parseInt(matcher.group(1));
                m = Integer.parseInt(matcher.group(2));
            }
            else
            {
                logger.log(Level.SEVERE, "Invalid values for N and M");
                n = 0;
                m = 0;
                return;
            }
            for (int i = 0; i < n; i++)
            {
                String path = d.readLine().trim();
                addFolder(path);
            }
            long mkdirs = 0;
            for (int i = 0; i < m; i++)
            {
                String path = d.readLine().trim();
                int cost = createFolder(path);
                mkdirs += cost;
            }
            writeResponse(testCase, ""+mkdirs);

        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file test #" + testCase);
            return;
        }
        catch (NullPointerException e)
        {
            return;
            // already logged;
        }
    }

    private int createFolder(String path)
    {
        if (path==null || path.isEmpty() || folders.containsKey(path))
        {
            return 0;
        }
        int lastSlash = path.lastIndexOf("/");
        String parent = path.substring(0, lastSlash);
        int temp = createFolder(parent);
        folders.put(path, temp+1);
        return temp+1;
    }

    private void addFolder(String path)
    {
        if (path==null || path.isEmpty() || path.equals("/") ||folders.containsKey(path))
        {
            return;
        }
        int lastSlash = path.lastIndexOf("/");
        String parent = path.substring(0, lastSlash);
        addFolder(parent);
        folders.put(path, 0);
    }

    private void writeResponse(int testCase, String value)
    {
        try
        {
            dos.write((outputPrefix + testCase + ": " + value + "\n").getBytes());
        }
        catch (IOException ex)
        {
            logger.log(Level.SEVERE, "Could not write output for testcase #" + testCase);
        }
    }

    public static void main(String args[]) throws IOException
    {
        FixIt fixit = new FixIt();
    }
}
