
import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class SnapperChain
{

    private BufferedReader d;
    private DataOutputStream dos = null;
    private Logger logger = Logger.getLogger(SnapperChain.class.getName());
    private int n, k, t;
    private static final String outputPrefix = "Case #";
    private static final Pattern tPattern = Pattern.compile("(\\d+)");
    private static final Pattern nkPattern = Pattern.compile("(\\d+)\\s*(\\d+)");

    public SnapperChain() throws IOException
    {
        try
        {
            d = new BufferedReader(new InputStreamReader(new FileInputStream(new File("A-large.in"))));
            dos = new DataOutputStream(new FileOutputStream(new File("A-large.out")));
        }
        catch (FileNotFoundException ex)
        {
            logger.log(Level.SEVERE, "Could not find file");
        }
        try
        {
            Matcher m = tPattern.matcher(d.readLine().trim());
            if (m.matches())
            {
                t = Integer.parseInt(m.group(1));
            }
            else
            {
                logger.log(Level.SEVERE, "Invalid value for T");
                t = 0;
            }
        }
        catch (NullPointerException e)
        {
            //file could not be opened, already logged, so nothing to do
            throw e;
        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file");
            throw e;
        }
        for (int i = 0; i < t; i++)
        {
            startTest(i + 1);
        }
    }

    private void startTest(int testId)
    {
        try
        {
            Matcher m = nkPattern.matcher(d.readLine().trim());
            if (m.matches())
            {
                n = Integer.parseInt(m.group(1));
                k = Integer.parseInt(m.group(2));
            }
            else
            {
                logger.log(Level.SEVERE, "Invalid values for N and K");
                n = 0;
                k = 0;
                return;
            }
            if (k % 2 == 0)
            {
                writeResponse(testId, "OFF");
                return;
            }
            k++;
            long temp = 1<<n;
            if (k % temp == 0) writeResponse(testId, "ON");
            else writeResponse(testId, "OFF");
        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file test #" + testId);
            return;
        }
        catch (NullPointerException e)
        {
            return;
            // already logged;
        }
    }

    private void writeResponse(int testCase, String value)
    {
        try
        {
            dos.write((outputPrefix + testCase + ": " + value + "\n").getBytes());
        }
        catch (IOException ex)
        {
            logger.log(Level.SEVERE, "Could not write output for testcase #"+testCase);
        }
    }

    public static void main(String args[])
    {
        try
        {
            SnapperChain snapper = new SnapperChain();
        }
        catch (IOException ex)
        {
        }
    }
}
