
import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Collections;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;
import java.util.TreeMap;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * @author Adrian Buturuga
 */
public class Chess
{

    private BufferedReader d;
    private DataOutputStream dos = null;
    private Logger logger = Logger.getLogger(this.getClass().getName());
    private int n, t, m;
    private int board[][], helper[][];
    private static final String outputPrefix = "Case #";
    private static final String inputFileName = "C-small.in";
    private static final String outputFileName = "C-small.out";
    private Map<Integer, Integer> boards;

    public Chess() throws IOException
    {
        try
        {
            d = new BufferedReader(new InputStreamReader(new FileInputStream(new File(inputFileName))));
            dos = new DataOutputStream(new FileOutputStream(new File(outputFileName)));
        }
        catch (FileNotFoundException ex)
        {
            logger.log(Level.SEVERE, "Could not find file");
        }
        try
        {
            t = Integer.parseInt(d.readLine().trim());
        }
        catch (NullPointerException e)
        {
            //file could not be opened, already logged, so nothing to do
            throw e;
        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file");
            throw e;
        }
        boards = new TreeMap<Integer, Integer>(Collections.reverseOrder());
        for (int i = 0; i < t; i++)
        {
            startTest(i + 1);
        }
    }

    public void startTest(int testCase)
    {
        try
        {
            boards.clear();
            String[] mn = d.readLine().trim().split("\\s");
            m = Integer.parseInt(mn[0]);
            n = Integer.parseInt(mn[1]);
            board = new int[m][n];
            helper = new int[m][n];
            for (int i = 0; i < m; i++)
            {
                String temp = d.readLine().trim();
                for (int j = 0; j < n / 4; j++)
                {
                    char c = temp.charAt(j);
                    int val;
                    if (("" + c).matches("[A-F]"))
                    {
                        val = 10 + c - 'A';
                    }
                    else
                    {
                        val = c - '0';
                    }
                    board[i][4 * j] = ((val & 8) != 0) ? 1 : 0;
                    board[i][4 * j + 1] = ((val & 4) != 0) ? 1 : 0;
                    board[i][4 * j + 2] = ((val & 2) != 0) ? 1 : 0;
                    board[i][4 * j + 3] = ((val & 1) != 0) ? 1 : 0;
                    helper[i][4 * j] = helper[i][4 * j + 1] = helper[i][4 * j + 2] = helper[i][4 * j + 3] = 1;
                }
                helper[i][n - 1] = 1;
            }
            for (int i = 0; i < n; i++)
            {
                helper[m - 1][i] = 1;
            }
            buildHelper(m - 1, n - 1);
            long piecesLeft = n * m;
            while (piecesLeft != 0)
            {
                piecesLeft -= eliminateMaxBoard();
            }
            writeResponse(testCase);

        }
        catch (IOException e)
        {
            return;
        }
        catch (NullPointerException e)
        {
            return;
            // already logged;
        }
    }

    private long eliminateMaxBoard()
    {
        int max = 0;
        int x = 0;
        int y = 0;
        for (int i = 0; i < m; i++)
        {
            for (int j = 0; j < n; j++)
            {
                if (helper[i][j] > max)
                {
                    max = helper[i][j];
                    x = i;
                    y = j;
                }
            }
        }
        for (int i = x; i < x + max; i++)
        {
            for (int j = y; j < y + max; j++)
            {
                helper[i][j] = 0;
            }
        }
        buildHelper(m - 1, n - 1);
        buildHelper(x, y + max - 1);
        Integer prev = boards.get(max);
        if (prev == null)
        {
            prev = 0;
        }
        boards.put(max, prev + 1);
        return max * max;
    }

    private void buildHelper(int lines, int columns)
    {
        for (int i = lines - 1; i >= 0; i--)
        {
            for (int j = columns - 1; j >= 0; j--)
            {
                if (helper[i][j] != 0)
                {
                    if ((board[i + 1][j + 1] == board[i][j])
                            && (board[i + 1][j] == board[i][j + 1])
                            && (board[i][j] != board[i + 1][j]))
                    {
                        if ((helper[i + 1][j] == helper[i][j + 1])
                                && (helper[i + 1][j + 1] == helper[i + 1][j]))
                        {
                            helper[i][j] = helper[i + 1][j + 1] + 1;
                        }
                        else
                        {
                            int min = Math.min(helper[i + 1][j], Math.min(helper[i][j + 1], helper[i + 1][j + 1]));
                            helper[i][j] = min + 1;
                        }
                    }
                    else
                    {
                        helper[i][j] = 1;
                    }
                }
            }
        }
    }

    private void writeResponse(int testCase)
    {
        try
        {
            dos.write((outputPrefix + testCase + ": " + boards.size() + "\n").getBytes());
            Iterator<Entry<Integer, Integer>> i = boards.entrySet().iterator();
            while (i.hasNext())
            {
                Entry<Integer, Integer> entry = i.next();
                dos.write((entry.getKey() + " " + entry.getValue() + "\n").getBytes());
            }
        }
        catch (IOException ex)
        {
            logger.log(Level.SEVERE, "Could not write output for testcase #" + testCase);


        }
    }

    public static void main(String args[]) throws IOException
    {
        Chess chess = new Chess();

    }
}

