
import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class ThemePark
{

    private BufferedReader d;
    private DataOutputStream dos = null;
    private Logger logger = Logger.getLogger(ThemePark.class.getName());
    private long k, r;
    private int n, t;
    private static final String outputPrefix = "Case #";
    private static final Pattern numericPattern = Pattern.compile("(\\d+)");
    private static final Pattern rknPattern = Pattern.compile("(\\d+)\\s*(\\d+)\\s*(\\d+)");
    int currentGroup = 0;
    long completeTurns = 0;
    long previousSolution = 0;

    public ThemePark() throws IOException
    {
        try
        {
            d = new BufferedReader(new InputStreamReader(new FileInputStream(new File("C-large.in"))));
            dos = new DataOutputStream(new FileOutputStream(new File("C-large.out")));
        }
        catch (FileNotFoundException ex)
        {
            logger.log(Level.SEVERE, "Could not find file");
        }
        try
        {
            Matcher m = numericPattern.matcher(d.readLine().trim());
            if (m.matches())
            {
                t = Integer.parseInt(m.group(1));
            }
            else
            {
                logger.log(Level.SEVERE, "Invalid value for T");
                t = 0;
            }
        }
        catch (NullPointerException e)
        {
            //file could not be opened, already logged, so nothing to do
            throw e;
        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file");
            throw e;
        }
        for (int i = 0; i < t; i++)
        {
            startTest(i + 1);
        }
    }

    private void startTest(int testCase)
    {
        currentGroup = 0;
        completeTurns = 0;
        previousSolution = 0;
        long groups[];
        long sums[];
        try
        {
            Matcher m = rknPattern.matcher(d.readLine().trim());
            if (m.matches())
            {
                r = Long.parseLong(m.group(1));
                k = Long.parseLong(m.group(2));
                n = Integer.parseInt(m.group(3));
            }
            else
            {
                logger.log(Level.SEVERE, "Invalid values for R, K and N");
                return;
            }
            groups = new long[n];
            sums = new long[n];
            String[] groupStrings = d.readLine().trim().split("\\s");
            for (int i = 0; i < n; i++)
            {
                groups[i] = Long.parseLong(groupStrings[i]);
                try
                {
                    sums[i] = sums[i - 1] + groups[i];
                }
                catch (IndexOutOfBoundsException e)
                {
                    sums[i] = groups[i];
                }
            }
            if (sums[n - 1] <= k)
            {
                writeResponse(testCase, "" + r * sums[n - 1] + (testCase < t ? "\n" : ""));
            }
            else
            {
                //System.out.println(r+" "+k+" "+n);
                for (int i = 0; i < r; i++)
                {
                    long expectedMaximum = previousSolution + k;
                    previousSolution = getMaximum(sums, expectedMaximum);
                    if (testCase == 16 ) System.out.println(previousSolution+" "+i);
                }
                writeResponse(testCase, "" + previousSolution + (testCase < t ? "\n" : ""));
            }
        }
        catch (IOException e)
        {
            logger.log(Level.SEVERE, "Could not read from file test #" + testCase);
            return;
        }
        catch (NullPointerException e)
        {
            return;
            // already logged;
        }
    }

    private long getMaximum(long[] sums, long expected)
    {
        int last = sums.length - 1;
        if ((currentGroup != 0) && (sums[0] + sums[last] * (completeTurns + 1) <= expected))
        {
            completeTurns++;
            currentGroup = 0;
        }
        return locate(currentGroup, last, expected, sums);
    }

    private long locate(int start, int stop, long expected, long[] values)
    {
        long turnSum = values[values.length - 1];
        if (start == stop || start > stop)
        {
            long result = values[start] + completeTurns * values[values.length - 1];
            acceptUntilGroup(start);
            return result;
        }
        if (start == stop - 1)
        {
            if (values[stop] + completeTurns * turnSum <= expected)
            {
                long result = values[stop] + completeTurns * turnSum;
                acceptUntilGroup(stop);
                return result;
            }
            else
            {
                long result = values[start] + completeTurns * turnSum;
                acceptUntilGroup(start);
                return result;
            }
        }
        int mid = (stop + start) / 2;
        if (values[mid] + completeTurns * turnSum == expected)
        {
            acceptUntilGroup(mid);
            return expected;
        }
        else if (values[mid] + completeTurns * turnSum > expected)
        {
            return locate(start, mid - 1, expected, values);
        }
        else
        {
            return locate(mid, stop, expected, values);
        }
    }

    private void acceptUntilGroup(int group)
    {
        if (group == n - 1)
        {
            currentGroup = 0;
            completeTurns++;
        }
        else
        {
            currentGroup = group + 1;
        }
    }

    private void writeResponse(int testCase, String value)
    {
        try
        {
            dos.write((outputPrefix + testCase + ": " + value).getBytes());
        }
        catch (IOException ex)
        {
            logger.log(Level.SEVERE, "Could not write output for testcase #" + testCase);
        }
    }

    public static void main(String args[]) throws IOException
    {
        ThemePark t = new ThemePark();
    }
}
