package mk.chip.codejam;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Stack;

public class FashionShowMain {

//	static final String IN_FILE = "D:\\B-small-practice.in";
//	static final String IN_FILE = "D:\\B-large-practice.in";
//	static final String IN_FILE = "D:\\C-large-practice.in";
	static final String IN_FILE = "D:\\D-small-attempt2.in";
//	static final String IN_FILE = "D:\\A-large-practice.in";
//	static final String IN_FILE = "D:\\codejam_in.txt";
	static final String OUT_FILE = "D:\\codejam_out.txt";
	static FileReader inFile = null;
	static FileWriter outFile = null;
	static BufferedReader in = null;
	static BufferedWriter out = null;
	
	static long startTime = System.currentTimeMillis();

	static Line[] rows, cols, diagUp, diagDown;
	static Cell[][] matrix;

	public static void main(String[] args) {
		// Open input and output file
		try {
			openIn();
			openOut();

			// Run the solution
			solution();
		} catch (IOException e) {
			e.printStackTrace();
		}

		// Close intput and output file
		closeInAndOut();
		reportTime("Exec time %s sec");
	}

	/**
	* Solution of a codejam problem
	* @throws IOException
	*/
	static void solution() throws IOException {
		// Number of cases
		int cases = Integer.parseInt(in.readLine());
		for (int t = 1; t <= cases; t++) {
			Stack<Integer> si = getInts(in.readLine().trim());
			int parM = si.pop();
			int parN = si.pop();
			
			rows = initLinesArray(new Line[parN], "Row", false);
			cols = initLinesArray(new Line[parN], "Col", false);
			diagUp = initLinesArray(new Line[2 * parN - 1], "DiagU", true);
			diagDown = initLinesArray(new Line[2 * parN - 1], "DiagD", true);
			matrix = new Cell[parN][parN];
			
			// Initialize
			for (int i = 0; i < parN; i++) {
				for (int j = 0; j < parN; j++) {
					matrix[i][j] = new Cell(i, j).presetVal('.');
				}
			}
			
			// Load models
			for (int n = 0; n < parM; n++) {
				String[] model = in.readLine().split(" ");
				char v = model[0].toCharArray()[0];
				int r = Integer.valueOf(model[1]) - 1;
				int c = Integer.valueOf(model[2]) - 1;
				matrix[r][c].presetVal(v);
			}
			
			//printMatrix();
			//print("----------");
			
			// Iterate upgrades until no more upgrades
			int upgradesCnt;
			do {
				upgradesCnt = 0;
				for (int i = 0; i < parN; i++) {
					for (int j = 0; j < parN; j++) {
						upgradesCnt = matrix[i][j].upgrade(upgradesCnt);
					}
				}
			} while (upgradesCnt > 0);
			
			//printMatrix();
			
			writeAndPrint(String.format("Case #%s: %s %s", t, totalPoints(), addedModels()));
			for (int i = 0; i < parN; i++) {
				for (int j = 0; j < parN; j++) {
					Cell c = matrix[i][j];
					if (c.modified && c.val != '.') writeAndPrint(c.output());
				}
			}
		}
	}
 
	static class Cell {
		List<Line> attachments = new ArrayList<Line>();
		final int r, c; 
		char val = '.';
		boolean modified = false;
		
		Cell(int row, int col) {
			this.r = row;
			this.c = col;
			attachments.add(rows[r].attachCell(this));
			attachments.add(cols[c].attachCell(this));
			attachments.add(diagUp[r + c].attachCell(this));
			attachments.add(diagDown[r - c + rows.length - 1].attachCell(this));
		}
		
		Cell presetVal(char v) {
			for (Line lin : attachments) lin.valueChange(val, v);
			val = v;
			return this;
		}
		
		Cell setVal(char v) {
			modified = true;
			presetVal(v);
			return this;
		}
		
		int upgrade(int cnt) {
			if (val == '.') {
				if (tryUpgradeTo('+')) return cnt + 1;
				if (tryUpgradeTo('x')) return cnt + 1;
			}

			if (tryUpgradeTo('o')) return cnt + 1;
			
			return cnt;
		}
		
		private boolean tryUpgradeTo(char c) {
			boolean upgradable = true;
			for (Line lin : attachments) {
				upgradable = lin.isUpgradable(val, c);
				if (!upgradable) break;
			}
			
			if (upgradable) {
				setVal(c);
				return true;
			}
			
			return false;
		}
		
		String output() {return val + " " + (r + 1) + " " + (c + 1);}
	}
	
	static class Line {
		String name;
		//int points = 0, xcnt = 0, crosscnt = 0, models = 0;
		int xcnt = 0, crosscnt = 0, ocnt = 0;
		List<Cell> cells = new ArrayList<Cell>();
		
		Line(String name) {this.name = name;}
		
		Line attachCell(Cell c) {
			cells.add(c);
			return this;
		}
		
		int getModelsCnt() {return ocnt + xcnt + crosscnt;}
		
		int getPoints() {return 2 * ocnt + xcnt + crosscnt;}

		void valueChange(char oldVal, char newVal) {
			if (oldVal == 'o') ocnt--;
			else if (oldVal == 'x') xcnt--;
			else if (oldVal == '+') crosscnt--;
			
			if (newVal == 'o') ocnt++;
			else if (newVal == 'x') xcnt++;
			else if (newVal == '+') crosscnt++;			
		}
		boolean isArtistic() {return ocnt + unrequired() < 2;}
		
		boolean isUpgradable(char a, char b) {
			int p = crosscnt, x = xcnt, o = ocnt;
			if (a == 'o') return false;
			else if (a == '+') p--;
			else if (a == 'x') x--;
			
			if (b == 'o') {
				o++;
				return o + (marker() == '+' ? x : p) < 2;
			}
			
			if (a != '.') return false; // Not upgradable
			else if (b == '+') p++;
			else if (b == 'x') x++;
			
			return o + (marker() == '+' ? x : p) < 2;
		}
		
/*		boolean isUpgradable(char a, char b) {
			int m = models, n = required();
			// remove old
			if (a == 'o') return false;
			if (a != '.') {
				m--;
				if (a == marker()) n--;
			}
			// add new
			m++;
			if (b == marker()) n++;
			
			return m < 2 || n > 0;
		}
*/		
		int required() {return crosscnt;}
		int unrequired() {return xcnt;}
		char marker() {return '+';}
		char unmarker() {return 'x';}
		
		void print() {
			for (Cell c : cells) System.out.print(c.val);
			System.out.println();
		}
	}
	
	static class Diagonal extends Line {
		Diagonal(String name) {super(name);}
		
		@Override
		int required() {return xcnt;}
		@Override
		int unrequired() {return crosscnt;}
		@Override
		char marker() {return 'x';}
		@Override
		char unmarker() {return '+';}
	}
	
	static Line[] initLinesArray(Line[] lines, String name, boolean isDiag) {
		for (int i = 0; i < lines.length; i++) {
			lines[i] = isDiag ? new Diagonal(name + " " + i) : new Line(name + " " + i);
		}
		return lines;
	}
	
	static void printMatrix() {
		for (Line lin : rows) lin.print();
	}
	
	static int totalPoints() {
		int pnt = 0;
		for (Line lin : rows) 
			pnt += lin.getPoints();
		return pnt;
	}
	
	static int addedPoints() {
		int pnt = 0;
		for (int i = 0; i < rows.length; i++) {
			for (int j = 0; j < cols.length; j++) {
				Cell c= matrix[i][j];
				if (c.modified) {
					if (c.val != '.') {
						pnt++;
						if (c.val == 'o') pnt++;
					}
				}
			}
		}
		return pnt;
	}
	
	static int totalModels() {
		int models = 0;
		for (Line lin : rows) models += lin.getModelsCnt();
		return models;
	}
	
	static int addedModels() {
		int models = 0;
		for (int i = 0; i < rows.length; i++) {
			for (int j = 0; j < cols.length; j++) {
				Cell c= matrix[i][j];
				if (c.modified) {
					if (c.val != '.') {
						models++;
					}
				}
			}
		}
		return models;
	}
	
//---------------------------------------------	
	
	/**
	* @param str  Line containing multiple integer values
	* @return     Stack containing parsed Integer values in FILO order
	*/
	static Stack<Integer> getInts(String str) {
		Stack<Integer> ls = new Stack<Integer>();
		for (String s : str.split(" ")) ls.push(Integer.parseInt(s));
		return ls;
	}
     
	/**
	* Writes simultaneously to output file and console
	* @param str
	* @throws IOException
	*/
	static void writeAndPrint(String str) throws IOException {
		System.out.println(str);
		out.write(str);
		out.newLine();
	}
	
	/**
	 * Simple print to console method
	 * @param o item to print
	 */
	static void print(Object o) {System.out.println(o);}
     
	/**
	* Opens the predefined input file
	* @throws FileNotFoundException
	*/
	static void openIn() throws FileNotFoundException {
		inFile = new FileReader(IN_FILE);
		in = new BufferedReader(inFile);
	}
 
	/**
	* Opens an output file
	* @throws IOException
	*/
	static void openOut() throws IOException {
		outFile = new FileWriter(OUT_FILE);
		out = new BufferedWriter(outFile);
	}
 
	static void reportTime(String msg) {
		print(String.format(msg, (System.currentTimeMillis() - startTime) / 1000.0));
	}
	
	/**
	* Close input and output file and corresponding reader/writer
	*/
	static void closeInAndOut() {
		if (out != null) {
			try {out.close();}
			catch (IOException e) {}
		}
		if (outFile != null) {
			try {out.close();}
			catch (IOException e) {}
		}
		if (in != null) {
			try {out.close();}
			catch (IOException e) {}
		}
		if (inFile != null) {
			try {out.close();}
			catch (IOException e) {}
		}
	}
 
}