import java.io.IOException;
import java.math.BigInteger;
import java.util.HashMap;
import java.util.Map;

import Library.Input;
import Library.Output;

/*************************************************************************
 *  Compilation:  javac Converter.java
 *  Execution:    java Converter
 *  
 *  Converts an integer to and from its base b representation.
 *  No error checking is currently implemented.
 *
 *  Remarks
 *  -------
 *   - See also Integer.toHexString(), Integer.toString(int i, int radix)
 *   - See also Integer.parseInt(String s, int radix)
 *
 *************************************************************************/

class Converter { 

   // converts integer n into a base b string
    static String toString(BigInteger n, int base) {
       // special case
       if (n.equals(BigInteger.valueOf(0))) return "0";

       String digits = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
       String s = "";
       while (n.compareTo(BigInteger.valueOf(0)) > 0) {
          BigInteger d = n.mod(BigInteger.valueOf(base));
          s = digits.charAt(d.intValue()) + s;
          n = n.divide(BigInteger.valueOf(base));
       }
       return s;
    }

    static void inputError(String s) {
        throw new RuntimeException("Input error with" + s);
    }

    // convert a String representing a base b integer into an int
    static BigInteger fromString(String s, int b) {
       BigInteger result = BigInteger.valueOf(0);
       int digit = 0;
       for (int i = 0; i < s.length(); i++) {
          char c = s.charAt(i);
          if (c >= '0' && c <= '9')
             digit = c - '0';
          else if (c >= 'a' && c <= 'z')
             digit = 10 + c - 'a';
          else inputError(s);

          if (digit < b) result = (BigInteger.valueOf(b).multiply(result)).add(BigInteger.valueOf(digit));
          else return null;
       }
       return result;
    }

}


public class Base {

	private static Input in = new Input();
	private static Output out = new Output("output/Base.out");
	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		int T = in.readInt();
		for (int i = 0; i < T; i++) {
			String msg = in.readString();
			Map<String,Integer> map = new HashMap<String,Integer>();
			map.put(String.valueOf(msg.charAt(0)),Integer.valueOf(1));
			int curr = 0;
			for (int j = 1; j < msg.length(); j++) {
				String currChar = String.valueOf(msg.charAt(j));
				if (!map.containsKey(currChar)) {
					map.put(currChar, Integer.valueOf(curr));
					curr++;
					if (curr == 1)
						curr++;
				}
			}
			String currmsg = converToMap(msg, map);
			if (curr == 0 || curr  == 1)
				curr = 2;
			BigInteger currint = Converter.fromString(currmsg, curr);
			
			out.printf("Case #%d: %s\n", i+1, currint.toString());
		}
	}
	private static String converToMap(String msg, Map<String, Integer> map) {
		String ret = "";
		for (int i = 0; i < msg.length(); i++) {
			int x = map.get(String.valueOf(msg.charAt(i))).intValue();
			if (x >= 10) {
				ret = ret.concat(String.valueOf('a' + x - 10));
			} else {
				ret = ret.concat(String.valueOf(x));
			}
		}
		System.err.println(ret);
		return ret;
	}
}
