package me.chiwang.codejam.qualification_round_2017;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.List;
import java.util.PriorityQueue;
import java.util.concurrent.Callable;
import java.util.concurrent.CancellationException;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class ProblemC {

	private static final String DATA_FILE_NAME = "C-small-1-attempt0.in";

	private static final String PACKAGE_PATH = "me.chiwang.codejam.qualification_round_2017".replace(".",
			File.separator);
	private static final String DATA_FILE_PATH = File.separator + PACKAGE_PATH + File.separator + DATA_FILE_NAME;
	private static final String OUTPUT_FILE_PATH = "/home/chiwang/Documents/codejam/"
			+ getOutputFilename(DATA_FILE_NAME);

	private static final int NUM_OF_THREAD = Runtime.getRuntime().availableProcessors();

	private static class Task implements Callable<String> {

		private class Stall implements Comparable<Stall> {
			public final long S;
			public final long left;
			public final long right;
			public final long ls;
			public final long rs;

			public Stall(long left, long right) {
				this.S = left + (right - left) / 2;
				this.left = left;
				this.right = right;
				this.ls = S - left - 1;
				this.rs = right - S - 1;
			}

			public long getMax() {
				return ls > rs ? ls : rs;
			}

			public long getMin() {
				return ls < rs ? ls : rs;
			}

			@Override
			public String toString() {
				return left + ", " + S + ", " + right;
			}

			@Override
			public int compareTo(Stall other) {
				if (this.getMin() > other.getMin()) {
					return -1;
				} else if (this.getMin() < other.getMin()) {
					return 1;
				} else {
					if (this.getMax() > other.getMax()) {
						return -1;
					} else if (this.getMax() < other.getMax()) {
						return 1;
					} else {
						return this.S < other.S ? -1 : 1;
					}
				}
			}
		}

		private int caseNum;
		private long N;
		private long K;

		public Task(int caseNum, long N, long K) {
			this.caseNum = caseNum;
			this.N = N;
			this.K = K;
		}

		@Override
		public String call() throws Exception {
			PriorityQueue<Stall> queue = new PriorityQueue<>();
			queue.add(new Stall(0, N + 1));

			Stall curr = null;
			for (long i = 0; i < K; i++) {
				curr = queue.remove();
				queue.add(new Stall(curr.left, curr.S));
				queue.add(new Stall(curr.S, curr.right));
			}

			return fr(curr.getMax(), curr.getMin());
		}

		private String fr(long max, long min) {
			return String.format("Case #%d: %d %d%n", caseNum, max, min);
		}
	}

	private static void parseInputAndProcess(ExecutorService executorService, List<Future<String>> computedTasks,
			InputStream is) {

		try (BufferedReader br = new BufferedReader(new InputStreamReader(is, StandardCharsets.UTF_8))) {
			final int T = Integer.parseInt(br.readLine());

			for (int caseNum = 1; caseNum <= T; caseNum++) {
				String[] parts = br.readLine().split(" ");
				Future<String> futureResult = executorService
						.submit(new Task(caseNum, Long.parseLong(parts[0]), Long.parseLong(parts[1])));
				computedTasks.add(futureResult);
			}

			executorService.shutdown();

		} catch (NumberFormatException | IOException ex) {
			ex.printStackTrace();
			System.exit(-1);
		}
	}

	public static void main(String[] args) {

		final long startTime = System.currentTimeMillis();

		ClassLoader classloader = Thread.currentThread().getContextClassLoader();
		InputStream is = classloader.getClass().getResourceAsStream(DATA_FILE_PATH);

		List<Future<String>> computedTasks = new ArrayList<>();
		ExecutorService executorService = Executors.newFixedThreadPool(NUM_OF_THREAD);

		parseInputAndProcess(executorService, computedTasks, is);

		try (BufferedWriter bw = new BufferedWriter(new FileWriter(OUTPUT_FILE_PATH))) {
			for (Future<String> result : computedTasks) {
				bw.write(result.get());
			}
		} catch (CancellationException | ExecutionException | InterruptedException | IOException ex) {
			ex.printStackTrace();
			System.exit(-1);
		}

		final long endTime = System.currentTimeMillis();

		System.out.println(String.format("Computation finished in %d seconds.%n", (endTime - startTime) / 1000));
	}

	private static String getOutputFilename(String inputFilename) {
		int idx = inputFilename.lastIndexOf('.');

		if (idx != -1) {
			return inputFilename.substring(0, idx) + ".out";
		} else {
			return inputFilename + ".out";
		}
	}
}
