package cdj2013.pb;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Scanner;

/**
 * Problem B. Lawnmower
 * 
 * Alice and Bob have a lawn in front of their house, shaped like an N metre by M metre rectangle. 
 * 
 * Each year, they try to cut the lawn in some interesting pattern. 
 * They used to do their cutting with shears, which was very time-consuming; 
 * but now they have a new automatic lawnmower with multiple settings, and they want to try it out. 
 * The new lawnmower has a height setting - you can set it to any height h between 1 and 100 millimetres, 
 * and it will cut all the grass higher than h it encounters to height h. 
 * 
 * You run it by entering the lawn at any part of the edge of the lawn; 
 * then the lawnmower goes in a straight line, perpendicular to the edge of the lawn it entered, 
 * cutting grass in a swath 1m wide, until it exits the lawn on the other side. 
 * 
 * The lawnmower's height can be set only when it is not on the lawn.
 * 
 * Alice and Bob have a number of various patterns of grass that they could have on their lawn. 
 * 
 * For each of those, they want to know whether it's possible to cut the grass into this pattern with their new lawnmower. 
 * 
 * Each pattern is described by specifying the height of the grass on each 1m x 1m square of the lawn.
 * 
 * The grass is initially 100mm high on the whole lawn.

Input

The first line of the input gives the number of test cases, T. T test cases follow. Each test case begins with a line containing two integers: N and M. Next follow N lines, with the ith line containing M integers ai,j each, the number ai,j describing the desired height of the grass in the jth square of the ith row.

Output

For each test case, output one line containing "Case #x: y", where x is the case number (starting from 1) and y is either the word "YES" if it's possible to get the x-th pattern using the lawnmower, or "NO", if it's impossible (quotes for clarity only).

Limits

1  T  100.

Small dataset

1  N, M  10.
1  ai,j  2.
Large dataset

1  N, M  100.
1  ai,j  100.

input

-----------
3
3 3
2 1 2
1 1 1
2 1 2
5 5
2 2 2 2 2
2 1 1 1 2
2 1 2 1 2
2 1 1 1 2
2 2 2 2 2
1 3
1 2 1
--------------

output

------
Case #1: YES
Case #2: NO
Case #3: YES
------
 * @author chmin.seo@gmail.com
 *
 */
public class ProblemB {

	/* h : height ( 1 ~ 100 millis ), h   ܵ  ´.
	 */
//	static String FILE_NAME = "B-small-attempt0.in";
	static String FILE_NAME = "B-large.in";
	public static void main(String[] args) throws FileNotFoundException {
//		Scanner scanner = new Scanner(new FileInputStream(new File("b-sample.txt")) ) ;
		Scanner scanner = new Scanner(new FileInputStream(new File(FILE_NAME)) ) ;
		int sample = scanner.nextInt();
		
		for ( int i = 0 ; i < sample ; i++) {
			processSample((i+1), scanner);
		}
	}
	
	static void processSample(int caseNum, Scanner scanner) {
		boolean fail = false;
		int row, col ;
		int [][] lawn = null; 
		row = scanner.nextInt();
		col = scanner.nextInt();
		
		lawn = new int[row][col];
		
		// init
		for( int r = 0 ; r< row ; r++) {
			for( int c = 0 ; c < col ; c++ ) {
				lawn[r][c] = scanner.nextInt();
			}
		}
		
//		printLawn(lawn);
		
		
		// checking
		outer :
		for( int r = 0 ; r < row ; r++) {
			for( int c = 0 ; c < col ; c++) {
				int maxInRow = findMaxValue(lawn, r, true);
				int maxInCol = findMaxValue(lawn, c, false);
				
				int value = lawn[r][c];
				/*
				 * 
				 * i j  X ؼ   R C .
				 * 
				 * R - i ࿡  ū   
				 * C - j   ū   
				 * 
				 * ־  Ϸ  ؾ .
				 * 
				 *  if X < R then X >= C
				 *  
				 *        or
				 *        
				 *  if X < C then X >= R
				 * 
				 * 
				 *   ٸ
				 * 
				 * X < R and X < C
				 * 
				 *   !
				 * 
				 */
				if ( value < maxInRow && value < maxInCol ) {
						fail = true;
						break outer;
				}
				
			}
		}
		
		if ( fail ) {
			System.out.println("Case #" + caseNum + ": NO");
		} else {
			System.out.println("Case #" + caseNum + ": YES");
		}
		
	}
		
	static int findMaxValue(int [][] lawn, int idx, boolean horizontal ) {
		int max = -1;
		if ( horizontal) {
			for ( int c = 0 ; c < lawn[0].length ; c++ ) {
				if ( lawn[idx][c] > max ) {
					max = lawn[idx][c];
				}
			}
		} else {
			for( int r = 0 ; r < lawn.length ; r++) {
				if ( lawn[r][idx] > max) {
					max = lawn[r][idx];
				}
			}
		}
		return max;
	}
	static void printLawn(int [][] L) {
		for( int i = 0 ; i < L.length ; i++ ) {
			for( int j = 0 ; j < L[i].length ; j++ ) {
				System.out.print(L[i][j] + " ");
			}
			System.out.println();
		}
	}
	
	
	
	
	
	
	
	
	
}
