package cdj2013;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Scanner;

/**
 * 
 * Problem

Tic-Tac-Toe-Tomek is a game played on a 4 x 4 square board. 
The board starts empty, except that a single 'T' symbol may appear in one of the 16 squares. 
There are two players: X and O. 
They take turns to make moves, with X starting. 
In each move a player puts her symbol in one of the empty squares. 
Player X's symbol is 'X', and player O's symbol is 'O'.

After a player's move, if there is a row, column or a diagonal containing 4 of that player's symbols, 
or containing 3 of her symbols and the 'T' symbol, 
she wins and the game ends. 
Otherwise the game continues with the other player's move. 

If all of the fields are filled with symbols and nobody won, the game ends in a draw. 

See the sample input for examples of various winning positions.



Given a 4 x 4 board description containing 'X', 'O', 'T' and '.' characters (where '.' represents an empty square), 
describing the current state of a game, determine the status of the Tic-Tac-Toe-Tomek game going on. 

The statuses to choose from are:

"X won" (the game is over, and X won)
"O won" (the game is over, and O won)
"Draw" (the game is over, and it ended in a draw)
"Game has not completed" (the game is not over yet)
If there are empty cells, and the game is not over, you should output "Game has not completed", even if the outcome of the game is inevitable.
Input

The first line of the input gives the number of test cases, T. T test cases follow. Each test case consists of 4 lines with 4 characters each, with each character being 'X', 'O', '.' or 'T' (quotes for clarity only). Each test case is followed by an empty line.

Output

For each test case, output one line containing "Case #x: y", where x is the case number (starting from 1) and y is one of the statuses given above. Make sure to get the statuses exactly right. When you run your code on the sample input, it should create the sample output exactly, including the "Case #1: ", the capital letter "O" rather than the number "0", and so on.

Limits

The game board provided will represent a valid state that was reached through play of the game Tic-Tac-Toe-Tomek as described above.

Small dataset

1  T  10.

Large dataset

1  T  1000.

Sample


Input 
 	
Output 
 
6
XXXT
....
OO..
....

XOXT
XXOO
OXOX
XXOO

XOX.
OX..
....
....

OOXX
OXXX
OX.T
O..O

XXXO
..O.
.O..
T...

OXXX
XO..
..O.
...O

Case #1: X won
Case #2: Draw
Case #3: Game has not completed
Case #4: O won
Case #5: O won
Case #6: O won

Note

Although your browser might not render an empty line after the last test case in the sample input, in a real input file there would be one.
 * @author chmin
 *
 */
public class Problem01 {
//	static String FILE_NAME = "A-small-attempt0.in";
	static String FILE_NAME = "A-large.in";
	
	static char x = 'X';
	static char o = 'O';
	static char t = 'T';
	static char empty = '.';
	
	static char draw = 'D';
	
	static int not_completed = 0;
	
	static StringBuilder sb = new StringBuilder();
	
	static void fillMatrix(char [][] mx) throws FileNotFoundException {
		
		Scanner scanner = new Scanner(new FileInputStream(new File(FILE_NAME)));
		
		int line = Integer.parseInt(scanner.nextLine());
		
		for( int i = 0 ; i < line ; i++ ) {
			checkMatrix((i+1), scanner);
			
		}
	}
	
	static void checkMatrix(int caseNum, Scanner scanner ) {
		char [][] mx = new char [4][4];
		char [] line  = null;
		
		not_completed = 0; // reset
		int cnt_draw = 0;
		char winner = '\0';
		
		boolean winner_found = false;
		
		for( int r = 0 ; r < 4 ; r ++ ) {
			String row = scanner.next();
			if ( row.length() != 4) throw new RuntimeException ("4 chars expected, but not : " + row.length());
			for( int c = 0 ; c < row.length() ; c++ ) {
				mx[r][c] = row.charAt(c);
			}
		}
		
//		System.out.println( "--");
//		printMatrix(mx);
		
		
		// horizontal direction 
		for( int r = 0 ; r < 4 ; r ++ ) {
			line = new char[]{ mx[r][0], mx[r][1], mx[r][2], mx[r][3] };
			winner = checkLine(line);
			if ( winner == x) {
				System.out.println("Case #" + caseNum + ": X won");
				winner_found = true;
				break;
			} else if ( winner == o ) {
				System.out.println("Case #" + caseNum + ": O won");
				winner_found = true;
				break;
			} else if ( winner == draw ) {
				cnt_draw ++ ;
			}
		}
		
		if( winner_found ) {
			return;
		}
		
		// vertical direction 
		for( int c= 0 ; c < 4 ; c ++ ) {
			line = new char[]{ mx[0][c], mx[1][c], mx[2][c], mx[3][c] };
			winner = checkLine(line);
			if ( winner == x) {
				System.out.println("Case #" + caseNum + ": X won");
				winner_found = true;
				break;
			} else if ( winner == o ) {
				System.out.println("Case #" + caseNum + ": O won");
				winner_found = true;
				break;
			}  else if ( winner == draw ) {
				cnt_draw ++ ;
			}
		}
		if( winner_found) {
			return;
		}
		
		// diagonal direction 
		
		line = new char[] {mx[0][0], mx[1][1], mx[2][2], mx[3][3]};
		winner = checkLine(line);
		if ( winner == x) {
			System.out.println("Case #" + caseNum + ": X won");
			winner_found = true;
		
		} else if ( winner == o ) {
			System.out.println("Case #" + caseNum + ": O won");
			winner_found = true;
		}  else if ( winner == draw ) {
			cnt_draw ++ ;
		}
		
		if ( winner_found) return;
		
		line = new char[]{mx[0][3], mx[1][2], mx[2][1], mx[3][0]};
		winner = checkLine(line);
		if ( winner == x) {
			System.out.println("Case #" + caseNum + ": X won");
			winner_found = true;
		
		} else if ( winner == o ) {
			System.out.println("Case #" + caseNum + ": O won");
			winner_found = true;
		}  else if ( winner == draw ) {
			cnt_draw ++ ;
		}
		if ( winner_found) return;
		
		
		if ( not_completed > 0) { // no empty square
			System.out.println("Case #" + caseNum + ": Game has not completed");
		} else {
			System.out.println("Case #" + caseNum + ": Draw");
		}
		
	}
	
	static char checkLine(char [] line) {
		char winner = '\0';
		
		int nx = 0, no = 0, nt = 0;
		for( int i = 0 ; i < line.length ; i++ ) {
			if ( line[i] == empty){
				not_completed++ ;
			}
			else if ( line[i] == o ) no ++;
			else if ( line[i] == x) nx ++;
			else if ( line[i] == t ) nt ++;
		}
		
		
		if ( nt <= 1) {
			if ( nx + nt == 4 ) {
				winner = x;
			} else if ( no + nt == 4) {
				winner = o;
			} else {
				winner = draw;
			}
		}
		
		return winner;
		
	}

	
	static void printMatrix(char [][] mx) {
		for ( int i = 0 ; i < 4 ; i++) {
			for( int j = 0 ; j < 4 ; j++) {
				System.out.print(mx[i][j]);
			}
			System.out.println();
		}
	}
	public static void main(String[] args) throws FileNotFoundException {
		char [][] matrix = new char[4][4];
		
		fillMatrix(matrix);
		
	}
}
