import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.Closeable;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;


public class QuestionA {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------

    private static final BigInteger FOUR = new BigInteger("4");


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] splitLine = line.split(" ");

            long arminMoteSize = Long.parseLong(splitLine[0]);
            int numOtherMotes = Integer.parseInt(splitLine[1]);

            splitLine = bufferedReader.readLine().split(" ");

            List<Integer> moteSizeList = new ArrayList<Integer>();
            for (int i = 0; i < numOtherMotes; i++) {
                moteSizeList.add(Integer.parseInt(splitLine[i]));
            }

            Collections.sort(moteSizeList);

            int numOperations = iterate(arminMoteSize, moteSizeList, 0, moteSizeList.size(), 0);

            bufferedWriter.write("Case #" + (caseNum + 1) + ": " + numOperations + "\n");
            System.out.println("Case #" + (caseNum + 1) + ": " + numOperations);
        }

        bufferedWriter.flush();
    }


    private int iterate(long currentArminMoteSize, List<Integer> moteSizeList, int moteIndex, int moteEndIndex, int turns) {
        if (moteIndex >= moteEndIndex) return turns;

        while (moteIndex < moteEndIndex) {
            int curMote = moteSizeList.get(moteIndex);

            if (curMote < currentArminMoteSize) {
                currentArminMoteSize += curMote;
            } else {
                break;
            }

            moteIndex++;
        }

        if (moteIndex < moteEndIndex) {
            int addition = (turns > moteSizeList.size()) ? Integer.MAX_VALUE : iterate((2 * currentArminMoteSize) - 1, moteSizeList, moteIndex, moteEndIndex, turns + 1);
            int subtract = iterate(currentArminMoteSize, moteSizeList, moteIndex, moteEndIndex - 1, turns + 1);

            if (addition < subtract) {
                return addition;
            } else {
                return subtract;
            }
        }

        return turns;
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionA prog = new QuestionA();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionA inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
