import java.io.FileReader;
import java.io.BufferedReader;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.io.IOException;
import java.io.Closeable;


public class QuestionD {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            int numInputs = Integer.parseInt(bufferedReader.readLine());
            line = bufferedReader.readLine();

            String[] splitLine = line.split(" ");

            if (splitLine != null && splitLine.length == numInputs && numInputs >= 1) {
                int[] numArray = new int[numInputs + 1];

                for (int i = 0; i < splitLine.length; i++) {
                    numArray[i + 1] = Integer.parseInt(splitLine[i]);
                }

                int numSwaps = 0;
                for (int i = 0; i < numArray.length; i++) {
                    if (numArray[i] != i) {
                        int tmpValue = numArray[i];
                        do {
                            int newTmpValue = numArray[tmpValue];
                            numArray[tmpValue] = tmpValue;
                            tmpValue = newTmpValue;
                            numSwaps++;
                        } while (numArray[tmpValue] != tmpValue && tmpValue != i);
                        numArray[i] = tmpValue;
                    }
                }

                String result = (numSwaps * 2) + ".000000";
                bufferedWriter.write("Case #" + (caseNum + 1) + ": " + result + "\n");
                System.out.println("Case #" + (caseNum + 1) + ": " + result);
            } else {
                System.out.println("Something is wrong with case # " + (caseNum + 1) + ". Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionD prog = new QuestionD();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionD inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out. println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
