import java.io.FileReader;
import java.io.BufferedReader;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.io.IOException;
import java.io.Closeable;
import java.util.List;
import java.util.ArrayList;

public class ThemePark {

    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        long numCases = Long.parseLong(line.trim());

        for (long i = 0; i < numCases; i++) {
            line = bufferedReader.readLine();
            String line2 = bufferedReader.readLine();

            if (line == null || line2 == null) {
                System.out.println("Unexpected EOF at case " + (i + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] splitInput = line.trim().split(" ");

            if (splitInput != null && splitInput.length == 3) {
                int maxRuns = Integer.parseInt(splitInput[0]); // roller coaster max runs
                int maxCapacity = Integer.parseInt(splitInput[1]); // max capacity
                int maxGroups = Integer.parseInt(splitInput[2]); // num groups

                splitInput = line2.trim().split(" ");

                if (splitInput != null && splitInput.length == maxGroups) {
                    List<Integer> groupList = new ArrayList<Integer>(splitInput.length); // List of gruop Sizes

                    for (int j = 0; j < splitInput.length; j++) {
                        groupList.add(Integer.parseInt(splitInput[j]));
                    }

                    long totalProfit = 0;
                    int groupIndex = 0;

                    // Simulating the rollercoast runs
                    for (long currentRun = 0; currentRun < maxRuns; currentRun++) {
                        long currentCapacity = maxCapacity;
                        int totalGroupsBoarded = 0;

                        // Making sure the maximum amount of people board in order
                        while (totalGroupsBoarded < maxGroups && groupList.get(groupIndex) <= currentCapacity) {
                            currentCapacity -= groupList.get(groupIndex);
                            groupIndex++;
                            totalGroupsBoarded++;

                            if (groupIndex >= maxGroups) {
                                groupIndex = 0;
                            }
                        }

                        totalProfit += (maxCapacity - currentCapacity);
                    }

                    bufferedWriter.write("Case #" + (i + 1) + ": " + totalProfit + "\n");
                } else {
                    System.out.println("Something is wrong. Failed to match second line: \n\t" + line + "\n\t" + line2);
                }
            } else {
                System.out.println("Something is wrong. Failed to match first line: \n\t" + line + "\n\t" + line2);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // EntryPoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        ThemePark themePark = new ThemePark();

        if (args.length != 2) {
            System.out.println("Usage: java ThemePark inputFile outputFile");
            System.exit(0);
        }

        try {
            themePark.init(args[0], args[1]);
            themePark.execute();
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            themePark.reset();
        }
    }
}
