import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.util.SortedSet;
import java.util.TreeSet;
import java.util.ArrayList;
import java.util.List;
import java.util.Collection;
import java.util.Collections;
import java.math.BigInteger;

public class FairWarning {

    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;

    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int i = 0; i < numCases; i++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (i + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] splitInput = line.split(" ");

            if (splitInput != null && splitInput.length > 0) {
                int n = Integer.parseInt(splitInput[0]); // total Input

                bufferedWriter.write("Case #" + (i + 1) + ": ");
                System.out.print("Case #" + (i + 1) + ": ");

                if (n + 1 != splitInput.length) {
                    System.out.println("Expected " + (n + 1) + " inputs but got " + splitInput.length + ". Data on line is wrong: " + line);
                } else if (n <= 1) {
                    bufferedWriter.write("0");
                } else {
                    SortedSet<BigInteger> bigIntegerSortedSet = new TreeSet<BigInteger>();

                    for (int j = 0; j < n; j++) {
                        bigIntegerSortedSet.add(new BigInteger(splitInput[j + 1]));
                    }

                    List<BigInteger> deltaList = new ArrayList<BigInteger>();
                    BigInteger oldBigInteger = null;
                    for (BigInteger bigInteger : bigIntegerSortedSet) {
                        if (oldBigInteger != null) {
                            deltaList.add(bigInteger.subtract(oldBigInteger));
                        }
                        oldBigInteger = bigInteger;
                    }

                    Collections.sort(deltaList);

                    BigInteger gcd = deltaList.get(0);
                    for (BigInteger bigInteger : deltaList) {
                        gcd = bigInteger.gcd(gcd);

                        if (gcd.compareTo(BigInteger.ONE) == 0) {
                            break;
                        }
                    }

                    BigInteger timeUntilReckoning;
                    if (gcd.equals(BigInteger.ONE)) {
                        timeUntilReckoning = BigInteger.ZERO;
                    } else {
                        timeUntilReckoning = gcd.subtract(bigIntegerSortedSet.first().add(gcd).mod(gcd));

                        if (timeUntilReckoning.compareTo(gcd) == 0) {
                            timeUntilReckoning = BigInteger.ZERO;
                        }
                    }

                    bufferedWriter.write(timeUntilReckoning.toString());
                    System.out.println(timeUntilReckoning.toString());
                }

                bufferedWriter.write("\n");
            } else {
                System.out.println("Something is wrong. Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        FairWarning fairWarning = new FairWarning();

        if (args.length != 2) {
            System.out.println("Usage: java FairWarning inputFile outputFile");
            System.exit(0);
        }

        try {
            fairWarning.init(args[0], args[1]);
            fairWarning.execute();
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            fairWarning.reset();
        }
    }
}
