import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.Closeable;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;


public class QuestionA {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------

    private static final BigInteger FOUR = new BigInteger("4");


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] splitLine = line.split(" ");

            if (splitLine != null && splitLine.length >= 2) {
                BigInteger startRadius = new BigInteger(splitLine[0]);
                BigInteger paint = new BigInteger(splitLine[1]);

                BigInteger nextRadius = startRadius.add(BigInteger.ONE);

                BigInteger smallArea = startRadius.multiply(startRadius);
                BigInteger bigArea = nextRadius.multiply(nextRadius);

                BigInteger delta = bigArea.subtract(smallArea);

                BigInteger numRings = BigInteger.ZERO;
                while (paint.compareTo(BigInteger.ZERO) >= 0) {
                    //System.out.println("Paint: " + paint.toString() + " / delta: " + delta.toString());
                    paint = paint.subtract(delta);
                    delta = delta.add(FOUR);
                    numRings = numRings.add(BigInteger.ONE);
                }

                numRings = numRings.subtract(BigInteger.ONE);

                bufferedWriter.write("Case #" + (caseNum + 1) + ": " + numRings.toString() + "\n");
                System.out.println("Case #" + (caseNum + 1) + ": " + numRings.toString());
            } else {
                System.out.println("Something is wrong. Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionA prog = new QuestionA();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionA inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
