import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;


public class QuestionA {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------

    private static final int NO_COLOR = 0;


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] splitLine = line.split(" ");

            if (splitLine != null && splitLine.length >= 2) {
                int n = Integer.parseInt(splitLine[0]);
                int m = Integer.parseInt(splitLine[1]);

                Set<String> dirExist = new TreeSet<String>();
                for (int i = 0; i < n; i++) {
                    line = bufferedReader.readLine();
                    while (line.length() > 1) {
                        dirExist.add(line);
                        line = line.substring(0, line.lastIndexOf('/'));
                    }
                }

                int numMkdir = 0;
                for (int i = 0; i < m; i++) {
                    line = bufferedReader.readLine();

                    while (line.length() > 1) {
                        if (!dirExist.add(line)) {
                            break;
                        }
                        numMkdir++;
                        line = line.substring(0, line.lastIndexOf('/'));
                    }
                }

                bufferedWriter.write("Case #" + (caseNum + 1) + ": " + numMkdir + "\n");
                System.out.println("Case #" + (caseNum + 1) + ": " + numMkdir);
            } else {
                System.out.println("Something is wrong. Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionA prog = new QuestionA();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionA inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
