import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.Closeable;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;


public class QuestionB {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] splitLine = line.split(" ");

            int numDiamonds = Integer.parseInt(splitLine[0]);
            int x = Integer.parseInt(splitLine[1]);
            int y = Integer.parseInt(splitLine[2]);

            float prob = 0;
            if (x == 0 && y == 0) {
                prob = numDiamonds > 0 ? 1 : 0;
            } else {
                // Figuring out how much needs to already be filled
                int maxHeight = Math.abs(x) + y;
                int minRealmFilledOut = maxHeight / 2;

                if (y == maxHeight) {
                    // No probability required for topmost diamond
                    int getMinDiamondRequiredForLevel = getMinDiamondsRequiredForFillingOutRealm(minRealmFilledOut + 1);
                    if (numDiamonds <= getMinDiamondRequiredForLevel) {
                        prob = 0;
                    } else {
                        prob = 1;
                    }
                } else {
                    int getMinDiamondRequiredForLevel = getMinDiamondsRequiredForFillingOutRealm(minRealmFilledOut);

                    if (numDiamonds < getMinDiamondRequiredForLevel + y + 1) {
                        prob = 0;
                    } else if (numDiamonds > getMinDiamondRequiredForLevel + maxHeight + y) {
                        prob = 1;
                    } else {
                        float bestCase = y + 1;
                        float actualTries = numDiamonds - getMinDiamondRequiredForLevel;

                        float actualSuccess = (2 * (actualTries - bestCase)) + 1;

                        prob = actualSuccess / (2 * actualTries);
                    }
                }
            }

            String probStr = Float.toString(prob);
            if (probStr.length() > 8) {
                probStr = probStr.substring(0, 8);
                prob = Float.parseFloat(probStr);
            }

            bufferedWriter.write("Case #" + (caseNum + 1) + ": " + prob + "\n");
            System.out.println("Case #" + (caseNum + 1) + ": " + prob);
        }

        bufferedWriter.flush();
    }

    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    private static int getMinDiamondsRequiredForFillingOutRealm(int minRealmToFillOut) {
        if (minRealmToFillOut == 0) return 0;

        int someVal = (minRealmToFillOut - 1);
        int coeffForFour = (someVal / 2) * (someVal + 1) + (someVal % 2 != 0 ? (someVal / 2) + 1 : 0);

        return (coeffForFour * 4) + minRealmToFillOut;
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionB prog = new QuestionB();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionB inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
