import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.util.Map;
import java.util.HashMap;


public class QuestionC {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine().trim();

            int numRect = Integer.parseInt(line);

            boolean[][] matrix = new boolean[100][100];

            for (int i = 0; i < numRect; i++) {
                line = bufferedReader.readLine().trim();
                String[] splitLine = line.split(" ");

                int x1 = Integer.parseInt(splitLine[0]);
                int y1 = Integer.parseInt(splitLine[1]);
                int x2 = Integer.parseInt(splitLine[2]);
                int y2 = Integer.parseInt(splitLine[3]);

                int minX = Math.min(x1, x2);
                int maxX = Math.max(x1, x2);
                int minY = Math.min(y1, y2);
                int maxY = Math.max(y1, y2);

                for (int x = minX; x <= maxX; x++) {
                    for (int y = minY; y <= maxY; y++) {
                        matrix[x - 1][y - 1] = true;
                    }
                }
            }

            int count = 1;
            while (iterate(matrix)) {
                count++;
            }

            bufferedWriter.write("Case #" + (caseNum + 1) + ": " + count + "\n");
            System.out.println("Case #" + (caseNum + 1) + ": " + count);
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private boolean iterate(boolean[][] matrix) {
        int numBacteria = 0;
        for (int y = matrix.length - 1; y >= 0; y--) {
            for (int x = matrix.length - 1; x >= 0; x--) {
                if (matrix[y][x]) {
                    // There's a bacteria, and see if it should still survive or die
                    if ((y == 0 || !matrix[y - 1][x]) && (x == 0 || !matrix[y][x - 1])) {
                        matrix[y][x] = false;
                    } else {
                        numBacteria++;
                    }
                } else {
                    if (y != 0 && x != 0 && matrix[y - 1][x] && matrix[y][x - 1]) {
                        matrix[y][x] = true;
                        numBacteria++;
                    }
                }
            }
        }

        return numBacteria > 0;
    }

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionC prog = new QuestionC();

        try {
            String pathPrefix = "D:\\Depot\\google-code\\2010\\round2\\src\\main\\resources\\";
            String filename = "C-small-attempt0";
            prog.init(pathPrefix + filename + ".in", pathPrefix + filename + ".out");

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
