import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.util.Queue;
import java.util.LinkedList;


public class QuestionA {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            Queue<Location> queue = new LinkedList<Location>();

            String[] splitLine = line.split(" ");

            if (splitLine != null && splitLine.length > 1) {
                int numInputs = Integer.parseInt(splitLine[0]);

                for (int i = 0; i < numInputs; i++) {
                    int offset = 1 + (i * 2);

                    boolean isBlue = splitLine[offset].equals("B");
                    int pos = Integer.parseInt(splitLine[offset + 1]);

                    queue.add(new Location(isBlue, pos));
                }

                int totalSteps = 0;
                int oSteps = 0;
                int bSteps = 0;
                int oLastPos = 1;
                int bLastPos = 1;

                while (!queue.isEmpty()) {
                    Location curLoc = queue.remove();
                    int delta = 0;

                    if (curLoc.isBlue) {
                        delta = Math.max(0, getDelta(curLoc.pos, bLastPos) - bSteps) + 1;
                        bLastPos = curLoc.pos;
                        bSteps = 0;
                        oSteps += delta;
                    } else {
                        delta = Math.max(0, getDelta(curLoc.pos, oLastPos) - oSteps) + 1;
                        oLastPos = curLoc.pos;
                        oSteps = 0;
                        bSteps += delta;
                    }

                    totalSteps += delta;
                }

                bufferedWriter.write("Case #" + (caseNum + 1) + ": " + totalSteps + "\n");
                //System.out.println("Case #" + (caseNum + 1) + ": " + totalSteps);
            } else {
                System.out.println("Something is wrong. Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private int getDelta(int val1, int val2) {
        if (val1 > val2) {
            return val1 - val2;
        }
        return val2 - val1;
    }


    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Class - Private
    //-------------------------------------------------------------

    private class Location {
        public boolean isBlue;
        public int pos;

        public Location(boolean isBlue, int pos) {
            this.isBlue = isBlue;
            this.pos = pos;
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionA prog = new QuestionA();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionA inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out. println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
