import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.util.regex.Pattern;
import java.util.regex.Matcher;

public class SnapperChain {

    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        Pattern pattern = Pattern.compile("(\\d+?)\\W+?(\\d+?)\\W*", Pattern.DOTALL);

        String line = bufferedReader.readLine();
        long numCases = Long.parseLong(line.trim());

        for (long i = 0; i < numCases; i++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (i + 1) + ", expected " + (numCases + 1));
                break;
            }

            Matcher matcher = pattern.matcher(line);

            if (matcher.matches()) {
                int n = Integer.parseInt(matcher.group(1));
                int k = Integer.parseInt(matcher.group(2));

                if (n == 0 || k == 0) {
                    bufferedWriter.write("Case #" + (i + 1) + ": OFF\n");
                } else {
                    int modVal = 1 << n;
                    int testVal = k % modVal;

                    boolean isOn = (testVal == (modVal - 1));

                    bufferedWriter.write("Case #" + (i + 1) + ": " + (isOn ? "ON" : "OFF") + "\n");
                }
            } else {
                System.out.println("Something is wrong. Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        SnapperChain snapperChain = new SnapperChain();

        if (args.length != 2) {
            System.out.println("Usage: java SnapperChain inputFile outputFile");
            System.exit(0);
        }

        try {
            snapperChain.init(args[0], args[1]);
            snapperChain.execute();
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            snapperChain.reset();
        }
    }
}
