import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;


public class QuestionC {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            int numCandy = Integer.parseInt(bufferedReader.readLine());
            line = bufferedReader.readLine();

            String[] splitLine = line.split(" ");

            if (splitLine != null && splitLine.length == numCandy && numCandy > 1) {
                int xorValue = 0;
                int total = 0;
                int min = Integer.MAX_VALUE;

                for (int i = 0; i < splitLine.length; i++) {
                    int val = Integer.parseInt(splitLine[i]);
                    total += val;
                    xorValue = xorValue ^ val;
                    if (val < min) min = val;
                }

                String result = (xorValue == 0) ? Integer.toString(total - min) : "NO";

                bufferedWriter.write("Case #" + (caseNum + 1) + ": " + result + "\n");
                System.out.println("Case #" + (caseNum + 1) + ": " + result);
            } else {
                System.out.println("Something is wrong with case # " + (caseNum + 1) + ". Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionC prog = new QuestionC();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionC inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out. println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
