import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.util.Set;
import java.util.TreeSet;
import java.util.List;
import java.util.ArrayList;


public class QuestionB {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] splitLine = line.split(" ");

            if (splitLine != null && splitLine.length >= 2) {
                int n = Integer.parseInt(splitLine[0]);
                long k = Integer.parseInt(splitLine[1]);
                long b = Integer.parseInt(splitLine[2]);
                long t = Integer.parseInt(splitLine[3]);

                int numChicksCanReachBarn = 0;
                int numChicksProcessed = 0;
                boolean[] canMakeToEnd = new boolean[n];
                String[] distanceLine = bufferedReader.readLine().split(" ");
                String[] speedLine = bufferedReader.readLine().split(" ");
                for (int i = n - 1; i >= 0 && numChicksCanReachBarn < k; i--) {
                    long distance = Integer.parseInt(distanceLine[i]);
                    long speed = Integer.parseInt(speedLine[i]);

                    numChicksProcessed++;

                    long locationAfterTime = (speed * t) + distance;
                    if (locationAfterTime >= b) {
                        canMakeToEnd[i] = true;
                        numChicksCanReachBarn++;
                    }
                }

                String strSwap;

                if (numChicksCanReachBarn < k) {
                    strSwap = "IMPOSSIBLE";
                } else {
                    int numSwaps = 0;
                    int theEnd = n - numChicksProcessed;
                    for (int i = n - numChicksProcessed + 1; i < n; i++) {
                        if (!canMakeToEnd[i]) {
                            numSwaps += (i - theEnd);
                            theEnd++;
                        }
                    }

                    strSwap = "" + numSwaps;
                }

                bufferedWriter.write("Case #" + (caseNum + 1) + ": " + strSwap + "\n");
                System.out.println("Case #" + (caseNum + 1) + ": " + strSwap);
            } else {
                System.out.println("Something is wrong. Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionB prog = new QuestionB();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionB inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
