import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.util.List;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import java.util.Vector;
import java.math.BigInteger;


public class MakeItSmooth {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------

    private static final int DIFF = 0;
    private static final int DELETE = 1;
    private static final int INSERT = 2;

    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] splitLine = line.split(" ");

            if (splitLine != null && splitLine.length >= 4) {
                int deleteCost = Integer.parseInt(splitLine[0]);
                int insertCost = Integer.parseInt(splitLine[1]);
                int maxSmooth = Integer.parseInt(splitLine[2]);
                int n = Integer.parseInt(splitLine[3]);

                Vector<Integer> list = new Vector<Integer>();

                line = bufferedReader.readLine();
                splitLine = line.split(" ");
                for (int i = 0; i < n; i++) {
                    list.add(Integer.parseInt(splitLine[i]));
                }

                int cost = 0;
                for (int i = 0; i < list.size() - 1; i++) {
                    int curVal = list.get(i);
                    int nextVal = list.get(i + 1);
                    int diff = Math.abs(nextVal - curVal);

                    if (diff <= maxSmooth) {
                        continue;
                    } else {
                        int numInserts = (int) Math.ceil((double) diff / maxSmooth);
                        int costOfInserts = numInserts * insertCost;

                        int action = DIFF;
                        int currentCost = Math.abs(diff - maxSmooth);
                        if (deleteCost < currentCost) {
                            action = DELETE;
                        }
                        if (costOfInserts < currentCost && maxSmooth > 0) {
                            action = INSERT;
                        }

                        switch (action) {
                            case DELETE:
                                list.remove(i + 1);
                                i--;
                                cost += deleteCost;
                                break;

                            case INSERT:
                                int valToInsert = 0;
                                if (nextVal > curVal) {
                                    valToInsert = curVal + maxSmooth;
                                } else {
                                    valToInsert = curVal - maxSmooth;
                                }

                                list.insertElementAt(valToInsert, i + 1);
                                cost += insertCost;
                                break;

                            case DIFF:
                                int valToChangeTo = curVal + maxSmooth;
                                if (i + 2 < list.size() - 1) {

                                    int secondVal = list.get(i + 2);
                                    if (curVal > secondVal) {
                                        valToChangeTo = Math.max(curVal - maxSmooth, secondVal);
                                    } else {
                                        valToChangeTo = Math.min(curVal + maxSmooth, secondVal);
                                    }
                                }
                                list.insertElementAt(valToChangeTo, i + 1);
                                list.removeElementAt(i + 2);

                                cost += Math.abs(nextVal - valToChangeTo);
                                break;
                        }
                    }
                }

                bufferedWriter.write("Case #" + (caseNum + 1) + ": " + cost + "\n");
                System.out.println("Case #" + (caseNum + 1) + ": " + cost);
            } else {
                System.out.println("Something is wrong. Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        MakeItSmooth prog = new MakeItSmooth();

        if (args.length != 2) {
            System.out.println("Usage: java MakeItSmooth inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
