import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.Closeable;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;


public class QuestionA {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------

    private static final char PLAYER_X = 'X';
    private static final char PLAYER_O = 'O';
    private static final char PIECE_T = 'T';
    private static final char PIECE_EMPTY = '.';


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        char[][] board = new char[4][4];

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            boolean error = false;

            for (int i = 0 ; i < 4 ; i++) {
                line = bufferedReader.readLine();
                if (line == null || line.length() != 4) {
                    System.out.println("Unexpected EOF at case " + (caseNum + 1) + ", expected " + (numCases + 1));
                    error = true;
                    break;
                }
                board[i] = line.toCharArray();
            }

            if (error) {
                break;
            }

            WinnerResult result = findWinner(board);

            if (result.winner == PLAYER_X) {
                bufferedWriter.write("Case #" + (caseNum + 1) + ": X Won\n");
            } else if (result.winner == PLAYER_O) {
                bufferedWriter.write("Case #" + (caseNum + 1) + ": O Won\n");
            } else if (result.gameOver) {
                bufferedWriter.write("Case #" + (caseNum + 1) + ": Draw\n");
            } else {
                bufferedWriter.write("Case #" + (caseNum + 1) + ": Game has not completed\n");
            }

            bufferedReader.readLine();
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private WinnerResult findWinner(char[][] board) {
        boolean boardHasEmptySpots = false;
        int countX = 0;
        int countO = 0;

        // Check Winner Horizontal
        for (int i = 0; i < board.length; i++) {
            countX = 0;
            countO = 0;

            for (int k = 0; k < board[i].length; k++) {
                char elem = board[i][k];
                if (elem == PIECE_T) {
                    countX++;
                    countO++;
                } else if (elem == PLAYER_X) {
                    countX++;
                } else if (elem == PLAYER_O) {
                    countO++;
                } else {
                    boardHasEmptySpots = true;
                }
            }

            if (countX == board.length) {
                return new WinnerResult(PLAYER_X, true);
            } else if (countO == board.length) {
                return new WinnerResult(PLAYER_O, true);
            }
        }

        // Check Winner Vertical
        for (int k = 0; k < board[0].length; k++) {
            countX = 0;
            countO = 0;

            for (int i = 0; i < board.length; i++) {
                char elem = board[i][k];
                if (elem == PIECE_T) {
                    countX++;
                    countO++;
                } else if (elem == PLAYER_X) {
                    countX++;
                } else if (elem == PLAYER_O) {
                    countO++;
                } else {
                    boardHasEmptySpots = true;
                }
            }

            if (countX == board.length) {
                return new WinnerResult(PLAYER_X, true);
            } else if (countO == board.length) {
                return new WinnerResult(PLAYER_O, true);
            }
        }

        // Check Diagonal top-left to bottom-right
        countX = 0;
        countO = 0;
        for (int i = 0; i < board.length; i++) {
            char elem = board[i][i];
            if (elem == PIECE_T) {
                countX++;
                countO++;
            } else if (elem == PLAYER_X) {
                countX++;
            } else if (elem == PLAYER_O) {
                countO++;
            }

            if (countX == board.length) {
                return new WinnerResult(PLAYER_X, true);
            } else if (countO == board.length) {
                return new WinnerResult(PLAYER_O, true);
            }
        }

        // Check Diagonal bottom-left to top-right
        countX = 0;
        countO = 0;
        for (int i = 0; i < board.length; i++) {
            char elem = board[board.length - 1 - i][i];
            if (elem == PIECE_T) {
                countX++;
                countO++;
            } else if (elem == PLAYER_X) {
                countX++;
            } else if (elem == PLAYER_O) {
                countO++;
            }

            if (countX == board.length) {
                return new WinnerResult(PLAYER_X, true);
            } else if (countO == board.length) {
                return new WinnerResult(PLAYER_O, true);
            }
        }

        return new WinnerResult(PIECE_EMPTY, !boardHasEmptySpots);
    }


    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Class - Private
    //-------------------------------------------------------------

    private class WinnerResult {
        public char winner;
        public boolean gameOver;

        private WinnerResult(char winner, boolean gameOver) {
            this.winner = winner;
            this.gameOver = gameOver;
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionA prog = new QuestionA();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionA inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
