import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.util.Map;
import java.util.HashMap;
import java.util.Stack;
import java.util.List;
import java.util.ArrayList;


public class QuestionB {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------

    private static int MAX_NUM_ASCII_CHARS = 128;


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            Map<Integer, Character> combinationMap = new HashMap<Integer, Character>();
            Map<Character, Character> opposeMap = new HashMap<Character, Character>();

            String[] splitLine = line.split(" ");

            if (splitLine != null && splitLine.length > 1) {
                int numCombinations = Integer.parseInt(splitLine[0]);

                for (int i = 0; i < numCombinations; i++) {
                    String combo = splitLine[i + 1];
                    int value = combineCharToInt(combo.charAt(0), combo.charAt(1));
                    combinationMap.put(value, combo.charAt(2));
                }

                int numOppose = Integer.parseInt(splitLine[1 + numCombinations]);

                for (int i = 0; i < numOppose; i++) {
                    String oppose = splitLine[i + 2 + numCombinations];
                    opposeMap.put(oppose.charAt(0), mapCharToSub(oppose.charAt(1)));
                    opposeMap.put(oppose.charAt(1), mapCharToSub(oppose.charAt(0)));
                }

                Stack<Character> stack = new Stack<Character>();

                int numInvokeChars = Integer.parseInt(splitLine[numCombinations + numOppose + 2]);
                if (numInvokeChars > 0) {
                    String invokeList = splitLine[numCombinations + numOppose + 3];

                    if (numInvokeChars != invokeList.length()) {
                        System.out.println("--------Error #" + caseNum + "------: " + numInvokeChars + " vs "+ invokeList.length());
                    } else {
                        int[] letterBucket = new int[8];

                        for (int i = 0; i < numInvokeChars; i++) {
                            char curChar = invokeList.charAt(i);
                            boolean completed = false;

                            // Combine first
                            if (!stack.isEmpty()) {
                                Character transformedChar = combinationMap.get(combineCharToInt(stack.peek(), curChar));
                                if (transformedChar != null) {
                                    // Combined
                                    letterBucket[mapCharToSub(stack.pop())]--;
                                    stack.push(transformedChar);
                                    completed = true;
                                }
                            }

                            if (!completed) {
                                Character opposeC = opposeMap.get(curChar);
                                if (opposeC != null && letterBucket[opposeC] > 0) {
                                    // Opposing elements cleared out invocation list
                                    for (int j = 0; j < letterBucket.length; j++) {
                                        letterBucket[j] = 0;
                                    }
                                    stack.clear();
                                } else {
                                    stack.push(curChar);
                                    letterBucket[mapCharToSub(curChar)]++;
                                }
                            }
                        }
                    }
                }

                StringBuilder sb = new StringBuilder("[");
                if (!stack.isEmpty()) {
                    char[] charArray = new char[stack.size()];
                    while (!stack.isEmpty()) {
                        int size = stack.size();
                        charArray[size - 1] = stack.pop();
                    }

                    for (int i = 0; i < charArray.length - 1; i++) {
                        sb.append(charArray[i]);
                        sb.append(", ");
                    }
                    sb.append(charArray[charArray.length - 1]);
                }
                sb.append("]");

                String result = sb.toString();
                bufferedWriter.write("Case #" + (caseNum + 1) + ": " + result + "\n");
                System.out.println("Case #" + (caseNum + 1) + ": " + result);
            } else {
                System.out.println("Something is wrong. Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private int combineCharToInt(char c1, char c2) {
        if (c1 > c2) {
            return (c2 * MAX_NUM_ASCII_CHARS) + c1;
        }
        return (c1 * MAX_NUM_ASCII_CHARS) + c2;
    }


    private char mapCharToSub(char c) {
        switch (c) {
            case 'A':
                return 0;
            case 'D':
                return 1;
            case 'E':
                return 2;
            case 'F':
                return 3;
            case 'Q':
                return 4;
            case 'R':
                return 5;
            case 'S':
                return 6;
            case 'W':
                return 7;
            default:
                return Character.MAX_VALUE;
        }
    }


    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionB prog = new QuestionB();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionB inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out. println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
