import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Closeable;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.util.List;
import java.util.ArrayList;
import java.util.Collections;
import java.math.BigInteger;


public class Rotate {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------

    private static final int NO_COLOR = 0;
    private static final int RED_COLOR = 1;
    private static final int BLUE_COLOR = 2;


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        for (int i = 0; i < numCases; i++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (i + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] splitLine = line.split(" ");

            if (splitLine != null && splitLine.length >= 2) {
                int n = Integer.parseInt(splitLine[0]);
                int k = Integer.parseInt(splitLine[1]);
                int[][] matrix = new int[n][n];

                // Filling out the matrix rotated
                for (int p = 0; p < n; p++) {
                    line = bufferedReader.readLine();
                    //System.out.println(line);
                    int actualY = n - 1;
                    for (int q = n - 1; q >= 0; q--) {
                    //for (int q = 0; q < n; q++) {
                        if (line.charAt(q) == 'R') {
                            matrix[actualY][n - p - 1] = RED_COLOR;
                            actualY--;
                        } else if (line.charAt(q) == 'B') {
                            matrix[actualY][n - p - 1] = BLUE_COLOR;
                            actualY--;
                        }
                    }
                }
                /*System.out.println("---------" + k + "----------");

                for (int p = 0; p < n; p++) {
                    StringBuilder sb = new StringBuilder();
                    for (int q = 0; q < n; q++) {
                        if (matrix[p][q] == RED_COLOR) {
                            sb.append("R");
                        } else if (matrix[p][q] == BLUE_COLOR) {
                            sb.append("B");
                        } else {
                            sb.append(".");
                        }
                    }
                    System.out.println(sb);
                }*/

                int max_r_in_row = 0;
                int max_b_in_row = 0;

                for (int p = 0; p < n; p++) {
                    for (int q = 0; q < n; q++) {
                        int val = matrix[p][q];
                        if (val != NO_COLOR) {
                            int max = findRowCount(matrix, n, p, q, val);

                            if (val == RED_COLOR) {
                                if (max > max_r_in_row) {
                                    max_r_in_row = max;
                                }
                            } else {
                                if (max > max_b_in_row) {
                                    max_b_in_row = max;
                                }
                            }
                        }
                    }
                }

                String str = "";
                if (max_r_in_row >= k && max_b_in_row >= k) {
                    str = "Both";
                } else if (max_r_in_row >= k) {
                    str = "Red";
                } else if (max_b_in_row >= k) {
                    str = "Blue";
                } else {
                    str = "Neither";
                }

                bufferedWriter.write("Case #" + (i + 1) + ": " + str + "\n");
                System.out.println("Case #" + (i + 1) + ": " + str);
            } else {
                System.out.println("Something is wrong. Failed to match: " + line);
            }
        }

        bufferedWriter.flush();
    }


    private int findRowCount(int[][] matrix, int n, int p, int q, int color) {
        int max_count = 0;
        int horizontalCount = 0;
        for (int i = q; i < n; i++) {
            if (matrix[p][i] == color) {
                horizontalCount++;
            } else {
                break;
            }
        }
        max_count = horizontalCount;

        int verticalCount = 0;
        for (int j = p; j < n; j++) {
            if (matrix[j][q] == color) {
                verticalCount++;
            } else {
                break;
            }
        }

        max_count = Math.max(max_count, verticalCount);

        int diagonalRight = 0;
        for (int i = 0; (p + i) < n && (q + i) < n; i++) {
            if (matrix[p + i][q + i] == color) {
                diagonalRight++;
            } else {
                break;
            }
        }

        max_count = Math.max(max_count, diagonalRight);

        int diagonalLeft = 0;
        for (int i = 0; (p + i) < n && (q - i) >= 0; i++) {
            if (matrix[p + i][q - i] == color) {
                diagonalLeft++;
            } else {
                break;
            }
        }

        return Math.max(max_count, diagonalLeft);
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        Rotate prog = new Rotate();

        if (args.length != 2) {
            System.out.println("Usage: java Rotate inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
