import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.Closeable;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;


public class QuestionC {

    //-------------------------------------------------------------
    // Constants - Private - Static
    //-------------------------------------------------------------

    private static final BigInteger TWO = new BigInteger("2");


    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private FileReader fileReader = null;
    private BufferedReader bufferedReader = null;

    private FileWriter fileWriter = null;
    private BufferedWriter bufferedWriter = null;


    //-------------------------------------------------------------
    // Methods - Public
    //-------------------------------------------------------------

    public void init(String inputFileName, String outputFileName)
            throws IOException {
        reset();

        fileReader = new FileReader(inputFileName);
        bufferedReader = new BufferedReader(fileReader);

        fileWriter = new FileWriter(outputFileName);
        bufferedWriter = new BufferedWriter(fileWriter);
    }


    public void reset() {
        closeCloseable(bufferedReader);
        closeCloseable(fileReader);

        closeCloseable(bufferedWriter);
        closeCloseable(fileWriter);

        bufferedReader = null;
        fileReader = null;
        bufferedWriter = null;
        fileWriter = null;
    }


    public void execute()
            throws IOException {
        String line = bufferedReader.readLine();
        int numCases = Integer.parseInt(line.trim());

        BigInteger maxValue = null;
        List<TestCase> testCaseList = new ArrayList<TestCase>();
        for (int caseNum = 0; caseNum < numCases; caseNum++) {
            line = bufferedReader.readLine();

            if (line == null) {
                System.out.println("Unexpected EOF at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            String[] split = line.split(" ");

            if (split.length != 2) {
                System.out.println("Unexpected split at line " + (caseNum + 1) + ", expected " + (numCases + 1));
                break;
            }

            BigInteger lowerBound = new BigInteger(split[0]);
            BigInteger upperBound = new BigInteger(split[1]);

            if (maxValue == null) {
                maxValue = upperBound;
            } else {
                maxValue = maxValue.max(upperBound);
            }

            testCaseList.add(new TestCase(lowerBound, upperBound));
        }

        // Doing the test
        List<BigInteger> memoizedList = generateMemoizedList(maxValue);
        for (int caseNum = 0; caseNum < testCaseList.size(); caseNum++) {
            TestCase testCase = testCaseList.get(caseNum);
            int counter = 0;

            for (int i = 0; i < memoizedList.size(); i++) {
                BigInteger cmp = memoizedList.get(i);
                if (cmp.compareTo(testCase.lowerBound) >= 0 && cmp.compareTo(testCase.upperBound) <= 0) {
                    counter++;
                }
            }

            bufferedWriter.write("Case #" + (caseNum + 1) + ": " + counter + "\n");
        }

        bufferedWriter.flush();
    }


    //-------------------------------------------------------------
    // Methods - Private
    //-------------------------------------------------------------

    private BigInteger squareRoot(BigInteger bigInteger) {
        BigInteger delta = bigInteger.divide(TWO);
        BigInteger guess = delta;

        while (true) {
            BigInteger guessedSquare = guess.multiply(guess);
            int comparison = guessedSquare.compareTo(bigInteger);
            if (comparison == 0) {
                return guess;
            }

            // Break if you can't adjust further
            if (delta.compareTo(BigInteger.ONE) <= 0) {
                break;
            }

            delta = delta.divide(TWO);
            if (guessedSquare.compareTo(bigInteger) < 0) {
                guess = guess.add(delta);
            } else {
                guess = guess.subtract(delta);
            }
        }

        return guess;
    }

    private boolean isPalindrome(BigInteger bigInteger) {
        String str = bigInteger.toString();
        for (int i = 0; i < str.length() / 2; i++) {
            if (str.charAt(i) != str.charAt(str.length() - 1 - i)) {
                return false;
            }
        }
        return true;
    }


    private List<BigInteger> generateMemoizedList(BigInteger max) {
        List<BigInteger> list = new ArrayList<BigInteger>();

        BigInteger squaredUpperBound = max;

        BigInteger upperBound = squareRoot(squaredUpperBound).add(BigInteger.ONE);

        BigInteger current = BigInteger.ONE;

        while (current.compareTo(upperBound) <= 0) {
            if (isPalindrome(current)) {
                BigInteger square = current.multiply(current);

                if (square.compareTo(squaredUpperBound) > 0) {
                    break;
                }

                if (isPalindrome(square)) {
                    list.add(square);
                }
            }

            current = current.add(BigInteger.ONE);
        }

        return list;
    }


    private void closeCloseable(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException e) {
                System.err.println("Failed to close closeable: " + e);
            }
        }
    }


    //-------------------------------------------------------------
    // Class - Private
    //-------------------------------------------------------------

    private class TestCase {
        public BigInteger lowerBound;
        public BigInteger upperBound;

        private TestCase(BigInteger lowerBound, BigInteger upperBound) {
            this.lowerBound = lowerBound;
            this.upperBound = upperBound;
        }
    }


    //-------------------------------------------------------------
    // Entrypoint
    //-------------------------------------------------------------

    public static void main(String[] args) {
        QuestionC prog = new QuestionC();

        if (args.length != 2) {
            System.out.println("Usage: java QuestionC inputFile outputFile");
            System.exit(0);
        }

        try {
            prog.init(args[0], args[1]);

            long startTime = System.currentTimeMillis();

            prog.execute();

            System.out.println("Runtime: " + ((System.currentTimeMillis() - startTime) / 1000));
        } catch (IOException e) {
            System.err.println(e);
        } finally {
            prog.reset();
        }
    }
}
