package com.codejam.qualification.b;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Locale;

/**
 * @author Christiaan Verpooten
 * @since 12/04/14
 */
public class Main {

    private void execute(String inputPath, String outputPath) throws IOException {
        BufferedReader reader = new BufferedReader(new FileReader(inputPath));
        BufferedWriter writer = new BufferedWriter(new FileWriter(outputPath));
        try {
            int numberOfCases = Integer.valueOf(reader.readLine());
            for (int i = 0; i < numberOfCases; i++) {
                String[] lineValues = reader.readLine().split(" ");
                double factoryCost = Double.valueOf(lineValues[0]);
                double cookieIncrease = Double.valueOf(lineValues[1]);
                double target = Double.valueOf(lineValues[2]);
                int numberOfFactories = 0;
                while(!isOptimal(numberOfFactories, factoryCost, cookieIncrease, target)) {
                    numberOfFactories++;
                }
                writer.write(String.format(Locale.US, "Case #%d: %.7f", i + 1, calculateSeconds(numberOfFactories, factoryCost, cookieIncrease, target)));
                writer.newLine();
            }
        } finally {
            reader.close();
            writer.close();
        }
    }

    private boolean isOptimal(int numberOfFactories, double factoryCost, double cookieIncrease, double target) {
        return (( numberOfFactories * cookieIncrease + 2.0) / (((numberOfFactories + 1) * cookieIncrease + 2 ))) + (factoryCost/target) >= 1.0;
    }

    private double calculateSeconds(int numberOfFactories, double factoryCost, double cookieIncrease, double target) {
        double factoryTime = 0.0f;
        for (int i = 0; i < numberOfFactories; i++) {
            factoryTime += (factoryCost / (2.0 + i * cookieIncrease));
        }
        return factoryTime + (target / (2.0 + numberOfFactories * cookieIncrease));
    }

    public static void main(String[] args) throws IOException {
        Main main = new Main();
        main.execute("C:\\Temp\\qualification\\b-large.in", "C:\\Temp\\qualification\\b-large.out");
    }
}
