package com.codejam.qualification.d;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Locale;

/**
 * @author Christiaan Verpooten
 * @since 12/04/14
 */
public class Main {

    private void execute(String inputPath, String outputPath) throws IOException {
        BufferedReader reader = new BufferedReader(new FileReader(inputPath));
        BufferedWriter writer = new BufferedWriter(new FileWriter(outputPath));
        try {
            int numberOfCases = Integer.valueOf(reader.readLine());
            for (int i = 0; i < numberOfCases; i++) {
                int numberOfBlocks = Integer.valueOf(reader.readLine());
                List<Double> naomiBlocks = readBlockWeights(reader);
                List<Double> kenBlocks = readBlockWeights(reader);
                int warScore = getWarScore(naomiBlocks, kenBlocks);
                int deceitfulWarScore = getDeceitfulWarScore(naomiBlocks, kenBlocks);
                writer.write(String.format(Locale.US, "Case #%d: %d %d", i + 1, deceitfulWarScore, warScore));
                writer.newLine();

            }
        } finally {
            reader.close();
            writer.close();
        }
    }

    private int getWarScore(List<Double> naomiBlocks, List<Double> kenBlocks) {
        int result = 0;
        List<Double> naomiBlocksCopy = new ArrayList<>(naomiBlocks);
        List<Double> kenBlocksCopy = new ArrayList<>(kenBlocks);
        for(Double naomiWeight : naomiBlocksCopy) {
            Double kenWeight = selectWarOptimal(kenBlocksCopy, naomiWeight);
            if(naomiWeight > kenWeight) {
                result++;
            }
            kenBlocksCopy.remove(kenWeight);
        }
        return result;
    }

    private int getDeceitfulWarScore(List<Double> naomiBlocks, List<Double> kenBlocks) {
        int result = 0;
        List<Double> naomiBlocksCopy = new ArrayList<>(naomiBlocks);
        List<Double> kenBlocksCopy = new ArrayList<>(kenBlocks);
        for(Double naomiWeight : naomiBlocksCopy) {
            if(naomiWeight < kenBlocksCopy.get(0)) {
                kenBlocksCopy.remove(kenBlocksCopy.size() - 1);
            } else {
                kenBlocksCopy.remove(0);
                result++;
            }
        }
        return result;
    }



    private Double selectWarOptimal(List<Double> options, double shownWeight) {
        for(Double option : options) {
            if(option > shownWeight) {
                return option;
            }
        }
        return options.get(0);
    }

    private List<Double> readBlockWeights(BufferedReader reader) throws IOException {
        String[] blockWeightStrings = reader.readLine().split(" ");
        List<Double> result = new ArrayList<>();
        for(String weightString : blockWeightStrings) {
            result.add(Double.valueOf(weightString));
        }
        Collections.sort(result);
        return result;
    }

    public static void main(String[] args) throws IOException {
        Main main = new Main();
        main.execute("C:\\Temp\\qualification\\d-large.in", "C:\\Temp\\qualification\\d-large.out");
    }
}
