import java.util.ArrayList;
import java.util.Scanner;

public class Rotate {

    public static final int EMPTY = -1;
    public static final int RED = 0;
    public static final int BLUE = 1;
    
    private static final int[] ROWROT = { 6, 5, 4, 3, 2, 1, 0 };

    public static void main (String[] args) {
    
        Scanner sc = new Scanner(System.in);
        int numCases = sc.nextInt();
        ArrayList<int[][]> boards = new ArrayList<int[][]>(numCases);
        int[] ks = new int[numCases];
        for (int i = 0; i < numCases; ++i) {
            int n = sc.nextInt();
            ks[i] = sc.nextInt();
            int[][] temp = new int[n][n];
            for (int j = 0; j < n; ++j) {
                String line = sc.next().trim();
                for (int m = 0; m < line.length(); ++m) {
                    switch (line.charAt(m)) {
                        case '.':
                            temp[j][m] = EMPTY;
                            break;
                        case 'R':
                            temp[j][m] = RED;
                            break;
                        case 'B':
                            temp[j][m] = BLUE;
                            break;
                        default:
                            System.err.println("bad input");
                            break;
                    }
                }
            }
            boards.add(temp);
        }
        
        for (int i = 0; i < numCases; ++i) {
            int temp[][] = rotate(boards.remove(i));
            boards.add(i, gravity(temp));
        }
        
        for (int i = 0; i < numCases; ++i) {
            //print (boards.get(i));
            System.out.print("Case #" + (i+1) + ": ");
            boolean bluewon = winner(ks[i], BLUE, boards.get(i));
            boolean redwon = winner(ks[i], RED, boards.get(i));
            if (bluewon && redwon) {
                System.out.println("Both");
            }
            else if (bluewon) {
                System.out.println("Blue");
            }
            else if (redwon) {
                System.out.println("Red");
            }
            else {
                System.out.println("Neither");
            }
        }
    }
    
    private static int[][] gravity (int[][] orig) {
        int n = orig.length;
        int[][] result = new int[n][n];
    
        for (int c = 0; c < n; ++c) {
            int top = n-1;
            for (int r = n-1; r >= 0; --r) {
                if (orig[r][c] != EMPTY) {
                    result[top][c] = orig[r][c];
                    --top;
                }
            }
            for (int r = 0; r <= top; ++r) {
                result[r][c] = EMPTY;
            }
        }
        
        return result;
    }
    
    // for debugging
    private static void print (int[][] in) {
        for (int a = 0; a < in.length; ++a) {
            for (int b = 0; b < in.length; ++b) {
                if (in[a][b] == EMPTY) {
                    System.out.print(".");
                }
                else if (in[a][b] == RED) {
                    System.out.print("R");
                }
                else if (in[a][b] == BLUE) {
                    System.out.print("B");
                }
            }
            System.out.println();
        }
        System.out.println();
    }
    
    private static int[][] rotate (int[][] orig) {
        int n = orig.length;
        int[][] result = new int[n][n];
        for (int x = 0; x < n; ++x) {
            for (int y = 0; y < n; ++y) {
                result[y][n-1-x] = orig[x][y];
            }
        }
        return result;
    }
    
    private static boolean winner (int k, int color, int[][] board) {
        int n = board.length;
        int[] cols = new int[n];
        for (int r = 0; r < n; ++r) {
            int inarow = 0;
            for (int c = 0; c < n; ++c) {
                if (board[r][c] == color) {
                    ++inarow;
                    ++cols[c];
                    if (inarow >= k || cols[c] >= k) {
                        return true;
                    }
                }
                else {
                    inarow = 0;
                    cols[c] = 0;
                }
            }
        }

        for (int r = n-1; r >= 0; --r) {
            for (int c = 0; c < n; ++c) {
                int leftdiag = 0;
                for (int c2 = c, r2 = r; c2 >=0 && r2 >= 0; --c2, --r2) {
                    if (board[r2][c2] == color) {
                        ++leftdiag;
                        if (leftdiag >= k) {
                            return true;
                        }
                    }
                    else {
                        leftdiag = 0;
                    }
                }
                int rightdiag = 0;
                for (int c2 = c, r2 = r; c2 < n && r2 >= 0; ++c2, --r2) {
                    if (board[r2][c2] == color) {
                        ++rightdiag;
                        if (rightdiag >= k) {
                            return true;
                        }
                    }
                    else {
                        rightdiag = 0;
                    }
                }
            }
        }
        
        return false;
    }

}