import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;

import java.math.BigInteger;

class CombinationGenerator {

    private int[] a;
    private int n;
    private int r;
    private BigInteger numLeft;
    private BigInteger total;

    // ------------
    // Constructor
    // ------------

    public CombinationGenerator(int n, int r) {
        if (r > n) {
            throw new IllegalArgumentException();
        }
        if (n < 1) {
            throw new IllegalArgumentException();
        }
        this.n = n;
        this.r = r;
        a = new int[r];
        BigInteger nFact = getFactorial(n);
        BigInteger rFact = getFactorial(r);
        BigInteger nminusrFact = getFactorial(n - r);
        total = nFact.divide(rFact.multiply(nminusrFact));
        reset();
    }

    // ------
    // Reset
    // ------

    public void reset() {
        for (int i = 0; i < a.length; i++) {
            a[i] = i;
        }
        numLeft = new BigInteger(total.toString());
    }

    // ------------------------------------------------
    // Return number of combinations not yet generated
    // ------------------------------------------------

    public BigInteger getNumLeft() {
        return numLeft;
    }

    // -----------------------------
    // Are there more combinations?
    // -----------------------------

    public boolean hasMore() {
        return numLeft.compareTo(BigInteger.ZERO) == 1;
    }

    // ------------------------------------
    // Return total number of combinations
    // ------------------------------------

    public BigInteger getTotal() {
        return total;
    }

    // ------------------
    // Compute factorial
    // ------------------

    private static BigInteger getFactorial(int n) {
        BigInteger fact = BigInteger.ONE;
        for (int i = n; i > 1; i--) {
            fact = fact.multiply(new BigInteger(Integer.toString(i)));
        }
        return fact;
    }

    // --------------------------------------------------------
    // Generate next combination (algorithm from Rosen p. 286)
    // --------------------------------------------------------

    public int[] getNext() {

        if (numLeft.equals(total)) {
            numLeft = numLeft.subtract(BigInteger.ONE);
            return a;
        }

        int i = r - 1;
        while (a[i] == n - r + i) {
            i--;
        }
        a[i] = a[i] + 1;
        for (int j = i + 1; j < r; j++) {
            a[j] = a[i] + j - i;
        }

        numLeft = numLeft.subtract(BigInteger.ONE);
        return a;

    }
}

public class SolutionC {

    public static String sample = "welcome to code jam";

    public static void main(String[] args) {
        try {
            String inFile = "./test2009/C-small-attempt3.in";
            String outFile = "./test2009/C.out";
            BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(new File(inFile))));
            BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(new File(outFile))));
            int numCase = Integer.parseInt(reader.readLine());
            for (int i = 0; i < numCase; i++) {
                String input = reader.readLine();
                int ret = 0;
                if (input.length() == sample.length()) {
                    if (input.equals(sample)) {
                        ret++;
                    }
                } else if (input.length() > sample.length()) {
                    CombinationGenerator x = new CombinationGenerator(input.length(), sample.length());
                    // StringBuffer combination;

                    while (x.hasMore()) {
                        // combination = new StringBuffer();
                        int[] indices = x.getNext();
                        boolean pass = false;
                        for (int k = 0; k < indices.length; k++) {
                            if (input.charAt(indices[k]) != sample.charAt(k)) {
                                pass = true;
                                break;
                            }
                            // combination.append(input.charAt(indices[k]));
                        }
                        // System.out.println(combination.toString());
                        // if (combination.toString().equals(sample)) {
                        if (!pass) {
                            ret++;
                            if (ret > 9999) {
                                break;
                            }
                        }
                    }
                }

                String result = "" + ret;
                // System.out.println(ret);
                if (result.length() < 4) {
                    int len = result.length();
                    for (int j = 0; j < 4 - len; j++) {
                        result = "0" + result;
                    }
                }
                // System.out.println("Case #" + (i + 1) + ": " + result);
                writer.write("Case #" + (i + 1) + ": " + result + "\r\n");
            }
            writer.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
