import java.io.IOException;
import java.util.Scanner;
import java.util.List;
import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.Set;
import java.util.HashSet;

import com.google.common.base.*;
import com.google.common.collect.*;

public class CodeJamRPI {

	private enum Game {
		WIN, LOSS
	}

	public static void main(String[] args) throws IOException {
		Scanner in = new Scanner(System.in);
		int numOfCases = in.nextInt();

		for (int caseNum = 1; caseNum <= numOfCases; caseNum++) {
			int teams = in.nextInt();

			Game[][] games = new Game[teams][teams];

			for (int i = 0; i < teams; i++) {
				String r = in.next();
				for (int j = 0; j < teams; j++) {
					char c = r.charAt(j);

					if (c == '.') {
						continue;
					}

					games[i][j] = c == '0' ? Game.LOSS : Game.WIN;
				}
			}

			System.out.format("Case #%d:\n", caseNum);
			for (int i = 0; i < teams; i++) {
				System.out.println(rpi(games, i));
			}
		}
	}

	static double wp(Game[][] games, int team) {
		return wp(games, team, -1);
	}

	static double wp(Game[][] games, int team, int team2) {
		double gamesPlayed = 0;
		double winCount = 0;

		for (int i = 0; i < games.length; i++) {
			Game game = games[team][i];
			if (game == null || i == team2) {
				continue;
			}

			gamesPlayed++;

			if (game == Game.WIN) {
				winCount++;
			}
		}

		return winCount / gamesPlayed;
	}

	static double owp(Game[][] games, int team) {
		double wpSum = 0.0;
		int opponents = 0;

		for (int i = 0; i < games.length; i++) {
			if (games[team][i] != null) {
				opponents++;
				wpSum += wp(games, i, team);
			}
		}

		return wpSum / opponents;
	}

	static double oowp(Game[][] games, int team) {
		double owpSum = 0.0;
		int opponents = 0;

		for (int i = 0; i < games.length; i++) {
			if (games[team][i] != null) {
				opponents++;
				owpSum += owp(games, i);
			}
		}

		return owpSum / opponents;
	}

	static double rpi(Game[][] games, int team) {
		return 0.25 * wp(games, team) + 0.5 * owp(games, team) + 0.25 * oowp(games, team);
	}

}
