import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;


@SuppressWarnings("unused")
public class SolutionA {

  // NOTE: Download input files to TOP-LEVEL directory of project.
  // Example: "A-small-attempt0", "A-large"
  private static final String FILENAME = "A-small-attempt0";

  /*
   * API for output:
   * - void sout(Object): output to console
   * - void fout(Object): output to output file
   * - void out(Object): output to console and output file
   * - void outCase(int, Object): outputs "Case #[i]: " + obj.toString()
   *
   * API for file reading:
   * - String[] getStrings(), String getString()
   * - int[] getInts(), int getInt()
   * - long[] getLongs(), long getLong()
   * - double[] getDoubles(), double getDouble()
   */
  private void solveCase(int caseNumber) throws Exception {
    int[] data = getInts();
    int D = data[0];
    int N = data[1];
    double[][] h = new double[N][];
    for (int i = 0; i < N; ++i) {
      h[i] = getDoubles();
    }
    List<double[]> horses = Arrays.asList(h);
    horses.sort(new Comparator<double[]>() {
      @Override
      public int compare(double[] o1, double[] o2) {
        return Double.compare(o1[0], o2[0]);
      }
    });

    int slow = N - 1;
    for (int i = N - 2; i >= 0; --i) {
      if (horses.get(slow)[1] > horses.get(i)[1]) {
        slow = i;
        break;
      }
      double intersection = horses.get(i)[1] * ((horses.get(slow)[0] - horses.get(i)[0]) / (horses.get(i)[1] - horses.get(slow)[1])) + horses.get(i)[0];

      if (intersection > D) {
        slow = i;
      }
    }

    double result = D / ((D - horses.get(slow)[0]) / horses.get(slow)[1]);

    outCase(caseNumber, result);
  }


  /* ----- Code run from main() ----- */

  private SolutionA() {
    try {
      rd = new BufferedReader(new FileReader(FILENAME + ".in"));
      wr = new PrintWriter(new FileWriter(FILENAME + ".out"));
      numCases = getInt();
      isInitialized = true;
    } catch (Exception e) {
      sout("Error reading file:");
      e.printStackTrace();
    }
  }

  private void solveCases() {
    if (!isInitialized) {
      return;
    }

    for(int i = 1; i <= numCases; ++i) {
      try {
        solveCase(i);
      } catch (Exception e) {
        sout("Exception in Case " + i + ".");
        e.printStackTrace();
        break;
      }
    }
  }

  private void tearDown() {
    try {
      if (wr != null) {
        wr.close();
      }
    } catch (Exception e) {
      sout("Error closing writer.");
      e.printStackTrace();
    }

    try {
      if (rd != null) {
        rd.close();
      }
    } catch (Exception e) {
      sout("Error closing reader.");
      e.printStackTrace();
    }
  }

  /* ----- Utility fields ----- */

  private BufferedReader rd = null;
  private PrintWriter wr = null;
  private boolean isInitialized = false;
  private int numCases = -1;

  /* ----- Output utilities ----- */

  private void sout(Object s) {
    System.out.println(s);
  }

  private void fout(Object s) {
    if (wr == null) {
      throw new RuntimeException("Writer has not been initialized.");
    }
    wr.println(s);
  }

  private void out(Object s) {
    sout(s);
    fout(s);
  }

  private void outCase(int c, Object s) {
    String out = "Case #" + c + ": " + s.toString();
    sout(out);
    fout(out);
  }

  /* ----- Input utilities ----- */

  private String[] getStrings() throws Exception {
    if (rd == null) {
      throw new RuntimeException("Reader has not been initialized.");
    }
    return rd.readLine().split(" ");
  }

  private int[] getInts() throws Exception {
    String[] strData = getStrings();
    int length = strData.length;
    int[] arr = new int[length];
    for(int i = 0; i < length; ++i) {
      arr[i] = Integer.parseInt(strData[i], 10);
    }
    return arr;
  }

  private long[] getLongs() throws Exception {
    String[] strData = getStrings();
    int length = strData.length;
    long[] arr = new long[length];
    for(int i = 0; i < length; ++i) {
      arr[i] = Long.parseLong(strData[i], 10);
    }
    return arr;
  }

  private double[] getDoubles() throws Exception {
    String[] strData = getStrings();
    int length = strData.length;
    double[] arr = new double[length];
    for (int i = 0; i < length; ++i) {
      arr[i] = Double.parseDouble(strData[i]);
    }
    return arr;
  }

  private String getString() throws Exception {
    String[] strData = getStrings();
    if (strData.length != 1) {
      throw new RuntimeException("Misinterpreted the file in getString().");
    }
    return strData[0];
  }

  private int getInt() throws Exception {
    int[] intData = getInts();
    if (intData.length != 1) {
      throw new RuntimeException("Misinterpreted the file in getInt().");
    }
    return intData[0];
  }

  private long getLong() throws Exception {
    long[] longData = getLongs();
    if (longData.length != 1) {
      throw new RuntimeException("Misinterpreted the file in getLong().");
    }
    return longData[0];
  }

  private double getDouble() throws Exception {
    double[] doubleData = getDoubles();
    if (doubleData.length != 1) {
      throw new RuntimeException("Misinterpreted the file in getDouble().");
    }
    return doubleData[0];
  }


  /* Start program via code in constructor */
  public static void main(String[] args) {
    SolutionA solution = new SolutionA();
    solution.solveCases();
    solution.tearDown();
  }
}
