package infinite;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import java.util.Queue;

public class Solver {
	private FileReader m_fileReader;
	private FileWriter m_fileWriter;
	private BufferedReader m_bufferedReader;
	private BufferedWriter m_bufferedWriter;
	
	private int m_numCases;
	
	private class Node {
		private int m_minutes;
		private ArrayList<Integer> m_diners;
		private ArrayList<ArrayList<Integer>> m_history;
		
		public Node(int minutes, ArrayList<Integer> diners, ArrayList<ArrayList<Integer>> history) {
			m_minutes = minutes;
			m_diners = diners;
			m_history = history;
		}
		
		public int getMinutes() {
			return m_minutes;
		}
		
		public boolean isEmpty() {
			return m_diners.size() == 0;
		}
		
		public Node eat() {
			ArrayList<Integer> newDiners = new ArrayList<Integer>(m_diners);
			ArrayList<ArrayList<Integer>> newHistory = new ArrayList<ArrayList<Integer>>(m_history);
			
			int size = newDiners.size();
			
			for(int x = 0; x < size; x++) {
				newDiners.set(x, newDiners.get(x) - 1);
			}
			
			Integer zero = new Integer(0);
			while(newDiners.remove(zero));
			newHistory.add(newDiners);
			
			return new Node(m_minutes + 1, newDiners, newHistory);
		}
		
		private Node _move(int movePancakes) {
			ArrayList<Integer> newDiners = new ArrayList<Integer>(m_diners);
			ArrayList<ArrayList<Integer>> newHistory = new ArrayList<ArrayList<Integer>>(m_history);
			
			int lastIndex = newDiners.size() - 1;
			int largestPlate = newDiners.get(lastIndex);
			newDiners.set(lastIndex, largestPlate - movePancakes);
			newDiners.add(movePancakes);
			Collections.sort(newDiners);
			
			newHistory.add(newDiners);
			
			return new Node(m_minutes + 1, newDiners, newHistory);
		}
		
		public ArrayList<Node> move() {
			ArrayList<Node> newNodes = new ArrayList<Node>();
			
			int lastIndex = m_diners.size() - 1;
			int largestPlate = m_diners.get(lastIndex);
			int moveMin = largestPlate / 2;
			int moveMax = largestPlate - 1;
			for(int x = moveMin; x <= moveMax; x++) {
				newNodes.add(_move(x));
			}
			
			return newNodes;
		}
		
		public void printHistory() throws IOException {
			for(int x = 0; x < m_history.size(); x++) {
				m_bufferedWriter.write("Minute " + x + ": " + m_history.get(x) + "\n");
			}
		}
	}
	
	public Solver() {
		try {
			m_fileReader = new FileReader("input.txt");
			m_fileWriter = new FileWriter("output.txt");
			m_bufferedReader = new BufferedReader(m_fileReader);
			m_bufferedWriter = new BufferedWriter(m_fileWriter);
			
			m_numCases = Integer.parseInt(m_bufferedReader.readLine());
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		for(int x = 1; x <= m_numCases; x++) {
			_solveCase(x);
		}
		
		try {
			m_bufferedReader.close();
			m_bufferedWriter.close();
			m_fileReader.close();
			m_fileWriter.close();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	private void _solveCase(int caseNum) {
		int numDiners;
		ArrayList<Integer> diners = new ArrayList<Integer>();
		Queue<Node> queue = new LinkedList<Node>();
		
		try {
			String line = m_bufferedReader.readLine();
			numDiners = Integer.parseInt(line);
			
			line = m_bufferedReader.readLine();
			String[] parts = line.split(" ");
			assert(parts.length == numDiners);
			for(int x = 0; x < numDiners; x++) {
				diners.add(Integer.parseInt(parts[x]));
			}
		} catch (IOException e) {
			e.printStackTrace();
		} catch (NumberFormatException e) {
			e.printStackTrace();
		}
		
		//Prepare root node
		ArrayList<ArrayList<Integer>> history = new ArrayList<ArrayList<Integer>>();
		history.add(diners);
		Collections.sort(diners);
		Node root = new Node(0, diners, history);
		queue.add(root);
		
		//Do BFS
		while(queue.size() > 0) {
			//Get head Node
			Node node = queue.poll();
			
			//Check pancake clear
			if(node.isEmpty()) {
				try {
					//node.printHistory();
					m_bufferedWriter.write("Case #" + caseNum + ": " + node.getMinutes() + "\n");
				} catch (IOException e) {
					e.printStackTrace();
				}
				
				return;
			}
			
			//Either move or eat
			queue.add(node.eat());
			queue.addAll(node.move());
		}
	}
}
