package dijkstra;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;

public class Solver {
	private FileReader m_fileReader;
	private FileWriter m_fileWriter;
	private BufferedReader m_bufferedReader;
	private BufferedWriter m_bufferedWriter;
	
	private int m_numCases;
	
	public static final int O = 0;
	public static final int I = 1;
	public static final int J = 2;
	public static final int K = 3;
	public static final int NO = 4;
	public static final int NI = 5;
	public static final int NJ = 6;
	public static final int NK = 7;
	
	public static final int[][] LOOKUP = {
			{O,	I,	J,	K,	NO,	NI,	NJ,	NK},
			{I,	NO,	K,	NJ,	NI,	O,	NK,	J},
			{J,	NK,	NO,	I,	NJ,	K,	O,	NI},
			{K,	J,	NI,	NO,	NK,	NJ,	I,	O},
			{NO,NI,	NJ,	NK,	O,	I,	J,	K},
			{NI,O,	NK,	J,	I,	NO,	K,	NJ},
			{NJ,K,	O,	NI,	J,	NK,	NO,	I},
			{NK,NJ,	I,	O,	K,	J,	NI,	NO}
	};
	
	public static void testLookup() {
		for(int x = 0; x < 8; x++) {
			for(int y = x; y < 8; y++) {
				int nx = x > 3 ? x - 4 : x;
				int ny = y > 3 ? y - 4 : y;
				assert(LOOKUP[x][y] == LOOKUP[nx][ny]);
				assert(LOOKUP[nx][y] == LOOKUP[x][ny]);
			}
		}
	}
	
	public Solver() {		
		try {
			m_fileReader = new FileReader("input.txt");
			m_fileWriter = new FileWriter("output.txt");
			m_bufferedReader = new BufferedReader(m_fileReader);
			m_bufferedWriter = new BufferedWriter(m_fileWriter);
			
			m_numCases = Integer.parseInt(m_bufferedReader.readLine());
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		for(int x = 1; x <= m_numCases; x++) {
			_solveCase(x);
		}
		
		try {
			m_bufferedReader.close();
			m_bufferedWriter.close();
			m_fileReader.close();
			m_fileWriter.close();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	private void _solveCase(int caseNum) {
		String line = null;
		int L = 0;
		int X = 0;
		String fullString = null;
		ArrayList<Integer> iPoints = new ArrayList<Integer>();
		ArrayList<Integer> kPoints = new ArrayList<Integer>();
		
		try {
			line = m_bufferedReader.readLine();
			String[] parts = line.split(" ");
			
			assert(parts.length == 2);
			
			L = Integer.parseInt(parts[0]);
			X = Integer.parseInt(parts[1]);
			
			line = m_bufferedReader.readLine();
			fullString = new String(new char[X]).replace("\0", line);
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		if(L * X >= 3) {
			int fullStringLength = fullString.length();
			int sResult = O;
			int iResult = O;
			int kResult = O;
			
			for(int x = 0; x < fullStringLength; x++) {
				sResult = LOOKUP[sResult][convertChar(fullString.charAt(x))];
				
				if(x < fullStringLength - 2) {
					iResult = LOOKUP[iResult][convertChar(fullString.charAt(x))];
					kResult = LOOKUP[convertChar(fullString.charAt(fullStringLength - x - 1))][kResult];
					
					if(iResult == I) iPoints.add(x);
					if(kResult == K) kPoints.add(fullStringLength - x - 1);
				}
			}
			
			if(!iPoints.isEmpty() && !kPoints.isEmpty() && sResult == NO) {
				int iPointsSize = iPoints.size();
				int kPointsSize = kPoints.size();
				
				for(int x = 0; x < iPointsSize; x++) {
					for(int y = 0; y < kPointsSize; y++) {
						int begin = iPoints.get(x) + 1;
						int end = kPoints.get(y);
						if(end <= begin) break;
						else
						{
							if(_evaluateString(fullString.substring(begin, end)) == J) {
								try {
									m_bufferedWriter.write("Case #" + caseNum + ": YES\n");
								} catch (IOException e) {
									e.printStackTrace();
								}
								
								return;
							}
						}
					}
				}
			}
		}
		
		try {
			m_bufferedWriter.write("Case #" + caseNum + ": NO\n");
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	private int _evaluateString(String s) {
		int result = convertChar(s.charAt(0));
		
		for(int x = 1; x < s.length(); x++) {
			result = LOOKUP[result][convertChar(s.charAt(x))];
		}
		
		return result;
	}
	
	private int convertChar(char c) {
		if(c == 'i') return I;
		else if(c == 'j') return J;
		else return K;
	}
}
