package googlejam.ludi;

import java.io.*;
import java.util.*;

public class TrainTimeTable {
	
	public class Time implements Comparable<Time> {

		protected int hour;
		protected int minute;
		
		public Time(int hour, int minute) {
			this.hour = hour;
			this.minute = minute;
		}
		
		public Time(Time arg0) {
			this.hour = arg0.hour;
			this.minute = arg0.minute;
		}
		
		public void add(int m) {
			int tmp = minute + m;
			hour += tmp/60;
			minute = tmp%60;
		}

		public int compareTo(Time arg0) {
			
			if (arg0 == null) {
				return 0;
			}

			if (arg0.hour != this.hour) {
				return (arg0.hour > this.hour)?-1:1;
			} else if (arg0.minute != this.minute) {
				return (arg0.minute > this.minute)?-1:1;
			}

			return 0;
		}
		
		public String toString() {
			return "";
		}
	}
	
	public class TimeTable {
		
		protected Time dTime;
		protected Time aTime;
		
	}
	
	private ArrayList<TimeTable> A = new ArrayList<TimeTable>();
	private ArrayList<TimeTable> B = new ArrayList<TimeTable>();
	private int turnAroundTime = 0;
	
	private int fromA = 0;
	private int fromB = 0;
	
	public int[] trainTimeTable(String[] Astr, String[] Bstr, int turnaround) {

		for (String s : Astr) {
			String[] tmp = s.split("\\s");
			TimeTable tt = new TimeTable();
			tt.aTime = new Time(Integer.parseInt(tmp[1].substring(0, 2)), Integer.parseInt(tmp[1].substring(3, 5)));
			tt.dTime = new Time(Integer.parseInt(tmp[0].substring(0, 2)), Integer.parseInt(tmp[0].substring(3, 5)));
			A.add(tt);
		}
		for (String s : Bstr) {
			String[] tmp = s.split("\\s");
			TimeTable tt = new TimeTable();
			tt.aTime = new Time(Integer.parseInt(tmp[1].substring(0, 2)), Integer.parseInt(tmp[1].substring(3, 5)));
			tt.dTime = new Time(Integer.parseInt(tmp[0].substring(0, 2)), Integer.parseInt(tmp[0].substring(3, 5)));
			B.add(tt);
		}
		
		
		this.turnAroundTime = turnaround;

		for (int i=0;i<A.size();) {

			TimeTable tt = A.remove(i);
			forward(tt, true);
			backward(tt, true);
		}
		
		fromB += this.B.size();

		return new int[]{fromA, fromB};
	}
	
	private void forward(TimeTable tt, boolean inA) {
		
		ArrayList<TimeTable> cur = inA?B:A;
		
		Time lastest = new Time(0, 0);
		TimeTable theone = null;
		
		for (TimeTable x : cur) {

			Time tmp = new Time(x.aTime);
			tmp.add(this.turnAroundTime);
			
			if (tmp.compareTo(tt.dTime) <= 0) {
				if (tmp.compareTo(lastest) >= 0) {
					lastest = tmp;
					theone = x;
				}
			}
		}
		
		if (theone != null) {
			cur.remove(theone);
			forward(theone, !inA);
		} else {
			if (inA) {
				fromA++;
			} else {
				fromB++;
			}
		}
		
	}
	
	private void backward(TimeTable tt, boolean inA) {
		
		ArrayList<TimeTable> cur = inA?B:A;
		
		Time earlist = new Time(23, 59);
		TimeTable theone = null;
		
		for (TimeTable x : cur) {

			Time tmp = new Time(tt.aTime);
			tmp.add(this.turnAroundTime);
			
			if (tmp.compareTo(x.dTime) <= 0) {
				if (x.dTime.compareTo(earlist) < 0) {
					earlist = x.dTime;
					theone = x;
				}
			}
		}
		
		if (theone != null) {
			cur.remove(theone);
			backward(theone, !inA);
		}
		
	}
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {

		try {
			BufferedReader reader = new BufferedReader(new FileReader(
					"D:\\MyDoc\\Workspace\\GoogleJam\\TrainTimeTable\\B-small-attempt0.in"));
			PrintStream out = new PrintStream(
					new FileOutputStream(
							"D:\\MyDoc\\Workspace\\GoogleJam\\TrainTimeTable\\B-small.out"));

			int totalTestCase = Integer.parseInt(reader.readLine());

			long t = System.currentTimeMillis();

			for (int i = 1; i <= totalTestCase; i++) {
				
				int ta = Integer.parseInt(reader.readLine());
				String[] nn = reader.readLine().split("\\s");
				int asize = Integer.parseInt(nn[0]);
				int bsize = Integer.parseInt(nn[1]);
				String[] a = new String[asize];
				String[] b = new String[bsize];
				
				for (int aa=0;aa<asize;aa++) {
					a[aa] = reader.readLine();
				}
				for (int bb=0;bb<bsize;bb++) {
					b[bb] = reader.readLine();
				}

				TrainTimeTable ttt = new TrainTimeTable();
				int[] result = ttt.trainTimeTable(a, b, ta);

				String r = "Case #" + i + ": " + result[0] + " " + result[1];
				out.println(r);
				System.out.println(r);

			}

			System.out.println(System.currentTimeMillis() - t);

			reader.close();
			out.close();

		} catch (Exception e) {
			e.printStackTrace();
		}
	}

}
