/*
Problem

Tic-Tac-Toe-Tomek is a game played on a 4 x 4 square board. The board starts empty, except that a single 'T' symbol may appear in one of the 16 squares. There are two players: X and O. They take turns to make moves, with X starting. In each move a player puts her symbol in one of the empty squares. Player X's symbol is 'X', and player O's symbol is 'O'.

After a player's move, if there is a row, column or a diagonal containing 4 of that player's symbols, or containing 3 of her symbols and the 'T' symbol, she wins and the game ends. Otherwise the game continues with the other player's move. If all of the fields are filled with symbols and nobody won, the game ends in a draw. See the sample input for examples of various winning positions.

Given an 4 x 4 board description containing 'X', 'O', 'T' and '.' characters (where '.' represents an empty square), describing the current state of a game, determine the status of the Tic-Tac-Toe-Tomek game going on. The statuses to choose from are:

"X won" (the game is over, and X won)
"O won" (the game is over, and O won)
"Draw" (the game is over, and it ended in a draw)
"Game has not completed" (the game is not over yet)
Input

The first line of the input gives the number of test cases, T. T test cases follow. Each test case consists of 4 lines with 4 characters each, with each character being 'X', 'O', '.' or 'T' (quotes for clarity only). Each test case is followed by an empty line.

Output

For each test case, output one line containing "Case #x: y", where x is the case number (starting from 1) and y is one of the statuses given above. Make sure to get the statuses exactly right. When you run your code on the sample input, it should create the sample output exactly, including the "Case #1: ", the capital letter "O" rather than the number "0", and so on.

Limits

The game board provided will represent a valid state that was reached through play of the game Tic-Tac-Toe-Tomek as described above.

Small dataset

1 ≤ T ≤ 10.

Large dataset

1 ≤ T ≤ 1000.

Sample


Input 
 	
Output 
 
6
XXXT
....
OO..
....

XOXT
XXOO
OXOX
XXOO

XOX.
OX..
....
....

OOXX
OXXX
OX.T
O..O

XXXO
..O.
.O..
T...

OXXX
XO..
..O.
...O

Case #1: X won
Case #2: Draw
Case #3: Game has not completed
Case #4: O won
Case #5: O won
Case #6: O won

Note

Although your browser might not render an empty line after the last test case in the sample input, in a real input file there would be one. */
package test.bolpor.topcoding.google.jam.cjbv.y2013.r1;

import test.bolpor.topcoding.google.jam.base.ProblemSolver;
import test.bolpor.topcoding.google.jam.practice.y2010.r1a.A_CBP;

public class A extends ProblemSolver
{
	public static void main(String[] args) throws java.io.IOException
	{
		A processor;

		processor = new A();
		processor.setFilePrefix("A-large");
		processor.start();
	}
	
	@Override
	public String processCase(int caseNumber) throws java.io.IOException
	{
		for ( int i = 0; i < 4; i++ )
			board[i] = nextString().toCharArray();
		boolean spaces = false;
		for ( int i = 0; i < 4; i++ )
			for ( int j = 0; j < 4; j++ )
			{
				char c = charAt(i, j);
				if ( '.' == c ) spaces = true;
				if ( test(i, j) )
					return c + " won";
			}
		
		return spaces ? "Game has not completed" : "Draw";
	}
	
	boolean test(int i, int j)
	{
		char c = charAt(i, j);
		if ( c == '.' ) return false;
		if ( c == 'T' ) return false;
		
		if ( test(i, j, c, +1, +0, +2, +0, +3, 0) ) return true;
		if ( test(i, j, c, +0, +1, +0, +2, +0, +3) ) return true;
		if ( test(i, j, c, +1, +1, +2, +2, +3, +3) ) return true;
		if ( test(i, j, c, +1, -1, +2, -2, +3, -3) ) return true;
		return false;
	}

	boolean test(int i, int j, char c, int x1, int y1, int x2, int y2, int x3, int y3)
	{
		int c1 = charAt(i + x1, j + y1);
		if ( c1 == '.' ) return false;

		int c2 = charAt(i + x2, j + y2);
		if ( c2 == '.' ) return false;
		int c3 = charAt(i + x3, j + y3);
		if ( c3 == '.' ) return false;

		if ( c1 == 'T' ) c1 = c;
		if ( c2 == 'T' ) c2 = c;
		if ( c3 == 'T' ) c3 = c;
		return (c == c1) && (c == c2) && (c == c3);
	}

	char charAt(int i, int j)
	{
		if ( i < 0 ) return '.';
		if ( j < 0 ) return '.';
		if ( i > 3 ) return '.';
		if ( j > 3 ) return '.';
		
		return board[i][j];
	}

	char[][] board = new char[4][];
}
