package org.bolpor.cjbv.gcodejam.c2017;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.math.BigInteger;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeSet;

public class ProblemC {
	//private static String FILE_NAME = "old_magician-small";
	//private static String FILE_NAME = "ProblemC-sample";
	private static String FILE_NAME = "C-small-2-attempt1";

	public static void main(String[] args) throws Exception {
		new ProblemC(FILE_NAME).run();
	}
	
	public ProblemC(String fileName) throws Exception {
		in = new BufferedReader(new InputStreamReader(getClass().getResourceAsStream(fileName + ".in")));
		//out = new PrintStream(new File(fileName + ".out"));
		out = new PrintStream(new File("/Users/cjbolanos/Downloads/" + fileName + ".txt"));
	}

	public void run() throws IOException {
		int T = readInt();
		for ( int i = 1; i <= T; i++ ) {
			String result = processCase(i);
			out.printf("Case #%d: %s\n", i, result);
			System.out.printf("Case #%d: %s\n", i, result);
		}
		out.flush();
		out.close();
	}
	
	static BigInteger TWO = BigInteger.valueOf(2);
	public String processCase(int caseN) throws IOException {
		BigInteger[] array = readBigIntegerArray();
		BigInteger N = array[0];
		BigInteger K = array[1];
		
		Map<BigInteger, Segment> map = new HashMap<>();
		TreeSet<Segment> set = new TreeSet<>();
		addSegment(map, set, N);
		
		Segment segment = null;
		BigInteger middle = null;
		BigInteger sizeLeft = null;
		BigInteger sizeRight = null;
		for ( BigInteger i = BigInteger.ZERO; i.compareTo(K) < 0; i = i.add(BigInteger.ONE) ) {
			segment = set.last();
			if ( segment.dec() ) {
				set.remove(segment);
				map.remove(segment.size);
			}
				
			middle = segment.size.add(BigInteger.ONE).divide(TWO);

			/*
			System.out.printf("[%5s] Stall: %5s, leftS: %5s, rightS: %5s\n",
					i, middle, middle.subtract(segment.left), 
					segment.right.subtract(middle));
					*/
			sizeLeft = middle.subtract(BigInteger.ONE);
			sizeRight = segment.size.subtract(sizeLeft).subtract(BigInteger.ONE);
			addSegment(map, set, sizeLeft);
			addSegment(map, set, sizeRight);
			/*
			System.out.printf("[%s] Size:%s, Left:%s, Right: %s\n",
					i, segment, sizeLeft, sizeRight);*/
		}
		
		int compare = sizeLeft.compareTo(sizeRight);
		if ( compare >= 0 ) {
			return sizeLeft.toString() + " " + sizeRight.toString();
		}
		return sizeRight.toString() + " " + sizeLeft.toString();
	}

	public void addSegment(Map<BigInteger, Segment> map, TreeSet<Segment> set, 
			BigInteger size) {
		if ( size.compareTo(BigInteger.ZERO) <= 0 ) return;
		Segment segment = map.get(size);
		if ( null == segment ) {
			segment = new Segment(size);
			map.put(size, segment);
			set.add(segment);
		} else {
			segment.inc();
		}
	}

	public int readInt() throws IOException {
		return Integer.valueOf(readLine());
	}

	public int[] readIntArray() throws IOException {
		return readIntArray(" ");
	}

	public int[] readIntArray(String regex) throws IOException {
		String[] tokens = readLine().split(" ");
		int[] array = new int[tokens.length];
		for ( int i = 0; i < array.length; i++ ) {
			array[i] = Integer.valueOf(tokens[i]);
		}
		return array;
	}

	public BigInteger[] readBigIntegerArray() throws IOException {
		return readBigIntegerArray(" ");
	}

	public BigInteger[] readBigIntegerArray(String regex) throws IOException {
		String[] tokens = readLine().split(" ");
		BigInteger[] array = new BigInteger[tokens.length];
		for ( int i = 0; i < array.length; i++ ) {
			array[i] = new BigInteger(tokens[i]);
		}
		return array;
	}

	public String[] readStringArray() throws IOException {
		return readLine().split(" ");
	}

	public String[] readStringArray(String regex) throws IOException {
		return readLine().split(regex);
	}

	public String readLine() throws IOException {
		return in.readLine();
	}

	static class Segment implements Comparable<Segment> {
		Segment(BigInteger size) {
			this.size = size;
			this.count = BigInteger.ONE;
		}

		public String toString() {
			return size.toString();
		}

		public int compareTo(Segment s) {
			return size.compareTo(s.size);
		}

		public void inc() {
			count = count.add(BigInteger.ONE);
		}

		public boolean dec() {
			count = count.subtract(BigInteger.ONE);
			return count.compareTo(BigInteger.ZERO) <= 0;
		}

		final BigInteger size;
		BigInteger count;
	}

	BufferedReader in;
	PrintStream out;
}
