/*
Treasure
Problem

Following an old map, you have stumbled upon the Dread Pirate Larry's secret treasure trove!

The treasure trove consists of N locked chests, each of which can only be opened by a key of a specific type. Furthermore, once a key is used to open a chest, it can never be used again. Inside every chest, you will of course find lots of treasure, and you might also find one or more keys that you can use to open other chests. A chest may contain multiple keys of the same type, and you may hold any number of keys.

You already have at least one key and your map says what other keys can be found inside the various chests. With all this information, can you figure out how to unlock all the chests?

For example, suppose the treasure trove consists of four chests as described below, and you began with exactly one key of type 1:

Chest Number  |  Key Type To Open Chest  |  Key Types Inside
--------------+--------------------------+------------------
1             |  1                       |  None
2             |  1                       |  1, 3
3             |  2                       |  None
4             |  3                       |  2
You can open all the chests in this example if you do them in the order 2, 1, 4, 3. If you start by opening chest #1 first, then you will have used up your only key, and you will be stuck.
Input

The first line of the input gives the number of test cases, T. T test cases follow. Each test case begins with a single line containing two positive integers K and N, representing the number of keys you start with and the number of chests you need to open.

This is followed by a line containing K integers, representing the types of the keys that you start with.

After that, there will be N lines, each representing a single chest. Each line will begin with integers Ti and Ki, indicating the key type needed to open the chest and the number of keys inside the chest. These two integers will be followed by Ki more integers, indicating the types of the keys contained within the chest.

Output

For each test case, output one line containing "Case #x: C1 C2 ... CN", where x is the case number (starting from 1), and where Ci represents the index (starting from 1) of the ith chest that you should open.

If there are multiple ways of opening all the chests, choose the "lexicographically smallest" way. In order words, you should choose to make C1 as small as possible, and if there are multiple ways of making C1 as small as possible, choose the one that makes C2 as small as possible, and so on.

If there is no way to open all the chests, you should instead output one line containing "Case #x: IMPOSSIBLE".

Limits

1 ≤ T ≤ 25.
1 ≤ K.
All chest types and key types will be integers between 1 and 200 inclusive.
Small dataset

1 ≤ N ≤ 20.
In each test case, there will be at most 40 keys altogether.
Large dataset

1 ≤ N ≤ 200.
In each test case, there will be at most 400 keys altogether.
Sample


Input 
 	
Output 
 
3
1 4
1
1 0
1 2 1 3
2 0
3 1 2
3 3
1 1 1
1 0
1 0
1 0
1 1
2
1 1 1
Case #1: 2 1 4 3
Case #2: 1 2 3
Case #3: IMPOSSIBLE

 */
package test.bolpor.topcoding.google.jam.cjbv.y2013.r1;

import java.util.Arrays;
import java.util.HashSet;
import java.util.TreeMap;

import org.cj.framework.datast.collections.Stack;

import test.bolpor.topcoding.google.jam.base.ProblemSolver;

public class D extends ProblemSolver
{
	public static void main(String[] args) throws java.io.IOException
	{
		D processor;

		processor = new D();
		processor.setFilePrefix("D-small-attempt2");
		processor.start();
	}
	
	@Override
	public String processCase(int caseNumber) throws java.io.IOException
	{
		keys = nextInteger();
		chests = nextInteger();
		TreeMap<String, Integer> orderedChests = new TreeMap<String, Integer>();
		for ( int i = 1; i <= chests; i++ )
			orderedChests.put(Integer.toString(i), i);
		
		myKeys = nextIntegers(keys);

		chestKey = new int[chests + 1];
		chestKeys = new int[chests + 1][];
		for ( int i = 1; i <= chests; i++ )
		{
			chestKey[i] = nextInteger();
			int keys = nextInteger();
			chestKeys[i] = nextIntegers(keys);
		}

		int[] bestMatch = null;
		StringBuilder builder = new StringBuilder();

		int tries = 0;
		System.err.printf("\n  Processing %d chests", chests);
		Stack<Node> stack = new Stack<Node>();
		stack.push(new Node());
		next: while ( ! stack.isEmpty() )
		{
			Node node = stack.pop();
			// Any chests that cant be opened because this chest was opened?
			for ( int chest : node.closedChests )
			{
				int key = chestKey[chest];
				if ( node.availableKeys[key] >= 1 ) continue;
				int keys = node.futureKeys[key];
				for ( int i = 0; i < chestKeys[chest].length; i++ )
					if ( chestKeys[chest][i] == key )
						keys--;
				if ( keys < 1 )
				{
					System.err.printf("\nChest %d cannot be opened in node %s, %s)",
							chest,
							Arrays.toString(node.openedChests),
							keysToString(node.availableKeys));
					continue next;
				}
			}

			if ( ++tries % 10000 == 0 )
				System.err.printf("\nPushing new node (opened %s, available %s)",
						Arrays.toString(node.openedChests),
						keysToString(node.availableKeys));
			if ( 0 == node.closedChests.size() )
			{
				// MATCH!
				builder.setLength(0);
				for ( int i = 0; i < node.openedChests.length; i++ )
					builder.append(i > 0 ? " " : "").append(node.openedChests[i]);
				System.err.printf("\n  MATCH! %s", builder);
				String s = builder.toString();
				if ( (null == bestMatch) || (compareTo(node.openedChests, bestMatch) < 0) )
					bestMatch = node.openedChests.clone();
			}
			else
			{
				for ( int i = 1; i < node.availableKeys.length; i++ )
				{
					if ( node.availableKeys[i] + node.futureKeys[i] < node.requiredKeys[i] )
						continue next;
				}
				for ( int i = chests; i >= 1; i-- )
				{
					if ( ! node.closedChests.contains(i) ) continue;
					int requiredKey = chestKey[i];
					if ( 0 < node.availableKeys[requiredKey] )
					{
						Node n2 = new Node(node, i);
						if ( (null == bestMatch) || (compareTo(node.openedChests, bestMatch) < 0) )
							stack.push(n2);
						//System.err.printf("\nPushing new node (opened %s, available %s)",
						//		Arrays.toString(n2.openedChests),
						//		keysToString(n2.availableKeys));
					}
				}
			}
		}
		return null != bestMatch ? chestsToString(bestMatch) : "IMPOSSIBLE";
	}

	int compareTo(int[] a, int[] b)
	{
		for ( int i = 0; i < a.length; i++ )
			if ( a[i] != b[i] )
				return a[i] - b[i];
		return 0;
	}
	String keysToString(int[] keys)
	{
		StringBuilder b = new StringBuilder();
		for ( int i = 0; i < keys.length; i++ )
			if ( keys[i] > 0 )
				b.append(" ").append(i).append(":").append(keys[i]);
		return b.toString();
	}

	String chestsToString(int[] chests)
	{
		StringBuilder b = new StringBuilder();
		for ( int i = 0; i < chests.length; i++ )
				b.append(i > 0 ? " " : "").append(chests[i]);
		return b.toString();
	}

	class Node
	{
		Node()
		{
			requiredKeys = new int[200 + 1];
			futureKeys = new int[200 + 1];

			availableKeys = new int[200 + 1];
			for ( int i = 0; i < myKeys.length; i++ )
				availableKeys[myKeys[i]]++;

			openedChests = new int[0];
			closedChests = new HashSet<Integer>();
			for ( int i = 1; i <= chests; i++ )
			{
				closedChests.add(i);
				requiredKeys[chestKey[i]]++;
				for ( int j : chestKeys[i] )
					futureKeys[j] ++;
			}
		}

		Node(Node node, int chest)
		{
			openedChests = new int[node.openedChests.length + 1];
			System.arraycopy(node.openedChests, 0, openedChests, 0, openedChests.length - 1);
			openedChests[openedChests.length - 1] = (short) chest;

			closedChests = new HashSet<Integer>();
			closedChests.addAll(node.closedChests);
			closedChests.remove(chest);

			availableKeys = node.availableKeys.clone();
			availableKeys[chestKey[chest]]--;
			for ( int i = 0; i < chestKeys[chest].length; i++ )
				availableKeys[chestKeys[chest][i]]++;

			this.requiredKeys = node.requiredKeys.clone();
			this.futureKeys = node.futureKeys.clone();
			requiredKeys[chestKey[chest]]--;
			for ( int j : chestKeys[chest] )
				futureKeys[j]--;
		}

		int[] availableKeys;
		int[] openedChests;
		int[] requiredKeys;
		int[] futureKeys;
		HashSet<Integer> closedChests;
	}

	int keys;
	int chests;
	int[] myKeys;
	int[][] chestKeys;
	int[] chestKey;
}
