package com.miku;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.math.BigInteger;

/**
 * Hello world!
 * 
 */
public class App {

    private static final BigInteger TWO = BigInteger.valueOf(2);

    public static boolean isPalindrome(BigInteger bi) {
        String number = bi.toString();
        int digitCount = number.length();
        if (digitCount == 1) {
            return true;
        }

        for (int i = 0; i < digitCount / 2; i++) {
            if (number.charAt(i) != number.charAt(digitCount - i - 1)) {
                return false;
            }
        }
        return true;
    }

    public static BigInteger sqrt(BigInteger n) {
        if (n.signum() >= 0) {
            final int bitLength = n.bitLength();
            BigInteger root = BigInteger.ONE.shiftLeft(bitLength / 2);

            while (!isSqrt(n, root)) {
                root = root.add(n.divide(root)).divide(TWO);
            }
            return root;
        } else {
            throw new ArithmeticException("square root of negative number");
        }
    }

    private static boolean isSqrt(BigInteger n, BigInteger root) {
        final BigInteger lowerBound = root.pow(2);
        final BigInteger upperBound = root.add(BigInteger.ONE).pow(2);
        return lowerBound.compareTo(n) <= 0 && n.compareTo(upperBound) < 0;
    }

    public static boolean isPerfectSquare(BigInteger n) {
        BigInteger nearest = sqrt(n);
        BigInteger square = nearest.multiply(nearest);
        return n.compareTo(square) == 0;
    }

    public static long checkRange(BigInteger start, BigInteger stop) {
        long counter = 0;
        for (BigInteger i = start; i.compareTo(stop) < 0; i = i
                .add(BigInteger.ONE)) {
            boolean isPerfectSquare = isPerfectSquare(i);
            if (isPalindrome(i) && isPerfectSquare) {
                if (isPalindrome(sqrt(i))) {
                    // System.out.println(i.toString() + ": " + sqrt(i) + "^2");
                    counter += 1;
                }
            }
        }
        return counter;
    }

    public static void main(String[] args) {
        // BigInteger start = new BigInteger("9999999990000");
        // BigInteger stop = start.add(new BigInteger("10000"));
        // BigInteger stop = new BigInteger("100000000000000");
        // BigInteger start = new BigInteger("9999999990000");
        // BigInteger start = new
        // BigInteger("9999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999000");
        // BigInteger stop = new
        // BigInteger("10000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000");

        // BigInteger start = new BigInteger("100");
        // BigInteger stop = new BigInteger("1000");

        if (args.length != 1) {
            System.err.println("usage: cfair [FILENAME]");
            System.exit(1);
        }
        File file = new File(args[0]);
        try {
            final BufferedReader br = new BufferedReader(new FileReader(file));
            // just consume the number of cases
            final long numberOfTests = Long.parseLong(br.readLine());
            long currentCaseNumber = 1;
            String line;
            while ((line = br.readLine()) != null) {
                String[] range = line.split("\\s+");
                assert (range.length == 2);
                BigInteger start = new BigInteger(range[0]);
                BigInteger stop = new BigInteger(range[1]);
                stop = stop.add(BigInteger.ONE);
                // System.out.println(start + ", " + stop);
                System.out.println("Case #" + currentCaseNumber + ": "
                        + checkRange(start, stop));
                currentCaseNumber += 1;
            }
            br.close();
        } catch (IOException ioe) {
            System.err.println(ioe);
        }
        // System.out.println(checkRange(start, stop));
    }
}
