import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;


public class TicTacToeTomekUmpire {
	private boolean mayBeIncomplete = false;
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		if(args == null || args.length < 2){
			System.err.println("Usage: TicTacToeTomekUmpire <inFileName outFileName>");
		}
		TicTacToeTomekUmpire umpire = new TicTacToeTomekUmpire();
		umpire.decide(args[0], args[1]);
	}
	
	private void decide(String inFileName, String outFileName){
		FileHelper helper = new FileHelper();
		try {
			helper.init(inFileName, outFileName);
			String currentLine;
			int totalTestCases = 0;
			try{
				totalTestCases = Integer.parseInt(helper.getNextLine());
			}catch(NumberFormatException e){
				System.err.println("First line is not a number.");
				e.printStackTrace();
				System.exit(0);
			}
			
			String firstLine, secondLine, thirdLine, fourthLine, winner;
			testCaseLoop:for(int currentTestCase=0; currentTestCase < totalTestCases; currentTestCase++){
				mayBeIncomplete = false;
				winner = null;
				firstLine = helper.getNextLine();
				secondLine = helper.getNextLine();
				thirdLine = helper.getNextLine();
				fourthLine = helper.getNextLine();
				//Empty line
				helper.getNextLine();
				if((winner =checkWinner(firstLine)) != null){
					helper.putNextLine("Case #"+(currentTestCase+1) +": "+winner+" won");
					continue;
				}
				
				if((winner =checkWinner(secondLine)) != null){
					helper.putNextLine("Case #"+(currentTestCase+1) +": "+winner+" won");
					continue;
				}
				
				if((winner =checkWinner(thirdLine)) != null){
					helper.putNextLine("Case #"+(currentTestCase+1) +": "+winner+" won");
					continue;
				}
				
				if((winner =checkWinner(fourthLine)) != null){
					helper.putNextLine("Case #"+(currentTestCase+1) +": "+winner+" won");
					continue;
				}
				for(int count=0;count<4;count++){
					if((winner =checkWinner(firstLine.substring(count, count+1)
							+ secondLine.substring(count, count+1)
							+ thirdLine.substring(count, count+1)
							+ fourthLine.substring(count, count+1))) != null){
						helper.putNextLine("Case #"+(currentTestCase+1) +": "+winner+" won");
						continue testCaseLoop;
					}
				}
				if((winner =checkWinner(firstLine.substring(0, 1)
						+ secondLine.substring(1, 2)
						+ thirdLine.substring(2, 3)
						+ fourthLine.substring(3, 4))) != null){
					helper.putNextLine("Case #"+(currentTestCase+1) +": "+winner+" won");
					continue;
				}
				
				if((winner =checkWinner(firstLine.substring(3, 4)
						+ secondLine.substring(2, 3)
						+ thirdLine.substring(1, 2)
						+ fourthLine.substring(0, 1))) != null){
					helper.putNextLine("Case #"+(currentTestCase+1) +": "+winner+" won");
					continue;
				}
				if(!mayBeIncomplete){
					helper.putNextLine("Case #"+(currentTestCase+1) +": Draw");
				}else{
					helper.putNextLine("Case #"+(currentTestCase+1) +": Game has not completed");
				}
			}
		}catch(FileNotFoundException e){
			System.err.println("Error while initiating input file.");
			e.printStackTrace();
		} catch (IOException e) {
			System.err.println("Error while reading next line or creating output file.");
			e.printStackTrace();
		}finally{
			try {
				helper.cleanup();
			} catch (IOException e) {
				System.err.println("Error while closing streams.");
				e.printStackTrace();
			}
		}
	}
	
	private String checkWinner(String line){
		if(line.contains(".")){
			mayBeIncomplete = true;
			return null;
		}
		if(line.contains("O") && !line.contains("X")){
			return "O";
		}else if(line.contains("X") && !line.contains("O")){
			return "X";
		}else{
			return null;
		}
	}
	
	private class FileHelper{
		private BufferedReader br = null;
		private BufferedWriter bw = null;
		private void init(final String inFfileName, final String outFileName) throws IOException{
			br = new BufferedReader(new FileReader(inFfileName));
			bw = new BufferedWriter(new FileWriter(outFileName));
		}
		
		private String getNextLine() throws IOException{
			String currentLine;
			while ((currentLine = br.readLine()) != null) {
				return currentLine;
			}
			return null;
		}
		
		private void cleanup() throws IOException{
			br.close();
			bw.flush();
			bw.close();
		}
		
		private void putNextLine(String content) throws IOException{
			bw.append(content).append("\n");
		}
	}

}
