import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
/**
 * 
 * @author Chandrakant Dhome
 */
public class WaterBedHandler {
	private static String inputFileName = "B-small-attempt1.in";
	private static String outputFileName = "Output.out";
	private BufferedReader fileReader = null;
	private BufferedWriter fileWriter = null;
	
	public static void main(String[] args) {
		WaterBedHandler processor = new WaterBedHandler();
		processor.process();
	}
	private void process() {
		fileReader = FileHandler.getInputStreamFromFileName(inputFileName);
		if(fileReader == null){
			System.out.println("Cannot read from input file.");
			return;
		}
		fileWriter = FileHandler.getOutputStreamFromFileName(outputFileName);
		if(fileWriter == null){
			System.out.println("Cannot write to output file.");
			return;
		}
		int noOfTestCases = 0;
		try {
			noOfTestCases = new Integer(fileReader.readLine()).intValue();
		} catch (NumberFormatException e) {
			e.printStackTrace();
			System.out.println("First line does not contain no of test cases.");
			return;
		} catch (IOException e) {
			e.printStackTrace();
			System.out.println("Error reading file, "+inputFileName);
			return;
		}
		String labels = "abcdefghijklmnopqrstuvwxyz";
		int labelCnt = 1;
		int testCaseCnt = 0;
		while(testCaseCnt < noOfTestCases){
			String[] rowsNCol;
			try {
				rowsNCol = fileReader.readLine().split("\\s");
				int noOfRows = new Integer(rowsNCol[0]).intValue();
				int noOfCol = new Integer(rowsNCol[1]).intValue();
				int[][] waterBED = new int[noOfRows][noOfCol];
				String[][] basins = new String[noOfRows][noOfCol];
				for(int rowCnt=0; rowCnt < noOfRows; rowCnt++){
					String[] arrLine = fileReader.readLine().split("\\s");
					for(int colCnt=0; colCnt<noOfCol;colCnt++){
						waterBED[rowCnt][colCnt] = new Integer(arrLine[colCnt]).intValue();
					}
				}
				basins[0][0]="a";
				labelCnt = 1;
				for(int rowCnt=0; rowCnt < noOfRows; rowCnt++){
					for(int colCnt=0; colCnt<noOfCol;colCnt++){
						int currentAltitude = waterBED[rowCnt][colCnt];
						int[] rowNCol = getLowestAltitudeNearBy(waterBED, rowCnt, colCnt, noOfRows, noOfCol);
						int lowestROW = rowNCol[0];
						int lowerstCol = rowNCol[1];
						if(waterBED[lowestROW][lowerstCol] < currentAltitude){
							if(basins[lowestROW][lowerstCol] != null){
								basins[rowCnt][colCnt] = basins[lowestROW][lowerstCol]; 
							}else if(basins[rowCnt][colCnt] != null){
								basins[lowestROW][lowerstCol] = basins[rowCnt][colCnt]; 
							}else{
								basins[rowCnt][colCnt] = String.valueOf(labels.charAt(labelCnt));
								basins[lowestROW][lowerstCol] = String.valueOf(labels.charAt(labelCnt));
								labelCnt++;
							}
						}else if(waterBED[lowestROW][lowerstCol] == currentAltitude && basins[rowCnt][colCnt] == null){
								basins[rowCnt][colCnt] = String.valueOf(labels.charAt(labelCnt));
								labelCnt++;
						}else if(basins[rowCnt][colCnt] == null){
							basins[rowCnt][colCnt] = String.valueOf(labels.charAt(labelCnt));
							labelCnt++;
						}
					}
				}
				
				fileWriter.append("Case #"+(testCaseCnt+1)+":");
				for(int rowCnt=0; rowCnt < noOfRows; rowCnt++){
					fileWriter.append("\n");
					for(int colCnt=0; colCnt<noOfCol;colCnt++){
						fileWriter.append(basins[rowCnt][colCnt]+" ");
					}
				}
				fileWriter.append("\n");
			} catch (IOException e) {
				e.printStackTrace();
			}
			testCaseCnt++;
		}
		try {
			fileReader.close();
			fileWriter.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.out.println("File reader/writer cannot be closed...Exiting.");
		}
	}
	private int[] getLowestAltitudeNearBy(int[][] waterBED, int rowCnt,
			int colCnt, int noOfRows, int noOfCol) {
		int[] rowNCol = new int[2];
		int lowestAlt = 10;
		if(rowCnt+1 < noOfRows && waterBED[rowCnt+1][colCnt] <= lowestAlt){
			lowestAlt = waterBED[rowCnt+1][colCnt];
			rowNCol[0]=rowCnt+1;
			rowNCol[1]=colCnt;
		}
		if(colCnt+1 < noOfCol && waterBED[rowCnt][colCnt+1] <= lowestAlt){
			lowestAlt = waterBED[rowCnt][colCnt+1];
			rowNCol[0]=rowCnt;
			rowNCol[1]=colCnt+1;
		}
		if(colCnt-1 >= 0 && waterBED[rowCnt][colCnt-1] <= lowestAlt){
			lowestAlt = waterBED[rowCnt][colCnt-1];
			rowNCol[0]=rowCnt;
			rowNCol[1]=colCnt-1;
		}
		if(rowCnt-1 >= 0 && waterBED[rowCnt-1][colCnt] <= lowestAlt){
			lowestAlt = waterBED[rowCnt-1][colCnt];
			rowNCol[0]=rowCnt-1;
			rowNCol[1]=colCnt;
		}
		return rowNCol;
	}
}
