import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Date;


public class FairNSquare {
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		if(args == null || args.length < 2){
			System.err.println("Usage: FairNSquare <inFileName outFileName>");
		}
		FairNSquare calculator = new FairNSquare();
		calculator.calculate(args[0], args[1]);
	}
	
	private void calculate(String inFileName, String outFileName){
		FileHelper helper = new FileHelper();
		Date currentDate = new Date();
		try {
			helper.init(inFileName, outFileName);
			int totalTestCases = 0;
			try{
				totalTestCases = Integer.parseInt(helper.getNextLine());
			}catch(NumberFormatException e){
				System.err.println("First line is not a number.");
				e.printStackTrace();
				System.exit(0);
			}
			String currentLine;
			long start, end;
			int totalFairNSquare;
			for(int testCaseCount=0; testCaseCount < totalTestCases; testCaseCount++){
				System.out.println(testCaseCount);
				totalFairNSquare = 0;
				currentLine = helper.getNextLine();
				start = Long.parseLong(currentLine.substring(0, currentLine.indexOf(" ")));
				end = Long.parseLong(currentLine.substring(currentLine.indexOf(" ")+1, currentLine.length()));
				double startSqrt = 0;
				do{
					startSqrt = Math.sqrt(start);
					start++;
				}while(startSqrt % 1 != 0);
				double endSqrt = 0;
				do{
					endSqrt = Math.sqrt(end);
					end--;
				}while(endSqrt % 1 != 0);
				for(double counter=startSqrt;counter<=endSqrt;counter++){
					if(isPalindrome(counter) && isPalindrome(counter * counter)){
						totalFairNSquare++;
					}
				}
				helper.putNextLine("Case #"+(testCaseCount + 1) +": "+totalFairNSquare);
			}
		}catch(FileNotFoundException e){
			System.err.println("Error while initiating input file.");
			e.printStackTrace();
		} catch (IOException e) {
			System.err.println("Error while reading next line or creating output file.");
			e.printStackTrace();
		}finally{
			try {
				helper.cleanup();
			} catch (IOException e) {
				System.err.println("Error while closing streams.");
				e.printStackTrace();
			}
		}
		System.out.println("Total Time:"+ ((new Date().getTime() - currentDate.getTime()))/1000);
	}
	
	private boolean isPalindrome(double number){
		//System.out.println(number);
		String numberString = Double.toString(number);
		for(int index=0; index < numberString.lastIndexOf('.')/2;index++){
			if(numberString.charAt(index) != numberString.charAt(numberString.lastIndexOf('.')-(index + 1))){
				return false;
			}
		}
		return true;
	}
	
	private class FileHelper{
		private BufferedReader br = null;
		private BufferedWriter bw = null;
		private void init(final String inFfileName, final String outFileName) throws IOException{
			br = new BufferedReader(new FileReader(inFfileName));
			bw = new BufferedWriter(new FileWriter(outFileName));
		}
		
		private String getNextLine() throws IOException{
			String currentLine;
			while ((currentLine = br.readLine()) != null) {
				return currentLine;
			}
			return null;
		}
		
		private void cleanup() throws IOException{
			br.close();
			bw.flush();
			bw.close();
		}
		
		private void putNextLine(String content) throws IOException{
			bw.append(content).append("\n");
		}
	}

}
