import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
/**
 * An algorithm that will determine the number of possible 
 * interpretations for a given pattern for a given alien string.
 * @author Chandrakant Dhome
 */
public class AlienLanguageProcessor {
	private static String inputFileName = "A-small-attempt0.in";
	private static String outputFileName = "Output.out";
	private BufferedReader fileReader = null;
	private BufferedWriter fileWriter = null;
	
	public static void main(String[] args) {
		AlienLanguageProcessor processor = new AlienLanguageProcessor();
		processor.process();
	}
	private void process() {
		fileReader = FileHandler.getInputStreamFromFileName(inputFileName);
		if(fileReader == null){
			System.out.println("Cannot read from input file.");
			return;
		}
		fileWriter = FileHandler.getOutputStreamFromFileName(outputFileName);
		if(fileWriter == null){
			System.out.println("Cannot write to output file.");
			return;
		}
		int noOfTestCases = 0;
		int noOfWords = 0;
		int wordLength = 0;
		int noOfPossibilities = 0;
	
		try {
			String[] dbMETAarr = fileReader.readLine().split("\\s");
			wordLength = new Integer(dbMETAarr[0]).intValue();
			noOfWords = new Integer(dbMETAarr[1]).intValue();
			noOfTestCases = new Integer(dbMETAarr[2]).intValue();
		} catch (NumberFormatException e) {
			e.printStackTrace();
			System.out.println("First line contains invalid META data.");
			return;
		} catch (IOException e) {
			e.printStackTrace();
			System.out.println("Error reading file, "+inputFileName);
			return;
		}
		if(wordLength == 0 || noOfWords == 0 || noOfTestCases == 0){
			System.out.println("Invalid META conditions, wordLength="+wordLength+", noOfWords="+noOfWords+", noOfTestCases="+noOfTestCases);
		}
		List wordArr = new ArrayList();
		String pattern = null;
		String[] patternArr = null;;
		try {
			for(int wordCounter = 0; wordCounter < noOfWords; wordCounter++){
				wordArr.add(fileReader.readLine());
			}
			for(int patternCount = 0; patternCount < noOfTestCases; patternCount++){
				noOfPossibilities = 0;
				pattern = fileReader.readLine();
				patternArr = createPatternArr(pattern, wordLength);
				Iterator wordArrIter = wordArr.iterator();
				while(wordArrIter.hasNext()){
					String nextWord = (String)wordArrIter.next();
					int charCnt = 0;
					while(charCnt<wordLength){
						if(patternArr[charCnt].indexOf(nextWord.charAt(charCnt)) < 0)
							break;
						charCnt++;
					}
					if(charCnt == wordLength)
					noOfPossibilities++;
				}
				fileWriter.append("Case #"+(patternCount+1)+": "+noOfPossibilities+"\n");
			}
			
		} catch (IOException e) {
			System.out.println(e.getMessage());
			e.printStackTrace();
		}finally{
			try {
				fileReader.close();
				fileWriter.close();
			} catch (IOException e) {
				e.printStackTrace();
				System.out.println("File reader/writer cannot be closed...Exiting.");
			}
		}
	}
	
	private String[] createPatternArr(String pattern, int noOfChars) {
		String[] patternArr = new String[noOfChars];
		int parOpenIndex = pattern.indexOf('(');
		int parCloseIndex = -1;
		int patternCnt = 0;
		while(parOpenIndex > -1)
		{
			parCloseIndex = pattern.indexOf(')', parOpenIndex);
			patternArr[patternCnt] = pattern.substring(parOpenIndex+1, parCloseIndex);
			patternCnt++;
			parOpenIndex = pattern.indexOf('(', parCloseIndex);
		}
		parCloseIndex++;
		while(parCloseIndex < pattern.length()){
			patternArr[patternCnt] = String.valueOf(pattern.charAt(parCloseIndex));
			patternCnt++;parCloseIndex++;
		}
		return patternArr;
	}
}
