import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.StringTokenizer;


public class LawnMower {
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		if(args == null || args.length < 2){
			System.err.println("Usage: LawnMower <inFileName outFileName>");
		}
		LawnMower mower = new LawnMower();
		mower.mowLawn(args[0], args[1]);
	}
	
	private void mowLawn(String inFileName, String outFileName){
		FileHelper helper = new FileHelper();
		try {
			helper.init(inFileName, outFileName);
			int totalTestCases = 0;
			try{
				totalTestCases = Integer.parseInt(helper.getNextLine());
			}catch(NumberFormatException e){
				System.err.println("First line is not a number.");
				e.printStackTrace();
				System.exit(0);
			}
			int noOfRows = 0, noOfColumns = 0;
			String metaData;
			StringTokenizer rowTokenizer = null;
			int[][] lawn;
			testCaseLoop: for(int currentTestCase=0; currentTestCase < totalTestCases; currentTestCase++){
				try{
					metaData = helper.getNextLine();
					noOfRows = Integer.parseInt(metaData.substring(0,metaData.indexOf(" ")));
					noOfColumns = Integer.parseInt(metaData.substring(metaData.indexOf(" ")+1,metaData.length()));
				}catch(NumberFormatException e){
					System.err.println("First line is not a number.");
					e.printStackTrace();
					System.exit(0);
				}
				lawn = new int[noOfRows][noOfColumns];
				int columnNum;
				for(int rowNum = 0; rowNum < noOfRows; rowNum++){
					columnNum = 0;
					rowTokenizer = new StringTokenizer(helper.getNextLine());
					while(rowTokenizer.hasMoreTokens()){
						lawn[rowNum][columnNum] = Integer.parseInt(rowTokenizer.nextToken());
						columnNum++;	
					}
				}
				
				for(int rowNum = 0; rowNum < noOfRows; rowNum++){
					for(columnNum = 0; columnNum < noOfColumns; columnNum++){
						int heightToCompare = lawn[rowNum][columnNum];
						int tempRowNum;
						for(tempRowNum=0; tempRowNum<noOfRows;tempRowNum++){
							if(lawn[tempRowNum][columnNum] > heightToCompare ){
								break;
							}
						}
						if(tempRowNum == noOfRows) continue;
						int tempColumnNum;
						for(tempColumnNum=0; tempColumnNum<noOfColumns;tempColumnNum++){
							if(lawn[rowNum][tempColumnNum] > heightToCompare ){
								helper.putNextLine("Case #"+(currentTestCase+1) +": NO");
								continue testCaseLoop;
							}
						}
					}
				}
			helper.putNextLine("Case #"+(currentTestCase+1) +": YES");
			}
		}catch(FileNotFoundException e){
			System.err.println("Error while initiating input file.");
			e.printStackTrace();
		} catch (IOException e) {
			System.err.println("Error while reading next line or creating output file.");
			e.printStackTrace();
		}finally{
			try {
				helper.cleanup();
			} catch (IOException e) {
				System.err.println("Error while closing streams.");
				e.printStackTrace();
			}
		}
	}
	
	private class FileHelper{
		private BufferedReader br = null;
		private BufferedWriter bw = null;
		private void init(final String inFfileName, final String outFileName) throws IOException{
			br = new BufferedReader(new FileReader(inFfileName));
			bw = new BufferedWriter(new FileWriter(outFileName));
		}
		
		private String getNextLine() throws IOException{
			String currentLine;
			while ((currentLine = br.readLine()) != null) {
				return currentLine;
			}
			return null;
		}
		
		private void cleanup() throws IOException{
			br.close();
			bw.flush();
			bw.close();
		}
		
		private void putNextLine(String content) throws IOException{
			bw.append(content).append("\n");
		}
	}

}
