package jam.qualif.c;

import java.io.IOException;

import file.input.InputProcessor;
import file.output.OutputGenerator;

public class Main {

	public static void main(String[] args) throws IOException {
		String file = "C-small-attempt1";
		ProblemInputProcessor pip = new ProblemInputProcessor(file + ".in");
		pip.startProcess();
		OutputGenerator og = new OutputGenerator(file + ".out",
				pip.getNumberOfTestCases());
		for (ProblemInput problemInput : pip) {
			System.out.println("Case: "+pip.getCurrentTestCaseNumber());
			og.printTestResult("\n" + problemInput.solve());
		}
		pip.endProcess();
		og.end();
		System.out.println("Done");
	}

}

class ProblemInputProcessor extends InputProcessor<ProblemInput> {

	public ProblemInputProcessor(String inputFile) {
		super(inputFile);
	}

	@Override
	protected ProblemInput getNextTestCase() {
		String[] inputs = getNextLine().split(" ");
		return new ProblemInput(Integer.parseInt(inputs[1]),
				Integer.parseInt(inputs[0]), getNextLine());
	}

}

class ProblemInput {

	private static final String YES = "YES";
	private static final String NO = "NO";

	static final int[][] transitions = new int[][] { 
		{ 1, 2, 3, 4 },
		{ 2, -1, 4, -3 },
		{ 3, -4, -1, 2 },
		{ 4, 3, -2, -1 } };

	int x;
	int l;
	String s;

	int[] str;

	public ProblemInput(int x, int l, String s) {
		this.x = x;
		this.l = l;
		this.s = s;
		str = new int[x * l];
		for (int i = 0; i < x * l; i++) {
			switch (s.charAt(i%l)) {
				case 'i':
					str[i] = 2;
					break;
				case 'j':
					str[i] = 3;
					break;
				case 'k':
					str[i] = 4;
					break;
				default:
					break;
			}
		}
	}

	public String solve() {
		int accI = 1;
		for (int i = 0; i < x * l; i++) {
			accI = multiply(accI, str[i]);
			if(accI == 2) {
				int accJ = 1;
				for(int j=i+1; j < x *l; j++) {
					accJ = multiply(accJ, str[j]);
					if(accJ == 3) {
						int accK =1;
						for(int k=j+1; k < x*l; k++) {
							accK = multiply(accK, str[k]);
						}
						if(accK == 4) {
							return YES;
						}
					}
				}
			}
		}
		return NO;
	}

	public int multiply(int a, int b) {
		int sga = a > 0 ? 1 : -1;
		int sgb = b > 0 ? 1 : -1;
		return sga * sgb * transitions[sga * a - 1][sgb * b - 1];
	}
}
