package file.input;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Iterator;

public abstract class InputProcessor<T> implements Iterable<T> {

	private String inputFile;
	private int numberOfTestCases;
	
	private int currentTestCaseNumber ;
	
	private BufferedReader br;
	
	public InputProcessor(String inputFile) {
		this.inputFile = inputFile;
	}
	
	public void startProcess() throws IOException {
		FileInputStream fis = new FileInputStream(inputFile);
		br = new BufferedReader(new InputStreamReader(fis));
		initNumberOfTestCases();
		this.currentTestCaseNumber = 1;
	}
	
	protected void initNumberOfTestCases() {
		try {
			String firstLine = br.readLine();
			numberOfTestCases = Integer.parseInt(firstLine);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	public void endProcess() {
		if(br != null) {
			try {
				br.close();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
	}
	
	protected abstract T getNextTestCase();
	
	protected T getNextTestCaseWrapper() {
		T result = getNextTestCase();
		currentTestCaseNumber++;
		return result;
	}

	@Override
	public Iterator<T> iterator() {
		return new InputProcessorIterator();
	}
	
	protected BufferedReader getReader() {
		return br;
	}
	
	protected String getNextLine() {
		try {
			return getReader().readLine();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return null;
	}
	
	public int getNumberOfTestCases() {
		return numberOfTestCases;
	}
	
	public int getCurrentTestCaseNumber() {
		return currentTestCaseNumber;
	}
	
	class InputProcessorIterator implements Iterator<T> {

		@Override
		public boolean hasNext() {
			return getCurrentTestCaseNumber() <= getNumberOfTestCases(); 
		}

		@Override
		public T next() {
			return getNextTestCaseWrapper();
		}

		@Override
		public void remove() {
			// NA
		}
		
	}

}
