package jam.qualif.d;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.TreeMap;
import java.util.TreeSet;

public class TreasureQuest {

	public static final String IMPOSSIBLE = "IMPOSSIBLE";

	int numberOfKeys;
	int numberOfChests;
	List<Integer> startKeys;
	TreeMap<Integer, Chest> chests = new TreeMap<Integer, Chest>();

	public TreasureQuest(int numberOfKeys, int numberOfChests,
			List<Integer> startKey) {
		this.numberOfKeys = numberOfKeys;
		this.numberOfChests = numberOfChests;
		this.startKeys = startKey;
	}

	public String solve() {
		ArrayList<Integer> opened = new ArrayList<Integer>();
		TreeSet<Integer> toOpen = new TreeSet<Integer>(chests.keySet());
		ArrayList<Integer> keys = new ArrayList<Integer>();
		keys.addAll(startKeys);

		boolean canOpen = true;
		Integer lastTrial = 0;
		while (canOpen) {
			Integer toOpenChestNum = toOpen.higher(lastTrial);
			Chest c = chests.get(toOpenChestNum);
			if (c.open(keys)) {
				// open the chest
				opened.add(toOpenChestNum);
				toOpen.remove(toOpenChestNum);
				keys.addAll(c.keysInside);
				lastTrial = 0;
				if (toOpen.size() == 0) {
					return concat(opened);
				}
				canOpen = toOpen.size() > 0;
			} else {
				if (toOpen.higher(toOpenChestNum) != null) {
					// continue opening
					lastTrial = toOpenChestNum;
					canOpen = true;
				} else {
					while (canOpen) {
						// backout if possible
						if (opened.size() == 0) {
							canOpen = false;
							return IMPOSSIBLE;
						} else {

							lastTrial = opened.remove(opened.size() - 1);
							toOpen.add(lastTrial);
							Chest c2 = chests.get(lastTrial);
							for (Integer k : c2.getKeysInside()) {
								keys.remove(k);
							}
							keys.add(c2.getKeyType());
							canOpen = toOpen.higher(lastTrial) != null;
						}
					}
				}
			}
		}
		return IMPOSSIBLE;
	}

	private static String concat(ArrayList<Integer> chests) {
		if (chests.size() == 0) {
			return "";
		}
		StringBuilder sb = new StringBuilder(Integer.toString(chests.get(0)));
		for (int i = 1; i < chests.size(); i++) {
			sb.append(" ").append(Integer.toString(chests.get(i)));
		}
		return sb.toString();
	}

	public void addChest(Integer i, Chest c) {
		chests.put(i, c);
	}

}

class Chest {

	int keyType;
	int numKeysInside;
	List<Integer> keysInside = new ArrayList<Integer>();

	public Chest(int keyType, int numKeysInside) {
		this.keyType = keyType;
		this.numKeysInside = numKeysInside;
	}

	public void addKey(Integer key) {
		keysInside.add(key);
	}

	public boolean open(List<Integer> keys) {
		for (Iterator<Integer> iterator = keys.iterator(); iterator.hasNext();) {
			Integer key = iterator.next();
			if (key == keyType) {
				iterator.remove();
				return true;
			}
		}
		return false;
	}

	public List<Integer> getKeysInside() {
		return keysInside;
	}

	public int getKeyType() {
		return keyType;
	}

}
