package file.output;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;

public class OutputGenerator {

	private static final String PREFIX = "Case #%d:";
	private static final String ONE_LINE_TEMPLATE = PREFIX + " %s";

	private String outputFile;
	private int numTestCases;

	private PrintWriter pw;

	private int currentTestCase = 1;

	public OutputGenerator(String outputFile, int numTestCases)
			throws FileNotFoundException {
		this.outputFile = outputFile;
		this.numTestCases = numTestCases;
		pw = new PrintWriter(new File(outputFile));
	}

	/**
	 * Example: Case #1: my answer
	 * 
	 * @param result
	 */
	public void printOneLineTestResult(String result) {
		if (currentTestCase > numTestCases) {
			throw new IllegalStateException("Too many outputs");
		}
		pw.println(String.format(ONE_LINE_TEMPLATE, currentTestCase, result));
		currentTestCase++;
	}

	/**
	 * Example:<br>
	 * Case #1:<br>
	 * answer1<br>
	 * answer2<br>
	 * 
	 * @param result
	 */
	public void printTestResult(String result) {
		if (currentTestCase > numTestCases) {
			throw new IllegalStateException("Too many outputs");
		}
		pw.println(String.format(PREFIX, currentTestCase) + result);
		currentTestCase++;
	}

	public void end() {
		if (pw != null) {
			pw.close();
		}
	}

	public String getOutputFile() {
		return outputFile;
	}

	public int getNumTestCases() {
		return numTestCases;
	}

	public int getCurrentTestCase() {
		return currentTestCase;
	}

}
