import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Scanner;

public class Main{

	/**
	 * @param args
	 */
	public static void main(String[] args){
		try{
			final File file = new File(args[0]);
			final Scanner scanner = new Scanner(file);
			final String name = file.getName();
			final TicTacToeTomek ticTacToe = new TicTacToeTomek(new File(name.substring(0, name.length() - 2) + "out"));

			boolean start = true;
			int noOfCases = 0;
			int caseNo = 0;
			int lineNo = 0;
			boolean notFinished = false;
			boolean done = false;
			while(scanner.hasNextLine() && caseNo <= noOfCases){
				final String line = scanner.nextLine();
				if(start){
					noOfCases = Integer.parseInt(line);
					start = false;
					caseNo = 1;
				}else{
					if(ticTacToe.addLine(caseNo, lineNo, line)){
						while(lineNo < 4){
							if(scanner.hasNextLine()){
								scanner.nextLine();
							}
							lineNo++;
						}
						done = true;
					}else{
						lineNo++;
					}
					if(lineNo == 4){
						if(!done){
							//check verticals and diagonals
							for(int i = 0; i < 4; i++){
								final int outcome = ticTacToe.analyseVertical(i);
								if(outcome == TicTacToeTomek.SQUARE_X){
									ticTacToe.output(caseNo, TicTacToeTomek.SQUARE_X);
									done = true;
									break;
								}else if(outcome == TicTacToeTomek.SQUARE_O){
									ticTacToe.output(caseNo, TicTacToeTomek.SQUARE_O);
									done = true;
									break;
								}else if(outcome == TicTacToeTomek.SQUARE_EMPTY){
									notFinished = true;
								}
							}
							if(!done){
								final int outcome = ticTacToe.analyseDiagonals();
								if(outcome == TicTacToeTomek.SQUARE_X){
									ticTacToe.output(caseNo, TicTacToeTomek.SQUARE_X);
								}else if(outcome == TicTacToeTomek.SQUARE_O){
									ticTacToe.output(caseNo, TicTacToeTomek.SQUARE_O);
								}else{
									if(notFinished){
										ticTacToe.output(caseNo, TicTacToeTomek.SQUARE_EMPTY);
									}else{
										ticTacToe.output(caseNo, TicTacToeTomek.SQUARE_T);
									}
								}
							}
							//go to the next case
							if(scanner.hasNextLine()){
								scanner.nextLine();
							}
						}
						//reset all variables
						notFinished = false;
						done = false;
						caseNo++;
						lineNo = 0;
					}
				}
			}
			ticTacToe.close();
			scanner.close();
		}catch(FileNotFoundException e){
			e.printStackTrace();
		}
	}

	public static class TicTacToeTomek{
		public final static int SQUARE_EMPTY = 0, SQUARE_X = 1, SQUARE_O = 2, SQUARE_T = 3;
		public final static char SYMBOL_EMPTY = '.', SYMBOL_X = 'X', SYMBOL_O = 'O', SYMBOL_T = 'T';
		public final static String[] OUTCOMES = { "Game has not completed", "X won", "O won", "Draw"};
		public final int[][] squares = new int[4][4];
		public PrintWriter out;

		public TicTacToeTomek(File file){
			try{
				out = new PrintWriter(new FileWriter(file));
			}catch(IOException e){
				e.printStackTrace();
			}
		}

		public final boolean addLine(int caseNo, int line, String l){
			if(line >= 0 && line < 4){
				for(int i = 0; i < 4; i++){
					if(l.charAt(i) == SYMBOL_EMPTY){
						squares[line][i] = SQUARE_EMPTY;
					}else if(l.charAt(i) == SYMBOL_X){
						squares[line][i] = SQUARE_X;
					}else if(l.charAt(i) == SYMBOL_O){
						squares[line][i] = SQUARE_O;
					}else{
						squares[line][i] = SQUARE_T;
					}
				}
				final int outcome = analyseHorizontal(line);
				if(outcome == SQUARE_X){
					output(caseNo, SQUARE_X);
					return true;
				}else if(outcome == SQUARE_O){
					output(caseNo, SQUARE_O);
					return true;
				}
			}
			return false;
		}

		public final int analyseHorizontal(int l){
			int start = 1;
			int first = squares[l][0];
			if(first == SQUARE_T){
				start = 2;
				first = squares[l][1];
			}
			if(first == SQUARE_EMPTY){
				return SQUARE_EMPTY;
			}
			for(int i = start; i < 4; i++){
				if(squares[l][i] == SQUARE_T || squares[l][i] == first){
					continue;
				}else if(squares[l][i] == SQUARE_EMPTY){
					return SQUARE_EMPTY;
				}else{
					return SQUARE_T;
				}
			}
			return first;
		}

		public final int analyseVertical(int l){
			boolean notSame = false;
			int start = 1;
			int first = squares[0][l];
			if(first == SQUARE_T){
				start = 2;
				first = squares[1][l];
			}
			if(first == SQUARE_EMPTY){
				return SQUARE_EMPTY;
			}
			for(int i = start; i < 4; i++){
				if(squares[i][l] == SQUARE_T || squares[i][l] == first){
					continue;
				}else if(squares[i][l] == SQUARE_EMPTY){
					return SQUARE_EMPTY;
				}else{
					if(notSame && i == 3){
						return SQUARE_T;
					}else{
						notSame = true;
					}
				}
			}
			if(notSame){
				return SQUARE_T;
			}
			return first;
		}

		public int analyseDiagonals(){
			int outcome = -1;
			int start = 1;
			int first = squares[0][0];
			if(first == SQUARE_T){
				first = squares[1][1];
				start = 2;
			}
			if(first == SQUARE_EMPTY){
				outcome = SQUARE_EMPTY;
			}
			if(outcome != SQUARE_EMPTY){
				for(int i = start; i < 4; i++){
					if(squares[i][i] == SQUARE_T || squares[i][i] == first){
						continue;
					}else if(squares[i][i] == SQUARE_EMPTY){
						outcome = SQUARE_EMPTY;
						break;
					}else{
						outcome = SQUARE_T;
						break;
					}
				}
				if(outcome == -1){
					return first;
				}
			}
			start = 1;
			first = squares[0][3];
			if(first == SQUARE_T){
				first = squares[1][2];
				start = 2;
			}
			if(first == SQUARE_EMPTY){
				return SQUARE_EMPTY;
			}
			for(int i = start; i < 4; i++){
				if(squares[i][3 - i] == SQUARE_T || squares[i][3 - i] == first){
					continue;
				}else if(squares[i][3 - i] == SQUARE_EMPTY){
					return SQUARE_EMPTY;
				}else{
					if(outcome == SQUARE_T){
						return SQUARE_T;
					}else{
						return SQUARE_EMPTY;
					}
				}
			}
			return first;
		}

		public final void output(int caseNo, int t){
			final String s = "Case #" + caseNo + ": " + OUTCOMES[t];
			System.out.println(s);
			out.println(s);
		}

		public final void close(){
			out.close();
		}
	}

}
