package com.boney.google;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.List;
import java.util.Set;
import java.util.SortedSet;

import org.apache.commons.lang.StringUtils;

import com.google.common.base.Throwables;
import com.google.common.collect.Lists;
import com.google.common.collect.Sets;

import edu.emory.mathcs.backport.java.util.Arrays;

public class LawnMover {

	public static void main(String[] args) {
		LawnMover sk = new LawnMover();
		try {
			sk.doTheJob();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	class GardenSquare {
		int currHeight;
		boolean hasBeenCut;

		public GardenSquare(int currHeight, boolean hasBeenCut) {
			this.currHeight = currHeight;
			this.hasBeenCut = hasBeenCut;
		}

		public boolean canCutTo(int newHeight) {
			if (hasBeenCut) {
				return newHeight == currHeight;
			}
			return newHeight <= currHeight;
		}

		@Override
		public String toString() {
			return currHeight + " " + hasBeenCut;
		}

	}

	private void doTheJob() throws Exception {
		String thisLine;
		String inputFileName = "C:/Boney/Google/QR2013/lawnmover-input.txt";
		FileWriter fw = new FileWriter(
				"C:/Boney/Google/QR2013/lawnmover-output.txt");
		try {
			BufferedReader br = new BufferedReader(
					new FileReader(inputFileName));
			thisLine = br.readLine();
			int totalTestCases = Integer.parseInt(thisLine);
			System.out.println("Total test cases: " + totalTestCases);
			for (int testCase = 0; testCase < totalTestCases; testCase++) {
				boolean allTrue = true;
				thisLine = br.readLine();
				List<String> splitIntsStsrs = Lists.newArrayList(StringUtils
						.split(thisLine, ' '));
				int N = Integer.parseInt(splitIntsStsrs.get(0));
				int M = Integer.parseInt(splitIntsStsrs.get(1));
				int garden[][] = new int[N][M];
				SortedSet<Integer> uniqueHeights = Sets.newTreeSet();
				for (int i = 0; i < N; i++) {
					thisLine = br.readLine();
					splitIntsStsrs = Lists.newArrayList(StringUtils.split(
							thisLine, ' '));
					for (int j = 0; j < M; j++) {
						garden[i][j] = Integer.parseInt(splitIntsStsrs.get(j));
						uniqueHeights.add(garden[i][j]);
					}
				}
				System.out.println("\nNew garden, all wanted heights : "
						+ uniqueHeights + " \n");
				System.out.println("\nNew garden, max height "
						+ uniqueHeights.last() + " \n");
				for (int i = 0; i < garden.length; i++) {
					System.out.println(Arrays.toString(garden[i]));
				}

				if (uniqueHeights.last() > 100) {
					System.out.println("\n>>>>>>>>>>>>>>> Max height not supported! "
									+ uniqueHeights.last() + " \n");
					allTrue = false;
				} else {
					// Assume garden can be cut to the max height
					List<Integer> heights = Lists.reverse(Lists
							.newArrayList(uniqueHeights.headSet(
									uniqueHeights.last()).iterator()));
					System.out.println("New list of heights " + heights);

					GardenSquare cutgarden[][] = new GardenSquare[N][M];
					for (int i = 0; i < N; i++) {
						for (int j = 0; j < M; j++) {
							if (garden[i][j] == uniqueHeights.last()) {
								cutgarden[i][j] = new GardenSquare(
										uniqueHeights.last(), true);
							} else {
								cutgarden[i][j] = new GardenSquare(
										uniqueHeights.last(), false);
							}
						}
					}

					for (int height : heights) {
						for (int i = 0; i < N; i++) {
							boolean canCutRow = true;
							for (int t = 0; t < M; t++) {
								if (!cutgarden[i][t].canCutTo(height)) {
									canCutRow = false;
									break;
								}
							}
							if (canCutRow) {
								for (int t = 0; t < M; t++) {
									cutgarden[i][t].currHeight = height;
									if (cutgarden[i][t].currHeight == garden[i][t]) {
										cutgarden[i][t].hasBeenCut = true;
									}
								}
							}
						}
						

						for (int j = 0; j < M; j++) {
							boolean canCutRow = true;
							for (int t = 0; t < N; t++) {
								if (!cutgarden[t][j].canCutTo(height)) {
									canCutRow = false;
									break;
								}
							}
							if (canCutRow) {
								for (int t = 0; t < N; t++) {
									cutgarden[t][j].currHeight = height;
									if (cutgarden[t][j].currHeight == garden[t][j]) {
										cutgarden[t][j].hasBeenCut = true;
									}
								}
							}
						}
					
					}
						
					System.out.println("\nAfter cut to max height "
							+ uniqueHeights.last() + " \n");
					for (int i = 0; i < N; i++) {
						for (int j = 0; j < M; j++) {
							System.out.print(" " + cutgarden[i][j]);
							allTrue = allTrue && cutgarden[i][j].hasBeenCut;
						}
						System.out.println();
					}

				}
				
				System.out.println("Case #" + (testCase + 1) + " " + (allTrue ? "YES" : "NO") );
				fw.write("Case #" + (testCase + 1) + ": " + (allTrue ? "YES" : "NO") + "\n");

			}

			fw.flush();
			fw.close();
			br.close();
		} // end try
		catch (Exception e) {
			System.err.println("Error: " + e);
			Throwables.propagate(e);
		}
	}

}
