package com.boney.google;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.List;

import com.google.common.collect.Lists;

import edu.emory.mathcs.backport.java.util.Arrays;

public class TicTacToe {

	public static void main(String[] args) {

		TicTacToe sk = new TicTacToe();
		try {
			sk.doTheJob();
		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	enum GameResults {

		X_WON("X won"), O_WON("O won"), DRAW("Draw"), NOT_COMPLETE(
				"Game has not completed"), ;

		private String result;

		private GameResults(String str) {
			this.result = str;
		}

		public boolean isNotComplete() {
			return this == NOT_COMPLETE;
		}

		public String getResult() {
			return result;
		}
	}

	private void doTheJob() throws Exception {

		String thisLine;
		String inputFileName = "C:/Boney/Google/QR2013/tictactoe-input.txt";
		FileWriter fw = new FileWriter(
				"C:/Boney/Google/QR2013/tictactoe-output.txt");
		try {
			BufferedReader br = new BufferedReader(
					new FileReader(inputFileName));
			thisLine = br.readLine();
			int totalTestCases = Integer.parseInt(thisLine);
			System.out.println("Total test cases: " + totalTestCases);
			StringBuilder out;
			for (int testCase = 0; testCase < totalTestCases; testCase++) {
				boolean containsEmpty = false;
				GameResults gameResults = GameResults.NOT_COMPLETE;
				char[][] gameState = new char[4][4];

				boolean hasXWon = true;
				boolean hasOWon = true;
				List<String> testCaseStrings = Lists.newArrayList();
				for (int j = 0; j < 4; j++) {
					testCaseStrings.add(br.readLine());
				}
				br.readLine(); // For empty line
				for (int j = 0; j < 4; j++) {
					thisLine = testCaseStrings.get(j);
					if (thisLine.length() != 4) {
						throw new RuntimeException("Error parsing input "
								+ thisLine);
					}
					hasXWon = true;
					hasOWon = true;
					for (int i = 0; i < 4; i++) {
						gameState[j][i] = thisLine.charAt(i);
						if (thisLine.charAt(i) == '.') {
							containsEmpty = true;
						}
						if (hasXWon
								&& !(thisLine.charAt(i) == 'X' || thisLine
										.charAt(i) == 'T')) {
							hasXWon = false;
						}
						if (hasOWon
								&& !(thisLine.charAt(i) == 'O' || thisLine
										.charAt(i) == 'T')) {
							hasOWon = false;
						}
					}
					if (hasXWon) {
						gameResults = GameResults.X_WON;
						break;
					} else if (hasOWon) {
						gameResults = GameResults.O_WON;
						break;
					}
				}
				System.out.println("\nNext Game\n");
				for (int i = 0; i < gameState.length; i++) {
					System.out.println(Arrays.toString(gameState[i]));
				}

				// Has X won?
				// Horizontal X - 0,1,2,3 - checked!

				// Vertical Y - 0X,1X,2X,3X
				// Diagnal where X=Y
				if (gameResults.isNotComplete()) {
					boolean hasXWonDiag = true;
					boolean hasOWonDiag = true;
					for (int j = 0; j < 4; j++) {
						hasXWon = true;
						hasOWon = true;
						for (int i = 0; i < 4; i++) {
							if (hasXWon
									&& !(gameState[i][j] == 'X' || gameState[i][j] == 'T')) {
								hasXWon = false;
							}
							if (hasOWon
									&& !(gameState[i][j] == 'O' || gameState[i][j] == 'T')) {
								hasOWon = false;
							}
						}
						if (hasXWon) {
							gameResults = GameResults.X_WON;
							break;
						} else if (hasOWon) {
							gameResults = GameResults.O_WON;
							break;
						}

						if (hasXWonDiag
								&& !(gameState[j][j] == 'X' || gameState[j][j] == 'T')) {
							hasXWonDiag = false;
						}
						if (hasOWonDiag
								&& !(gameState[j][j] == 'O' || gameState[j][j] == 'T')) {
							hasOWonDiag = false;
						}
					}

					if (!hasXWon && !hasOWon && hasXWonDiag) {
						gameResults = GameResults.X_WON;
					} else if (!hasXWon && !hasOWon && hasOWonDiag) {
						gameResults = GameResults.O_WON;
					}
					if (gameResults.isNotComplete()) {
						int x = 0;
						int y = 3;
						hasXWonDiag = true;
						hasOWonDiag = true;
						while (x < 4) {
							if (hasXWonDiag
									&& !(gameState[x][y] == 'X' || gameState[x][y] == 'T')) {
								hasXWonDiag = false;
							}
							if (hasOWonDiag
									&& !(gameState[x][y] == 'O' || gameState[x][y] == 'T')) {
								hasOWonDiag = false;
							}
							x++;
							y--;
						}

						if (hasXWonDiag) {
							gameResults = GameResults.X_WON;
						} else if (hasOWonDiag) {
							gameResults = GameResults.O_WON;
						}
					}
				}
				if(!containsEmpty && gameResults.isNotComplete()) {
					gameResults = GameResults.DRAW;
				}
				System.out.println("Case #" + (testCase + 1) + " " + gameResults.getResult());
				fw.write("Case #" + (testCase + 1) + ": " + gameResults.getResult() + "\n");
			}

			fw.flush();
			fw.close();
			br.close();
		} // end try
		catch (IOException e) {
			System.err.println("Error: " + e);
		}

	}

}
