package com.boney.google;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.List;
import java.util.SortedSet;

import org.apache.commons.lang.StringUtils;

import com.google.common.collect.Lists;
import com.google.common.collect.Sets;

public class FairAndSquare {

	public static void main(String[] args) {
		FairAndSquare sk = new FairAndSquare();
		try {
			sk.doTheJob();
		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	private void doTheJob() throws Exception {
		String thisLine;
		String inputFileName = "C:/Boney/Google/QR2013/fairsquare-input.txt";
		FileWriter fw = new FileWriter(
				"C:/Boney/Google/QR2013/fairsquare-output.txt");
		try {
			BufferedReader br = new BufferedReader(
					new FileReader(inputFileName));
			thisLine = br.readLine();
			int totalTestCases = Integer.parseInt(thisLine);
			System.out.println("Total test cases: "
					+ totalTestCases);
			for (int testCase = 0; testCase < totalTestCases; testCase++) {
				thisLine = br.readLine();
				List<String> splitIntsStsrs = Lists.newArrayList(StringUtils.split(thisLine, ' '));
				BigDecimal start = new BigDecimal(splitIntsStsrs.get(0));
				BigDecimal limit = new BigDecimal(splitIntsStsrs.get(1));
				System.out.println("Limit starts at " + start.toPlainString() + " and ends at " + limit.toPlainString());
				SortedSet<BigDecimal> potentialSquares = getPotentialSquares(start, limit);
				System.out.println("Potential squares : " + potentialSquares);
				System.out.println("Case #" + (testCase + 1) + ": " + potentialSquares.size());
				fw.write("Case #" + (testCase + 1) + ": " + potentialSquares.size() + "\n");
			}
			fw.flush();
			fw.close();
			br.close();
		} // end try
		catch (IOException e) {
			System.err.println("Error: " + e);
		}

	}
	
	static final BigDecimal TWO = new BigDecimal(2);
	static final BigDecimal THREE = new BigDecimal(3);
	static final BigDecimal FOUR = new BigDecimal(4);
	static final BigDecimal NINE = new BigDecimal(9);
	
	SortedSet<BigDecimal> getTrimmedSet(SortedSet<BigDecimal> origSet, BigDecimal start, BigDecimal limit) {
		SortedSet<BigDecimal> potentialSquarables = Sets.newTreeSet();
		for(BigDecimal bd : origSet) {
			BigDecimal powVal = bd.pow(2);
			System.out.println(powVal + " - " + start.compareTo(powVal) + " - " + limit.compareTo(powVal));
			if(start.compareTo(powVal) <= 0 && limit.compareTo(powVal) >= 0) {
				potentialSquarables.add(powVal);
			}
		}
		return potentialSquarables;
	}
	
	SortedSet<BigDecimal> getPotentialSquares(BigDecimal start, BigDecimal limit) {
		SortedSet<BigDecimal> potentialSquarables = Sets.newTreeSet();
		if(start.compareTo(BigDecimal.ONE) <= 0 && limit.compareTo(BigDecimal.ONE) >= 0) {
			potentialSquarables.add(BigDecimal.ONE);
		}
		if(start.compareTo(FOUR) <= 0 && limit.compareTo(FOUR) >= 0) {
			potentialSquarables.add(TWO);
		}
		if(start.compareTo(NINE) <= 0 && limit.compareTo(NINE) >= 0) {
			potentialSquarables.add(THREE);
		}
		if(limit.toPlainString().length() > 2)
		for (int i = 0; i < limit.toString().length()-2; i++) {
			boolean even = false;
			if (i % 2 == 0) {
				System.out.println("i is even " + i);
				even = true;
			}
			StringBuilder sb2 = new StringBuilder("2");
			for (int j = 0; j < i; j++) {
				sb2.append("0");
			}
			potentialSquarables.add(new BigDecimal(sb2.append("2").toString()));
			if (even) {
				potentialSquarables.addAll(getVariations("01", i));
			} else {
				potentialSquarables.addAll(getVariations("012", i));
				sb2 = new StringBuilder("2");
				for (int j = 0; j < i; j++) {
					if(j  == i / 2) {
						sb2.append("1");
					} else {
						sb2.append("0");
					}
				}
				potentialSquarables.add(new BigDecimal(sb2.append("2").toString()));
			}
			BigDecimal latestAdded = potentialSquarables.last();
			System.out.println("Latest added value " + latestAdded.toPlainString());
			BigDecimal lastAddPow = latestAdded.pow(2);
			if(lastAddPow.compareTo(limit) > 0) {
				// 400000080000004
				// 40000000000000
				// 20000002
				return getTrimmedSet(potentialSquarables.headSet(limit.add(BigDecimal.ONE)), start, limit);
			}
		}
		return getTrimmedSet(potentialSquarables.headSet(limit.add(BigDecimal.ONE)), start, limit);
	}
	
	public List<BigDecimal> getVariations(String a, int n) {
		int l = a.length();
		int numberOfOptions = (int) Math.pow(l, n);
		char[][] optionsTable = new char[numberOfOptions][n];

		for (int x = 0; x < n; x++) {
			int t2 = (int) Math.pow(l, x);
			for (int p1 = 0; p1 < numberOfOptions;) {
				for (int al = 0; al < l; al++) {
					for (int p2 = 0; p2 < t2; p2++) {
						optionsTable[p1][x] = a.charAt(al);
						p1++;
					}
				}
			}
		}

		List<BigDecimal> result = Lists.newArrayList();
		for (char[] option : optionsTable) {
			if (isThisAPalindrom(option)) {
				if (option.length % 2 == 1) {
					// Does this contain a 2, if yes, only if its in the middle, add it.
					boolean addIt = true;
					for(int t1 = 0; t1 < option.length; t1++) {
						if(option[t1] == '2' && t1 != (option.length/2)) {
							addIt = false;
							break;
						}
					}
					if(addIt) {
						result.add(new BigDecimal(new StringBuilder("1").append(option).append("1").toString()));
					}
				} else {
					result.add(new BigDecimal((new StringBuilder("1").append(option).append("1").toString())));
				}
			}
		}
		return result;
	}
	
	public boolean isThisAPalindrom(char[] numberCombo) {
		int x = 0;
		int y = numberCombo.length - 1;
		while (y > x) {
			if (numberCombo[x] != numberCombo[y]) {
				return false;
			}
			x++;
			y--;
		}
		return true;
	}

	
	

}
