package com.boney.codejam;

import java.io.File;
import java.io.FileWriter;
import java.util.Scanner;

public class MineSweeper {

	private static final String PATH = "C:/Boney/CodeJam/MineSweeper";

	private void doTheJob() throws Exception {
		Scanner scanner = new Scanner(new File(PATH + "/input.txt"));
		FileWriter fileWriter = new FileWriter(new File(PATH + "/output.txt"));
		int totalTestCases = Integer.parseInt(scanner.next());
		System.out.println("Total test cases : " + totalTestCases);
		for (int i = 0; i < totalTestCases; i++) {
			int rows = Integer.parseInt(scanner.next());
			int cols = Integer.parseInt(scanner.next());
			int mines = Integer.parseInt(scanner.next());
			System.out.println("Test Case " + (i + 1) + " : Rows " + rows + " Cols " + cols + " Mine " + mines + " Free " + ((rows * cols) - mines));

			char[][] arr = new char[rows][cols];
			fillWith(arr, '*');

			boolean impossible = false;
			if (mines == 0) {
				fillWith(arr, '.');
				arr[0][0] = 'c';
			} else {
				int totalCells = rows * cols;
				int freeCellsRequired = totalCells - mines;
				if (freeCellsRequired == 0) {
					impossible = true;
				} else {
					// 1 free cell .. rows * cols free cells.
					if (freeCellsRequired == 1) {
						arr[0][0] = 'c';
					} else {
						impossible = extractUsingMoveOnXAndY(rows, cols, mines, arr, totalCells, freeCellsRequired);
						// System.out.println("---");
						if (impossible) {
							fillWith(arr, '*');
							freeCellsRequired = totalCells - mines;
							impossible = moveOnYAndThenX(rows, cols, mines, arr, totalCells, freeCellsRequired);
						}
						// System.out.println("---");
						if (impossible) {
							fillWith(arr, '*');
							freeCellsRequired = totalCells - mines;
							impossible = anotherMove(rows, cols, mines, arr, totalCells, freeCellsRequired);
						}

					}
				}
			}

			if (!impossible) {
				System.out.println("Case #" + (i + 1) + ":");
				fileWriter.write("Case #" + (i + 1) + ":\n");
				for (int x = 0; x < rows; x++) {
					for (int y = 0; y < cols; y++) {
						System.out.print(arr[x][y] + " ");
						fileWriter.write(arr[x][y]);
					}
					System.out.println();
					fileWriter.write("\n");
				}
			} else {
				System.out.println("Case #" + (i + 1) + ": Impossible");
				fileWriter.write("Case #" + (i + 1) + ":\nImpossible\n");
			}
		}
		fileWriter.flush();
		fileWriter.close();
		scanner.close();
	}

	private boolean anotherMove(int rows, int cols, int mines, char[][] arr, int totalCells, int freeCellsRequired) {
		int curX = 0;
		int curY = 0;
		boolean impossible = false;
		boolean reset = false;
		while (freeCellsRequired > 0) {
			arr[curX][curY] = '0';
			// for (int x = 0; x < rows; x++) {
			// for (int y = 0; y < cols; y++) {
			// System.out.print(arr[x][y] + " ");
			// }
			// System.out.println();
			// }
			int freeCells = countFree(arr);
			if ((totalCells - freeCells) < mines) {
				impossible = true;
			}
			freeCellsRequired = totalCells - freeCells - mines;
			if (freeCellsRequired > 0) {

				if (freeCellsRequired >= 3) {
					if ((curY + 1) < cols) {
						curY++;
					}
					if ((curX + 1) < rows) {
						curX++;
					}
				} else {
					if (!reset) {
						curX = 0;
						curY = 0;
						reset = true;
					}
					// Shift Cursor
					if (cols >= rows) {
						if ((curY + 1) < cols) {
							curY++;
						} else if ((curX + 1) < rows) {
							curX++;
							curY = 0;
						} else {
							freeCellsRequired = 0;
						}
					} else {
						if ((curX + 1) < rows) {
							curX++;
						} else if ((curY + 1) < cols) {
							curY++;
							curX = 0;
						} else {
							freeCellsRequired = 0;
						}
					}
				}
			}
		}
		arr[curX][curY] = 'c';
		return impossible;
	}

	private boolean moveOnYAndThenX(int rows, int cols, int mines, char[][] arr, int totalCells, int freeCellsRequired) {
		int curX = 0;
		int curY = 0;
		boolean impossible = false;
		while (freeCellsRequired > 0) {
			arr[curX][curY] = '0';
			// for (int x = 0; x < rows; x++) {
			// for (int y = 0; y < cols; y++) {
			// System.out.print(arr[x][y] + " ");
			// }
			// System.out.println();
			// }
			int freeCells = countFree(arr);
			if ((totalCells - freeCells) < mines) {
				impossible = true;
			}
			freeCellsRequired = totalCells - freeCells - mines;
			if (freeCellsRequired > 0) {
				// Shift Cursor
				if (cols >= rows) {
					if ((curY + 1) < cols) {
						curY++;
					} else if ((curX + 1) < rows) {
						curX++;
						curY = 0;
					} else {
						freeCellsRequired = 0;
					}
				} else {
					if ((curX + 1) < rows) {
						curX++;
					} else if ((curY + 1) < cols) {
						curY++;
						curX = 0;
					} else {
						freeCellsRequired = 0;
					}
				}
			}
		}
		arr[curX][curY] = 'c';
		return impossible;
	}

	private boolean extractUsingMoveOnXAndY(int rows, int cols, int mines, char[][] arr, int totalCells, int freeCellsRequired) {
		int curX = 0;
		int curY = 0;
		int delta = 0;
		boolean impossible = false;
		boolean moveOnY = false;
		boolean moveOnX = false;
		if (cols >= rows) {
			moveOnY = true;
		} else {
			moveOnX = true;
		}
		while (freeCellsRequired > 0) {
			arr[curX][curY] = '0';
			// for (int x = 0; x < rows; x++) {
			// for (int y = 0; y < cols; y++) {
			// System.out.print(arr[x][y] + " ");
			// }
			// System.out.println();
			// }
			int freeCells = countFree(arr);
			if ((totalCells - freeCells) < mines) {
				impossible = true;
			}
			freeCellsRequired = totalCells - freeCells - mines;
			if (freeCellsRequired > 0) {
				// Shift Cursor
				if (moveOnY) {
					if ((curY + 1) < cols) {
						curY++;
					} else if ((curX + 1) < rows) {
						curX++;
						curY = delta++;
						moveOnX = true;
						moveOnY = false;
					} else {
						freeCellsRequired = 0;
					}
				} else if (moveOnX) {
					if ((curX + 1) < rows) {
						curX++;
					} else if ((curY + 1) < cols) {
						curY++;
						curX = delta;
						moveOnX = false;
						moveOnY = true;
					} else {
						freeCellsRequired = 0;
					}
				}
			}
		}
		arr[curX][curY] = 'c';
		return impossible;
	}

	private void fillWith(char[][] arr, char filler) {
		for (int x = 0; x < arr.length; x++) {
			for (int y = 0; y < arr[x].length; y++) {
				arr[x][y] = filler;
			}
		}
	}

	private int countFree(char[][] arr) {
		for (int x = 0; x < arr.length; x++) {
			for (int y = 0; y < arr[x].length; y++) {
				if (arr[x][y] == '0') {
					arr[x][y] = '.';
					if ((x - 1) >= 0) {
						arr[x - 1][y] = '.';
					}
					if ((x + 1) < arr.length) {
						arr[x + 1][y] = '.';
					}
					if (((x - 1) >= 0) && ((y - 1) >= 0)) {
						arr[x - 1][y - 1] = '.';
					}
					if (((x - 1) >= 0) && ((y + 1) < arr[x].length)) {
						arr[x - 1][y + 1] = '.';
					}
					if (((x + 1) < arr.length) && ((y - 1) >= 0)) {
						arr[x + 1][y - 1] = '.';
					}
					if (((x + 1) < arr.length) && ((y + 1) < arr[x].length)) {
						arr[x + 1][y + 1] = '.';
					}
					if ((y - 1) >= 0) {
						arr[x][y - 1] = '.';
					}
					if ((y + 1) < arr[x].length) {
						arr[x][y + 1] = '.';
					}
				}
			}
		}

		int count = 0;
		for (char[] element : arr) {
			for (char element2 : element) {
				if ((element2 == '.') || (element2 == '0')) {
					count++;
				}
			}
		}
		return count;
	}

	public static void main(String[] args) throws Exception {
		MineSweeper mt = new MineSweeper();
		mt.doTheJob();
	}

}
