package com.google.codejam.clue.welcome;

import java.lang.ref.PhantomReference;
import java.math.BigDecimal;

public class Matcher {
	// data to search sequence in
	private String data;
	
	// sequence to find
	private String pattern = "welcome to code jam";

	private Matcher(String data) {
		super();
		this.data = data;
	}
	
	public static Matcher getInstance(String data){
		return new Matcher(data);
		//wewwleclecoomelecome
	}
	
	public BigDecimal getExactSubSequenceCount() {
		return getExactSubSequenceCount(0);
	}
	
	public BigDecimal getExactSubSequenceCount(int recursion){
		final int patternLength = pattern.length();
		final int dataLength = data.length();
		/* We will iterate over string by collecting chars to create full phrase and ignoring 
		 * characters not on their places. Ignored chars form new string which will be analysed.
		 * If one phrase is collected, than set it's permutations count as multiplication of 
		 * char frequencies on necessary positions, other characters (event not iterated over are
		 * concatenated with ignored and analysed one more time.
		 * 
		 * Thus we could get some amount of phrases, their perm. count are multiplied. If no 
		 * full phrases, than result is zero.
		 * 
		 */
		int cursorPos = 0;
		StringBuffer deferredChars = new StringBuffer();
		
		int currExpCharNum = 0;		
		
		// accumulator for phrase permutations
		BigDecimal phraseResult = BigDecimal.ONE;
		
		// while cursor position is in string, iterate over characters of pattern string		
		while (currExpCharNum < patternLength && cursorPos < dataLength)	{			
			// currently iterated character
			char currExpChar = pattern.charAt(currExpCharNum);
			
			// position of currently iterated character
			int currExpCharPos = data.indexOf(currExpChar, cursorPos);
			
			// if character is not found, current phrase search is not successful
			if (currExpCharPos < 0) {
				Util.log(recursion, "Character '"+currExpChar+"' was not found. ");
				return BigDecimal.ZERO;				
				
			} else {
				// move cursor and add characters to deffered list
				while (cursorPos < currExpCharPos) {
					char cursorChar = data.charAt(cursorPos);
					
					// add only characters from pattern string
					if (pattern.indexOf(cursorChar) > 0) {
						deferredChars.append(cursorChar);
					}
					cursorPos++;
				}
				cursorPos = currExpCharPos;
				

				int charCount = 0;
				char cursorChar = currExpChar;
				boolean isIgnoredChar = false;
				
				char nextChar = 0;
				// search till next pattern char is found, if it's not present search till any pattern char is found 
				if (currExpCharNum < patternLength -1) {
					nextChar = pattern.charAt(nextChar+1);
				}
				
				// count subsequent characters, ignoring non-pattern characters
				while (cursorPos < dataLength && 
							(nextChar == 0 || cursorChar != nextChar)) {
										
					// calc only characters from pattern
					if (cursorChar == currExpChar) {
						charCount++;
					}
					
					cursorPos++;
					if (cursorPos < dataLength) {
						cursorChar = data.charAt(cursorPos);
						isIgnoredChar = pattern.indexOf(cursorChar) < 0;
					}
				}
				
				//Util.log(recursion, "Character '"+currExpChar+" was found "+charCount+" times.");
				
				// modify perm count
				phraseResult = phraseResult.multiply(BigDecimal.valueOf(charCount));
			}
			
			// search next char from pattern
			currExpCharNum++;
		}
		
		// phrase is constructed
		if (currExpCharNum == patternLength) {
			// search against characters left	
			// TODO: seems to be little design/algorithm misunderstanding:)
			deferredChars.append(data.substring(cursorPos));
			Matcher m = getInstance(deferredChars.toString());			
			Util.log(recursion, "Search more: '"+deferredChars+"'.");
			BigDecimal defferedStringResult = m.getExactSubSequenceCount(recursion+1);			
			

			if (!BigDecimal.ZERO.equals(defferedStringResult)) {
				// if subsequent search was successful,include to results 				
				BigDecimal res = defferedStringResult.multiply(phraseResult);
				Util.log(recursion, "Search more found " + defferedStringResult);
				return res;
				
			} else {
				// otherwise return current phrase results only
				Util.log(recursion, "Search more was not successful.");
				return phraseResult;
			}
		} else {
			// phrase was not constructed: we've not found last character of pattern anyway
			return BigDecimal.ZERO;
		}
	}
}
