package com.google.codejam.clue.welcome;

import java.util.Arrays;

public class Basin {
	int[][] attitudes;
	int width;
	int height;
	public Basin(int width, int height) {
		super();
		this.width = width;
		this.height = height;
		attitudes = new int[height][width];
	}
	
	public void setAttitude(int x, int y, int value) {
		attitudes[x][y] = value;
	}
	
	public static Basin getInstance(String values) {		
		int firstSpacePos = values.indexOf(" ");
		int secondSpacePos = values.indexOf(" ", firstSpacePos+1);
		int height = Integer.parseInt(values.substring(0, firstSpacePos));
		int width = Integer.parseInt(values.substring(firstSpacePos+1, secondSpacePos));
		
		int strPos = secondSpacePos;		
		Basin result = new Basin(width, height);
		for (int y=0; y<height; y++) {
			for (int x=0; x<width; x++) {
					
				int nextStrPos = values.indexOf(' ', strPos+1);
				if (nextStrPos < 0) {
					nextStrPos = values.length();
				}
				String attitudeStr = values.substring(strPos+1, nextStrPos);
				result.attitudes[y][x] = Integer.parseInt(attitudeStr);
				strPos = values.indexOf(' ', strPos+1);			
			}
		}		
		
		return result;
	}
	
	public int[][] getMarksNumArray() {
		int[][] result = new int[height][width];
		
		int markNum=1;
		
		boolean notMarkedCellsLeft = true;
		
		while (notMarkedCellsLeft) {
		
			int minX = 0;
			int minY = 0;
			int minValue = 10001;
			// select minimal not-marked cell
			for (int x=0; x<width; x++) {
				for (int y=0; y<height; y++) {
					if (result[y][x]==0 && attitudes[y][x]<minValue) {
						minX = x;
						minY = y;
						minValue = attitudes[y][x];
					}
				}
			}
			
			if (minValue != 10001) {
				markSelfAndNeighbours(result, minX, minY, markNum, minValue, -1, -1);
				
			} else {
				notMarkedCellsLeft = false;
				
			}
			markNum++;
		}
		return result;
	}
	
	public char[][] getMarksCharArray(){
		int[][] intArr = getMarksNumArray();
		char[] translArr = new char[30]; 
		char[][] result = new char[height][width]; 
		for (int y=0; y<height; y++) {
			for (int x=0; x<width; x++) {
				int intToken = intArr[y][x];
				if (translArr[intToken] == 0) {
					translArr[intToken] = nextChar(translArr);
				}
			}
		}
		
		for (int y=0; y<height; y++) {
			for (int x=0; x<width; x++) {
				int intToken = intArr[y][x];
				result[y][x] = translArr[intToken];
			}
		}
		
		return result;		
	}
	
	private char nextChar(char[] arr){
		char result = 0;
		for (int i=0; i<arr.length; i++) {
			if (arr[i] > result) {
				result = arr[i];
			}
		}
		if (result == 0) {
			result = 'a';
		} else {
			result = (char)((int) result+1);
		}
		return result;
	}
	
	private void markSelfAndNeighbours(int[][] marks, int x, int y, int color, int value, int prevX, int prevY){
		if (   x >= 0 && x < width 
			&& y >= 0 && y < height) {
			
			int currValue = attitudes[y][x];			
			int prevValue;
			if (prevX < 0) {
				prevValue = attitudes[y][x];
			} else {
				prevValue = attitudes[prevY][prevX];				
			}
			
			boolean pressedToLeft = x==0;
			boolean pressedToRight = x == width - 1;
			boolean pressedToBottom = y == height -1;
			boolean pressedToTop = y == 0;
			
			int leftValue = pressedToLeft ? 10001 : attitudes[y][x-1];
			int rightValue = pressedToRight ? 10001 : attitudes[y][x+1];
			int bottomValue = pressedToBottom ? 10001 : attitudes[y+1][x];
			int topValue = pressedToTop ? 10001 : attitudes[y-1][x];
			
			boolean leftIsNotMarkedOrGreater = pressedToLeft || (attitudes[y][x-1] > currValue && marks[y][x-1] == 0);
			boolean rightIsNotMarkedOrGreater = pressedToRight || (attitudes[y][x+1] > currValue && marks[y][x+1] == 0);
			boolean topIsNotMarkedOrGreater = pressedToTop || (attitudes[y-1][x] > currValue && marks[y-1][x] ==0);
			boolean bottomIsNotMarkedOrGreater = pressedToBottom || (attitudes[y+1][x] > currValue && marks[y+1][x] == 0);
			
			boolean prevValueIsSmallerOrEqual = currValue > prevValue || prevX < 0;
			
			int minNeighbourValue = Math.min(Math.min(leftValue, rightValue), Math.min(topValue, bottomValue));
			boolean prevValueIsMinimal = minNeighbourValue == prevValue || prevX < 0;
			if (marks[y][x] ==0) {
				if (prevValueIsSmallerOrEqual && prevValueIsMinimal) {
					marks[y][x] = color;
				}
				if (leftIsNotMarkedOrGreater && x>0) {
					markSelfAndNeighbours(marks, x-1, y, color, value, x, y);
				}
				if (rightIsNotMarkedOrGreater && x<width - 1) {
					markSelfAndNeighbours(marks, x+1, y, color, value, x, y);
				}
				if (topIsNotMarkedOrGreater && y>0) {
					markSelfAndNeighbours(marks, x, y-1, color, value, x, y);
				}
				if (bottomIsNotMarkedOrGreater && y<height - 1) {
					markSelfAndNeighbours(marks, x, y+1, color, value, x, y);
				}
				
			}
		}
	}
	
	private void tryMarkCell(int[][] marks, int x, int y, int color, int value) {
		if (x>0 && y>0 && x<width && y<height && marks[y][x]==0) {
			if ((x <= 0 || attitudes[y][x] >= value)
					&& (y <= 0 || attitudes[y][x] >= value)
					&& (y <= height - 1 || attitudes[y+1][x] >= value)
					&& (x <= width - 1 || attitudes[x][y+1] >= value))
			{
				marks[y][x] = color;
			}
		}		
	}
}
