import java.io.Reader;
import java.io.FileInputStream;
import java.util.InputMismatchException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.BufferedReader;
import java.io.FilenameFilter;
import java.util.Locale;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.IOException;
import java.io.FileOutputStream;
import java.io.File;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class Main {
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		InputStream inputStream;
		try {
			final String regex = "A-(small|large).*[.]in";
			File directory = new File(".");
			File[] candidates = directory.listFiles(new FilenameFilter() {
				public boolean accept(File dir, String name) {
					return name.matches(regex);
				}
			});
			File toRun = null;
			for (File candidate : candidates) {
				if (toRun == null || candidate.lastModified() > toRun.lastModified())
					toRun = candidate;
			}
			inputStream = new FileInputStream(toRun);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("a.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		FastScanner in = new FastScanner(inputStream);
		PrintWriter out = new PrintWriter(outputStream);
		TaskA solver = new TaskA();
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i, in, out);
		out.close();
	}
}

class TaskA {
    int[] xx = new int[]{0, -1, 0, 1};
    int[] yy = new int[]{-1, 0, 1, 0};

    int r;
    int c;

    int[][] a;

    public void solve(int testNumber, FastScanner in, PrintWriter out) {

        r = in.nextInt();
        c = in.nextInt();

        a = new int[r][c];

        for (int i = 0; i < r; i++) for (int j = 0; j < c; j++) a[i][j] = -1;

        for (int i = 0; i < r; i++) {
            String s = in.next();
            for (int j = 0; j < c; j++) {
                switch (s.charAt(j)) {
                    case '.':
                        break;
                    case '<':
                        a[i][j] = 0;
                        break;
                    case '^':
                        a[i][j] = 1;
                        break;
                    case '>':
                        a[i][j] = 2;
                        break;
                    case 'v':
                        a[i][j] = 3;
                        break;
                    default:
                        out.println("bad");
                }
            }
        }

        int ans = 0;
        while (true) {
            boolean left = false;
            for (int i = 0; i < r; i++) {
                for (int j = 0; j < c; j++) {
                    if (a[i][j] == -1)
                        continue;

                    int ddd = direct(i, j);

                    if (ddd == -1)
                        continue;
                    if (ddd == -2) {
                        out.format("Case #%d: %s\n", testNumber, "IMPOSSIBLE");
                        return;
                    }

                    left = true;
                    a[i][j] = ddd;
                    ans++;
                    break;
                }
                if (left)
                    break;
            }
            if (!left)
                break;
        }

out.format("Case #%d: %d\n", testNumber, ans);
    }

    public int direct(int x, int y) {
        int curx = x;
        int cury = y;
        while (true) {
            curx += xx[a[x][y]];
            cury += yy[a[x][y]];

            if (curx < 0 || curx >= r || cury < 0 || cury >= c) {
                break;
            }
            if (a[curx][cury] != -1) {
                return -1;
            }
        }

        for (int k = 0; k < 4; k++) {
            curx = x;
            cury = y;
            while (true) {
                curx += xx[k];
                cury += yy[k];

                if (curx < 0 || curx >= r || cury < 0 || cury >= c) {
                    break;
                }
                if (a[curx][cury] != -1) {
                    return k;
                }
            }
        }
        return -2;
    }
}

class FastScanner extends BufferedReader {

    public FastScanner(InputStream is) {
        super(new InputStreamReader(is));
    }

    public int read() {
        try {
            int ret = super.read();
return ret;
        } catch (IOException e) {
            throw new InputMismatchException();
        }
    }

    public String next() {
        StringBuilder sb = new StringBuilder();
        int c = read();
        while (isWhiteSpace(c)) {
            c = read();
        }
        if (c < 0) {
            return null;
        }
        while (c >= 0 && !isWhiteSpace(c)) {
            sb.appendCodePoint(c);
            c = read();
        }
        return sb.toString();
    }

    public int nextInt() {
        int c = read();
        while (isWhiteSpace(c)) {
            c = read();
        }
        int sgn = 1;
        if (c == '-') {
            sgn = -1;
            c = read();
        }
        int ret = 0;
        while (c >= 0 && !isWhiteSpace(c)) {
            if (c < '0' || c > '9') {
                throw new NumberFormatException("digit expected " + (char) c
                        + " found");
            }
            ret = ret * 10 + c - '0';
            c = read();
        }
        return ret * sgn;
    }

    static boolean isWhiteSpace(int c) {
        return c >= 0 && c <= 32;
    }

    public String readLine() {
        try {
            return super.readLine();
        } catch (IOException e) {
            return null;
        }
    }

}

