package countingsheep;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Locale;
import java.util.Random;
import java.util.StringTokenizer;
import java.util.concurrent.Callable;
import java.util.concurrent.Future;
import java.util.concurrent.ScheduledThreadPoolExecutor;

public class CountingSheep implements Runnable {

	private PrintWriter out;

	final String file = "C:\\GCJ\\"
			+ this.getClass().getName()
					.substring(this.getClass().getName().lastIndexOf('.') + 1)
			+ "\\input";
	Random rnd = new Random(42);

	static class InputData {
		private BigInteger N;

		InputData(FastReader in) throws IOException {
			N = new BigInteger(in.next());
		}

		void solve(PrintWriter out) {
			if (N.compareTo(BigInteger.ZERO) == 0) {
				out.println("INSOMNIA");
				return;
			}
			boolean[] digits = { false, false, false, false, false, false,
					false, false, false, false };
			for (int i = 1; i < 999999999; i++) {
				BigInteger N2 = N.multiply(new BigInteger(i + ""));
				if (procesarNum(N2.toString().toCharArray(), digits)) {
					out.println(N2);
					return;
				}
			}
			out.println("INSOMNIA");
		}

		boolean procesarNum(char[] num, boolean[] digits) {
			Arrays.sort(num);
			byte count = 0;
			for (char i = 48; i < 58; i++) {
				digits[i - 48] |= Arrays.binarySearch(num, i) >= 0;
				if (digits[i - 48]) {
					count++;
				}
			}
			if (count == 10) {
				return true;
			}
			return false;
		}
	}

	static class Solver implements Callable<String> {

		InputData data;

		Solver(InputData data) {
			this.data = data;
		}

		@Override
		public String call() throws Exception {
			StringWriter out = new StringWriter();
			data.solve(new PrintWriter(out));
			return out.toString();
		}

	}

	public void run() {
		try {
			FastReader in = new FastReader(new BufferedReader(new FileReader(
					file + ".in")));
			out = new PrintWriter(file + ".out");

			ScheduledThreadPoolExecutor service = new ScheduledThreadPoolExecutor(
					7);

			int tests = in.nextInt();
			@SuppressWarnings("unchecked")
			Future<String>[] ts = new Future[tests];
			for (int test = 0; test < tests; ++test) {
				ts[test] = service.submit(new Solver(new InputData(in)));
			}
			for (int test = 0; test < tests; ++test) {
				while (!ts[test].isDone()) {
					Thread.sleep(500);
				}
				// System.err.println("Test " + test);
				out.print("Case #" + (test + 1) + ": ");
				System.out.print("Case #" + (test + 1) + ": ");
				out.print(ts[test].get());
				System.out.print(ts[test].get());
			}
			service.shutdown();

			out.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	static class FastReader {
		public FastReader(BufferedReader in) {
			this.in = in;
			eat("");
		}

		private StringTokenizer st;
		private BufferedReader in;

		void eat(String s) {
			st = new StringTokenizer(s);
		}

		String next() throws IOException {
			while (!st.hasMoreTokens()) {
				String line = in.readLine();
				if (line == null) {
					return null;
				}
				eat(line);
			}
			return st.nextToken();
		}

		int nextInt() throws IOException {
			return Integer.parseInt(next());
		}

		long nextLong() throws IOException {
			return Long.parseLong(next());
		}

		double nextDouble() throws IOException {
			return Double.parseDouble(next());
		}
	}

	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new CountingSheep().run();
	}

}
