package com.netopyr;

import java.io.IOException;
import java.net.URISyntaxException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;

public class TicTacToeTomek {

    private static final String FILENAME = "small.txt";
    private static final Charset ENCODING = StandardCharsets.UTF_8;

    private List<Data> dataList;

    private void readInput() throws URISyntaxException, IOException {
        final Path path = Paths.get(TicTacToeTomek.class.getResource(FILENAME).toURI());
        final List<String> input = Files.readAllLines(path, ENCODING);
        final int n = Integer.parseInt(input.get(0));
        dataList = new ArrayList<Data>(n);
        for (int i=0; i<n; i++) {
            dataList.add(new Data(input, i));
        }
    }

    private void calculateResults() {
        for (int i=0; i<dataList.size(); i++) {
            final Data data = dataList.get(i);
            final int index = i+1;
            System.out.print("Case #" + index + ": ");
            if (data.xWins()) {
                System.out.println("X won");
            } else if (data.oWins()) {
                System.out.println("O won");
            } else if (data.notFinished()) {
                System.out.println("Game has not completed");
            } else {
                System.out.println("Draw");
            }
        }
    }

    public static void main(String... args) throws IOException, URISyntaxException {
        final TicTacToeTomek runner = new TicTacToeTomek();

        runner.readInput();
        runner.calculateResults();
    }

    private static class Data {
        private final List<String> input;
        private final int index;

        private Data(List<String> input, int index) {
            this.input = input;
            this.index = index;
        }

        private char get(int col, int row) {
            return input.get(5 * index + 1 + row).charAt(col);
        }

        public boolean xWins() {
            return wins('X');
        }

        public boolean oWins() {
            return wins('O');
        }

        private boolean wins(char c) {
            for (int i=0; i<4; i++) {
                if (row(c, i) || col(c, i)) {
                    return true;
                }
            }
            if (match(c,0,0) && match(c,1,1) && match(c,2,2) && match(c,3,3)) {
                return true;
            }
            if (match(c,0,3) && match(c,1,2) && match(c,2,1) && match(c,3,0)) {
                return true;
            }
            return false;
        }

        private boolean col(char c, int col) {
            return match(c, col, 0) && match(c, col, 1) && match(c, col, 2) && match(c, col, 3);
        }

        private boolean row(char c, int row) {
            return match(c, 0, row) && match(c, 1, row) && match(c, 2, row) && match(c, 3, row);
        }

        private boolean match(char c, int col, int row) {
            final char c0 = get(col, row);
            return c0 == c || c0 == 'T';
        }

        public boolean notFinished() {
            for (int col = 0; col<4; col++) {
                for (int row = 0; row<4; row++) {
                    if (get(row, col) == '.') {
                        return true;
                    }
                }
            }
            return false;
        }
    }

}
