package com.netopyr;

import java.io.IOException;
import java.net.URISyntaxException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;

public class Lawnmower {

    private static final String FILENAME = "small.txt";
    private static final Charset ENCODING = StandardCharsets.UTF_8;

    private final List<Pattern> patterns = new ArrayList<Pattern>();

    private void readInput() throws URISyntaxException, IOException {
        final Path path = Paths.get(Lawnmower.class.getResource(FILENAME).toURI());
        final List<String> input = Files.readAllLines(path, ENCODING);
        final int t = Integer.parseInt(input.get(0));
        int line = 1;
        for (int i=0; i<t; i++) {
            final String[] dimStrings = input.get(line++).split(" ");
            final int row = Integer.parseInt(dimStrings[0]);
            final int col = Integer.parseInt(dimStrings[1]);
            final Pattern pattern = new Pattern(col, row);
            for (int y=0; y<row; y++) {
                final String[] items = input.get(line++).split(" ");
                for (int x=0; x<col; x++) {
                    pattern.set(x, y, Integer.parseInt(items[x]));
                }
            }
            patterns.add(pattern);
        }
    }

    private void calculateResults() {
        for (int i=0; i<patterns.size(); i++) {
            System.out.print("Case #" + (i+1) + ": ");
            if (patterns.get(i).isPossible()) {
                System.out.println("YES");
            } else {
                System.out.println("NO");
            }
        }
    }

    public static void main(String... args) throws IOException, URISyntaxException {
        final Lawnmower runner = new Lawnmower();

        runner.readInput();
        runner.calculateResults();
    }

    private static class Pattern {

        private final int[][]a;
        private final int col;
        private final int row;

        private Pattern(int col, int row) {
            this.col = col;
            this.row = row;
            this.a = new int[col][row];
        }

        public void set(int x, int y, int i) {
            a[x][y] = i;
        }

        public boolean isPossible() {
            final boolean[][] ok = new boolean[col][row];
            for (int x=0; x< col; x++) {
                int max = 0;
                for (int y=0; y< row; y++) {
                    max = Math.max(a[x][y], max);
                }
                for (int y=0; y< row; y++) {
                    if (a[x][y] == max) {
                        ok[x][y] = true;
                    }
                }
            }
            for (int y=0; y< row; y++) {
                int max = 0;
                for (int x=0; x< col; x++) {
                    max = Math.max(a[x][y], max);
                }
                for (int x=0; x< col; x++) {
                    if (a[x][y] == max) {
                        ok[x][y] = true;
                    }
                }
            }
            for (int x=0; x< col; x++) {
                for (int y=0; y< row; y++) {
                    if (!ok[x][y]) {
                        return false;
                    }
                }
            }
            return true;
        }
    }

}
