package com.netopyr;

import java.io.IOException;
import java.math.BigInteger;
import java.net.URISyntaxException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;

public class FairAndSquare {
    private static final String FILENAME = "large_1.txt";
    private static final Charset ENCODING = StandardCharsets.UTF_8;

    private BigInteger[] start;
    private BigInteger[] end;

    private void readInput() throws URISyntaxException, IOException {
        final Path path = Paths.get(FairAndSquare.class.getResource(FILENAME).toURI());
        final List<String> input = Files.readAllLines(path, ENCODING);
        final int n = Integer.parseInt(input.get(0));
        start = new BigInteger[n];
        end   = new BigInteger[n];
        for (int i=0; i<n; i++) {
            final String[] nums = input.get(i+1).split(" ");
            start[i] = new BigInteger(nums[0]);
            end[i] = new BigInteger(nums[1]);
        }
    }

    private void calculateResults() {
        final int n = start.length;
        for (int i=0; i<n; i++) {
            System.out.print("Case #" + (i+1) + ": ");
            int sum = 0;
            BigInteger root = findMinPalindrome(start[i]);
            BigInteger square;
            while ((square = root.multiply(root)).compareTo(end[i]) <= 0) {
                if (isPalindrome(square)) {
                    sum++;
                }
                root = findNextPalindrome(root);
            }
            System.out.println(sum);
        }
    }

    private BigInteger findMinRoot(BigInteger needle) {
        BigInteger high = BigInteger.ONE;
        while (high.multiply(high).compareTo(needle) < 0) {
            high = high.shiftLeft(1);
        }
        if (high.multiply(high).compareTo(needle) == 0) {
            return high;
        }
        BigInteger low = high.shiftRight(1);

        while (low.compareTo(high) <= 0) {
            final BigInteger mid = low.add(high).shiftRight(1);

            final int compare = mid.multiply(mid).compareTo(needle);
            if (compare < 0) {
                low = mid.add(BigInteger.ONE);
            } else if (compare > 0) {
                high = mid.subtract(BigInteger.ONE);
            } else {
                return mid;
            }
        }
        return low;
    }

    private BigInteger findMinPalindrome(BigInteger needle) {
        final String root = findMinRoot(needle).toString();
        final int n = root.length();
        final String prefix = root.substring(0, n/2);

        final StringBuilder builder = new StringBuilder(prefix);
        builder.reverse();
        builder.insert(0, root.substring(n/2, Math.round(n/2.0f)));
        builder.insert(0, prefix);
        BigInteger palindrome = new BigInteger(builder.toString());

        while (palindrome.multiply(palindrome).compareTo(needle) < 0) {
            palindrome = findNextPalindrome(palindrome);
        }
        return palindrome;
    }

    private BigInteger findNextPalindrome(BigInteger value) {
        final StringBuilder palindrome = new StringBuilder(value.toString());
        final int n = palindrome.length();
        int i0 = Math.round(n / 2.0f) - 1;
        int i1 = n / 2;

        char c;
        do {
            if (i1 == n) {
                final StringBuilder builder = new StringBuilder("1");
                for (int i=0; i<n-1; i++) {
                    builder.append("0");
                }
                builder.append("1");
                return new BigInteger(builder.toString());
            }
            c = palindrome.charAt(i0);
            c = (char)(c + 1);
            if (c > '9') {
                c = '0';
            }
            palindrome.setCharAt(i0, c);
            palindrome.setCharAt(i1, c);
            i0--;
            i1++;
        } while (c == '0');

        return new BigInteger(palindrome.toString());
    }

    private boolean isPalindrome(BigInteger num) {
        final String s = num.toString();
        final int n = s.length();
        for (int i = 0; i<n/2; i++) {
            if (!s.substring(i, i+1).equals(s.substring(n-i-1, n-i))) {
                return false;
            }
        }
        return true;
    }

    public static void main(String... args) throws IOException, URISyntaxException {
        final FairAndSquare runner = new FairAndSquare();

        runner.readInput();
        runner.calculateResults();
    }
}
