package com.netopyr;

import java.io.IOException;
import java.math.BigInteger;
import java.net.URISyntaxException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;

public class FairAndSquare {
    private static final String FILENAME = "small.txt";
    private static final Charset ENCODING = StandardCharsets.UTF_8;

    private BigInteger[] start;
    private BigInteger[] end;

    private void readInput() throws URISyntaxException, IOException {
        final Path path = Paths.get(FairAndSquare.class.getResource(FILENAME).toURI());
        final List<String> input = Files.readAllLines(path, ENCODING);
        final int n = Integer.parseInt(input.get(0));
        start = new BigInteger[n];
        end   = new BigInteger[n];
        for (int i=0; i<n; i++) {
            final String[] nums = input.get(i+1).split(" ");
            start[i] = new BigInteger(nums[0]);
            end[i] = new BigInteger(nums[1]);
        }
    }

    private void calculateResults() {
        final int n = start.length;
        for (int i=0; i<n; i++) {
            System.out.print("Case #" + (i+1) + ": ");
            int sum = 0;
            BigInteger square;
            for (BigInteger root = findMinRoot(start[i]); (square = root.multiply(root)).compareTo(end[i]) <= 0; root = root.add(BigInteger.ONE)) {
                if (isPalindrome(root) && isPalindrome(square)) {
                    sum++;
                }
            }
            System.out.println(sum);
        }
    }

    private BigInteger findMinRoot(BigInteger min) {
        BigInteger result = BigInteger.ONE;
        while (result.multiply(result).compareTo(min) <= 0) {
            result = result.shiftLeft(1);
        }
        result = result.shiftRight(1);
        while (result.multiply(result).compareTo(min) < 0) {
            result = result.add(BigInteger.ONE);
        }
        return result;
    }

    private boolean isPalindrome(BigInteger num) {
        final String s = num.toString();
        final int n = s.length();
        for (int i = 0; i<n/2; i++) {
            if (!s.substring(i, i+1).equals(s.substring(n-i-1, n-i))) {
                return false;
            }
        }
        return true;
    }

    public static void main(String... args) throws IOException, URISyntaxException {
        final FairAndSquare runner = new FairAndSquare();

        runner.readInput();
        runner.calculateResults();
    }
}
