import java.io.OutputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.PrintWriter;
import java.util.Arrays;
import java.io.InputStreamReader;
import java.util.StringTokenizer;
import java.io.BufferedReader;
import java.io.InputStream;

/** Built using CHelper plug-in Actual solution is at the top */
public class Main {
  public static void main(String[] args) {
    InputStream inputStream;
    try {
      inputStream = new FileInputStream("input.txt");
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
    OutputStream outputStream;
    try {
      outputStream = new FileOutputStream("output.txt");
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
    InputReader in = new InputReader(inputStream);
    PrintWriter out = new PrintWriter(outputStream);
    AmpleSyrup solver = new AmpleSyrup();
    solver.solve(1, in, out);
    out.close();
  }

  static class AmpleSyrup {
    public void solve(int testNumber, InputReader in, PrintWriter out) {
      int t = in.nextInt();

      for (int test = 1; test <= t; ++test) {
        int n = in.nextInt(), k = in.nextInt();
        Pancake[] pancakes = new Pancake[n];
        for (int i = 0; i < n; ++i) {
          pancakes[i] = new Pancake(in.nextLong(), in.nextLong());
        }

        Arrays.sort(pancakes);
        double ans = solve(k, pancakes);
        out.println(String.format("Case #%d: %.9f", test, ans));
      }
    }

    double solve(int k, Pancake[] pancakes) {
      int n = pancakes.length;
      double r = 0;
      for (int i = 0; i + k <= n; ++i) {
        Pancake[] subPancakes = new Pancake[n - i];
        for (int j = 0; j < subPancakes.length; ++j) {
          subPancakes[j] = new Pancake(pancakes[i + j].radius, pancakes[i + j].height);
        }
        Arrays.sort(
            subPancakes,
            1,
            subPancakes.length,
            (a, b) -> Double.compare(verticalArea(b), verticalArea(a)));
        double area = area(pancakes[i].radius);
        for (int j = 0; j < k; ++j) {
          area += verticalArea(subPancakes[j].radius, subPancakes[j].height);
        }
        r = Math.max(r, area);
      }
      return r;
    }

    double area(long radius) {
      return Math.PI * radius * radius;
    }

    double verticalArea(Pancake pancake) {
      return verticalArea(pancake.radius, pancake.height);
    }

    double verticalArea(long radius, long height) {
      return Math.PI * 2 * radius * height;
    }
  }

  static class InputReader {
    private BufferedReader br;
    private StringTokenizer st;

    String next() {
      try {
        while (st == null || !st.hasMoreTokens()) {
          String s = br.readLine();
          if (s != null) {
            st = new StringTokenizer(s);
          }
        }
        if (st.hasMoreTokens()) {
          return st.nextToken();
        } else {
          return null;
        }
      } catch (Exception ex) {
        throw new RuntimeException(ex);
      }
    }

    public int nextInt() {
      return Integer.parseInt(next());
    }

    public long nextLong() {
      return Long.parseLong(next());
    }

    public InputReader(InputStream inputStream) {
      br = new BufferedReader(new InputStreamReader(inputStream));
    }
  }

  static class Pancake implements Comparable<Pancake> {
    long radius;
    long height;

    public Pancake(long radius, long height) {
      this.radius = radius;
      this.height = height;
    }

    public int compareTo(Pancake o) {
      return Long.compare(o.radius, this.radius);
    }
  }
}
