import java.io.*;
import java.util.*;
import java.math.*;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 * @author coderbd
 */
public class Main {
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		InputStream inputStream;
		try {
			final String regex = "C-(small|large).*[.]in";
			File directory = new File(".");
			File[] candidates = directory.listFiles(new FilenameFilter() {
				public boolean accept(File dir, String name) {
					return name.matches(regex);
				}
			});
			File toRun = null;
			for (File candidate : candidates) {
				if (toRun == null || candidate.lastModified() > toRun.lastModified())
					toRun = candidate;
			}
			inputStream = new FileInputStream(toRun);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("c.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		TaskC solver = new TaskC();
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i, in, out);
		out.close();
	}
}

class TaskC {

    // 0  1  2  3  4  5  6  7
    // 1 -1  i -i  j -j  k -k
    public static int[][] MATRIX = {
            {0, 1 ,2, 3, 4, 5, 6, 7},
            {1, 0, 3, 2, 5, 4, 7, 6},
            {2, 3, 1, 0, 6, 7, 5, 4},
            {3, 2, 0, 1, 7, 6, 4, 5},
            {4, 5, 7, 6, 1, 0, 2, 3},
            {5, 4, 6, 7, 0, 1, 3, 2},
            {6, 7, 4, 5, 3, 2, 1, 0},
            {7, 6, 5, 4, 2, 3, 0, 1}
    };

    private int getID(char c) {
        if (c == '1')
            return 0;
        if (c == 'i')
            return 2;
        if (c == 'j')
            return 4;
        if (c == 'k')
            return 6;
        throw new RuntimeException();
    }

    private int multiply(int a, int b) {
        return MATRIX[a][b];
    }

    private int[] transform(String s, int l, int x) {
        int[] a = new int[l*x];
        for (int i = 0, id = 0; i < a.length; i++, id++) {
            if (id == l)
                id = 0;
            a[i] = getID(s.charAt(id));
        }
        return a;
    }

    private int[] preprocess(int[] a, int n) {
        int[] ca = new int[n+1];
        for (int i = 0; i < n; i++)
            ca[i+1] = multiply(ca[i], a[i]);
        return ca;
    }

    private boolean func(int[] ca, int n) {
        for (int i = 1; i < n; i++) {
            int first = ca[i];
            if (first == 2) {
                for (int j = i + 1; j < n; j++) {
                    int second = multiply(3, ca[j]);
                    if (second == 4) {
                        int third = multiply(7, ca[n]);
                        if (third == 6)
                            return true;
                    }
                }
            }
        }
        return false;
    }

    public void solve(int testNumber, InputReader in, OutputWriter out) {
        int l = in.readInt();
        int x = in.readInt();
        String s = in.readString();
        int[] a = transform(s, l, x);
        int[] ca = preprocess(a, l * x);
        if (func(ca, l * x))
            out.printLine("Case #" + testNumber + ": YES");
        else
            out.printLine("Case #" + testNumber + ": NO");
    }

}

class InputReader {

    private InputStream stream;
    private byte[] buf = new byte[1024];
    private int curChar;
    private int numChars;

    public InputReader(InputStream stream) {
        this.stream = stream;
    }

    public int read() {
        if (numChars == -1)
            throw new InputMismatchException();
        if (curChar >= numChars) {
            curChar = 0;
            try {
                numChars = stream.read(buf);
            }
            catch (IOException e) {
                throw new InputMismatchException();
            }
            if (numChars <= 0)
                return -1;
        }
        return buf[curChar++];
    }

    public int readInt() {
        int c = read();
        while (isSpaceChar(c))
            c = read();
        int sgn = 1;
        if (c == '-') {
            sgn = -1;
            c = read();
        }
        int res = 0;
        do {
            if (c < '0' || c > '9')
                throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while (!isSpaceChar(c));
        return res * sgn;
    }

    public String readString() {
        int c = read();
        while (isSpaceChar(c))
            c = read();
        StringBuffer res = new StringBuffer();
        do {
            res.appendCodePoint(c);
            c = read();
        } while (!isSpaceChar(c));
        return res.toString();
    }

    public static boolean isSpaceChar(int c) {
        return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
    }

    public String next() {
        return readString();
    }

}

class OutputWriter {

    private final PrintWriter writer;

    public OutputWriter(OutputStream outputStream) {
        writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
    }

    public void print(Object... objects) {
        for (int i = 0; i < objects.length; i++) {
            if (i != 0)
                writer.print(' ');
            writer.print(objects[i]);
        }
    }

    public void printLine(Object... objects) {
        print(objects);
        writer.println();
    }

    public void close() {
        writer.close();
    }

}
