import java.io.*;
import java.util.*;
import java.math.*;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 * @author coderbd
 */
public class Main {
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		InputStream inputStream;
		try {
			final String regex = "A-(small|large).*[.]in";
			File directory = new File(".");
			File[] candidates = directory.listFiles(new FilenameFilter() {
				public boolean accept(File dir, String name) {
					return name.matches(regex);
				}
			});
			File toRun = null;
			for (File candidate : candidates) {
				if (toRun == null || candidate.lastModified() > toRun.lastModified())
					toRun = candidate;
			}
			inputStream = new FileInputStream(toRun);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("a.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		TaskA solver = new TaskA();
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i, in, out);
		out.close();
	}
}

class TaskA {

    public boolean isArrow(char c) {
        return c != '.';
    }

    public void solve(int testNumber, InputReader in, OutputWriter out) {
        int r = in.readInt();
        int c = in.readInt();
        char[][] grid = new char[r][];
        for (int i = 0; i < r; i++)
            grid[i] = in.readLine().toCharArray();

        boolean okay = true;
        int ans = 0;
        List<Integer>[] rows = new List[r];
        for (int i = 0; i < r; i++)
            rows[i] = new ArrayList<Integer>();
        List<Integer>[] cols = new List[c];
        for (int i = 0; i < c; i++)
            cols[i] = new ArrayList<Integer>();

        for (int i = 0; i < r; i++)
            for (int j = 0; j < c; j++)
                if (isArrow(grid[i][j])) {
                    rows[i].add(j);
                    cols[j].add(i);
                }

        for (int i = 0; i < r; i++)
            for (int j = 0; j < c; j++)
                if (isArrow(grid[i][j])) {
                    int rs = rows[i].size();
                    int leftMost = rows[i].get(0);
                    int rightMost = rows[i].get(rs - 1);
                    int cs = cols[j].size();
                    int upperMost = cols[j].get(0);
                    int bottomMost = cols[j].get(cs - 1);

                    if (grid[i][j] == '>') {
                        if (rightMost > j)
                            continue;
                        else if (leftMost < j)
                            ans++;
                        else if (upperMost < i)
                            ans++;
                        else if (bottomMost > i)
                            ans++;
                        else
                            okay = false;
                    }
                    else if (grid[i][j] == '<') {
                        if (leftMost < j)
                            continue;
                        else if (rightMost > j)
                            ans++;
                        else if (upperMost < i)
                            ans++;
                        else if (bottomMost > i)
                            ans++;
                        else
                            okay = false;
                    }
                    else if (grid[i][j] == '^') {
                        if (upperMost < i)
                            continue;
                        else if (rightMost > j)
                            ans++;
                        else if (leftMost < j)
                            ans++;
                        else if (bottomMost > i)
                            ans++;
                        else
                            okay = false;
                    }
                    else if (grid[i][j] == 'v') {
                        if (bottomMost > i)
                            continue;
                        else if (rightMost > j)
                            ans++;
                        else if (leftMost < j)
                            ans++;
                        else if (upperMost < i)
                            ans++;
                        else
                            okay = false;
                    }
                }

        if (okay)
            out.printLine("Case #" + testNumber + ": " + ans);
        else
            out.printLine("Case #" + testNumber + ": IMPOSSIBLE");
    }

}

class InputReader {

    private InputStream stream;
    private byte[] buf = new byte[1024];
    private int curChar;
    private int numChars;

    public InputReader(InputStream stream) {
        this.stream = stream;
    }

    public int read() {
        if (numChars == -1)
            throw new InputMismatchException();
        if (curChar >= numChars) {
            curChar = 0;
            try {
                numChars = stream.read(buf);
            }
            catch (IOException e) {
                throw new InputMismatchException();
            }
            if (numChars <= 0)
                return -1;
        }
        return buf[curChar++];
    }

    public int readInt() {
        int c = read();
        while (isSpaceChar(c))
            c = read();
        int sgn = 1;
        if (c == '-') {
            sgn = -1;
            c = read();
        }
        int res = 0;
        do {
            if (c < '0' || c > '9')
                throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while (!isSpaceChar(c));
        return res * sgn;
    }

    public String readString() {
        int c = read();
        while (isSpaceChar(c))
            c = read();
        StringBuffer res = new StringBuffer();
        do {
            res.appendCodePoint(c);
            c = read();
        } while (!isSpaceChar(c));
        return res.toString();
    }

    public static boolean isSpaceChar(int c) {
        return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
    }

    private String readLine0() {
        StringBuffer buf = new StringBuffer();
        int c = read();
        while (c != '\n' && c != -1) {
            if (c != '\r')
                buf.appendCodePoint(c);
            c = read();
        }
        return buf.toString();
    }

    public String readLine() {
        String s = readLine0();
        while (s.trim().length() == 0)
            s = readLine0();
        return s;
    }

    public String next() {
        return readString();
    }

}

class OutputWriter {

    private final PrintWriter writer;

    public OutputWriter(OutputStream outputStream) {
        writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
    }

    public void print(Object... objects) {
        for (int i = 0; i < objects.length; i++) {
            if (i != 0)
                writer.print(' ');
            writer.print(objects[i]);
        }
    }

    public void printLine(Object... objects) {
        print(objects);
        writer.println();
    }

    public void close() {
        writer.close();
    }

}
