package jam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.util.Arrays;
import java.util.Scanner;

public class CookieSolver {
	double farmCost;
	final double baseCookieRate = 2.0;
	double farmRate;
	double targetCookies;
	
	CookieSolver(Double testData, double fRate, double tCookies) {
		farmCost = testData;
		farmRate = fRate;
		targetCookies = tCookies;
	}
	
	double timeToTarget(double farms) {
		double totalRate = (farms*farmRate) + baseCookieRate;
		return targetCookies/totalRate;
	}
	
	double timeToFarm(double farms) {
		double totalRate = (farms*farmRate) + baseCookieRate;
		return farmCost/totalRate;	
	}
	
	double winTime() {
		double farms=0;
		Double totalTime = 0.0;
		while(targetCookies > 0.0) {
			double withoutFarm = timeToTarget(farms);
			double ftime = timeToFarm(farms) ; 
			double withFarm = ftime + timeToTarget(farms+1);
			if (withoutFarm<withFarm) {
				totalTime += withoutFarm;
				break;
			}else {
				totalTime += ftime;
				farms++;
			}
		}
		
		return totalTime;
	}
	
	static void outputWriter(String[] outputs, String outpath) {
		File opfile = new File(outpath);
		if (!opfile.exists()) {
			try {
				opfile.createNewFile();
			} catch (IOException e) {
				System.err.println("Unable to create output file:"+outpath);
				return;
			}			
		}
		Writer owriter = null;
		try {
			owriter = new OutputStreamWriter(new FileOutputStream(opfile));
			for(String testOut: outputs) {
				owriter.write(testOut);				
			}
		} catch (FileNotFoundException e) {
			System.err.println("Created file not found:"+outpath);
			return;
		} catch (IOException e) {
			System.err.println("Unable to write on file:"+outpath);
			return;
		}finally{
			try {
				if(owriter != null) owriter.close();
			} catch (IOException e) {
				System.err.println("Failed to close resource:"+outpath);
			}
		}
	}
	
	public static void main(String[] args) {
		System.out.println("Enter absolute file path: input");
		Scanner inputScanner = new Scanner(System.in);
		String inpath = inputScanner.next();
		String outpath = inpath+".out";
		inputScanner.close();
		
		System.out.println("File name: "+ inpath);
		try {
			inputScanner = new Scanner(new File(inpath));
		} catch (FileNotFoundException e) {
			System.err.println(inpath+" file not found!!");
			return;
		}
		
		// Hope input file is formatted correctly.
		int testCases = inputScanner.nextInt();
		System.out.println("File has "+testCases+" testcases");
		String[] outputs = new String[testCases];
		for(int t=0 ; t<testCases ; t++) {
			Double[] testData= new Double[3];
			inputScanner.nextLine();
			for(int arr=0 ; arr<3 ; arr++) {
				testData[arr] = inputScanner.nextDouble();
			}
			System.out.println(Arrays.toString(testData));
			CookieSolver cs = new CookieSolver(testData[0], testData[1], testData[2]);  
			double answer = cs.winTime();
			outputs[t] = "Case #"+(t+1)+": "+answer+"\n";
			System.out.println(outputs[t]);
		}
		
		outputWriter(outputs, outpath);
	}
}
