package drainage;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStreamReader;
import java.io.PrintStream;

public class Drainage {
	static Direction[] directions = new Direction[] {
			new Direction(0,-1), // N
			new Direction(-1,0), // W
			new Direction(1,0),  // E
			new Direction(0,1) // S
	};
	
	static class Direction {
		int x, y;
		Direction(int x, int y) {
			this.x = x;
			this.y = y;
		}
		
		// doesn't really belong in this class but too lazy to move it
		int getValue(int[][] map, int h, int w, int x, int y) {
			int rx = x + this.x;
			int ry = y + this.y;
			if (rx >= 0 && rx < w && ry >= 0 && ry < h) {
				return map[ry][rx];
			} else {
				return Integer.MAX_VALUE;
			}
		}
	}
	
	public static void main(String[] args) throws Exception {
		BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream("/tmp/B-large.in")));
//		BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream("/tmp/drain.in")));
		
		PrintStream out = new PrintStream(new FileOutputStream("/tmp/out.txt"));
		
		String firstLine = reader.readLine();
		int t = Integer.parseInt(firstLine);
		
		for (int caseIndex = 1; caseIndex <= t; caseIndex++) {
			String hw = reader.readLine();
			String hwSplit[] = hw.split(" ");
			assert hwSplit.length == 2;
			int h = Integer.parseInt(hwSplit[0]);
			int w = Integer.parseInt(hwSplit[1]);
			
			int heightMap[][] = new int[h][w];
			for (int y = 0; y < h; y++) {
				String line = reader.readLine();
				String[] heightsStr = line.split(" ");
				assert heightsStr.length == w;
				int heights[] = new int[w];
				for (int x = 0; x < w; x++) {
					heights[x] = Integer.parseInt(heightsStr[x]);
				}
				heightMap[y] = heights;
			}
			
			Label[][] solution = solve(h, w, heightMap);
			
			String output = "Case #" + caseIndex + ":";
			System.out.println(output);
			out.println(output);
			
			for (int y = 0; y < h; y++) {
				StringBuffer buf = new StringBuffer();
				for (int x = 0; x < w; x++) {
					buf.append(solution[y][x].c).append(' ');
				}
				out.println(buf);
				System.out.println(buf);
			}
		}
	}
	
	static class Label {
		char c;
	}
	
	static Label[][] solve(int h, int w, int[][] heightMap) {
		char c = 'a';
		
		Label[][] labelMap = new Label[h][w];
		
		for (int y = 0; y < h; y++) {
			for (int x = 0; x < w; x++) {
				if (labelMap[y][x] == null) {
					Label label = new Label();
					
					int walkX = x;
					int walkY = y;
					while(true) {
						labelMap[walkY][walkX] = label;
						int currentValue = heightMap[walkY][walkX];
						
						Direction flow = null;
						for (Direction d : directions) {
							int neighbourValue = d.getValue(heightMap, h, w, walkX, walkY);
							if (neighbourValue < currentValue) {
								flow = d;
								currentValue = neighbourValue;
							}
						}
						
						if (flow == null) {
							label.c = c++;
							break;
						}
						
						int nextX = walkX + flow.x;
						int nextY = walkY + flow.y;
						Label nextLabel = labelMap[nextY][nextX];
						if (nextLabel != null) {
							assert nextLabel.c != 0;
							label.c = nextLabel.c;
							break;
						}
						
						walkX = nextX;
						walkY = nextY;
					}
				}
			}
		}
		
		return labelMap;
	}

}
