package codejam;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintStream;

abstract public class CodeJam {
	public final BufferedReader reader;
	public final PrintStream out;
	
	public CodeJam(String filename) {
		try {
			reader = new BufferedReader(new InputStreamReader(new FileInputStream("/tmp/" + filename + ".in")));
			String outfilename = "/tmp/" + filename + ".out";
			System.out.println("Writing to " + outfilename);
			out = new PrintStream(new FileOutputStream(outfilename));
		} catch (FileNotFoundException e) {
			throw new RuntimeException(e);
		}
	}
	
	public String readLine() {
		try {
			String line = reader.readLine();
//			System.out.println("in: " + line);
			return line;
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
	}
	
	public int readInt() {
		return Integer.parseInt(readLine());
	}
	
	public String[] readStringArray() {
		return readLine().split(" ");
	}
	
	public int[] readIntArray(int expectedLength) {
		int[] result = readIntArray();
		if (result.length != expectedLength) {
			throw new RuntimeException("expected " + expectedLength + " numbers, got " + result.length);
		}
		return result;
	}
	
	public int[] readIntArray() {
		String[] strings = readStringArray();
		int[] result = new int[strings.length];
		for (int i=0; i < strings.length; i++) {
			result[i] = Integer.parseInt(strings[i]);
		}
		return result;
	}
	
	
	public int[][] readIntMatrix(int height, int width) {
		int[][] matrix = new int[height][width];
		for (int y = 0; y < height; y++) {
			String[] cells = readStringArray();
			assert width == -1 || width == cells.length;
			for (int x = 0; x < cells.length; x++) {
				matrix[y][x] = Integer.parseInt(cells[x]);
			}
		}
		return matrix;
	}
	
	public void print(String line) {
		System.out.println(line);
		out.println(line);
	}
	
	public void printObj(Object obj) {
		print (obj.toString());
	}
	
	public void printObjArray(Object[] arr) {
		StringBuffer buf = new StringBuffer();
		for (Object obj : arr) {
			buf.append(obj).append(' ');
		}
		print(buf.toString());
	}
	
	public void printObjMatrix(Object[][] o) {
		for (Object[] line : o) {
			printObjArray(line);
		}
	}
}
