import java.util.*;
import java.util.function.*;
import java.io.*;

/**
  * @author Mighty Cohadar 
  */
public class Bravo {

	final int nn;
	final int kk;
	final double[] P;
	final double[] K;
	
	public Bravo(int nn, int kk, double[] P) {
		this.nn = nn;
		this.kk = kk;
		this.P = P;
		Arrays.sort(P);
		this.K = new double[kk];
	}

	public double solve(int bits) {
		double p = 1.0;
		for (int i = 0; i < kk; i++) {
			if ((bits & (1 << i)) != 0) {
				p *= K[i];
			} else {
				p *= (1 - K[i]);
			}
		}
		return p;
	}

	public double solveK() {
		double sum = 0;
		for (int i = 0; i < (1 << kk); i++) {
			if (Integer.bitCount(i) == kk / 2) {
				sum += solve(i);
			}
		}
		return sum;
	}

	public double sum(int bits) {
		long sum = 0;
		for (int i = 0; i < nn; i++) {
			if ((bits & (1 << i)) != 0) {
				sum += P[i];
			}
		}
		return sum;
	}

	public void fillK(int bits) {
		int j = 0;
		for (int i = 0; i < nn; i++) {
			if ((bits & (1 << i)) != 0) {
				K[j++] = P[i];
			}
		}		
	}

	public double solve1(int it) {
		double max = 0.0;
		for (int i = 0; i < (1 << nn); i++) {
			if (Integer.bitCount(i) == kk) {
				fillK(i);
				max = Math.max(max, solveK());
			}
		}
		return max;
	}

	public static Bravo load(Scanner scanner) {
		int nn = scanner.nextInt();
		int kk = scanner.nextInt();
		double[] P = new double[nn];
		for (int i = 0; i < P.length; i++) {
			P[i] = scanner.nextDouble();
		}
		return new Bravo(nn, kk, P);
	}	

	public static void main(String[] args) {
		Scanner scanner = new Scanner(System.in);
		int nt = scanner.nextInt();
		scanner.nextLine();
		assert 1 <= nt && nt <= 100 : "out of range, nt: " + nt;
		for (int it = 1; it <= nt; it++) {
			Bravo o = Bravo.load(scanner);
			System.out.printf("Case #%d: %.7f\n", it, o.solve1(it));
		}
	}

	static void debug(Object...os) {
		System.err.printf("%.65536s\n", Arrays.deepToString(os));
	}	

}
