package gcj2008.qualification.two;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Scanner;

public class Problem {

	/**
	 * @param args
	 */
	public static void main(String[] args) {

		if( args.length < 1 ) {
			System.err.println( "Missing command-line argument. " +
								"Please provide location of input file." );
			return;
		}

		Scanner fin = null;
		try {
			fin = new Scanner(new FileInputStream(args[0]));
		} catch (FileNotFoundException e) {
			System.err.println( e.getMessage() );
		}
		if( fin == null ) {
			System.err.println( "Error opening input file." );
			return;
		}
		
		/**
		 * The number of cases.
		 */
		int N = fin.nextInt();
		
		/**
		 * The turn-around time for the current case.
		 */
		int T;
		
		/**
		 * For each case, the number of trips from A to B and from B to A. 
		 */
		int[] NA = new int[N];
		int[] NB = new int[N];
		
		/**
		 * These arrays store the trip arrival and departure times
		 * from A to B and from B to A.
		 */
		Trip[] AtoB, BtoA;
		
		for( int n = 0; n < N; n++ ) {
			T = fin.nextInt();
			
			NA[n] = fin.nextInt();
			NB[n] = fin.nextInt();
			
			AtoB = new Trip[NA[n]];
			BtoA = new Trip[NB[n]];
			
			for( int i = 0; i < NA[n]; i++ ) {
				AtoB[i] = new Trip( fin.next().trim(), fin.next().trim() );
			}
			for( int j = 0; j < NB[n]; j++ ) {
				BtoA[j] = new Trip( fin.next().trim(), fin.next().trim() );
			}
			
			/*
			 * Start by assuming that we need one train for every trip.
			 * That is, NA trains need to start at station A, and NB trains
			 * need to start at station B.
			 * Then, if you have all the arrival and departure times at station A,
			 * use a greedy algorithm to pair each arrival time with the earliest
			 * departure time that occurs at least T minutes afterward.  For each
			 * of these pairs that can be made, we can subtract one from the number
			 * of trains needed to start at station A. (Because there is already a
			 * train starting at station B that will take care of the two connecting
			 * trips).
			 * If you do the same thing for all the arrival and departure times at
			 * station B, and, for each pair, subtract one from the number of trains
			 * needed to start at station B, we will have our answer! 
			 */
			
			// Sort with respect to events occurring at station B.
			Arrays.sort( AtoB, new ArrivalComp() );
			Arrays.sort( BtoA, new DepartureComp() );
			
			// Search for pairs of compatible arrival and departure times.
			int i = 0, j = 0;
			while( i < AtoB.length && j < BtoA.length ) {
				if( BtoA[j].departure - AtoB[i].arrival >= T ) {
					i++;
					j++;
					NB[n]--;
				} else {
					j++;
				}//~if/else
			}//~while
			
			// Sort with respect to events occurring at station A.
			Arrays.sort( BtoA, new ArrivalComp() );
			Arrays.sort( AtoB, new DepartureComp() );
			
			// Search for pairs of compatible arrival and departure times.
			i = j = 0;
			while( i < AtoB.length && j < BtoA.length ) {
				if( AtoB[i].departure - BtoA[j].arrival >= T ) {
					i++;
					j++;
					NA[n]--;
				} else {
					i++;
				}//~if/else
			}//~while
			
		}//~for...N

		// Output
		FileOutputStream fOutStream = null;
		try {
			fOutStream = new FileOutputStream( args[0].concat(".out") );
		} catch (FileNotFoundException e) {
			fOutStream = null;
		}
		
	    PrintWriter pw = new PrintWriter( new OutputStreamWriter(fOutStream) );
	    
	    for( int n = 0; n < N; n++ ) {
	    	pw.println("Case #" + (n+1) + ": " + NA[n] + " " + NB[n] );
	    }
	    
	    pw.close();
		
	}

	private static class Trip {
		int arrival, departure;
		
		public Trip( String depart24, String arrive24 ) {
			String[] arriveHHMM = arrive24.split(":");
			String[] departHHMM = depart24.split(":");
			
			if( arriveHHMM.length != 2 || departHHMM.length != 2 )
				throw new IllegalArgumentException();
			
			arrival = Integer.parseInt(arriveHHMM[0]) * 60 + Integer.parseInt(arriveHHMM[1]);
			departure = Integer.parseInt(departHHMM[0]) * 60 + Integer.parseInt(departHHMM[1]);
		}
	}
	
	private static class ArrivalComp implements Comparator<Trip> {

		@Override
		public int compare(Trip arg0, Trip arg1) {
			return arg0.arrival - arg1.arrival;
		}
		
	}
	
	private static class DepartureComp implements Comparator<Trip> {

		@Override
		public int compare(Trip arg0, Trip arg1) {
			return arg0.departure - arg1.departure;
		}
		
	}
	
}