package gcj2008.qualification.one;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;

public class Problem {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
	
		if( args.length < 1 ) {
			System.err.println( "Missing command-line argument. " +
								"Please provide location of input file." );
		}
		
		try {

			FileInputStream fInStream = new FileInputStream( args[0] );
		    BufferedReader br = new BufferedReader( new InputStreamReader(fInStream) );

		    int N, S, Q;
		    int indexOfMatchingEngine;
		    
		    N = Integer.parseInt( br.readLine().trim() );
		    
		    /**
		     * Stores the Search Engines available for this case
		     */
		    String[] engines;
		    
		    /**
		     * For each index, stores whether the corresponding search engine
		     * would still exist if the current subset of queries were passed to it.
		     */
		    boolean[] stillExists;
		    
		    int[] numSwitches = new int[N];
		    
		    for( int n = 0; n < N; n++ ) {
		    	
		    	System.out.println("Case #" + (n+1) + ":");
		    	
		    	numSwitches[n] = 0;
		    	
		    	S = Integer.parseInt( br.readLine().trim() );
		    	engines = new String[S];
		    	stillExists = new boolean[S];
		    	resetToTrue( stillExists );
		    	
		    	for( int s = 0; s < S; s++ ) {
		    		engines[s] = br.readLine().trim();
		    	}//~for...S
		    	
		    	Q = Integer.parseInt( br.readLine().trim() );
		    	
		    	for( int q = 0; q < Q; q++ ) {
		    		indexOfMatchingEngine = 
		    			setBoolToFalseIfStringMatchesTarget( br.readLine().trim(),
		    												 engines,
		    												 stillExists );
		    		
		    		if( !atLeastOneTrue(stillExists) ) {
		    			System.out.println( "Use search engine \"" + 
		    								engines[indexOfMatchingEngine] +
		    								"\" through query " + q + "." );
		    			resetToTrue(stillExists);
		    			stillExists[indexOfMatchingEngine] = false;
		    			numSwitches[n]++;
		    		}//~if
		    	}//~for...Q
		    	
		    	String str = null;
		    	for( int i = 0; i < S; i++ ) {
		    		if( stillExists[i] ) {
		    			str = engines[i];
		    			break;
		    		}
		    	}
		    	if( str==null ) str = "Uh Oh.";
		    	
		    	System.out.println( "Use search engine \"" + str + 
		    						"\" for remaining queries." );
		    	System.out.println( "Total switches = " + numSwitches[n] );
		    	
		    }//~for...N
			
			br.close();
		
			FileOutputStream fOutStream = new FileOutputStream( args[0].concat(".out") );
		    PrintWriter pw = new PrintWriter( new OutputStreamWriter(fOutStream) );
		    
		    for( int n = 0; n < N; n++ ) {
		    	pw.println("Case #" + (n+1) + ": " + numSwitches[n] );
		    }
		    
		    pw.close();
		    
		} catch( Exception e ) {
			System.err.println( e.getMessage() );
		}//~try/catch
	
	}//~main
	
	private static boolean atLeastOneTrue( boolean[] arr ) {
		
		for( int i = 0; i < arr.length; i++ ) {
			if( arr[i] ) return true;
		}
		
		return false;
	}
	
	private static void resetToTrue( boolean[] arr ) {
		for( int i = 0; i < arr.length; i++ ) {
			arr[i] = true;
		}
	}

	private static int setBoolToFalseIfStringMatchesTarget( String target, 
															String[] arrStr, 
															boolean[] arrBool ) {
		
		if( target == null || arrStr == null || arrBool == null ) 
			throw new NullPointerException();

		int I = arrStr.length > arrBool.length ? arrBool.length : arrStr.length;
		
		for( int i = 0; i < I; i++ ) {
		
			if( arrBool[i] && arrStr[i].equals(target) ) {
			
				arrBool[i] = false;
				return i;
				
			}
			
		}
		return -1;
	}		
}
