import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.Arrays;
import java.io.BufferedWriter;
import java.util.InputMismatchException;
import java.util.ArrayList;
import java.io.PrintStream;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.io.Writer;
import java.math.BigInteger;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class Main {
	public static void main(String[] args) {
		InputStream inputStream;
		try {
			inputStream = new FileInputStream("coinjam.in");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("coinjam.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		CoinJam solver = new CoinJam();
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i, in, out);
		out.close();
	}
}

class CoinJam {

    ArrayList<BigInteger> primes;
    boolean[] isPrime;

    public void solve(int testNumber, InputReader in, OutputWriter out) {
        int n = in.readInt();
        int j = in.readInt();
        generatePrimes((int) 1e7);
        out.printLine("Case #" + testNumber + ":");

        long bInt = (1L << (n - 1)) + 1;
        System.out.println("Base str -> " + Long.toBinaryString(bInt));
        for (int i = 0; (i < (1 << (n - 2))) && j > 0; i++) {
            long val = bInt | (i << 1);
            String valStr = Long.toBinaryString(val);
            System.out.println("Processing " + valStr);

            boolean isPrime = false;
            BigInteger[] bVals = new BigInteger[11];
            for (int b = 2; b <= 10; b++) {
                bVals[b] = getValue(val, b);
                System.out.println("For base " + b + " -> " + bVals[b]);
                if (bVals[b].isProbablePrime(28)) {
                    isPrime = true;
                    break;
                }
            }

            if (isPrime) {
                continue;
            }

            System.out.println("Found COMPOSITE -> " + valStr);

            out.print(valStr + " ");
            j--;
            int[] dvsrs = new int[11];
            for (int b = 2; b <= 10; b++) {
                boolean done = false;
                BigInteger lastPrime = primes.get(0);
                for (BigInteger x : primes) {
                    if (bVals[b].mod(x).equals(BigInteger.ZERO)) {
                        out.print(x + " ");
                        done = true;
                        break;
                    }
                    lastPrime = x;
                }

                System.out.println("Need to find probable primes for base " + b + " value = " + bVals[b]);
                int iter = 1;
                while (!done) {
                    lastPrime = lastPrime.nextProbablePrime();
                    if (bVals[b].mod(lastPrime).equals(BigInteger.ZERO)) {
                        out.print(lastPrime + " ");
                        done = true;
                    }
                    if (lastPrime.compareTo(bVals[b]) > 0) {
                        System.out.println("Something wrong ! Prime = " + lastPrime + " val was = " + bVals[b]);
                    }
                }
            }

            out.printLine();
        }
    }

    BigInteger getValue(long bits, int radix) {
        BigInteger mult = BigInteger.ONE;
        BigInteger res = BigInteger.ZERO;
        for (int i = 0; i < 32; i++) {
            if ((bits & (1 << i)) != 0) {
                res = res.add(mult);
            }
            mult = mult.multiply(BigInteger.valueOf(radix));
        }
        return res;
    }

    void generatePrimes(int n) {
        primes = new ArrayList<BigInteger>();
        isPrime = new boolean[n];
        Arrays.fill(isPrime, true);

        for (int i = 2; i * i <= n; i++) {
            if (isPrime[i]) {
                primes.add(BigInteger.valueOf(i));
                for (int j = i * i; j < n; j += i) {
                    isPrime[j] = false;
                }
            }
        }
    }
}

class InputReader {
    private InputStream stream;
    private byte[] buf = new byte[1024];
    private int curChar;
    private int numChars;
    private SpaceCharFilter filter;

    public InputReader(InputStream stream) {
        this.stream = stream;
    }

    public int read() {
        if (numChars == -1)
            throw new InputMismatchException();
        if (curChar >= numChars) {
            curChar = 0;
            try {
                numChars = stream.read(buf);
            } catch (IOException e) {
                throw new InputMismatchException();
            }
            if (numChars <= 0)
                return -1;
        }
        return buf[curChar++];
    }

    public int readInt() {
        int c = read();
        while (isSpaceChar(c))
            c = read();
        int sgn = 1;
        if (c == '-') {
            sgn = -1;
            c = read();
        }
        int res = 0;
        do {
            if (c < '0' || c > '9')
                throw new InputMismatchException();
            res *= 10;
            res += c - '0';
            c = read();
        } while (!isSpaceChar(c));
        return res * sgn;
    }

    public String readString() {
        int c = read();
        while (isSpaceChar(c))
            c = read();
        StringBuilder res = new StringBuilder();
        do {
            res.appendCodePoint(c);
            c = read();
        } while (!isSpaceChar(c));
        return res.toString();
    }

    public boolean isSpaceChar(int c) {
        if (filter != null)
            return filter.isSpaceChar(c);
        return isWhitespace(c);
    }

    public static boolean isWhitespace(int c) {
        return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
    }

    public String next() {
        return readString();
    }

    public interface SpaceCharFilter {
        public boolean isSpaceChar(int ch);
    }
}

class OutputWriter {
    private final PrintWriter writer;

    public OutputWriter(OutputStream outputStream) {
        writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
    }

    public void print(Object...objects) {
        for (int i = 0; i < objects.length; i++) {
            if (i != 0)
                writer.print(' ');
            writer.print(objects[i]);
        }
    }

    public void printLine() {
        writer.println();
    }

    public void printLine(Object...objects) {
        print(objects);
        writer.println();
    }

    public void close() {
        writer.close();
    }

}

