package com.coldroid.competitiveprogramming;

import com.coldroid.competitiveprogramming.gcj2014.CookieClickerAlpha;
import com.coldroid.competitiveprogramming.gcj2014.MagicTrick;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.nio.file.Paths;
import java.util.Scanner;

/**
 * Convenience class that loads an input file, and redirects standard output to an output file. Subclasses can focus on
 * implementing {@link #solve(Scanner)}, and using the Scanner to read input. Writing to standard output or calling
 * {@link #print(String, Object...)} will write to the provided output file. <p/>
 *
 * See known sublcasses for sample usage. {@link CookieClickerAlpha}, and {@link MagicTrick}.
 *
 * Note: Known subclasses will be provided on Github (https://github.com/coltin/) AFTER Google Code Jam is completed,
 * and will not be available during judging.
 */
public abstract class Solution {
    public abstract void solve(Scanner scanner);

    public void solve(String inputFilePath, String outputFilePath) {
        PrintStream outputPrintStream = makeOutputStream(outputFilePath);
        System.setOut(outputPrintStream);
        Scanner scanner = null;
        try {
            scanner = new Scanner(
                    new File(Paths.get(System.getProperty("user.dir"), "googlecodejam", "input", inputFilePath).toUri())
            );
            solve(scanner);
        } catch (FileNotFoundException exception) {
            exception.printStackTrace();
        } finally {
            if (scanner != null) {
                scanner.close();
            }
            if (outputPrintStream != null) {
                outputPrintStream.close();
            }
            System.setOut(System.out);
        }
    }

    /**
     * Convenience method that wraps System.out.println() and String.format().
     */
    protected void print(String formatString, Object... arguments) {
        System.out.println(String.format(formatString, arguments));
    }

    /**
     * Convenience method that wraps System.out.println() to print a single number.
     */
    protected void print(int number) {
        System.out.println(number);
    }

    /**
     * Convenience method to print an empty line.
     */
    protected void print() {
        System.out.println();
    }

    /**
     * Safetly creates an output stream from a file path. If the file is not found, or the path is null/empty, the
     * {@link System#out} {@link PrintStream} is returned.
     */
    private static PrintStream makeOutputStream(String outputFilePath) {
        PrintStream outputPrintStream = null;
        try {
            outputPrintStream = new PrintStream(new File(Paths.get(System.getProperty("user.dir"), "googlecodejam",
                    "output", outputFilePath).toUri()));
            return outputPrintStream;
        } catch (FileNotFoundException e) {
            if (outputPrintStream != null) {
                outputPrintStream.close();
            }
            e.printStackTrace();
            return System.out;
        }
    }
}
