import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Scanner;

public class FashionShow {
	private final char[] _types = new char[] { 'o', '+', 'x' };
	private final HashMap<Character, Integer> _points = new HashMap<Character, Integer>();
	
	public FashionShow() {
		_points.put('o', 2);
		_points.put('+', 1);
		_points.put('x', 1);
		_points.put('.', 0);
	}
	
	public void generate() {
		Scanner scanner = null;
		File file = new File("D-small-attempt0.in");
		FileWriter fw = null;
		
		try {
			fw = new FileWriter("D-small-output.in");
			int line = 0;
			scanner = new Scanner(file);
			int n = 0, m = 0, caseNumber = 0;
			List<ResultModel> preModels = new ArrayList<ResultModel>();
			
			while(scanner.hasNextLine()) {
				String text = scanner.nextLine();
				line++;
				
				if(line == 1) continue;
				
				String[] inputs = text.split(" ");
				
				if(inputs.length == 2) {
					n = Integer.parseInt(inputs[0]);
					m = Integer.parseInt(inputs[1]);
					preModels = new ArrayList<ResultModel>();
					caseNumber++;
				} else {
					char type = inputs[0].charAt(0);
					int row = Integer.parseInt(inputs[1]);
					int col = Integer.parseInt(inputs[2]);
					preModels.add(new ResultModel(type, row, col, true));
				}
				
				if(preModels.size() == m) {
					Result result = generateMaxShow(n, m, preModels);
					
					fw.write("Case #" + caseNumber + ": " + result.total + " " + result.additionalModels.size() + "\n");
					
					for(ResultModel model : result.additionalModels) {
						fw.write(model.getType() + " " + model.getRow() + " " + model.getCol() + "\n");
					}
				}
			}
			
			if(fw != null) fw.close();
		} catch(IOException ex) {
			
		} catch(Exception ex) {
			System.out.println(ex.getMessage());
		} finally {
			if(scanner != null)
				scanner.close();
		}
	}
	
	public Result generateMaxShow(int n, int m, List<ResultModel> preModels) {
		Model[][] grid = new Model[n + 1][n + 1];
		Result result = new Result();
		
		for(int i = 1; i <= n; i++) {
			for(int j = 1; j <= n; j++) {
				if(grid[i][j] == null) {
					grid[i][j] = new Model();
				}
			}
		}
		
		for(ResultModel model : preModels) {
			model.setLock(true);
			grid[model.row][model.col] = model;
		}
		
		for(int i = 1; i <= n; i++) {
			for(int j = 1; j <= n; j++) {
				Model current = grid[i][j];
				
				if(current != null && current.lock) {
					if(current.getType() != 'o' && isValidAll(grid, 'o', i, j)) {
						current.setType('o');
						result.additionalModels.add(new ResultModel(current, i, j));
					}
				} else {
					for(char type : _types) {
						if(isValidAll(grid, type, i, j)) {
							current.setType(type);
							result.additionalModels.add(new ResultModel(current, i, j));
							break;
						}
					}
				}
			}
		}
		
		result.total = 0;
		
		for(int i = 1; i <= n; i++) {
			for(int j = 1; j <= n; j++) {
				result.total += _points.get(grid[i][j].getType());
			}
		}
		
		return result;
	}
	
	private boolean isValidAll(Model[][] grid, char type, int row, int col) {
		int n = grid.length;
		
		if(row < 1 || col < 1 || row >= n || col >= n)
			return false;
		
		if(type == '.')
			return true;
		
		//check row + col
		for(int i = 1; i < n; i++) {
			if(i != row && !atleastOne(type, grid[i][col].getType(), '+'))
				return false;
			
			if(i != col && !atleastOne(type, grid[row][i].getType(), '+'))
				return false;
		}
		
		//check diagonal
		int startRow = 1, startCol = 1;
		if(row > col) startRow += row - col;
		else if(col > row) startCol += col - row;
		
		int loop = n - Math.max(startRow, startCol);
		
		for(int i = 0; i < loop; i++) {
			if(startRow + i != row && startCol + i != col && !atleastOne(type, grid[startRow + i][startCol + i].getType(), 'x'))
				return false;
		}
		
		//check opposite diagonal
		int r = row;
		int c = col;
		
		while(r < n - 1 && c > 1) {
			r++;
			c--;
		}
		
		while(r >= 1 && c < n) {
			if(r != row && c != col && !atleastOne(type, grid[r ][c].getType(), 'x'))
				return false;
			r--;
			c++;
		}
		
		return true;
	}
	
	private boolean atleastOne(char currentType, char anotherType, char expectedType) {
		if(anotherType == '.') return true;
		
		return currentType == expectedType || anotherType == expectedType;
	}
	
	class Result {
		public int total;
		public List<ResultModel> additionalModels;
		
		public Result() {
			additionalModels = new ArrayList<ResultModel>();
		}
	}
	
	class ResultModel extends Model {
		public int row;
		public int col;
		
		public ResultModel(char type, int row, int col, boolean lock) {
			super(type, lock);
			this.col = col;
			this.row = row;
		}
		
		public ResultModel(Model model, int row, int col) {
			this(model.type, row, col, model.lock);
		}
		
		public int getRow() {
			return row;
		}
		public void setRow(int row) {
			this.row = row;
		}
		public int getCol() {
			return col;
		}
		public void setCol(int col) {
			this.col = col;
		}
	}
	
	class Model {
		public boolean lock;
		public char type;
		
		public Model() {
			type = '.';
		}
		
		public Model(char type, boolean lock) {
			this.type = type;
			this.lock = lock;
		}
		
		public boolean isLock() {
			return lock;
		}
		public void setLock(boolean lock) {
			this.lock = lock;
		}
		public char getType() {
			return type;
		}
		public void setType(char type) {
			this.type = type;
		}
	}
}
