package ru.control9.google.jam;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class D {
    private static final Path input = Paths.get("D.in");
    private static final Path output = Paths.get("D.out");
    private boolean[][] rooks;
    private boolean[][] bishops;
    private int n;
    private int m;
    private int score;
    private boolean[] usedLines;
    private boolean[] usedCols;
    private boolean[] usedSums;
    private boolean[] usedDiffs;
    private Map<Pair, Integer> additions;
    private int bishopNum;
    private int rookNum;

    public static void main(String[] args) throws IOException {
        new D().solve();
    }

    private void solve() throws IOException {
        List<String> inputs = Files.readAllLines(input);
        int t = Integer.valueOf(inputs.get(0));
        List<String> results = new ArrayList<>(t);
        int casenum = 1;
        int line = 1;
        while (casenum <= t) {
            String[] header = inputs.get(line++).split(" ");
            n = Integer.valueOf(header[0]);
            m = Integer.valueOf(header[1]);

            List<String> caseInput = new ArrayList<>(m);
            for (int i = 0; i < m; i++) {
                caseInput.add(inputs.get(line++));
            }
            results.add("Case #"+casenum+": "+solveSmallCase(n, m, caseInput));
            casenum++;
        }
        Files.write(output, results);
    }

    private String solveSmallCase(int n, int m, List<String> caseInput) {
        bishops = new boolean[n][n];
        rooks = new boolean[n][n];

        bishopNum = 0;
        rookNum = 0;

        usedLines = new boolean[n];
        usedCols = new boolean[n];

        usedSums = new boolean[2*n];
        usedDiffs = new boolean[2*n];

        score = 0;

        for (int i = 0; i < m; i++) {
            String[] add = caseInput.get(i).split(" ");
            int x = Integer.parseInt(add[1]) - 1;
            int y = Integer.parseInt(add[2]) - 1;
            String typeCode = add[0];
            int type = 0;
            if (typeCode.equals(BISH_CODE)) type = BISH;
            if (typeCode.equals(ROOK_CODE)) type = ROOK;
            if (typeCode.equals(QUEEN_CODE)) type = QUEEN;

            assert type != 0;

            if ( (type & BISH) > 0) {
                addBishop(x, y);
            }
            if ( (type & ROOK) > 0) {
                addRook(x, y);
            }
        }

        additions = new HashMap<>();

        fillForSmallCase();

        StringBuilder sb = new StringBuilder();
        sb.append(score).append(" ").append(additions.size());
        for (Pair xy : additions.keySet()) {
            sb.append("\n");
            int code = additions.get(xy);
            if (QUEEN == code) sb.append(QUEEN_CODE);
            if (ROOK == code) sb.append(ROOK_CODE);
            if (BISH == code) sb.append(BISH_CODE);
            sb.append(" ").append(xy.x).append(" ").append(xy.y);
        }
        return sb.toString();
    }

    private void fillForSmallCase() {
        if (!usedLines[0]) {
            addRook(0, 0);
            if (!bishops[0][0]) addBishop(0, 0);
            write(0, 0);
        }
        for (int y = 0; y < n; y++) {
            if (!bishops[0][y]) {
                addBishop(0, y);
                write(0, y);
            }
        }

        for (int y = 1; y < n-1; y++) {
            if (!bishops[n-1][y]) {
                addBishop(n-1, y);
                write(n-1, y);
            }
        }

        fillRooks();
    }

    private void fillRooks() {
        for (int x = 0; x < n; x++) {
            if (usedLines[x]) continue;
            for (int y = 0; y < n; y++) {
                if (usedCols[y]) continue;
                addRook(x, y);
                write(x, y);
                break;
            }
        }
    }

    private void write(int x, int y) {
        int type = 0;
        if (bishops[x][y]) type+= BISH;
        if (rooks[x][y]) type += ROOK;
        additions.put(new Pair(x+1, y+1), type);
    }

    private void addRook(int x, int y) {
        rookNum++;
        rooks[x][y] = true;
        usedLines[x] = true;
        usedCols[y] = true;
        score++;
    }

    private void addBishop(int x, int y) {
        bishopNum++;
        bishops[x][y] = true;
        usedSums[x + y] = true;
        usedDiffs[x - y + n] = true;
        score++;
    }

    int BISH = 1;
    int ROOK = 2;
    int QUEEN = 3;

    private static final String BISH_CODE = "+";
    private static final String ROOK_CODE = "x";
    private static final String QUEEN_CODE = "o";


    private static final class Pair {
        protected final int x;
        protected final int y;

        private Pair(int x, int y) {
            this.x = x;
            this.y = y;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Pair pair = (Pair) o;

            if (x != pair.x) return false;
            return y == pair.y;

        }

        @Override
        public int hashCode() {
            int result = x;
            result = 31 * result + y;
            return result;
        }
    }

}
