package com.example.codejam.deceitfulwar;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;

public class DeceitfulWar {
	private static final int MIN_TEST_CASE_NUMBER = 1, MAX_TEST_CASE_NUMBER = 1000;

	private static final String ANSWER_HEADER_FORMAT = "Case #%d: %s";

	@SuppressWarnings("resource")
	public static void main(String[] args) throws IOException {
		if (args.length == 0)
			throw new IllegalArgumentException("No arguments passed");

		Reader reader = new FileReader(args[0]);
		String[] answers;
		try {
			BufferedReader buffer = new BufferedReader(reader);
			reader = buffer;

			int testCaseNumber = Integer.parseInt(buffer.readLine());
			if (testCaseNumber < MIN_TEST_CASE_NUMBER)
				throw new IllegalArgumentException(
						"Number is less than a minimum of " + MIN_TEST_CASE_NUMBER);
			if (testCaseNumber > MAX_TEST_CASE_NUMBER)
				throw new IllegalArgumentException(
						"Number is greated than a maximum " + MAX_TEST_CASE_NUMBER);
			answers = new String[testCaseNumber];

			for (int i = 0; i < testCaseNumber; i++) {
				answers[i] = solve(buffer, i + 1);
			}
		} finally {
			reader.close();
		}

		Writer writer = args.length > 1 ? new FileWriter(args[1]) :
			new OutputStreamWriter(System.out);
		try {
			BufferedWriter buffer = new BufferedWriter(writer);
			writer = buffer;
			for (int i = 0; i < answers.length; i++) {
				buffer.write(String.format(Locale.US,
						ANSWER_HEADER_FORMAT, i + 1, answers[i]));
				buffer.newLine();
			}
		} finally {
			writer.close();
		}
	}

	private static String solve(BufferedReader buffer, int number) throws IOException {
		int blocksNum = Integer.parseInt(buffer.readLine());

		List<Float> myBlockWeights; {
			String[] blockWeights = buffer.readLine().split(" ");
			if (blockWeights.length != blocksNum)
				throw new IllegalArgumentException(
						"The number or Naomi's blocks are not consistent with the reported number of blocks in " + number);
			myBlockWeights = new ArrayList<Float>(blocksNum);
			for (int i = 0; i < blocksNum; i++) {
				myBlockWeights.add(Float.valueOf(blockWeights[i]));
			}
			Collections.sort(myBlockWeights);
		}

		List<Float> opponentBlockWeights; {
			String[] blockWeights = buffer.readLine().split(" ");
			if (blockWeights.length != blocksNum)
				throw new IllegalArgumentException(
						"The number or Ken's blocks are not consistent with the reported number of blocks in " + number);
			opponentBlockWeights = new ArrayList<Float>(blocksNum);
			for (int i = 0; i < blocksNum; i++) {
				opponentBlockWeights.add(Float.valueOf(blockWeights[i]));
			}
			Collections.sort(opponentBlockWeights);
		}

		int deceitfulWarScore = 0;
		List<Float> deceitfulWarMyBlockWeights = new ArrayList<Float>(opponentBlockWeights);
		List<Float> deceitfulWarOpponentBlockWeights = new ArrayList<Float>(myBlockWeights);
		for (int i = 0; i < blocksNum; i++) {
			float myBlockWeight = deceitfulWarMyBlockWeights.remove(0);
			float opponentBlockWeight = 0;
			if (deceitfulWarOpponentBlockWeights.get(deceitfulWarOpponentBlockWeights.size() - 1) < myBlockWeight)
				opponentBlockWeight = deceitfulWarOpponentBlockWeights.remove(0);
			else {
				for (Iterator<Float> iterator = deceitfulWarOpponentBlockWeights.iterator();
						iterator.hasNext();) {
					opponentBlockWeight = iterator.next();
					if (opponentBlockWeight > myBlockWeight) {
						iterator.remove();
						break;
					}
				}
			}
			if (opponentBlockWeight > myBlockWeight) {
				deceitfulWarScore++;
			}
		}

		int warScore = 0;
		List<Float> warMyBlockWeights = new ArrayList<Float>(myBlockWeights);
		List<Float> warOpponentBlockWeights = new ArrayList<Float>(opponentBlockWeights);
		for (int i = 0; i < blocksNum; i++) {
			float myBlockWeight = warMyBlockWeights.remove(0);
			float opponentBlockWeight = 0;
			if (warOpponentBlockWeights.get(warOpponentBlockWeights.size() - 1) < myBlockWeight)
				opponentBlockWeight = warOpponentBlockWeights.remove(0);
			else {
				for (Iterator<Float> iterator = warOpponentBlockWeights.iterator();
						iterator.hasNext();) {
					opponentBlockWeight = iterator.next();
					if (opponentBlockWeight > myBlockWeight) {
						iterator.remove();
						break;
					}
				}
			}
			if (myBlockWeight > opponentBlockWeight) {
				warScore++;
			}
		}
		return "" + deceitfulWarScore + " " + warScore;
	}
}