package com.example.codejam.minesweepermaster;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import java.util.Locale;

public class MinesweeperMaster {
	private static final int MIN_TEST_CASE_NUMBER = 1, MAX_TEST_CASE_NUMBER = 230;

	private static final String ANSWER_HEADER_FORMAT = "Case #%d:%n%s";
	private static final String RESULT_IMPOSSIBLE = "Impossible";
	private static final String NEWLINE = System.getProperty("line.separator");

	@SuppressWarnings("resource")
	public static void main(String[] args) throws IOException {
		if (args.length == 0)
			throw new IllegalArgumentException("No arguments passed");

		Reader reader = new FileReader(args[0]);
		String[] answers;
		try {
			BufferedReader buffer = new BufferedReader(reader);
			reader = buffer;

			int testCaseNumber = Integer.parseInt(buffer.readLine());
			if (testCaseNumber < MIN_TEST_CASE_NUMBER)
				throw new IllegalArgumentException(
						"Number is less than a minimum of " + MIN_TEST_CASE_NUMBER);
			if (testCaseNumber > MAX_TEST_CASE_NUMBER)
				throw new IllegalArgumentException(
						"Number is greated than a maximum " + MAX_TEST_CASE_NUMBER);
			answers = new String[testCaseNumber];

			for (int i = 0; i < testCaseNumber; i++) {
				answers[i] = solve(buffer, i + 1);
			}
		} finally {
			reader.close();
		}

		Writer writer = args.length > 1 ? new FileWriter(args[1]) :
			new OutputStreamWriter(System.out);
		try {
			BufferedWriter buffer = new BufferedWriter(writer);
			writer = buffer;
			for (int i = 0; i < answers.length; i++) {
				buffer.write(String.format(Locale.US,
						ANSWER_HEADER_FORMAT, i + 1, answers[i]));
				buffer.newLine();
			}
		} finally {
			writer.close();
		}
	}

	private enum Slot {
		EMPTY('.'), MINE('*'), CLICKED('c');

		public final char symbol;
		Slot(char symbol) {
			this.symbol = symbol;
		}

		public static Slot[][] createGrid(int rowsNum, int columnsNum) {
			Slot[][] grid = new Slot[rowsNum][columnsNum];
			for (int rowIndex = 0; rowIndex < rowsNum; rowIndex++) {
				for (int columnIndex = 0; columnIndex < columnsNum; columnIndex++) {
					grid[rowIndex][columnIndex] = Slot.EMPTY;
				}
			}
			return grid;
		}

		public static String printGrid(Slot[][] grid) {
			StringBuilder result = new StringBuilder();
			for (Slot[] row : grid) {
				for (Slot slot : row) {
					result.append(slot.symbol);
				}
				result.append(NEWLINE);
			}
			int length = result.length();
			result.delete(length - NEWLINE.length(), length);
			return result.toString();
		}
	}

	private static String solve(BufferedReader buffer, int number) throws IOException {
		String[] input = buffer.readLine().split(" ");
		if (input.length != 3)
			throw new IllegalArgumentException("Test case " + number +
					" does not consist of 3 space-separated values");

		int rowsNum = Integer.parseInt(input[0]);
		int columnsNum = Integer.parseInt(input[1]);
		int minesNum = Integer.parseInt(input[2]);

		if (minesNum < 0)
			throw new IllegalArgumentException(
					"Mine value is less than the minimum of 0 at test case " + number);
		int freeSpace = rowsNum * columnsNum - minesNum;
		if (freeSpace <= 0)
			throw new IllegalArgumentException(
					"No free space at test case " + number);

		if (rowsNum > 1 && columnsNum > 1) {
			switch (freeSpace) {
			case 2: case 3:
				return RESULT_IMPOSSIBLE;
			}
		}

		Slot[][] grid = Slot.createGrid(rowsNum, columnsNum);

		grid[rowsNum - 1][columnsNum - 1] = Slot.CLICKED;

		if (minesNum == 0) {
			return Slot.printGrid(grid);
		}

		int minesUsed = 0, rowsDone = 0, columnsDone = 0;
		if (rowsNum > columnsNum) {
			do {
				for (int columnIndex = 0; columnIndex < columnsNum; columnIndex++) {
					grid[rowsDone][columnIndex] = Slot.MINE;
					if (++minesUsed == minesNum) {
						return Slot.printGrid(grid);
					}
				}
				rowsDone++;
			} while (rowsNum - rowsDone > columnsNum);
		} else if (columnsNum > rowsNum) {
			do {
				for (int rowIndex = 0; rowIndex < rowsNum; rowIndex++) {
					grid[rowIndex][columnsDone] = Slot.MINE;
					if (++minesUsed == minesNum) {
						return Slot.printGrid(grid);
					}
				}
				columnsDone++;
			} while (columnsNum - columnsDone > rowsNum);
		}

		for (int i = 0, max = Math.min(rowsNum, columnsNum); i < max; i++) {
			for (int j = i; j < max; j++) {
				grid[i + rowsDone][j + columnsDone] = Slot.MINE;
				if (++minesUsed == minesNum) {
					return Slot.printGrid(grid);
				}
				if (j == i) continue;
				grid[j + rowsDone][i + columnsDone] = Slot.MINE;
				if (++minesUsed == minesNum) {
					return Slot.printGrid(grid);
				}
			}
		}
		throw new IllegalStateException(
				"We should have finished the mines before this point " + number);
	}
}