package com.example.codejam.cookieclickeralpha;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import java.util.Locale;

public class CookieClickerAlpha {
	private static final int MIN_TEST_CASE_NUMBER = 1, MAX_TEST_CASE_NUMBER = 100;

	private static final String DECIMAL_FORMAT = "%.7f";

	@SuppressWarnings("resource")
	public static void main(String[] args) throws IOException {
		if (args.length == 0)
			throw new IllegalArgumentException("No arguments passed");

		Reader reader = new FileReader(args[0]);
		String[] answers;
		try {
			BufferedReader buffer = new BufferedReader(reader);
			reader = buffer;

			int testCaseNumber = Integer.parseInt(buffer.readLine());
			if (testCaseNumber < MIN_TEST_CASE_NUMBER)
				throw new IllegalArgumentException(
						"Number is less than a minimum of " + MIN_TEST_CASE_NUMBER);
			if (testCaseNumber > MAX_TEST_CASE_NUMBER)
				throw new IllegalArgumentException(
						"Number is greated than a maximum " + MAX_TEST_CASE_NUMBER);
			answers = new String[testCaseNumber];

			for (int i = 0; i < testCaseNumber; i++) {
				answers[i] = solve(buffer, i);
			}
		} finally {
			reader.close();
		}

		Writer writer = args.length > 1 ? new FileWriter(args[1]) :
			new OutputStreamWriter(System.out);
		try {
			BufferedWriter buffer = new BufferedWriter(writer);
			writer = buffer;
			for (int answerIndex = 0; answerIndex < answers.length; answerIndex++) {
				buffer.write("Case #" + (answerIndex + 1) + ": " + answers[answerIndex]);
				buffer.newLine();
			}
		} finally {
			writer.close();
		}
	}

	private static String solve(BufferedReader buffer, int number) throws IOException {
		String[] input = buffer.readLine().split(" ");
		if (input.length != 3)
			throw new IllegalArgumentException("Input line + " + number +
					" does not consist of 3 space-separated values");

		double farmPrice = Double.parseDouble(input[0]);
		double farmProduction = Double.parseDouble(input[1]);
		double goal = Double.parseDouble(input[2]);

		for (double secondsSpent = 0, cookiesPerSecond = 2;;) {
			double secondsToReachGoal = goal / cookiesPerSecond;
			double secondsToFarm = farmPrice / cookiesPerSecond;
			double secondsToFarmThenReachGoal = secondsToFarm +
					(goal / (cookiesPerSecond + farmProduction));
			if (secondsToReachGoal <= secondsToFarmThenReachGoal)
				return String.format(Locale.US, DECIMAL_FORMAT,
						secondsSpent + secondsToReachGoal);
			secondsSpent += secondsToFarm;
			cookiesPerSecond += farmProduction;
		}
	}
}