package qualification;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
import java.util.SortedSet;
import java.util.StringTokenizer;
import java.util.TreeSet;

public class CMain {

	private static class StallRange implements Comparable<StallRange>{
		long startIndex;
		long endIndex;
		
		public StallRange(long startIndex, long endIndex) {
			this.startIndex = startIndex;
			this.endIndex = endIndex;
		}
		
		public long getLength() {
			return endIndex - startIndex + 1; 
		}
		
		public Set<StallRange> split(long offset) {
			Set<StallRange> result = new HashSet<>();
			final long leftEndIndex = startIndex + offset - 1;
			if (leftEndIndex >= startIndex) {
				result.add(new StallRange(startIndex, leftEndIndex));
			} 
			
			final long rightStartIndex = startIndex + offset + 1;
			if (rightStartIndex <= endIndex) {
				result.add(new StallRange(rightStartIndex, endIndex));
			}
			return result;
		}

		@Override
		public int compareTo(StallRange o) {
			if (this.getLength() > o.getLength()) {
				return 1;
			} else if (this.getLength() == o.getLength()) {
				if (this.startIndex < o.startIndex) {
					return 1;
				} else if (this.startIndex == o.startIndex){
					return 0;
				} else  {
					return -1;
				}
			} else {
				return -1;
			}
		}

		@Override
		public String toString() {
			return "StallRange [startIndex=" + startIndex + ", endIndex=" + endIndex + "]";
		}
	}

	public static void main(String[] args) {
		String inputFileName = args[0];
		String outputFileName = args[1];
		BufferedReader reader = null;
		File outputfile = new File(outputFileName);
		FileOutputStream fos = null;
		try {
			fos = new FileOutputStream(outputfile);
		} catch (FileNotFoundException e1) {
			System.err.println("Output file not found");
			System.exit(1);
		}

		DataOutputStream dos = new DataOutputStream(fos);
		try {
			reader = new BufferedReader(new FileReader(inputFileName));

			String numberOfCasesStr = reader.readLine(); // Number of cases
			int numberOfCases = Integer.valueOf(numberOfCasesStr); // Default:
																	// number of
																	// cases
			for (int i = 0; i < numberOfCases; i++) {
				System.out.println("Case #" + (i + 1));
				// Read Case
				StringTokenizer tokenizer = new StringTokenizer(reader.readLine());
				final long numberOfStalls = Long.valueOf(tokenizer.nextToken());
				final long numberOfPeople = Long.valueOf(tokenizer.nextToken());

				// Solve Case
				String result = null;

				if (numberOfStalls == numberOfPeople) {
					result = "0 0";
				} else {
					StallRange freeStallRange = new StallRange(0,numberOfStalls - 1);
					SortedSet<StallRange> freeStalls = new TreeSet<>();
					freeStalls.add(freeStallRange);
					Set<StallRange> splitRanges = Collections.emptySet();
					for (int j = 0; j < numberOfPeople; j++) {
						freeStallRange = freeStalls.last();
						final long rangeLength = freeStallRange.getLength();
						long splitOffset = rangeLength % 2 == 0 ? (rangeLength / 2) - 1 : rangeLength / 2;
						splitRanges = freeStallRange.split(splitOffset);
						freeStalls.remove(freeStallRange);
						freeStalls.addAll(splitRanges);
					}
					
					long length1 = 0L;
					long length2 = 0L;
					final Object[] rangesArray = splitRanges.toArray();
					if (rangesArray.length == 2) {
						length1 = ((StallRange)rangesArray[0]).getLength();
						length2 = ((StallRange)rangesArray[1]).getLength();
					} else if (rangesArray.length == 1) {
						length1 = ((StallRange)rangesArray[0]).getLength();
					} 
					
					result = Math.max(length1, length2) + " " + Math.min(length1, length2);
				}

				try {
					dos.writeBytes("Case #" + (i + 1) + ": " + result + "\n");
				} catch (FileNotFoundException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		} catch (FileNotFoundException e) {
			System.out.println("Input file not found");
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			if (reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}
	}
}
