package qualification;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;
import java.util.stream.Collectors;
import java.util.stream.IntStream;

public class AMain {

	private static final char EMPTY_SIDE = '-';
	private static final char HAPPY_SIDE = '+';
	private static final String IMPOSSIBLE = "IMPOSSIBLE";

	public static void main(String[] args) {
		String inputFileName = args[0];
		String outputFileName = args[1];
		BufferedReader reader = null;
		File outputfile = new File(outputFileName);
		FileOutputStream fos = null;
		try {
			fos = new FileOutputStream(outputfile);
		} catch (FileNotFoundException e1) {
			System.err.println("Output file not found");
			System.exit(1);
		}

		DataOutputStream dos = new DataOutputStream(fos);
		try {
			reader = new BufferedReader(new FileReader(inputFileName));

			String numberOfCasesStr = reader.readLine(); // Number of cases
			int numberOfCases = Integer.valueOf(numberOfCasesStr); // Default: number of cases

			Map<Integer, Map<Integer, Map<String, Integer>>> validCombinations = new HashMap<>();

			final long startMillis = System.currentTimeMillis();
			for (int i = 0; i < numberOfCases; i++) {
				System.out.println("Case #" + (i + 1));
				// Read Case
				StringTokenizer tokenizer = new StringTokenizer(reader.readLine());
				String S = tokenizer.nextToken();
				final int K = Integer.valueOf(tokenizer.nextToken());

				// Solve Case
				String result;
				long numOfFlips = 0;
				boolean done = false;
				while (!done) {
					S = trimSides(S);
					if (S.length() < K) {
						if (S.length() > 0) {
							numOfFlips = -1;
						}
						done = true;
						continue;
					}
					final int firstIndexOfPlus = S.indexOf(HAPPY_SIDE);
					if (firstIndexOfPlus == -1) {
						S = flipPancakes(S, 0, K);
						numOfFlips++;
						continue;
					}
					
					final int lastIndexOfPlus = S.lastIndexOf(HAPPY_SIDE);
					int leadingMinuses = firstIndexOfPlus;
					int trailingMinuses = S.length() - 1 - lastIndexOfPlus;
					int initialFlipIndex;
					if (leadingMinuses >= trailingMinuses) {
						initialFlipIndex = 0;
					} else {
						initialFlipIndex = S.length() - K;
					}
					S = flipPancakes(S, initialFlipIndex, K);
					numOfFlips++;
					
				}
				result = numOfFlips >= 0 ? String.valueOf(numOfFlips) : IMPOSSIBLE;

				try {
					dos.writeBytes("Case #" + (i + 1) + ": " + result + "\n");
				} catch (FileNotFoundException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
			final long endMillis = System.currentTimeMillis();
			System.out.println("Time (ms): " + (endMillis - startMillis));
		} catch (

		FileNotFoundException e) {
			System.out.println("Input file not found");
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			if (reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}
	}
	
	private static String flipPancakes(String pancakes, int flipIndex, int numOfFlips) {
		StringBuilder builder = new StringBuilder(pancakes);
		for (int i = flipIndex; i < flipIndex + numOfFlips; i++) {
			builder.setCharAt(i, (pancakes.charAt(i) == HAPPY_SIDE) ? EMPTY_SIDE : HAPPY_SIDE);
		}
		return builder.toString();
	}

	private static String trimSides(String s) {
		final int firstIndexOfMinus = s.indexOf(EMPTY_SIDE);
		if (firstIndexOfMinus == -1) {
			return "";
		}

		final int lastIndexOfMinus = s.lastIndexOf(EMPTY_SIDE);
		return s.substring(firstIndexOfMinus, lastIndexOfMinus + 1);
	}

}
