package qualification;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;
import java.util.stream.Collectors;
import java.util.stream.IntStream;

public class AMain {

	private static final char EMPTY_SIDE = '-';
	private static final char HAPPY_SIDE = '+';
	private static final int IMPOSSIBLE = -1;

	public static void main(String[] args) {
		String inputFileName = args[0];
		String outputFileName = args[1];
		BufferedReader reader = null;
		File outputfile = new File(outputFileName);
		FileOutputStream fos = null;
		try {
			fos = new FileOutputStream(outputfile);
		} catch (FileNotFoundException e1) {
			System.err.println("Output file not found");
			System.exit(1);
		}

		DataOutputStream dos = new DataOutputStream(fos);
		try {
			reader = new BufferedReader(new FileReader(inputFileName));

			String numberOfCasesStr = reader.readLine(); // Number of cases
			int numberOfCases = Integer.valueOf(numberOfCasesStr); // Default: number of cases
			
			Map<Integer, Map<Integer, Map<String, Integer>>> validCombinations = new HashMap<>();
			
			for (int i = 0; i < numberOfCases; i++) {
				System.out.println("Case #" + (i + 1));
				// Read Case
				StringTokenizer tokenizer = new StringTokenizer(reader.readLine());
				final String S = tokenizer.nextToken();
				final int K = Integer.valueOf(tokenizer.nextToken());

				// Solve Case
				String result = "IMPOSSIBLE";
				final int lengthS = S.length();
				if (!validCombinations.containsKey(lengthS)) {
					validCombinations.put(lengthS, new HashMap<>());
				}

				final Map<Integer, Map<String, Integer>> validForLength = validCombinations.get(lengthS);
				if (!validForLength.containsKey(K)) {
					Map<String, Integer> combinationsForK = generateFlips(lengthS, K);
					validForLength.put(K, combinationsForK);
				}

				final Map<String, Integer> validPancakes = validCombinations.get(lengthS).get(K);
				if (validPancakes.containsKey(S)) {
					final Integer flips = validPancakes.get(S);
					result = String.valueOf(flips);
				}

				try {
					dos.writeBytes("Case #" + (i + 1) + ": " + result + "\n");
				} catch (FileNotFoundException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		} catch (

		FileNotFoundException e) {
			System.out.println("Input file not found");
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			if (reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}
	}

	private static Map<String, Integer> generateFlips(int length, int k) {
		Map<String, Integer> flips = new HashMap<>();
		char[] originalPancakes = new char[length];
		Arrays.fill(originalPancakes, HAPPY_SIDE);
		final String originalPancakesStr = String.valueOf(originalPancakes);
		flips.put(originalPancakesStr, 0);
		
		final int maxIndex = length - (k - 1);
		final List<Integer> indices = IntStream.range(0, maxIndex).boxed().collect(Collectors.toList());
		
		generateFlips(originalPancakes, indices, flips, k, 0);
				
		return flips;
	}

	private static void generateFlips(char[] pancakes, List<Integer> indices, Map<String, Integer> flips, int k, int numFlips) {
		numFlips++;
		for (int i = 0; i < indices.size(); i++) {
			final ArrayList<Integer> indicesCopy = new ArrayList<>(indices);
			char[] pancakesCopy = Arrays.copyOf(pancakes, pancakes.length);
			final Integer initialFlipIndex = indices.get(i);
			for (int flipIndex = initialFlipIndex; flipIndex < initialFlipIndex + k; flipIndex++) {
				pancakesCopy[flipIndex] = (pancakesCopy[flipIndex] == HAPPY_SIDE) ? EMPTY_SIDE : HAPPY_SIDE;
			}
			final String pancakeStr = String.valueOf(pancakesCopy);
			if (!flips.containsKey(pancakeStr)) {
				flips.put(pancakeStr, numFlips);
				indicesCopy.remove(initialFlipIndex);
				generateFlips(pancakesCopy, indicesCopy, flips, k, numFlips);
			} else {
				final Integer currentFlips = flips.get(pancakeStr);
				if (currentFlips > numFlips){
					flips.put(pancakeStr, numFlips);
					indicesCopy.remove(initialFlipIndex);
					generateFlips(pancakes, indicesCopy, flips, k, numFlips);
				}
				
			}
		}
	}
}
