import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.PrintWriter;

public class TicTacToeTomek {

	public static final char DRAW = '-';
	public static final char UNCOMPLETED = '.';

	private Position[][] rows;
	private Position[][] columns;
	private Position[][] diagonals;

	class Result {

		private char value = UNCOMPLETED;

		public Result(char value) {
			setValue(value);
		}

		public Result() {
			this(UNCOMPLETED);
		}

		public boolean isCompleted() {
			return value != UNCOMPLETED;
		}

		public boolean isDraw() {
			return value == DRAW;
		}

		public boolean isWinning() {
			return (isCompleted() && (!isDraw()));
		}

		public char getValue() {
			return value;
		}

		public void setValue(char value) {
			this.value = value;
		}

		public String toString() {
			if (!isCompleted()) {
				return "Game has not completed";
			} else {
				if (isDraw()) {
					return "Draw";
				} else {
					return getValue() + " won";
				}
			}
		}
	}

	class Position {
		private int x;
		private int y;

		public Position(int x, int y) {
			this.x = x;
			this.y = y;
		}

		public int getX() {
			return x;
		}

		public int getY() {
			return y;
		}

	}

	public TicTacToeTomek(int length) {
		rows = getRowsDirection(length);
		columns = getColumnsDirection(length);
		diagonals = getDiagonalDirection(length);
	}

	private boolean contains(char x, char[] input) {
		for (char y : input) {
			if (y == x) {
				return true;
			}
		}
		return false;
	}

	private Result check(char[] input) {
		Result result = new Result();

		if (!contains('.', input)) {
			char x = input[0];
			if ('T' == x) {
				x = input[1];
			}
			for (int i = 0; i < input.length; i++) {
				if (input[i] != x) {
					if (input[i] != 'T') {
						result.setValue(DRAW);
						return result;
					}
				}
			}
			result.setValue(x);
		}
		return result;
	}

	private Result checkSequence(char[][] input, Position[] positions) {
		char[] sequence = new char[positions.length];
		for (int i = 0; i < positions.length; i++) {
			sequence[i] = input[positions[i].getX()][positions[i].getY()];
		}
		return check(sequence);
	}

	private Result checkDirection(char[][] input, Position[][] positions) {
		Result result = new Result(DRAW);
		Result resultP = new Result();
		for (int i = 0; i < positions.length; i++) {
			resultP = checkSequence(input, positions[i]);
			if (resultP.isWinning()) {
				return resultP;
			} else {
				if (!resultP.isCompleted()) {
					result = resultP;
				}
			}
		}
		return result;
	}

	private Position[][] getRowsDirection(int length) {
		Position[][] direction = new Position[length][length];
		for (int i = 0; i < length; i++) {
			for (int j = 0; j < length; j++) {
				direction[i][j] = new Position(i, j);
			}
		}
		return direction;
	}

	private Position[][] getColumnsDirection(int length) {
		Position[][] direction = new Position[length][length];
		for (int i = 0; i < length; i++) {
			for (int j = 0; j < length; j++) {
				direction[i][j] = new Position(j, i);
			}
		}
		return direction;
	}

	private Position[][] getDiagonalDirection(int length) {
		Position[][] direction = new Position[2][length];
		for (int i = 0; i < length; i++) {
			direction[0][i] = new Position(i, i);
			direction[1][i] = new Position(length - i - 1, i);
		}
		return direction;
	}

	public Result solve(char[][] input) {
		if (input != null) {
			Result result = new Result();
			Result resultC = new Result();
			Result resultR = new Result();
			Result resultD = new Result();
			resultC = checkDirection(input, columns);

			if (!resultC.isWinning()) {
				resultR = checkDirection(input, rows);
				if (!resultR.isWinning()) {
					resultD = checkDirection(input, diagonals);
					if (!resultD.isWinning()) {
						if ((resultC.isCompleted()) && (resultD.isCompleted())
								&& (resultR.isCompleted()))
							// All complited but none winning => All Draw...
							// pick any one
							result = resultC;
					} else {
						result = resultD;
					}
				} else {
					result = resultR;
				}
			} else {
				result = resultC;
			}
			return result;
		}
		return null;
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		
		try {
			BufferedReader reader = new BufferedReader(new FileReader(new File(
					"A-small-attempt0.in")));
			int length = Integer.parseInt(reader.readLine());
			char[][][] input = new char[length][4][4];
			for (int i = 0; i < length; i++) {
				for (int j = 0; j < 4; j++) {
					input[i][j] = reader.readLine().toCharArray();
				}
				reader.readLine();
			}
			reader.close();

			PrintWriter output = new PrintWriter("out.txt");

			TicTacToeTomek solver = new TicTacToeTomek(4);
			for (int i = 0; i < input.length; i++) {
				output.println("Case #" + (i + 1) + ": "
						+ solver.solve(input[i]));
			}
			output.close();
		} catch (Exception ex) {
			ex.printStackTrace();
		}

	}

}
