import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;

public class Main {
	static enum TYPE{ CUBE4, BOOT4, PLUS4, STAIRS4, STRAIGHT4, RIGHT3, STRAIGHT3, S2, S1};
	static class Omino{
		int maxw;
		int maxh;
		int[][] shape;
		TYPE type;
		public Omino(int[][] Shape, int Maxw, int Maxh, TYPE Type)
		{
			shape = Shape;
			maxw = Maxw;
			maxh = Maxh;
			type = Type;
		}
		
		public boolean canFit(State map, int x, int y)
		{
			boolean out = true;
			for(int i=0; i< maxh; i++)
			{
				for(int j=0; j<maxw; j++)
				{
					if(map.map.length > y+i && map.map[0].length > x+j) 
					{
						//current shape part should fit on map
						if(shape[i][j]==1 && map.map[y+i][x+j]!=0)
						{
							return false; //space is already occupied
						}
						
					}
					else if(shape[i][j]==1) //if it should fit, but doesn't return false
					{
						return false;
					}
					
					//otherwise it fits and is not occupied, or is not a piece we need to check against
					
				}
			}
			
			return out;
		}
		
		@Override 
		public String toString()
		{
			StringBuilder out = new StringBuilder();
			for(int i=0; i<maxh; i++)
			{
				for(int j=0; j<maxw; j++)
				{
					out.append((shape[i][j]==1?"1":" "));
				}
				out.append("\r\n");
			}
			
			return out.toString();
		}
	}
	
	static class State{
		
		int[][] map;
		
		public State(int[][] Map)
		{
			map = Map;
		}
		
		public State(int[][] Map, Omino o, int x, int y)
		{
			map = new int[Map.length][Map[0].length];
			for(int i=0; i<map.length; i++) //do deep copy of map
			{
				for(int j=0; j<map[0].length; j++)
				{
					map[i][j] = Map[i][j];
				}
			}
			
			
			for(int i=0; i<o.maxh; i++)
			{
				for(int j=0; j<o.maxw; j++)
				{
					if(o.shape[i][j]==1)
					{
						map[y+i][x+j] = 1;
					}
				}
			}
		}
		
		public boolean isComplete()
		{
			for(int i=0; i<map.length; i++)
				for(int j=0; j<map[0].length; j++)
					if(map[i][j]==0)
						return false;
			return true;
		}
		
		@Override
		public String toString()
		{
			StringBuilder out = new StringBuilder();
			for(int i=0; i<map.length; i++)
			{
				for(int j=0; j<map[0].length; j++)
				{
					out.append(map[i][j]);
				}
				out.append("\r\n");
			}
			return out.toString();
		}
	}
	static StringBuilder out;
	public static void main(String[] args) throws NumberFormatException, IOException {
		BufferedReader in = new BufferedReader(new FileReader("input.in"));
		out = new StringBuilder();
		int T = Integer.parseInt(in.readLine());
		
		
		
		for(int t=0; t<T; t++)
		{
			String[] line = in.readLine().split(" ");
			int X = Integer.parseInt(line[0]);
			int R = Integer.parseInt(line[1]);
			int C = Integer.parseInt(line[2]);
			boolean result = solveTest(X, R, C);
			//System.out.println(result);
			
			out.append("Case #");
			out.append(t+1);
			out.append(": ");
			if(result)
			{
				out.append("GABRIEL");
			}
			else
			{
				out.append("RICHARD");
			}
			out.append("\r\n");
		}
		System.out.println(out.toString());
		BufferedWriter fOut = new BufferedWriter(new FileWriter("output.txt"));
		fOut.write(out.toString());
		fOut.close();
		System.out.println("DONE!");
	}
	
	static boolean solveTest(int X, int R, int C)
	{
		HashMap<String, State> visitedStatesSet = new HashMap<String, State>();
		ArrayDeque<State> Q = new ArrayDeque<State>();
		ArrayList<Omino> ominos = makeOminos(X);
		State start = new State(new int[R][C]);
		//Q.add(start);
		visitedStatesSet.put(start.toString(), start);
		
		
		HashSet<TYPE> typeSet = new HashSet<TYPE>();
		
		for(int o=0; o<ominos.size(); o++) //iterate through starting with each of the ominos
		{
			Q.clear();
			visitedStatesSet.clear();
			
			
			Omino startO = ominos.get(o);
			for(int i=0; i<R; i++)
			{
				for(int j=0; j<C; j++)
				{
					if(startO.canFit(start, j, i))
					{
						State newState = new State(start.map, startO, j, i);
						if(!visitedStatesSet.containsKey(newState.toString()))
						{
							visitedStatesSet.put(newState.toString(), newState);
							Q.add(newState);
							typeSet.add(startO.type);
						}
						
					}
				}
			}
			
			boolean canSolve = false;
			if(Q.isEmpty())
				canSolve = true;
			//from each starting point iterate through all possible moves until either running out of possibilities or finding a complete board
			while(!Q.isEmpty())
			{
				State S = Q.poll();
				if(S.isComplete())
				{
					canSolve = true;
					break; //meaning second guy wins
				}
				
				for(int o2=0; o2<ominos.size(); o2++) //iterate through starting with each of the ominos
				{
					Omino O = ominos.get(o2);
					for(int i=0; i<R; i++)
					{
						for(int j=0; j<C; j++)
						{
							if(O.canFit(S, j, i))
							{
								State newState = new State(S.map, O, j, i);
								if(!visitedStatesSet.containsKey(newState.toString()))
								{
									visitedStatesSet.put(newState.toString(), newState);
									Q.add(newState);								
								}
								
							}
						}
					}				
				}
			}
			if(!canSolve)
				return false;
			
		}
		
		if(X==1 && typeSet.size()<1)
		{
			return false; //meaning the first guy wins because there is at least 1 piece he could choose that wouldn't allow the second guy to even start
		}
		else if(X==2 && typeSet.size()<1)
		{
			return false; //meaning the first guy wins because there is at least 1 piece he could choose that wouldn't allow the second guy to even start
		}
		else if(X==3 && typeSet.size()<2)
		{
			return false; //meaning the first guy wins because there is at least 1 piece he could choose that wouldn't allow the second guy to even start
		}
		else if(X==4 && typeSet.size()<5)
		{
			return false; //meaning the first guy wins because there is at least 1 piece he could choose that wouldn't allow the second guy to even start
		}
		return true; //meaning the second guy wins
	}
	
	static ArrayList<Omino> makeOminos(int X)
	{
		ArrayList<Omino> ominos = new ArrayList<Omino>();
		if(X==1)
		{
			ominos.add(new Omino(new int[][] {{1}}, 1, 1, TYPE.S1));
		}
		else if(X==2)
		{
			ominos.add(new Omino(new int[][] {{1,1}}, 2, 1, TYPE.S2));
			ominos.add(new Omino(new int[][] {{1},{1}}, 1, 2, TYPE.S2));
		}
		else if(X==3)
		{
			//straight line
			ominos.add(new Omino(new int[][] {{1,1,1}}, 3, 1, TYPE.STRAIGHT3));
			ominos.add(new Omino(new int[][] {{1},{1},{1}}, 1, 3, TYPE.STRAIGHT3));
			
			//right angle
			ominos.add(new Omino(new int[][] {{0,1},{1,1}}, 2, 2, TYPE.RIGHT3));
			ominos.add(new Omino(new int[][] {{1,0},{1,1}}, 2, 2, TYPE.RIGHT3));
			ominos.add(new Omino(new int[][] {{1,1},{0,1}}, 2, 2, TYPE.RIGHT3));
			ominos.add(new Omino(new int[][] {{1,1},{1,0}}, 2, 2, TYPE.RIGHT3));
			
		}
		else if(X==4)
		{
			//square
			ominos.add(new Omino(new int[][] {{1,1},{1,1}}, 2, 2, TYPE.CUBE4));
			
			//boot
			ominos.add(new Omino(new int[][] {{1,1,1},{0,0,1}}, 3, 2, TYPE.BOOT4));
			ominos.add(new Omino(new int[][] {{1,1,1},{1,0,0}}, 3, 2, TYPE.BOOT4));
			
			ominos.add(new Omino(new int[][] {{1,0,0},{1,1,1}}, 3, 2, TYPE.BOOT4));
			ominos.add(new Omino(new int[][] {{0,0,1},{1,1,1}}, 3, 2, TYPE.BOOT4));
			
			ominos.add(new Omino(new int[][] {{1,0},{1,0},{1,1}}, 2, 3, TYPE.BOOT4));
			ominos.add(new Omino(new int[][] {{0,1},{0,1},{1,1}}, 2, 3, TYPE.BOOT4));
			
			ominos.add(new Omino(new int[][] {{1,1},{0,1},{0,1}}, 2, 3, TYPE.BOOT4));
			ominos.add(new Omino(new int[][] {{1,1},{1,0},{1,0}}, 2, 3, TYPE.BOOT4));
			
			//half plus
			ominos.add(new Omino(new int[][] {{1,0},{1,1},{1,0}}, 2, 3, TYPE.PLUS4));
			ominos.add(new Omino(new int[][] {{0,1},{1,1},{0,1}}, 2, 3, TYPE.PLUS4));
			
			ominos.add(new Omino(new int[][] {{1,1,1},{0,1,0}}, 3, 2, TYPE.PLUS4));
			ominos.add(new Omino(new int[][] {{0,1,0},{1,1,1}}, 3, 2, TYPE.PLUS4));
			
			//steps
			ominos.add(new Omino(new int[][] {{0,1,1},{1,1,0}}, 3, 2, TYPE.STAIRS4));
			ominos.add(new Omino(new int[][] {{1,1,0},{0,1,1}}, 3, 2, TYPE.STAIRS4));
			
			ominos.add(new Omino(new int[][] {{0,1},{1,1},{1,0}}, 2, 3, TYPE.STAIRS4));
			ominos.add(new Omino(new int[][] {{1,0},{1,1},{0,1}}, 2, 3, TYPE.STAIRS4));
			
			//line
			ominos.add(new Omino(new int[][] {{1,1,1,1}}, 4, 1, TYPE.STRAIGHT4));
			ominos.add(new Omino(new int[][] {{1},{1},{1},{1}}, 1, 4, TYPE.STRAIGHT4));
			
		}
		
		
		return ominos;
	}

}
