/*
 * The JJC Public Community License
 *
 * Copyright 2017 Jinghong Janice Chen
 *
 * Permission is hereby granted, free of charge, to Google personal obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including the rights to use, copy, merge, distribute
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/**
 * $Id$
 *
 * Filename: FileConnector.java
 * 
 * Purpose:  This class defines [TODO description to be supplied]
 * 
 * Project: Code Jam Rounds
 * 
 * Subsystem: com.google.codejam2017.round0
 * 
 * Author: Jinghong Janice Chen 
 * 
 * Create Date: Apr 8, 2017
 * 
 * Revision: 1.0
 * 
 * Notes:
 * <pre>
 * -----------------------------------------------------
 * Revision History
 * =================
 * Date        			Name          	    Change
 * ----        			-----------         -------
 * Apr 8, 2017                 Jinghong Chen       Initial version
 * </pre>
 */

package com.google.codejam2017.round0;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;

/**
 *
 * @author jjchen1
 */
public class FileConnector {
    
    private static String srcId = FileConnector.class.getName();

    /**
     * Constructor for FileConnector
     */
    public FileConnector()
    {
        //super();
    }
    
    
    /**
     * This method writes data to file. If the data contains the binary, the string should contains correct
     * representation of the character for for the binary.
     * 
     * @param fileName
     * @param data
     * @param isAppend
     * @return boolean
     * 
     */
    public static boolean writeToFile(String fileName, String data, boolean isAppend)
    {
        boolean isSuccess = false;
        try
        {
            try (FileWriter outFile = new FileWriter(fileName, isAppend)) {
                outFile.write(data);
                outFile.flush();
            }
            isSuccess = true;
        }
        catch(IOException e)
        {
            e.printStackTrace();
        }
        return isSuccess;
    }

    /**
     * Reads the content of a text file as lines
     *
     * @param aFileName File name
     * @return The content of a file as lines
     */
    public static ArrayList<String> readLines(String aFileName)
    {
        try {
            ArrayList<String> lines = new ArrayList<>();
            try (BufferedReader reader = new BufferedReader( new FileReader(aFileName) )) {
                String line;
                
                while ((line = reader.readLine()) != null) {
                    lines.add( line );
                }
            }

            return lines;
        }
        catch (FileNotFoundException fe) {
            fe.printStackTrace();
        }
        catch (IOException ioe) {
            ioe.printStackTrace();
        }

        return null;
    }
    
}
