import java.io.File;
import java.io.FileNotFoundException;
import java.util.Scanner;


public class Dijkstra {

   static String[][] table = {
      {"1",  "i",  "j",  "k"},
      {"i", "-1",  "k", "-j"},
      {"j", "-k", "-1",  "i"},
      {"k",  "j", "-i", "-1"}};


   class Letter {
      char let;
      int i;
      boolean neg = false;

      Letter(char letter, boolean negatory) {
         let = letter;

         switch (letter) {
         case '1':
            i = 0;
            break;
         case 'i':
            i = 1;
            break;
         case 'j':
            i = 2;
            break;
         case 'k':
            i = 3;
            break;
         }

         neg = negatory;
      }

      Letter multiply(Letter l) {
         Letter newLetter = makeLetter(table[i][l.i]);
         int negCount = 0;
         if (newLetter.neg) {
            negCount++;
         }
         if (neg) {
            negCount++;
         }
         if (l.neg) {
            negCount++;
         }
         newLetter.neg = negCount % 2 == 1;
         return newLetter;
      }

      String stringify() {
         return (neg ? "-" : "") + let;
      }

      public boolean equals(Letter l) {
         return let == l.let && neg == l.neg;
      }
   }

   public static void main(String[] arts) {
      new Dijkstra();
   }

   Dijkstra() {
      Scanner s = null;
      try {
         s = new Scanner(new File("file.in"));
      } catch (FileNotFoundException e) {
         e.printStackTrace();
      }
      long numCases = s.nextLong();
      s.nextLine();

      for (int i = 0; i < numCases; i++) {
         System.out.println("Case #" + (i + 1) + ": " + solveCase(makeString(s.nextLine(), s.nextLine())));
      }

      s.close();
   }

   public Letter makeLetter(String str) {
      if (str.length() == 1) {
         return new Letter(str.charAt(0), false);
      } else {
         return new Letter(str.charAt(1), true);
      }
   }

   String makeString(String lx, String str) {
      String diji = "";
      Scanner s = new Scanner(lx);
      s.nextLong();
      long numReps = s.nextLong();
      s.close();

      for (long i = 0; i < numReps; i++) {
         diji += str;
      }
      return diji;
   }

   String solveCase(String str) {
      char[] chars = str.toCharArray();
      int i = findLetter(new Letter('i', false), 0, chars);
      i = findLetter(new Letter('j', false), i, chars);
      i = findLetter(new Letter('k', false), i, chars);

      while (i != -1 && i < chars.length) {
         i = findLetter(new Letter('1', false), i, chars);
      }

      return i == chars.length ? "YES" : "NO";
   }

   int findLetter(Letter goal, int i, char[] chars) {
      if (i == -1) {
         return -1;
      }

      Letter cur = new Letter(chars[i++], false);
      if (cur.equals(goal)) {
         return i;
      }
      
      while (i < chars.length) {
         cur = cur.multiply(new Letter(chars[i++], false));
         if (cur.equals(goal)) {
            return i;
         }         
      }

      return -1;
   }

   Letter[] getLetters(String str) {
      Letter[] letters = new Letter[str.length()];
      char[] chars = str.toCharArray();

      for (int i = 0; i < letters.length; i++) {
         letters[i] = new Letter(chars[i], false);
      }

      return letters;
   }
}
