package org.jchien.codejam.cj2017.r1a;

import java.util.*;

/**
 * @author jchien
 */
public class Rat {
    private static class Pack implements Comparable<Pack> {
        int id;
        int qty;

        private Pack(int id, int qty) {
            this.id = id;
            this.qty = qty;
        }

        @Override
        public int compareTo(Pack o) {
            int diff = qty - o.qty;
            if (diff != 0) {
                return diff;
            }
            return this.id - o.id;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Pack pack = (Pack) o;

            if (id != pack.id) return false;
            if (qty != pack.qty) return false;

            return true;
        }

        @Override
        public int hashCode() {
            int result = id;
            result = 31 * result + qty;
            return result;
        }

        @Override
        public String toString() {
            return "Pack{" +
                    "id=" + id +
                    ", qty=" + qty +
                    '}';
        }
    }

    public static void main(String[] args) {
        Scanner in = new Scanner(System.in);
        int z = in.nextInt();

        for (int y=1; y <= z; y++) {
            int numIng = in.nextInt();
            int numPack = in.nextInt();

            // ingredient id -> (serving size -> packets)
            Map<Integer, Map<Integer, Set<Pack>>> ingMap = new TreeMap<>();

            Set<Pack> packsAvailable = new TreeSet<>();

            int[] srv = new int[numIng];
            for (int i=0; i < numIng; i++) {
                srv[i] = in.nextInt();
                ingMap.put(i, new TreeMap<>());
            }

            int packNum = 0;
            for (int j=0; j < numIng; j++) {
                int servingSize = srv[j];
                List<Integer> min = new ArrayList<>();
                List<Integer> max = new ArrayList<>();
                min.add(0);
                max.add(0);

                for (int i=0; i < numPack; i++) {
                    int qty = in.nextInt();

                    Pack p = new Pack(packNum, qty);
                    packsAvailable.add(p);
                    packNum++;

                    int numServings = 0;
                    int small;
                    int large;
                    do {
                        if (min.size() <= numServings) {
                            min.add(gmins(servingSize, numServings));
                            max.add(gmaxs(servingSize, numServings));
                        }

                        small = min.get(numServings);
                        large = max.get(numServings);

                        if (qty >= small && qty <= large) {
                            Map<Integer, Set<Pack>> srvMap = ingMap.get(j);
                            Set<Pack> set = srvMap.get(numServings);
                            if (set == null) {
                                set = new TreeSet<>();
                                srvMap.put(numServings, set);
                            }
                            set.add(p);
                        }
                        numServings++;
                    } while (qty >= small);
                }
            }

            /*for (Map.Entry<Integer, Map<Integer, Set<Pack>>> entry : ingMap.entrySet()) {
                System.out.println("ingredient " + entry.getKey() + ":");
                for (Map.Entry<Integer, Set<Pack>> innerEntry : entry.getValue().entrySet()) {
                    System.out.println("\t" + innerEntry.getKey() + " -> " + innerEntry.getValue());
                }
            }*/

            Set<Integer> servingCounts = new TreeSet<>();
            for (int i=0; i < numIng; i++) {
                servingCounts.addAll(ingMap.get(i).keySet());
            }


            int ans = 0;
            for (int numServings : servingCounts) {
                int numKits = getServingCount(ingMap, 0, numServings, packsAvailable);
                for (int i=1; i < numIng; i++) {
                    numKits = Math.min(numKits, getServingCount(ingMap, i, numServings, packsAvailable));
                }
                //System.out.println("serving num " + numServings + " -> " + numKits);


                if (numKits > 0) {
                    for (int i=0; i < numIng; i++) {
                        int kitsRemoved = 0;
                        Set<Pack> packs = ingMap.get(i).get(numServings);
                        Iterator<Pack> it = packs.iterator();
                        while (kitsRemoved < numKits) {
                            Pack p = it.next();
                            if (packsAvailable.contains(p)) {
                                packsAvailable.remove(p);
                                kitsRemoved++;
                            }
                        }
                    }
                }
                ans += numKits;
            }

            System.out.println("Case #" + y + ": " + ans);
        }
    }

    private static int getServingCount(Map<Integer, Map<Integer, Set<Pack>>> ingMap, int ingNum, int numServings, Set<Pack> available) {
        Set<Pack> set = ingMap.get(ingNum).get(numServings);
        if (set == null) {
            return 0;
        }
        int cnt = 0;
        for (Pack p : set) {
            if (available.contains(p)) {
                cnt++;
            }
        }
        return cnt;
    }

    private static int gmins(int servingSize, int numServings) {
        return (int)Math.ceil(servingSize * numServings * 0.9);
    }

    private static int gmaxs(int servingSize, int numServings) {
        return (int)Math.floor(servingSize * numServings * 1.1);
    }
}
