package codejam;

import java.util.Scanner;

public class Watersheds {

    public enum Direction {
        NORTH, WEST, EAST, SOUTH;
    }

    public static class Point {
        public Point(int line, int row) {
            this.line = line;
            this.row = row;
        }

        public int line;

        public int row;
    }

    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);

        int nMaps = scanner.nextInt();

        for (int n = 0; n < nMaps; n++) {
            int lines = scanner.nextInt();
            int rows = scanner.nextInt();

            int[][] input = readMap(scanner, lines, rows);

            char[][] output = initializeOutput(lines, rows);
            char curChar = 'a';

            for (int line = 0; line < lines; line++) {
                for (int row = 0; row < rows; row++) {
                    Point p = new Point(line, row);
                    char r = calculateValue(input, p, output, curChar);
                    if (r == curChar) {
                        curChar++;
                    }
                }
            }

            printResult(n + 1, output);
        }
        scanner.close();
        System.out.flush();
    }

    private static char calculateValue(int[][] input, Point p, char[][] output, char curChar) {
        char value = output[p.line][p.row];
        if (value != 0) {
            return value;
        }

        Direction direction = getLowestDirection(input, p);
        if (direction == null) {
            output[p.line][p.row] = curChar;
        } else {
            output[p.line][p.row] = calculateValue(input, getPoint(direction, p), output, curChar);
        }

        return output[p.line][p.row];
    }

    private static Direction getLowestDirection(int[][] input, Point point) {
        Direction lowestDirection = null;
        int lowestValue = Integer.MAX_VALUE;

        for (Direction direction : Direction.values()) {
            int value = getValue(direction, input, point);
            if (value < input[point.line][point.row] && value < lowestValue) {
                lowestDirection = direction;
                lowestValue = value;
            }
        }

        return lowestDirection;
    }

    private static int getValue(Direction direction, int[][] input, Point sourcePoint) {
        Point point = getPoint(direction, sourcePoint);
        if (point.line < 0 || point.line >= input.length || point.row < 0 || point.row >= input[0].length) {
            return Integer.MAX_VALUE;
        }

        return input[point.line][point.row];
    }

    private static Point getPoint(Direction direction, Point point) {
        Point result = new Point(point.line, point.row);

        switch (direction) {
        case NORTH:
            result.line--;
            break;
        case WEST:
            result.row--;
            break;
        case SOUTH:
            result.line++;
            break;
        case EAST:
            result.row++;
        }

        return result;
    }

    private static int[][] readMap(Scanner scanner, int lines, int rows) {
        int input[][] = new int[lines][rows];

        for (int line = 0; line < lines; line++) {
            for (int row = 0; row < rows; row++) {
                input[line][row] = scanner.nextInt();
            }
        }
        return input;
    }

    private static char[][] initializeOutput(int lines, int rows) {
        char[][] output = new char[lines][rows];
        for (int line = 0; line < lines; line++) {
            for (int row = 0; row < rows; row++) {
                output[line][row] = 0;
            }
        }
        return output;
    }

    private static void printResult(int caseNumber, char[][] output) {
        System.out.println("Case #" + caseNumber + ":");
        for (int line = 0; line < output.length; line++) {
            String separator = "";
            for (int row = 0; row < output[line].length; row++) {
                System.out.print(separator + output[line][row]);
                separator = " ";
            }
            System.out.println();
        }
    }
}