package codejam;

import java.io.InputStream;
import java.util.HashSet;
import java.util.Scanner;
import java.util.Set;

public class DecisionTree {

    public class Node {

        public double p;

        public String feature;

        public Node yes;

        public Node no;

        public int startIdx;

        public int endIdx;

        public Node(Double p, String feature, Node yes, Node no, int startIdx, int endIdx) {
            this.feature = feature;
            this.p = p;
            this.yes = yes;
            this.no = no;
            this.startIdx = startIdx;
            this.endIdx = endIdx;
        }

        public Node(Double p, int startIdx, int endIdx) {
            this(p, null, null, null, startIdx, endIdx);
        }

        public boolean isLeaf() {
            return this.yes == null;
        }
    }

    public void run(InputStream in) {
        Scanner scanner = new Scanner(in);

        int n = scanner.nextInt();

        for (int testCase = 0; testCase < n; testCase++) {
            int lines = scanner.nextInt();
            scanner.nextLine();

            StringBuilder sb = new StringBuilder();
            for (int i = 0; i < lines; i++) {
                sb.append(scanner.nextLine());
            }

            Node root = this.parseNode(sb.toString(), 0);

            System.out.printf("Case #%d:", testCase + 1);
            System.out.println();
            int animals = scanner.nextInt();
            for (int i = 0; i < animals; i++) {
                scanner.next("\\w*");
                int nFeatures = scanner.nextInt();
                Set<String> features = new HashSet<String>();
                for (int j = 0; j < nFeatures; j++) {
                    features.add(scanner.next("\\w*"));
                }

                System.out.printf("%1.7f", this.visit(root, features));
                System.out.println();
            }
        }
    }

    public double visit(Node n, Set<String> features) {
        if (n.isLeaf()) {
            return n.p;
        }

        if (features.contains(n.feature)) {
            return n.p * visit(n.yes, features);
        } else {
            return n.p * visit(n.no, features);
        }
    }

    public Node parseNode(String str, int position) {
        int idx = position;

        idx = this.jumpSpaces(str, idx);

        while (idx < str.length()) {
            if (str.charAt(idx) == '(') {
                idx++;
                break;
            }
            idx++;
        }

        if (idx >= str.length()) {
            return null;
        }

        idx = this.jumpSpaces(str, idx);

        StringBuilder buf = new StringBuilder();
        while (idx < str.length()) {
            char c = str.charAt(idx);
            if (Character.isDigit(c) || c == '.') {
                buf.append(c);
                idx++;
            } else {
                break;
            }
        }
        double p = Double.parseDouble(buf.toString());

        idx = this.jumpSpaces(str, idx);

        if (str.charAt(idx) == ')') {
            return new Node(p, position, idx);
        }

        buf = new StringBuilder();
        while (idx < str.length()) {
            if (Character.isLetter(str.charAt(idx))) {
                buf.append(str.charAt(idx));
                idx++;
            } else {
                break;
            }

        }
        String feature = buf.toString();

        Node yes = this.parseNode(str, idx);
        Node no = this.parseNode(str, yes.endIdx + 1);

        idx = no.endIdx + 1;
        idx = this.jumpSpaces(str, idx);

        if (str.charAt(idx) != ')') {
            throw new RuntimeException(") no lugar errado(" + idx + ": " + str);
        }

        return new Node(p, feature, yes, no, position, idx);
    }

    public int jumpSpaces(String str, int position) {
        int idx = position;
        while (idx < str.length()) {
            char c = str.charAt(idx);
            if (Character.isSpaceChar(c)) {
                idx++;
            } else {
                break;
            }
        }
        return idx;
    }

    public static void main(String[] args) {
        new DecisionTree().run(System.in);
    }
}
