import java.io.File;
import java.io.PrintWriter;
import java.util.Scanner;

public class ProblemC {	
	public static class Pair {
		public final long first;
		public final long second;
		
		public Pair(long first, long second) {
			this.first = first;
			this.second = second;
		}
	}
	
	public static long minAttackTurns(long a_d, long h_k, long b) {
		long turns = (long) Math.ceil((float) h_k / (float) a_d); 
		long maxBuffs;
		
		if (b == 0) {
		  maxBuffs = 0;
		} else {
			maxBuffs = (long) Math.ceil((float) (h_k - a_d) / (float) b);
		}
		
		//System.out.println("Max buffs " + maxBuffs + " " + h_k + " " + a_d + " " + b);
		//System.out.println("Initial turns " + turns);
		
		for (long i = 1; i <= maxBuffs; i++) {
			long mod_a_d = a_d + b * i;
			//System.out.println("Mod_a_d " + mod_a_d + ", h_k " + h_k);
			long mod_turns = (long) Math.ceil((float) h_k / (float) mod_a_d) + i;
			//System.out.println("i " + i + ", mod turns " + mod_turns);
			 
			if (mod_turns < turns) {
				turns = mod_turns;
			}
		}
		
		//System.out.println("Final turns are " + turns);
		
		return turns;
	}
	
	public static Pair turnsToDebuff(long a_k, long h_d, long d, long debuffCount) {
		long count = 0;
		long mod_h_d = h_d;
		long mod_a_k = a_k;
		
		while (debuffCount > 0) {
			count++;
			if (mod_h_d - mod_a_k <= 0) {
				mod_h_d = h_d - mod_a_k;
			} else {
				mod_a_k = mod_a_k - d;
				debuffCount--;
			}
		}
		
		return new Pair(count, mod_h_d);
	}
	
	public static long turnsToAttack(long mod_a_k, long h_d, long mod_h_d, long attackTurns) {
		long mAWK = (long) Math.ceil((float) mod_h_d / (float) mod_a_k) - 1;
		
		//System.out.println("Mawk " + mAWK);
		
		if (mAWK >= attackTurns) {
			return 0;
		}
		
		attackTurns -= mAWK;
		long aWK = (long) Math.ceil((float) h_d / (float) mod_a_k) - 1;
		//System.out.println("awk " + aWK);
		long restoreCount = 1 + (long) Math.floor((float) (attackTurns - 1) / (float) aWK);
		//System.out.println("restore " + restoreCount);
		return restoreCount;
	}
	
	public static long minDefenseTurns(long a_k, long h_d, long d, long attackTurns) {
		if (attackTurns * a_k < h_d) {
			return 0;
		} else {
			long minDebuffs = (long) Math.floor((float) a_k - ((float) h_d / 2.0)) + 1;
			long maxDebuffs;
			long turns = -1;
			
			if (d == 0) {
				maxDebuffs = 0;
			} else {
				maxDebuffs = (long) Math.ceil((float) a_k / (float) d);
			}
			
			for (long i = minDebuffs; i <= maxDebuffs; i++) {
				Pair x = turnsToDebuff(a_k, h_d, d, i);
				long turnsToDebuff = x.first;
				long mod_h_d = x.second;
				long mod_a_k = a_k - i * d;
				long turnsToFinish = turnsToAttack(mod_a_k, h_d, mod_h_d, attackTurns);

				//System.out.println("For " + i + " debufs, turns to debuff " + turnsToDebuff + ", to finish " + turnsToFinish);
				
				if (turns == -1 || turnsToDebuff + turnsToFinish < turns) {
					turns = turnsToDebuff + turnsToFinish;
				}
				
				if (turns > -1) {
					maxDebuffs = Math.min(maxDebuffs, turns);
				}
			}
			
			//System.out.println("Min defense turns are " + turns);
			
			return turns;
		}
	}
	
	public static void nextCase(long caseNum, PrintWriter writer, Scanner scanner) {
		long h_d = scanner.nextLong();
		long a_d = scanner.nextLong();
		long h_k = scanner.nextLong();
		long a_k = scanner.nextLong();
		long b   = scanner.nextLong();
		long d   = scanner.nextLong();
		
		String ans = "";

		long attackTurns = minAttackTurns(a_d, h_k, b);

		//System.out.println("Turns to attack " + attackTurns);
		if (attackTurns == 1) {
			ans = "" + 1;
		} else if (a_k - d >= h_d) {
			ans = "IMPOSSIBLE";
		} else if (attackTurns == 2 && a_k < h_d) {
			ans = "" + 2;
		} else if ((2 * a_k - 3 * d) >= h_d) {
			ans = "IMPOSSIBLE";
		} else {
			//System.out.println("Possible");
			long defenseTurns = minDefenseTurns(a_k, h_d, d, attackTurns);
			ans = "" + (attackTurns + defenseTurns);
		}
		
		writer.print("Case #" + caseNum + ": " + ans);
	}
	
	public static void main(String[] args) throws Exception {
		String fileName = "C-small-attempt0";
		PrintWriter writer = new PrintWriter(fileName + ".out", "UTF-8");
		Scanner scanner = new Scanner(new File(fileName + ".in"));
		int t = scanner.nextInt();
		
		for (int i = 0; i < t; i++) {
			//System.out.println("CASE #" + (i+1));
			
			nextCase(i+1, writer, scanner);
			
			
			if (i < t - 1) {
				writer.println("");
			}
		}
		
		writer.close();
		scanner.close();
	}
}
