import java.io.File;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Scanner;

public class ProblemDTrial3 {	
	public static class Change {
		public final int row;
		public final int col;
		public final char value;
		
		public Change(int row, int col, char value) {
			this.row = row;
			this.col = col;
			this.value = value;
		}
		
		public String toString() {
			return (this.value + " " + (this.row+1) + " " + (this.col+1));
		}
	}
	
	public static class Solution {
	    public final int score;
	    public final ArrayList<Change> changes;

	    public Solution(int score, ArrayList<Change> changes) { 
	        this.score = score;
	        this.changes = changes;
	    }
	    
	    public Solution max(Solution s) {
	    	if (s.score > this.score) {
	    		return s;
	    	}
	    	
	    	return this;
	    }
	    
	    public Solution addChange(Change c) {
	    	this.changes.add(c);
	    	return this;
	    }
	}
	
	public static class MoveCount {
		public final int index;
		public final int moveCount;
		
		public MoveCount(int index, int moveCount) {
			this.index = index;
			this.moveCount = moveCount;
		}
		
		public int compareTo(MoveCount m) {
			return Integer.compare(this.moveCount, m.moveCount);
		}
	}
	
	public static class MoveCountComparator implements Comparator<MoveCount> {
	    @Override
	    public int compare(MoveCount m1, MoveCount m2) {
	        return m2.compareTo(m1);
	    }
	}
	
	public static int index(int n, int row, int col) {
		return row * n + col;
	}
	
	public static int row(int n, int index) {
		return index / n;
	}
	
	public static int col(int n, int index) {
		return index % n;
	}
	
	public static void set(int n, Character stage[], int row, int col, Character value) {
		//System.out.println("Get index (" + row + ", " + col + ") for n="+ n);
		stage[index(n, row, col)] = value;
	}
	
	public static Character get(int n, Character stage[], int row, int col) {
		//System.out.println("Set index (" + row + ", " + col + ") for n="+ n);
		return stage[index(n, row, col)];
	}	
	
	public static Boolean xIsValid(int n, Character stage[], int row, int col) {
		for (int r = 0; r < n; r++) {
			if (r != row) {
				Character current = get(n, stage, r, col);
				if (current == 'o' || current == 'x') {
					return false;
				}
			}
		}
		
		for (int c = 0; c < n; c++) {
			if (c != col) {
				Character current = get(n, stage, row, c);
				if (current == 'o' || current == 'x') {
					return false;
				}
			}
		}
		
		return true;
	}
	
	public static Boolean plusIsValid(int n, Character stage[], int row, int col) {
		printStage(n, stage);
		
		for (int r = 0; r < n; r++) {
			int c = row + col - r;
			if (r != row && 0 <= c && c < n) {
				Character current = get(n, stage, r, c);
				if (current == 'o' || current == '+') {
					//System.out.println("Plus is valid: false");
					return false;
				}
			}
			
			c = r + col - row;
			if (r != row && 0 <= c && c < n) {
				Character current = get(n, stage, r, c);
				if (current == 'o' || current == '+') {
					//System.out.println("Plus is valid: false");
					return false;
				}
			}
		}

		//System.out.println("Plus is valid: true");
		return true;
	}
	
	public static Boolean moveIsValid(int n, Character stage[], int row, int col, Character value) {
		if (value == '.') {
			return true;
		} else if (value == '+') {
			return plusIsValid(n, stage, row, col);
		} else if (value == 'x') {
			return xIsValid(n, stage, row, col);
		} else if (value == 'o') {
			return plusIsValid(n, stage, row, col) && xIsValid(n, stage, row, col);
		} else {
			return false;
		}
	}
	
	public static ArrayList<Character> getValidMoves(int n, Character stage[], int row, int col) {
		Character current = stage[row * n + col];
		ArrayList<Character> moves = new ArrayList<Character>();
		
		if (current == 'x') {
			if (plusIsValid(n, stage, row, col)) { moves.add('o'); }
		} else if (current == '+') {
			if (xIsValid(n, stage, row, col)) { moves.add('o'); }
		} else if (current == '.') {
			Boolean xIsValid = xIsValid(n, stage, row, col);
			Boolean plusIsValid = plusIsValid(n, stage, row, col);
			
			if (xIsValid) { moves.add('x'); }
			if (plusIsValid) { moves.add('+'); }
			if (xIsValid && plusIsValid) { moves.add('o'); }
		}
		
		return moves;
	}
	
	public static int score(Character stage[]) {
		int score = 0;
		
		for (int i = 0; i < stage.length; i++) {
			Character current = stage[i];
		  
			if (current == 'o') { score += 2; }
			else if (current == '+' || current == 'x') { score += 1; }
		}
		
		return score;
	}
	
	public static Solution maxSolution(int n, Character stage[], int from, ArrayList<ArrayList<Character>> validMoves, ArrayList<MoveCount> moveCounts, int movesSoFar) {
		Solution maxSolution = new Solution(score(stage), new ArrayList<Change>());
		
		if (from < stage.length && movesSoFar < 3*n-1) {	
			int index = moveCounts.get(from).index;
			int row = row(n, index);
			int col = col(n, index);
			char original = get(n, stage, row, col);

			Solution localSolution;

			ArrayList<Character> moves = validMoves.get(index);
			
			Change change;
			for (int i = 0; i < moves.size(); i++) {
				char move = moves.get(i);
				if (moveIsValid(n, stage, row, col, move)) {
					change = new Change(row, col, move);
					set(n, stage, row, col, move);
					//System.out.println("Calling max solution with one change, from is " + (from+1) + ", moves so far " + (movesSoFar+1));
					localSolution = maxSolution(n, stage, from+1, validMoves, moveCounts, movesSoFar + 1).addChange(change);
					maxSolution = maxSolution.max(localSolution);
				}
			}
			
			set(n, stage, row, col, original);
			
			//localSolution = maxSolution(n, stage, from+1, validMoves, moveCounts, movesSoFar);
			//maxSolution = maxSolution.max(localSolution);
			//System.out.println("Calling max solution with no change, from is " + (from+1) + ", moves so far " + movesSoFar);
		}
		
		return maxSolution;
	}
	
	public static void printStage(int n, Character stage[]) {
		for (int i = 0; i < stage.length; i++) {
			////System.out.print(stage[i] + " ");
			if (i % n == n - 1) {
				////System.out.println("");
			}
		}
	}
	
	public static void next_case(int case_num, PrintWriter writer, Scanner scanner) {
		int n = scanner.nextInt();
		int m = scanner.nextInt();
		Character stage[] = 	new Character[n*n];
		
		System.out.println("Case " + case_num + ", size " + n);
		
		for (int i = 0; i < stage.length; i++) {
			stage[i] = '.';
		}
		
		for (int i = 0; i < m; i++) {
			Character value = scanner.next().charAt(0);
			int row = scanner.nextInt() - 1;
			int col = scanner.nextInt() - 1;
			set(n, stage, row, col, value);
		}
		
		ArrayList<ArrayList<Character>> validMoves = new ArrayList<ArrayList<Character>>();
		ArrayList<MoveCount> moveCounts = new ArrayList<MoveCount>();
		
		for (int i = 0; i < n * n; i++) {
			validMoves.add(getValidMoves(n, stage, row(n,i), col(n,i)));
		}
		
		for (int i = 0; i < validMoves.size(); i++) {
			moveCounts.add(new MoveCount(i, validMoves.get(i).size()));
		}
		Collections.sort(moveCounts, new MoveCountComparator());
		
		
		Solution maxSolution = maxSolution(n, stage, 0, validMoves, moveCounts, 0);
		//printStage(n, maxStage);
		//System.out.println("");
		
		writer.print("Case #" + case_num + ": " + maxSolution.score + " " + maxSolution.changes.size());
		
		for (int i = 0; i < maxSolution.changes.size(); i++) {
			writer.println("");
			writer.print(maxSolution.changes.get(i).toString());
		}
	}
	
	public static void main(String[] args) throws Exception {
		String fileName = "D-small-attempt2";
		PrintWriter writer = new PrintWriter(fileName + ".out", "UTF-8");
		Scanner scanner = new Scanner(new File(fileName + ".in"));
		int t = scanner.nextInt();
		
		for (int i = 0; i < t; i++) {
			next_case(i+1, writer, scanner);
			
			if (i < t - 1) {
				writer.println("");
			}
		}
		
		writer.close();
		scanner.close();
	}
}
