package round1c;

import java.io.IOException;
import java.io.PrintWriter;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.HashSet;
import java.util.List;
import java.util.Locale;
import java.util.PriorityQueue;
import java.util.Scanner;
import java.util.Set;


public class SolverA {

	private static final Path RESOURCE_PATH = Paths.get("resources/round1c/a");
	private static final DecimalFormat DOUBLE_FORMAT = new DecimalFormat("#.########", DecimalFormatSymbols.getInstance(Locale.US));

	public static void main(String[] args) throws IOException {
		SolverA s = new SolverA();

		//s.solve("example.in");
		//s.solve("testcases.in");
		//s.solve("A-small-attempt0.in");
		//s.solve("A-small-attempt1.in");
		//s.solve("A-small-attempt2.in");
		//s.solve("A-small-attempt3.in");
		//s.solve("A-small-attempt4.in");
		s.solve("A-large.in");
	}

	private String solveCase(Scanner in) {
		int n = in.nextInt();
		int k = in.nextInt();
		List<Pancake> pancakes = new ArrayList<>(n);
		
		for (int i = 0; i < n; i++) {
			Pancake p = new Pancake(i, in.nextInt(), in.nextInt());
			pancakes.add(p);
		}
		
		Set<Pancake> usedPancakes = new HashSet<>();
		PriorityQueue<Pancake> pq = new PriorityQueue<>(n, new SideSurfiestPancake());
		pq.addAll(pancakes);
		long relevantSurfaceArea = 0;
		for (int i = 0; i < k - 1; i++) {
			Pancake p = pq.poll();
			usedPancakes.add(p);
			relevantSurfaceArea += p.sideSurface;
		}

		long maxTopSurface = 0;
		for (Pancake p : usedPancakes) {
			maxTopSurface = Math.max(maxTopSurface, p.topSurface);
		}
		
		long maxTotalSurface = -1;
		for (Pancake p : pancakes) {
			if (usedPancakes.contains(p)) {
				continue;
			}
			long ts = Math.max(maxTopSurface, p.topSurface);
			long totalSurface = ts + p.sideSurface + relevantSurfaceArea;
			if (totalSurface > maxTotalSurface) {
				maxTotalSurface = totalSurface;
			}
		}
		
		return DOUBLE_FORMAT.format(Math.PI * maxTotalSurface);
	}
	
	private void solve(String filename) throws IOException {
		Path inputFile = RESOURCE_PATH.resolve(filename);
		if (filename.endsWith(".in")) {
			filename = filename.substring(0, filename.length() - 3);
		}
		Path outputFile = RESOURCE_PATH.resolve(filename + ".out.txt");
		try ( //
				Scanner scanner = new Scanner(Files.newBufferedReader(inputFile)); //
				PrintWriter writer = new PrintWriter(Files.newBufferedWriter(outputFile)); //
		){
			int nrOfCases = scanner.nextInt();
			for (int caseNr = 1; caseNr <= nrOfCases; caseNr++) {
				writer.println("Case #" + caseNr + ": " + solveCase(scanner));
			}
		}
	}
	
	private static class Pancake {
		public final int index;
		public final long radius;
		public final long height;
		public final long sideSurface;
		public final long topSurface;
		public final long totalSurface;
		
		private Pancake(int index, long radius, long height) {
			this.index = index;
			this.radius = radius;
			this.height = height;
			this.sideSurface = 2 * radius * height;
			this.topSurface = radius * radius;
			this.totalSurface = sideSurface + topSurface;
		}
		
		public String toString() {
			return radius + " "+ height +"  "+ sideSurface + " " + topSurface;
		}
	}
	
	private static class LargestTotalPancake implements Comparator<Pancake> {

		@Override
		public int compare(Pancake o1, Pancake o2) {
			return Long.compare(o2.totalSurface, o1.totalSurface);
		}
		
	}
	
	private static class SideSurfiestPancake implements Comparator<Pancake> {

		@Override
		public int compare(Pancake o1, Pancake o2) {
			return Long.compare(o2.sideSurface, o1.sideSurface);
		}
		
	}
	
}
