package codejam2016.round1b.a;

import java.io.IOException;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

import codejam2016.round1b.template.AbstractSolver;

public class SolverA extends AbstractSolver {

	@Override
	protected String solveCase() {
		final Map<String, Integer> numbers = new HashMap<>();
		numbers.put("ZERO", 0);
		numbers.put("ONE", 1);
		numbers.put("TWO", 2);
		numbers.put("THREE", 3);
		numbers.put("FOUR", 4);
		numbers.put("FIVE", 5);
		numbers.put("SIX", 6);
		numbers.put("SEVEN", 7);
		numbers.put("EIGHT", 8);
		numbers.put("NINE", 9);

		final Map<Integer, int[]> numbersLetterCounts = new HashMap<>();
		for (Map.Entry<String, Integer> entry : numbers.entrySet()) {
			numbersLetterCounts.put(entry.getValue(), calcLetterCounts(entry.getKey()));
		}

		Map<Integer, Integer> stage1map = new HashMap<>();
		addStageMapLine('Z', "ZERO", numbers, stage1map);
		addStageMapLine('W', "TWO", numbers, stage1map);
		addStageMapLine('U', "FOUR", numbers, stage1map);
		addStageMapLine('X', "SIX", numbers, stage1map);
		addStageMapLine('G', "EIGHT", numbers, stage1map);

		Map<Integer, Integer> stage2map = new HashMap<>();
		addStageMapLine('O', "ONE", numbers, stage2map);
		addStageMapLine('R', "THREE", numbers, stage2map);
		addStageMapLine('F', "FIVE", numbers, stage2map);
		addStageMapLine('S', "SEVEN", numbers, stage2map);

		Map<Integer, Integer> stage3map = new HashMap<>();
		addStageMapLine('I', "NINE", numbers, stage3map);

		String phonenumber = read();
		Map<Integer, Integer> resultMap = new TreeMap<>();
		int[] phonenumberCounts = calcLetterCounts(phonenumber);
		processStageMap(phonenumberCounts, numbersLetterCounts, stage1map, resultMap);
		processStageMap(phonenumberCounts, numbersLetterCounts, stage2map, resultMap);
		processStageMap(phonenumberCounts, numbersLetterCounts, stage3map, resultMap);
		
		StringBuilder result = new StringBuilder();
		for (Map.Entry<Integer, Integer> entry : resultMap.entrySet()) {
			int number = entry.getKey();
			int count = entry.getValue();
			for (int i = 0; i < count; i++) {
				result.append(number);
			}
		}
		return result.toString();
	}

	private void processStageMap(int[] phonenumberCounts, Map<Integer, int[]> numbersLetterCounts, Map<Integer, Integer> stageMap, Map<Integer, Integer> resultMap) {
		for (Map.Entry<Integer, Integer> stage : stageMap.entrySet()) {
			int uniqueChar = stage.getKey();
			int numberIntValue = stage.getValue();
			if (phonenumberCounts[uniqueChar] > 0) {
				int factor = phonenumberCounts[uniqueChar];
				for (int i = 0; i < 36; i++) {
					phonenumberCounts[i] -= (numbersLetterCounts.get(numberIntValue)[i] * factor);
				}
				if (resultMap.containsKey(numberIntValue)) {
					throw new RuntimeException("Number already present in map: "+ numberIntValue);
				}
				resultMap.put(numberIntValue, factor);
			}
		}
	}
	
	private void addStageMapLine(char uniqueChar, String word, Map<String, Integer> numbers, Map<Integer, Integer> stageMap) {
		int c = ((int)uniqueChar) - ((int)'A');
		stageMap.put(c, numbers.get(word));
	}
	
	private int[] calcLetterCounts(String word) {
		int[] letterCounts = new int[36];
		for (char c : word.toCharArray()) {
			int index = ((int)c) - ((int)'A');
			letterCounts[index]++;
		}
		return letterCounts;
	}
	
	public static void main(String[] args) throws IOException {
		SolverA s = new SolverA();

		Path resourcePath = Paths.get("resources", "codejam2016", "round1b", "a");
		//s.solve(resourcePath, "example");
		s.solve(resourcePath, "A-small-attempt0");
	}

}
