package codejam2017.qualification.template;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Queue;
import java.util.stream.Collectors;

public abstract class AbstractSolver {

	private static final Path resourceBasePath = Paths.get("resources", "codejam2017");
	private final Queue<String> inputWords = new ArrayDeque<>();
	private final List<String> outputLines = new ArrayList<>();

	protected abstract String solveCase();
	
	public final void solve(Path resourceDirectory, String filename) throws IOException {
		resourceDirectory = resourceBasePath.resolve(resourceDirectory);
		inputWords.clear();
		outputLines.clear();
		if (resourceDirectory.isAbsolute()) {
			throw new RuntimeException("getResourceDirectory() must return a relative path");
		}
		Path inputFile = resourceDirectory.resolve(filename + ".in.txt");
		Path outputFile = resourceDirectory.resolve(filename + ".out.txt");
		this.inputWords.addAll(readInputFile(inputFile));
		int nrOfCases = readInt();

		for (int caseNr = 1; caseNr <= nrOfCases; caseNr++) {
			String outputLine = "Case #" + caseNr + ": " + solveCase();
			outputLines.add(outputLine);
		}
		writeOutputFile(outputFile, outputLines);
	}
	
	protected String read() {
		return inputWords.poll();
	}

	protected int readInt() {
		return Integer.parseInt(read());
	}

	protected long readLong() {
		return Long.parseLong(read());
	}

	protected double readDouble() {
		return Double.parseDouble(read());
	}
	
	private static List<String> readInputFile(Path inputFile) throws IOException {
		List<String> lines = Files.readAllLines(inputFile);
		List<String> words = lines.stream().map(x -> x.split(" ")).flatMap(Arrays::stream).collect(Collectors.toList());
		return words;
	}
	
	private static void writeOutputFile(Path outputFile, List<String> lines) throws IOException {
		Files.write(outputFile, lines);
	}

}
