package abc.c;

import java.util.ArrayList;
import java.util.List;

import abc.template.AbstractCase;

public class CaseC extends AbstractCase {

	private final int jamcoinLength;
	private final int nrOfJamcoins;

	public CaseC(int caseNumber, int jamcoinLength, int nrOfJamcoins) {
		super(caseNumber);
		this.jamcoinLength = jamcoinLength;
		this.nrOfJamcoins = nrOfJamcoins;
	}

	@Override
	protected String doCalculation() {
		//System.err.println(generateJamcoinProof("1001"));
		StringBuilder sb = new StringBuilder();
		sb.append('1');
		for (int i = 2; i < jamcoinLength; i++) {
			sb.append('0');
		}
		sb.append('1');
		String base2string = sb.toString();
		long minJamcoin = Long.parseLong(base2string, 2);
		long maxJamcoin = Long.parseLong(base2string.replaceAll("0", "1"), 2);
		List<String> proofLines = new ArrayList<>();
		for (long jamcoin = minJamcoin; jamcoin <= maxJamcoin; jamcoin += 2) {
			String jamcoinString = Long.toBinaryString(jamcoin);
			String proof = generateJamcoinProof(jamcoinString);
			if (proof == null) {
				continue;
			}
			proofLines.add(jamcoinString + " " + proof);
			if (proofLines.size() == nrOfJamcoins) {
				break;
			}
		}
		StringBuilder result = new StringBuilder();
		result.append('\n');
		for (String proofLine : proofLines) {
			result.append(proofLine);
			result.append('\n');
		}
		return result.toString();
	}

	private static String generateJamcoinProof(String jamcoinString) {
		StringBuilder proof = new StringBuilder();
		for (int base = 2; base <= 10; base++) {
			long rebasedLong = Long.parseLong(jamcoinString, base);
			long divisor = getFirstDivisor(rebasedLong);
			if (divisor == -1) {
				return null;
			}
			if (proof.length() > 0) {
				proof.append(' ');
			}
			proof.append(divisor);
		}
		return proof.toString();
	}

	private static long getFirstDivisor(long nr) {
		long rootOfNr = (long) Math.ceil(Math.sqrt(nr));
		for (int i = 2; i <= rootOfNr; i++) {
			if ((nr % i) == 0) {
				return i;
			}
		}
		return -1;
	}
	
}
