package qualification;

import java.io.IOException;
import java.io.PrintWriter;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.PriorityQueue;
import java.util.Scanner;

public class SolverC {

	private static final Path RESOURCE_PATH = Paths.get("resources/qualification/c");

	public static void main(String[] args) throws IOException {
		SolverC s = new SolverC();

		//s.solve("example.in");
		//s.solve("testcases.in");
		//s.solve("C-small-1-attempt0.in");
		s.solve("C-small-2-attempt0.in");
		//s.solve("C-large.in");
	}

	private String solveCase(Scanner in) {
		long stalls = in.nextLong();
		long people = in.nextLong();
		
		if (stalls == people) {
			return "0 0";
		}
		
		PriorityQueue<StallRange> pq = new PriorityQueue<>();
		pq.add(new StallRange(stalls, 0));
		long lengthLeft = -1;;
		long lengthRight = -1;
		for (long i = 0; i < people; i++) {
			StallRange largestRange = pq.poll();
			long halfLength = (largestRange.length + 1) / 2;
			lengthLeft = halfLength - 1;
			if (lengthLeft > 0) {
				StallRange leftRange = new StallRange(halfLength - 1, largestRange.index);
				pq.add(leftRange);
			}
			long indexRight = largestRange.index + halfLength;
			lengthRight = (largestRange.index + largestRange.length) - indexRight;
			if (lengthRight > 0) {
				StallRange rightRange = new StallRange(lengthRight, indexRight);
				pq.add(rightRange);
			}
		}
		return lengthRight + " " + lengthLeft;
	}
	
	private void solve(String filename) throws IOException {
		Path inputFile = RESOURCE_PATH.resolve(filename);
		if (filename.endsWith(".in")) {
			filename = filename.substring(0, filename.length() - 3);
		}
		Path outputFile = RESOURCE_PATH.resolve(filename + ".out.txt");
		try ( //
				Scanner scanner = new Scanner(Files.newBufferedReader(inputFile)); //
				PrintWriter writer = new PrintWriter(Files.newBufferedWriter(outputFile)); //
		) {
			int nrOfCases = scanner.nextInt();
			for (int caseNr = 1; caseNr <= nrOfCases; caseNr++) {
				writer.println("Case #" + caseNr + ": " + solveCase(scanner));
			}
		}
	}
	
	private static class StallRange implements Comparable<StallRange> {
		public final long length;
		public final long index;

		public StallRange(long length, long index) {
			this.length = length;
			this.index = index;
		}

		@Override
		public int compareTo(StallRange o) {
			int cmp = Long.compare(o.length, this.length);
			if (cmp != 0) {
				return cmp;
			}
			return Long.compare(o.index, this.index);
		}
		
	}
	
}
