package gcj;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.StringTokenizer;

public class ProblemA
{
	private final String inputFile = "A-small.in";
	private final String outputFile = "A-small.out";

	private BufferedReader in = null;
	private BufferedWriter out = null;

	public static void main(String[] args)
	{
		ProblemA prog = new ProblemA();

		prog.openFiles();
		prog.solution();
		prog.closeFiles();

		System.out.println("THE END");
	}

	private void openFiles()
	{
		// init input file
		try
		{
			in = new BufferedReader(new FileReader(inputFile));
		}
		catch (FileNotFoundException ex)
		{
			System.out.println("Input file not found!");
		}

		// init output file
		try
		{
			out = new BufferedWriter(new FileWriter(outputFile));
		}
		catch (IOException ex)
		{
			System.out.println("Error writing output file!");
		}
	}

	private void closeFiles()
	{
		// close input file
		try
		{
			in.close();
		}
		catch (IOException e)
		{
			System.out.println("Error closing input!");
		}

		// close output file
		try
		{
			out.close();
		}
		catch (IOException e)
		{
			System.out.println("Error closing output!");
		}
	}

	private void solution()
	{
		try
		{
			String s = in.readLine();

			StringTokenizer st = new StringTokenizer(s);

			int T = Integer.parseInt(st.nextToken());

			System.out.println(T);

			// read and write data
			for (int i = 0; i < T; i++)
			{
				char[][] data = new char[4][4];

				// reads data
				for (int j = 0; j < 4; j++)
				{
					s = in.readLine();

					for (int k = 0; k < 4; k++)
					{
						data[j][k] = s.charAt(k);
					}

				}

				// reads empty line
				in.readLine();

				String answer = solveOne(data);

				System.out.println("result:" + answer);

				out.write("Case #" + Integer.toString(i + 1) + ": " + answer);
				out.newLine();
			}
		}
		catch (IOException e)
		{
			System.out.println("Error reading!");
		}
	}

	private String solveOne(char[][] data)
	{
		if (isWinner('X', data))
		{
			return "X won";
		}
		else if (isWinner('O', data))
		{
			return "O won";
		}
		else if (notFilled(data))
		{
			return "Game has not completed";
		}
		else
		{
			return "Draw";
		}
	}
	
	private boolean isWinner(char c, char[][] data)
	{
		for (int i = 0; i < 4; i++)
		{
			boolean goodRow = true;
			
			for (int j = 0; j < 4; j++)
			{
				if (data[i][j] != c && data[i][j] != 'T')
				{
					goodRow = false;
					break;
				}
			}
			
			if (goodRow)
			{
				return true;
			}
		}
		
		for (int i = 0; i < 4; i++)
		{
			boolean goodColumn = true;
			
			for (int j = 0; j < 4; j++)
			{
				if (data[j][i] != c && data[j][i] != 'T')
				{
					goodColumn = false;
					break;
				}
			}
			
			if (goodColumn)
			{
				return true;
			}
		}

		boolean goodDiagonal = true;
		
		for (int i = 0; i < 4; i++)
		{
			if (data[i][i] != c && data[i][i] != 'T')
			{
				goodDiagonal = false;
			}
		}
		
		if (goodDiagonal)
		{
			return true;
		}
		
		goodDiagonal = true;
		
		for (int i = 0; i < 4; i++)
		{
			if (data[i][3-i] != c && data[i][3-i] != 'T')
			{
				goodDiagonal = false;
			}
		}
		
		if (goodDiagonal)
		{
			return true;
		}
		
		return false;
	}
	
	private boolean notFilled(char[][] data)
	{
		for (int i = 0; i < 4; i++)
		{
			for (int j = 0; j < 4; j++)
			{
				if (data[i][j] == '.')
				{
					return true;
				}
			}
		}
		
		return false;
	}
}
