package com.nolmecolindor.gcj2011;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Deque;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.Map;
import java.util.Scanner;
import java.util.Set;

public class Problem_B_0 {

	private final static String COMBINER = "+";
	// Forbidden combinations
	
	private final Map<Character, Set<Character>> forbiddenPartners = new HashMap<Character, Set<Character>>();
	
	private void clearForbiddenCombinations() { forbiddenPartners.clear(); }
	
	private Set<Character> getForbiddenPartnersFor(final char element) {
		final Set<Character> result = forbiddenPartners.get(element);
		if (result != null) return result;
		final Set<Character> newSet = new HashSet<Character>();
		forbiddenPartners.put(element, newSet);
		return newSet;
	}
	
	private void registerForbiddenCombination(final char e1, final char e2) {
		getForbiddenPartnersFor(e1).add(e2);
		getForbiddenPartnersFor(e2).add(e1);
	}
	
	// Transformations
	private final Map<String, Character> transformations = new HashMap<String, Character>();
	
	private void clearTransformations() { transformations.clear(); }
	
	private void registerTransformation(final char e1, final char e2, final char newElement) {
		transformations.put(e1 + COMBINER + e2, newElement);
		transformations.put(e2 + COMBINER + e1, newElement);
	}

	// Current list
	private final Deque<Character> elementList = new LinkedList<Character>();
	private final Set<Character> forbiddenSet = new HashSet<Character>();
	private Character lastElement;
	private final Set<Character> oldForbiddenSet = new HashSet<Character>();
	
	private void clearElementList() {
		elementList.clear();
		forbiddenSet.clear();
		oldForbiddenSet.clear();
		lastElement = null;
	}
	
	private String solve(final InputStream inputStream, final Scanner inputTokens) throws IOException {

		clearElementList();
		clearTransformations();
		clearForbiddenCombinations();
		
		final int transNum = inputTokens.nextInt();
		String transformation;
		for (int i = 0; i < transNum; i++) {
			transformation = inputTokens.next();
			registerTransformation(transformation.charAt(0), transformation.charAt(1), transformation.charAt(2));
		}
		
		final int forbiddens = inputTokens.nextInt();
		String forbidden;
		for (int i = 0; i < forbiddens; i++) {
			forbidden = inputTokens.next();
			registerForbiddenCombination(forbidden.charAt(0), forbidden.charAt(1));
		}
		
		final int length = inputTokens.nextInt();
		
//		final byte[] in = new byte[length];
//		inputStream.read(in, 0, length);

		final char[] elements = inputTokens.next().toCharArray();

		char element;
		for (int i = 0; i < length; i++) {
			element = elements[i];
			
			final Character transformesTo = (lastElement == null) ? null : transformations.get(lastElement + COMBINER + element);
			if (transformesTo != null) { // Is it transforming?
				elementList.pollLast();
				elementList.add(transformesTo);
				forbiddenSet.clear();
				forbiddenSet.addAll(oldForbiddenSet);
				lastElement = null;
				
			} else if (forbiddenSet.contains(element)) { // Does it explode?
				clearElementList();
			} else { // Just add it
				elementList.add(element);
				oldForbiddenSet.clear();
				oldForbiddenSet.addAll(forbiddenSet);
				forbiddenSet.addAll(getForbiddenPartnersFor(element));
				lastElement = element;
			}

		}
			

		
		final StringBuilder result = new StringBuilder("[");
		while (!elementList.isEmpty()) {
			if (result.length() > 1) result.append(", ");
			result.append(elementList.poll());
		}
		result.append("]");
		return result.toString();
	}
	
	
	private void solveAll(final InputStream stream, final Scanner input) throws NumberFormatException, IOException {
		final int cases = input.nextInt();
		for (int caseNum = 1; caseNum <= cases; caseNum++) {
			System.out.println("Case #" + caseNum + ": " + solve(stream, input));
		}
	}
	
	public static void main(final String[] args) {
		try {
			final InputStream stream = ((args.length == 2) && args[0].equals("--input")) ? new FileInputStream(args[1]) : System.in;
			final Scanner input = new Scanner(stream);
			new Problem_B_0().solveAll(stream, input);
		} catch (NumberFormatException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
