package com.nolmecolindor.gcj2012.round0;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Scanner;
import java.util.Set;

public class Problem_A_0 {

	private final static String ENGLISH = "abcdefghijklmnopqrstuvwxyz";
	
	@SuppressWarnings("serial")
	private final static Set<Character> englishChars = new HashSet<Character>() {{ 
		for (char c: ENGLISH.toCharArray()) add(c);
	}};
	
	private final static Map<Character, Character> code = new HashMap<Character, Character>();
	
	private static void addSample(final char inChar, final char outChar) throws Exception {
		if (code.containsKey(inChar)) {
			final char oldChar = code.get(inChar);
			if (oldChar != outChar) {
				throw new Exception("...found conflictig data: " + inChar + "->" + oldChar + " vs. " + inChar + "->" + outChar + "!");
			}
		} else {
			code.put(inChar, outChar);
		}
	}
	
	private static void addSample(final String inText, final String outText) throws Exception {
		if (inText.length() == outText.length()) {
			final char[] i = inText.toCharArray();
			final char[] o = outText.toCharArray();
			for (int a = 0; a < i.length; a++) addSample(i[a], o[a]);
		} else {
			throw new Exception("Error: sample length mismatch!");
		}
	}
	
	@SuppressWarnings("serial")
	private static void initMappings() throws Exception {
		addSample('y', 'a');
		addSample('e', 'o');
		addSample('q', 'z');
		addSample("ejp mysljylc kd kxveddknmc re jsicpdrysi", "our language is impossible to understand");
		addSample("rbcpc ypc rtcsra dkh wyfrepkym veddknkmkrkcd", "there are twenty six factorial possibilities");
		addSample("de kr kd eoya kw aej tysr re ujdr lkgc jv", "so it is okay if you want to just give up");
		
		final Set<Character> unknownIn = new HashSet<Character>() {{
			addAll(englishChars);
			removeAll(code.keySet());
		}};

		if (unknownIn.isEmpty()) return;

		final Set<Character> unknownOut = new HashSet<Character>() {{
			addAll(englishChars);
			removeAll(code.values());
		}};
		
		if ((1 == unknownIn.size()) && (1 == unknownOut.size())) {
			code.put(unknownIn.iterator().next(), unknownOut.iterator().next());
		} else {
			throw new Exception("Can not deduce mapping. Need more input data.");
		}

	}
	
	private String solve(final Scanner input) {
		final StringBuilder result = new StringBuilder();
		final String inText = input.nextLine();
		for (char c: inText.toCharArray()) result.append(code.get(c));
		return result.toString();
	}
	
	
	private void solveAll(final Scanner input) throws NumberFormatException, IOException {
		final int cases = input.nextInt();
		input.nextLine();
		for (int caseNum = 1; caseNum <= cases; caseNum++) {
			System.out.println("Case #" + caseNum + ": " + solve(input));
		}
	}
	
	public static void main(final String[] args) {
		try {
			initMappings();
			final Scanner input = new Scanner(((args.length == 2) && args[0].equals("--input")) ? new FileInputStream(args[1]) : System.in);
			new Problem_A_0().solveAll(input);
		} catch (NumberFormatException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

}
