package com.nolmecolindor.gcj2011.round1a;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.Set;

public class Problem_B {
	
	private final Map<Integer, List<String>> dict = new HashMap<Integer, List<String>>();
	private final List<String> fullList = new ArrayList<String>();
	
	private void storeWord(final String word) {
		final int length = word.length();
		List<String> wordList = dict.get(length);
		if (wordList == null) {
			wordList = new ArrayList<String>();
			dict.put(length, wordList);
		}
		wordList.add(word);
		fullList.add(word);
	}

	private final List<String> possibilities = new ArrayList<String>();
	private final Set<Character> possibleChars = new HashSet<Character>();
	
	boolean debug;
	
	private void collectChars() {
		possibleChars.clear();
		for (String word: possibilities) for (char c: word.toCharArray()) possibleChars.add(c);
	}
	
	private int cost;
	
	private void guess(final String solution, final char c) {
		if (debug) System.out.println("Guessing " + c + ".");
		if (solution.indexOf(c) == -1) {
			cost++;
			Iterator<String> w = possibilities.iterator();
			while (w.hasNext()) if (w.next().indexOf(c) > -1) w.remove();
		} else {
			Iterator<String> w = possibilities.iterator();
			final int length = solution.length();
			final boolean[] match = new boolean[length];
			for (int i = 0; i < length; i++) match[i] = solution.charAt(i) == c;
			boolean good;
			String word;
			boolean localMatch;
			while (w.hasNext()) {
				word = w.next();
				good = true;
				for (int i = 0; good && (i < length); i++) {
					localMatch = word.charAt(i) == c;
					good = (match[i] && localMatch) || (!match[i] && !localMatch);
				}
				if (!good) w.remove();
			}
		}
		collectChars();
//		System.out.println("Cost is now " + cost + ".");
	}
	
	private int getCostFor(final String word, final String orderString) {
		if (debug) System.out.println("Testing word '" + word + "' for order '" + orderString + "'.");
		char[] order = orderString.toCharArray();
		int nextChar = 0;
		cost = 0;
		possibilities.clear();
		possibilities.addAll(dict.get(word.length()));
		collectChars();
		boolean interesting = false;
		char c = '_';
		
			
		while (possibilities.size() > 1) {
			if (debug) {
				System.out.println("Possibilities: ");
				for (String p: possibilities) System.out.println(p);
			}
			interesting = false;
			while (!interesting) {
				c = order[nextChar++];
				interesting = possibleChars.contains(c);
			}
			guess(word, c);
			if (debug) System.out.println(possibilities.size() + " possibilities remain.");
		}
		return cost;
	}
	
	private String getBestWord(final String order) {
		boolean hasAny = false;
		int bestCost = 0;
		String bestWord = null;
		
		for (final String word: fullList) {
				final int cost = getCostFor(word, order);
				if (debug) System.out.println("Cost for word '"+word+"', order '"+order+"': " + cost);
				if (!hasAny || (cost > bestCost)) {
					hasAny = true;
					bestCost = cost;
					bestWord = word;
				}
			}
		if (debug) {
			return bestWord + " (" + bestCost + ")";
		} else {
			return bestWord;
		}
	}
	
	private String solve(final Scanner input) {
		dict.clear();
		fullList.clear();
		final int words = input.nextInt();
		final int orders = input.nextInt();
		for (int i = 0; i < words; i++) {
			storeWord(input.next());
		}
		final StringBuilder result = new StringBuilder();
		for (int i = 0; i < orders; i++) {
			result.append(" " + getBestWord(input.next()));
		}
		return result.toString();
	}
	
	
	private void solveAll(final Scanner input) throws NumberFormatException, IOException {
		int cases = input.nextInt();
//		cases = 3;
		for (int caseNum = 1; caseNum <= cases; caseNum++) {
			debug = false && (caseNum == 5);
			System.out.println("Case #" + caseNum + ":" + solve(input));
		}
	}
	
	public static void main(final String[] args) {
		try {
			final Scanner input = new Scanner(((args.length == 2) && args[0].equals("--input")) ? new FileInputStream(args[1]) : System.in);
			new Problem_B().solveAll(input);
		} catch (NumberFormatException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
