package chandra.google.codejam.countingsheep;

import java.io.IOException;
import java.net.URISyntaxException;
import java.text.ParseException;
import java.util.List;

import chandra.google.codejam.utils.InputReader;
import chandra.google.codejam.utils.OutputWriter;

public class CountingSheep {
	
	private static final String OUPUT_FILE_NAME = "outputfile";
	private static final String LINE_SEPARATOR = "line.separator";
	//public static String INPUT_FILE = "A-small-practice.in";
	public static final String INPUT_FILE_NAME = "inputfile";
	
	int insomaniaDetector = 0;
	int validatedDigits = 0;
	boolean [] digitTracker = new boolean[10];
	
	
	public static void main(String[] args) {
		InputReader inputReader = new InputReader(INPUT_FILE_NAME);
	    
	    List<String> lines=null;
		try {
			lines = inputReader.getFileLines();
		} catch (IOException e) {
			e.printStackTrace();
			return;
		} catch (URISyntaxException e) {
			e.printStackTrace();
			return;
		}
	  		
		CountingSheep countingSheep = new CountingSheep();
		try {
			countingSheep.solve(lines);
		} catch (ParseException e) {
			e.printStackTrace();
			StringBuffer stringBuffer = new StringBuffer("Invalid Input");
			stringBuffer.append(System.getProperty(LINE_SEPARATOR));
			stringBuffer.append(e.getMessage());
			OutputWriter.create(OUPUT_FILE_NAME,stringBuffer);
		}

	}
	
	private void solve(List<String> lines) throws ParseException {
		StringBuffer buffer = new StringBuffer();
		
		int numberOfTestCases =  Integer.parseInt(lines.get(0));
		
		//validate input
		if(numberOfTestCases != (lines.size()-1)){
			throw new ParseException("Invalid no of cases -"+numberOfTestCases,numberOfTestCases);
		}
		
		for(int i=0;i<numberOfTestCases;i++){
			
			int N = Integer.parseInt(lines.get(i+1));			
			
			buffer.append(solveEachCase(i+1,N));
			
			buffer.append(System.getProperty(LINE_SEPARATOR));
		}
		
		OutputWriter.create(OUPUT_FILE_NAME, buffer);
	}
	
	private String solveEachCase(int caseNo, int N) {
		resetDigitTracker(digitTracker);
		String finalResult = null;
		validatedDigits=0;
		int multiplier = 1;
		while(true) {
			int calculatedValue = N * multiplier;
			boolean result = seperateDigitsAndSetDigitTracker(calculatedValue);
			if(result) {
				finalResult = "Case #"+caseNo+": "+calculatedValue;
				break;
			}
			else {
				multiplier++;
				if(insomaniaDetector >= 1000) {
					finalResult = "Case #"+caseNo+": INSOMNIA";
					break;
				}
			}
		}
		
		
		return finalResult;
	}
	
	
	
	private void resetDigitTracker (boolean [] digitTracker) {
		for(int i=0; i < digitTracker.length; i++) {
			digitTracker[i] = false;
		}
	}
	
	private boolean seperateDigitsAndSetDigitTracker(int N) {
		boolean result = false;
		boolean insomaiaUpdate = false;
		while(true) {
			int digit = N%10;
			boolean isPresent = digitTracker[digit];
			if(!isPresent) {
				digitTracker[digit] = true;
				validatedDigits++;
				insomaniaDetector = 0;
			}
			else {
				
				if(!insomaiaUpdate) {
					insomaniaDetector++;
					insomaiaUpdate=true;
				}
			}
			if(validatedDigits >= 10) {
				return true;
			}
			if(N < 10 ) {
				break;
			}
			else {
				N = N / 10;
			}
		}
		return result;
	}
	
	

}


