package chandra.google.codejam.coinjam;


import java.io.IOException;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.net.URISyntaxException;
import java.text.ParseException;
import java.util.List;

import chandra.google.codejam.utils.InputReader;
import chandra.google.codejam.utils.OutputWriter;

public class CoinJam {
	
	private static final String OUPUT_FILE_NAME = "outputfile_coinjam_small";
	private static final String LINE_SEPARATOR = "line.separator";
	//public static String INPUT_FILE = "A-small-practice.in";
	public static final String INPUT_FILE_NAME = "inputfile_coinjam";
	
	
	
	public static void main(String[] args) {
		InputReader inputReader = new InputReader(INPUT_FILE_NAME);
	    
	    List<String> lines=null;
		try {
			lines = inputReader.getFileLines();
		} catch (IOException e) {
			e.printStackTrace();
			return;
		} catch (URISyntaxException e) {
			e.printStackTrace();
			return;
		}
	  		
		CoinJam coinJam = new CoinJam();
		try {
			coinJam.solve(lines);
		} catch (ParseException e) {
			e.printStackTrace();
			StringBuffer stringBuffer = new StringBuffer("Invalid Input");
			stringBuffer.append(System.getProperty(LINE_SEPARATOR));
			stringBuffer.append(e.getMessage());
			OutputWriter.create(OUPUT_FILE_NAME,stringBuffer);
		}

	}
	
	private void solve(List<String> lines) throws ParseException {
		StringBuffer buffer = new StringBuffer();
		
		int numberOfTestCases =  Integer.parseInt(lines.get(0));
		
		//validate input
		if(numberOfTestCases != (lines.size()-1)){
			throw new ParseException("Invalid no of cases -"+numberOfTestCases,numberOfTestCases);
		}		
		
		for(int i=0;i<numberOfTestCases;i++){
			
			String inputStack = lines.get(i+1);	
			String [] inputs = inputStack.split(" ");
			long N = Integer.parseInt(inputs[0]);
			long J = Integer.parseInt(inputs[1]);
			
			buffer.append(solveEachCase(i+1,N,J));
			
			buffer.append(System.getProperty(LINE_SEPARATOR));
		}
		
		OutputWriter.create(OUPUT_FILE_NAME, buffer);
	}
	
	private String solveEachCase(int caseNo, long N, long J) {
		String finalResult = null;
		//Create a binary string of length N with first and last bit as 1 and all others as 0
		StringBuilder binaryString = new StringBuilder("1");
		for(long i=0; i < (N-2); i++) {
			binaryString.append("0");
		}
		binaryString.append("1");
		String binary = binaryString.toString();
		long jamCoinCount = 0;
		finalResult = "Case #"+caseNo+":\n";
		while(true) {
			if(jamCoinCount >= J)
				break;
			boolean primeFlag = false;
			//Get the decimal equivalent of it in all the bases and check if it is prime or not
			for(int base=2; base <= 10; base++) {
				BigInteger numberInBase = getNumber(binary, base);				
				//if the above number is prime then it will violate the coin jam rule				
				if(isPrime(numberInBase)){
					primeFlag = true;
					break;
				}
			}
			if(!primeFlag) {
				finalResult = finalResult + binary;
				//int [] trivialDivisors = new int [9]; 
				for(int base=2; base <= 10; base++) {
					BigInteger numberWithBase = getNumber(binary, base);
					BigInteger divisor = getTrivialDivisor(numberWithBase);
					finalResult = finalResult + " "+divisor;
				}
				finalResult = finalResult+"\n";
				jamCoinCount++;
			}
				//Get decimal equivalent for next number and add 2 to get next number ending with 1
				BigInteger decimalEquivalent = getNumber(binary, 2).add(BigInteger.valueOf(2));
				binary = getBinaryString(decimalEquivalent);			
			
		}
		
		return finalResult;
	}
	
	
	private boolean isPrime(BigInteger number) {  
		  long m= (long)Math.sqrt(number.longValue());
		  long number1= number.longValue();
		  for(int i=2;i<=m;i++){    
		   if(number1%i==0){    
			   return false; 
		   }    
		  }    
		  return true;
	}
	
	private BigInteger getNumber(String binary, int base) {
		BigInteger result = new BigInteger("0");
		BigInteger base1 = BigInteger.valueOf(base);
		for(int i=0; i < binary.length(); i++) {
			long bit = (long)Character.getNumericValue(binary.charAt(i));
			BigInteger bitBig = BigInteger.valueOf(bit);
			int exponent = binary.length()-1-i;
			result = result.add(bitBig.multiply(base1.pow(exponent)));
		}
		return result;
	}
	private String getBinaryString(BigInteger decimalNumber) {
		StringBuilder result = new StringBuilder();
		BigInteger value2 = BigInteger.valueOf(2);
		while(decimalNumber.longValue() > 1) {
			result.append(decimalNumber.mod(value2));
			decimalNumber = decimalNumber.divide(value2);
		}
		result.append(decimalNumber);
		result.reverse();
		return result.toString();
	}
	
	private BigInteger getTrivialDivisor(BigInteger number) {
		long m= (long)Math.sqrt(number.longValue());
		  long number1= number.longValue();
		  for(int i=2;i<=m;i++){    
		   if(number1%i==0){    
			   return BigInteger.valueOf(i); 
		   }    
		  }    
		  return BigInteger.valueOf(0);
	}
	
	
}


