package chandra.google.codejam.pancakes;


import java.io.IOException;
import java.net.URISyntaxException;
import java.text.ParseException;
import java.util.List;

import chandra.google.codejam.utils.InputReader;
import chandra.google.codejam.utils.OutputWriter;

public class PanCakes {
	
	private static final String OUPUT_FILE_NAME = "outputfile_pancakes_large";
	private static final String LINE_SEPARATOR = "line.separator";
	//public static String INPUT_FILE = "A-small-practice.in";
	public static final String INPUT_FILE_NAME = "inputfile_pancakes";
	
	
	public static void main(String[] args) {
		InputReader inputReader = new InputReader(INPUT_FILE_NAME);
	    
	    List<String> lines=null;
		try {
			lines = inputReader.getFileLines();
		} catch (IOException e) {
			e.printStackTrace();
			return;
		} catch (URISyntaxException e) {
			e.printStackTrace();
			return;
		}
	  		
		PanCakes panCakes = new PanCakes();
		try {
			panCakes.solve(lines);
		} catch (ParseException e) {
			e.printStackTrace();
			StringBuffer stringBuffer = new StringBuffer("Invalid Input");
			stringBuffer.append(System.getProperty(LINE_SEPARATOR));
			stringBuffer.append(e.getMessage());
			OutputWriter.create(OUPUT_FILE_NAME,stringBuffer);
		}

	}
	
	private void solve(List<String> lines) throws ParseException {
		StringBuffer buffer = new StringBuffer();
		
		int numberOfTestCases =  Integer.parseInt(lines.get(0));
		
		//validate input
		if(numberOfTestCases != (lines.size()-1)){
			throw new ParseException("Invalid no of cases -"+numberOfTestCases,numberOfTestCases);
		}
		
		for(int i=0;i<numberOfTestCases;i++){
			
			String inputStack = lines.get(i+1);			
			
			buffer.append(solveEachCase(i+1,inputStack));
			
			buffer.append(System.getProperty(LINE_SEPARATOR));
		}
		
		OutputWriter.create(OUPUT_FILE_NAME, buffer);
	}
	
	private String solveEachCase(int caseNo, String inputStack) {
		String finalResult = null;
		if(inputStack == null || inputStack.equals("+")) {
			finalResult = "Case #"+caseNo+": 0";
			return finalResult;
		}
		else if(inputStack.equals("-")) {
			finalResult = "Case #"+caseNo+": 1";
			return finalResult;
		}
		int flipsRequired = 0;
		char currentSign = inputStack.charAt(0);
		for(int i=0; i<inputStack.length(); i++) {
			if(inputStack.charAt(i) != currentSign) {
				//Need one flip to change i-1 bits to current sign
				flipsRequired++;
				currentSign=inputStack.charAt(i);
			}
		}
		if(currentSign=='-') {
			flipsRequired++;
		}
		finalResult = "Case #"+caseNo+": "+flipsRequired;
		return finalResult;
	}
}


