package hu.herba.codejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;

/**
 *
 * @author csorbazoli
 *
 */
public class TidyNumbers {

	public static void main(String[] args) {
		if (args.length < 1) {
			// process all files in input folder
			for (File input : new File("./input").listFiles()) {
				if (input.getName().endsWith(".in")) {
					System.out.println("Processing: " + input.getName() + "...");
					new TidyNumbers().process(input);
				}
			}
		} else {
			File input = new File("./input", args[0]);
			if (!input.canRead()) {
				error("Input file not found: " + input.getAbsolutePath());
			}
			new TidyNumbers().process(input);
		}
		System.out.println("READY");
	}

	private static void error(String msg) {
		System.err.println(msg);
		System.exit(-1);

	}

	private void process(File input) {
		// process input file
		try {
			Scanner scan = new Scanner(input);
			// open output
			PrintWriter out = new PrintWriter(new File("./output", input.getName().replace(".in", ".out")));
			try {
				// number of test cases
				int T = scan.nextInt();
				for (int i = 0; i < T; i++) {
					processTestCase(i + 1, scan, out);
				}
			} finally {
				out.close();
			}
		} catch (FileNotFoundException e) {
			error(e.getMessage());
		}

	}

	protected void processTestCase(int caseNum, Scanner scan, PrintWriter out) {
		boolean debug = false;
		if (caseNum == 0) {
			debug = true;
		}
		// get input
		StringBuilder result = new StringBuilder("Case #" + caseNum + ": ");
		String S = scan.next(); // single integer N, the last number counted by Tatiana
		if (debug) {
			System.out.print(caseNum + "# " + S + " -> ");
		}
		result.append(calculateOutput(S)); // return largest tidy number (digits non-decreasing order)
		System.out.println(result.toString());
		out.println(result.toString());
	}

	private String calculateOutput(String s) {
		StringBuilder ret = new StringBuilder(s);
		int pos = 0;
		while (pos < ret.length() - 1) {
			if (ret.charAt(pos) > ret.charAt(pos + 1)) {
				// need to decrease number from this point
				pos = decreaseNumber(ret, pos);
			} else {
				pos++;
			}
		}
		return ret.toString().replaceFirst("^0+", "");
	}

	private int decreaseNumber(StringBuilder number, int pos) {
		int ret = pos;
		number.setCharAt(pos, (char) (number.charAt(pos) - 1));
		for (int i = pos + 1; i < number.length(); i++) {
			number.setCharAt(i, '9');
		}
		if (ret > 0) {
			ret--; // need to check previous position
		}
		return ret;
	}

}
