package hu.herba.codejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;

/**
 * 
 * @author csorbazoli
 * 
 */
public class JamCoin {

	public static void main(String[] args) {
		if (args.length < 1) {
			// process all files in input folder
			for (File input : new File("./input").listFiles()) {
				if (input.getName().endsWith(".in")) {
					System.out.println("Processing: " + input.getName() + "...");
					new JamCoin().process(input);
				}
			}
		} else {
			File input = new File("./input", args[0]);
			if (!input.canRead()) {
				error("Input file not found: " + input.getAbsolutePath());
			}
			new JamCoin().process(input);
		}
		System.out.println("READY");
	}

	private static void error(String msg) {
		System.err.println(msg);
		System.exit(-1);

	}

	private void process(File input) {
		// process input file
		try {
			Scanner scan = new Scanner(input);
			// open output
			PrintWriter out = new PrintWriter(new File("./output", input.getName().replace(".in", ".out")));
			try {
				// number of test cases
				int T = scan.nextInt();
				for (int i = 0; i < T; i++) {
					processTestCase(i + 1, scan, out);
				}
			} finally {
				out.close();
			}
		} catch (FileNotFoundException e) {
			error(e.getMessage());
		}

	}

	private void processTestCase(int caseNum, Scanner scan, PrintWriter out) {
		boolean debug = false;
		if (caseNum == 0) {
			debug = true;
		}
		// get N, J
		StringBuilder result = new StringBuilder("Case #" + caseNum + ":\n");
		int N = scan.nextInt(); // N
		int J = scan.nextInt(); // J
		if (debug) {
			System.out.print(caseNum + "# " + N + " " + J + " -> ");
		}
		calculateOutput(result, N, J);
		// System.out.println(result.toString());
		out.println(result.toString());
	}

	private void calculateOutput(StringBuilder result, int n, int j) {
		long baseValue = (1 << (n - 1)) + 1L; // this is the first number
		// long maxValue = (1 << n) - 1;
		long curValue = baseValue;
		int resultCounter = 0;
		while (resultCounter < j) { // (curValue <= maxValue) {//
			if (isJamCoin(result, Long.toBinaryString(curValue))) {
				resultCounter++;
			}
			curValue += 2;
		}
	}

	private boolean isJamCoin(StringBuilder result, String curValue) {
		StringBuilder line = new StringBuilder(curValue);
		boolean ret = true;
		int base = 2;
		long nonTrivialDivisor;
		while (base <= 10) {
			nonTrivialDivisor = getNonTrivialDivisor(getNBaseValue(base, curValue));
			if (nonTrivialDivisor > 0) {
				line.append(" ").append(nonTrivialDivisor);
			} else {
				ret = false;
				break;
			}
			base++;
		}
		if (ret) {
			result.append(line).append("\n");
			System.out.println(line);
		}
		return ret;
	}

	private long getNonTrivialDivisor(long value) {
		long ret = 2;
		long sqrt = (long) Math.sqrt(value);
		while (ret <= sqrt) {
			if ((value % ret) == 0) {
				// System.out.println(value + " divider = " + ret);
				return ret;
			}
			ret++;
		}
		// System.out.println(value + " is PRIME!");
		return 0;
	}

	private long getNBaseValue(int base, String curValue) {
		long multiplier = 1L;
		long ret = 0L;
		for (int i = curValue.length(); i > 0; i--) {
			if (curValue.charAt(i - 1) == '1') {
				ret += multiplier;
			}
			multiplier *= base;
		}
		return ret;
	}

}
