package hu.herba.codejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;

/**
 * Problem
 * 
 * It's opening night at the opera, and your friend is the prima donna (the lead female singer). You will not be in the audience, but you want to make sure she
 * receives a standing ovation -- with every audience member standing up and clapping their hands for her.
 * 
 * Initially, the entire audience is seated. Everyone in the audience has a shyness level. An audience member with shyness level Si will wait until at least Si
 * other audience members have already stood up to clap, and if so, she will immediately stand up and clap. If Si = 0, then the audience member will always
 * stand up and clap immediately, regardless of what anyone else does. For example, an audience member with Si = 2 will be seated at the beginning, but will
 * stand up to clap later after she sees at least two other people standing and clapping.
 * 
 * You know the shyness level of everyone in the audience, and you are prepared to invite additional friends of the prima donna to be in the audience to ensure
 * that everyone in the crowd stands up and claps in the end. Each of these friends may have any shyness value that you wish, not necessarily the same. What is
 * the minimum number of friends that you need to invite to guarantee a standing ovation? Input
 * 
 * The first line of the input gives the number of test cases, T. T test cases follow. Each consists of one line with Smax, the maximum shyness level of the
 * shyest person in the audience, followed by a string of Smax + 1 single digits. The kth digit of this string (counting starting from 0) represents how many
 * people in the audience have shyness level k. For example, the string "409" would mean that there were four audience members with Si = 0 and nine audience
 * members with Si = 2 (and none with Si = 1 or any other value). Note that there will initially always be between 0 and 9 people with each shyness level.
 * 
 * The string will never end in a 0. Note that this implies that there will always be at least one person in the audience.
 * 
 * Output
 * 
 * For each test case, output one line containing "Case #x: y", where x is the test case number (starting from 1) and y is the minimum number of friends you
 * must invite. *
 * 
 * @author Zoltn
 * 
 */
public class StandingOvation {
	public static void main(String[] args) {
		if (args.length < 1) {
			// process all files in input folder
			for (File input : new File("./input").listFiles()) {
				if (input.getName().endsWith(".in")) {
					System.out.println("Processing: " + input.getName() + "...");
					new StandingOvation().process(input);
				}
			}
		} else {
			File input = new File("./input", args[0]);
			if (!input.canRead()) {
				error("Input file not found: " + input.getAbsolutePath());
			}
			new StandingOvation().process(input);
		}
		System.out.println("READY");
	}

	private static void error(String msg) {
		System.err.println(msg);
		System.exit(-1);

	}

	private void process(File input) {
		// process input file
		try {
			Scanner scan = new Scanner(input);
			// open output
			PrintWriter out = new PrintWriter(new File("./output", input.getName().replace(".in", ".out")));
			try {
				// number of test cases
				int T = scan.nextInt();
				for (int i = 0; i < T; i++) {
					processTestCase(i + 1, scan, out);
				}
			} finally {
				out.close();
			}
		} catch (FileNotFoundException e) {
			error(e.getMessage());
		}

	}

	private void processTestCase(int caseNum, Scanner scan, PrintWriter out) {
		// get X, R, C
		StringBuilder result = new StringBuilder("Case #" + caseNum + ": ");
		int Smax = scan.nextInt();
		String levels = scan.next();
		int friends = 0;
		int count;
		int standing = 0;
		for (int i = 0; i <= Smax; i++) {
			count = levels.charAt(i) - '0';
			standing += count; // current number of standing people
			if (standing < (i + 1)) { // need to involve friends
				friends += ((i + 1) - standing);
				standing = i + 1;
			}
		}
		result.append(friends);
		System.out.println(result);
		out.println(result.toString());
	}
}
