package hu.herba.codejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.HashSet;
import java.util.Scanner;
import java.util.Set;

/**
 * 
 * @author csorbazoli
 * 
 */
public class CountingSheeps {

	public static void main(String[] args) {
		if (args.length < 1) {
			// process all files in input folder
			for (File input : new File("./input").listFiles()) {
				if (input.getName().endsWith(".in")) {
					System.out.println("Processing: " + input.getName() + "...");
					new CountingSheeps().process(input);
				}
			}
		} else {
			File input = new File("./input", args[0]);
			if (!input.canRead()) {
				error("Input file not found: " + input.getAbsolutePath());
			}
			new CountingSheeps().process(input);
		}
		System.out.println("READY");
	}

	private static void error(String msg) {
		System.err.println(msg);
		System.exit(-1);

	}

	private void process(File input) {
		// process input file
		try {
			Scanner scan = new Scanner(input);
			// open output
			PrintWriter out = new PrintWriter(new File("./output", input.getName().replace(".in", ".out")));
			try {
				// number of test cases
				int T = scan.nextInt();
				for (int i = 0; i < T; i++) {
					processTestCase(i + 1, scan, out);
				}
			} finally {
				out.close();
			}
		} catch (FileNotFoundException e) {
			error(e.getMessage());
		}

	}

	private void processTestCase(int caseNum, Scanner scan, PrintWriter out) {
		boolean debug = false;
		if (caseNum == 0) {
			debug = true;
		}
		// get N
		StringBuilder result = new StringBuilder("Case #" + caseNum + ": ");
		long N = scan.nextLong(); // number N
		if (debug) {
			System.out.print(caseNum + "# " + N + " -> ");
		}
		String output = calculateOutput(N);
		result.append(output);
		// whole product should be i*j*k = -1
		System.out.println(result.toString());
		out.println(result.toString());
	}

	private String calculateOutput(long n) {
		if (n == 0) {
			return "INSOMNIA";
		}
		Set<Character> digits = new HashSet<>();
		for (int i = 0; i < 10; i++) {
			digits.add(Integer.toString(i).charAt(0));
		}
		long curN = n;
		int maxTry = 1000;
		while ((maxTry-- > 0)) {
			markDigits(digits, curN);
			if (digits.isEmpty()) {
				return Long.toString(curN);
			}
			curN += n;
		}
		return "INSOMNIA";
	}

	private void markDigits(Set<Character> digits, long curN) {
		String num = Long.toString(curN);
		for (char c : num.toCharArray()) {
			digits.remove(c);
		}
	}

}
