package hu.herba.codejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;

/**
 * Richard and Gabriel are going to play a game with the following rules, for some predetermined values of X, R, and C:
 * 
 * 1. Richard will choose any one of the possible X-ominoes. 2. Gabriel must use at least one copy of that X-omino, along with arbitrarily many copies of any
 * X-ominoes (which can include the one Richard chose), to completely fill in an R-by-C grid, with no overlaps and no spillover. That is, every cell must be
 * covered by exactly one of the X cells making up an X-omino, and no X-omino can extend outside the grid. Gabriel is allowed to rotate or reflect as many of
 * the X-ominoes as he wants, including the one Richard chose. If Gabriel can completely fill in the grid, he wins; otherwise, Richard wins.
 * 
 * Given particular values X, R, and C, can Richard choose an X-omino that will ensure that he wins, or is Gabriel guaranteed to win no matter what Richard
 * chooses?
 * 
 * Input
 * 
 * The first line of the input gives the number of test cases, T. T lines follow. Each contains three space-separated integers: X, R, and C.
 * 
 * Output
 * 
 * For each test case, output one line containing "Case #x: y", where x is the test case number (starting from 1) and y is either RICHARD (if there is at least
 * one choice that ensures victory for Richard) or GABRIEL (if Gabriel will win no matter what Richard chooses).
 * 
 * @author Zoltn
 * 
 */
public class OminousOmino {
	public static void main(String[] args) {
		if (args.length < 1) {
			// process all files in input folder
			for (File input : new File("./input").listFiles()) {
				if (input.getName().endsWith(".in")) {
					System.out.println("Processing: " + input.getName() + "...");
					new OminousOmino().process(input);
				}
			}
		} else {
			File input = new File("./input", args[0]);
			if (!input.canRead()) {
				error("Input file not found: " + input.getAbsolutePath());
			}
			new OminousOmino().process(input);
		}
		System.out.println("READY");
	}

	private static void error(String msg) {
		System.err.println(msg);
		System.exit(-1);

	}

	private void process(File input) {
		// process input file
		try {
			Scanner scan = new Scanner(input);
			// open output
			PrintWriter out = new PrintWriter(new File("./output", input.getName().replace(".in", ".out")));
			try {
				// number of test cases
				int T = scan.nextInt();
				for (int i = 0; i < T; i++) {
					processTestCase(i + 1, scan, out);
				}
			} finally {
				out.close();
			}
		} catch (FileNotFoundException e) {
			error(e.getMessage());
		}

	}

	private void processTestCase(int caseNum, Scanner scan, PrintWriter out) {
		// get X, R, C
		StringBuilder result = new StringBuilder("Case #" + caseNum + ": ");
		boolean secondWins = true;
		int X = scan.nextInt();
		int R = scan.nextInt();
		int C = scan.nextInt();
		int s = 0;
		if (X > 6) { // 7 has a leaky shape
			secondWins = false;
			s = 1;
		} else if ((X > R) && (X > C)) {// 1xX shape is greater then size of table
			secondWins = false;
			s = 2;
		} else if (((R * C) % X) != 0) {// table cannot be divided to X sized parts
			secondWins = false;
			s = 3;
		} else {
			switch (X) {
			case 1:
				secondWins = true;
				s = 4;
				break;
			case 2:
				secondWins = true;
				s = 5;
				break;
			case 3:
				if ((R >= X) && (C >= X)) {// if both sides greater
					secondWins = true;
					s = 6;
				} else if ((R <= 1) || (C <= 1)) {
					secondWins = false;
					s = 7;
				} else { // one side is 2
					secondWins = true;
					s = 8;
				}
				// ((R % X) == 0) || ((C % X) == 0); // at least one is dividable
				break;
			case 4:
				if ((R >= X) && (C >= X)) {// if both sides greater
					secondWins = true;
					s = 9;
				} else if ((R <= 2) || (C <= 2)) {
					secondWins = false;
					s = 10;
				} else { // one side is 3
					secondWins = true;
					s = 11;
				}
				break;
			// either 2x2 or 4x1
			case 5:
				// 5*N is OK as each item can be arranged in 3x5 rectangle
				if ((R >= X) && (C >= X)) {// if both sides greater
					secondWins = true;
					s = 12;
				} else if ((R <= 2) || (C <= 2)) {
					secondWins = false;
					s = 13;
				} else { // one side is 3 or 4
					secondWins = true;
					s = 14;
				}
				break;
			case 6:
				// 6*N is fine for each shape
				// 3^n*2M is fine for each shape
				if ((R >= X) && (C >= X)) {// if both sides greater
					secondWins = true;
					s = 15;
				} else if ((R <= 3) || (C <= 3)) {
					secondWins = false;
					s = 16;
				} else { // one side is 4 or 5
					secondWins = true;
					s = 17;
				}
				break;
			default:
				secondWins = false;
				s = 18;
			}
		}
		// write output: Case #n: GABRIEL/RICHARD
		if (secondWins) {
			result.append("GABRIEL");
		} else {
			result.append("RICHARD");
		}
		// System.out.println(result);
		// if (s == 13) {
		System.out.println(caseNum + "#: " + X + " " + R + " " + C + " -> " + (secondWins ? "G(2)" : "R(1)") + " (S: " + s + ")");
		// }
		out.println(result.toString());
	}
}
