package hu.herba.codejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;

/**
 *
 * @author csorbazoli
 *
 */
public class OversizedPancakeFlipper {

	public static void main(String[] args) {
		if (args.length < 1) {
			// process all files in input folder
			for (File input : new File("./input").listFiles()) {
				if (input.getName().endsWith(".in")) {
					System.out.println("Processing: " + input.getName() + "...");
					new OversizedPancakeFlipper().process(input);
				}
			}
		} else {
			File input = new File("./input", args[0]);
			if (!input.canRead()) {
				error("Input file not found: " + input.getAbsolutePath());
			}
			new OversizedPancakeFlipper().process(input);
		}
		System.out.println("READY");
	}

	private static void error(String msg) {
		System.err.println(msg);
		System.exit(-1);

	}

	private void process(File input) {
		// process input file
		try {
			Scanner scan = new Scanner(input);
			// open output
			PrintWriter out = new PrintWriter(new File("./output", input.getName().replace(".in", ".out")));
			try {
				// number of test cases
				int T = scan.nextInt();
				for (int i = 0; i < T; i++) {
					processTestCase(i + 1, scan, out);
				}
			} finally {
				out.close();
			}
		} catch (FileNotFoundException e) {
			error(e.getMessage());
		}

	}

	private void processTestCase(int caseNum, Scanner scan, PrintWriter out) {
		boolean debug = false;
		if (caseNum == 0) {
			debug = true;
		}
		// get input
		StringBuilder result = new StringBuilder("Case #" + caseNum + ": ");
		String S = scan.next(); // S represents the row of pancakes: each of its characters is either + (which represents a pancake that is initially happy side up)
		// or - (which represents a pancake that is initially blank side up).
		int K = scan.nextInt(); // K the size of pancake flipper
		if (debug) {
			System.out.print(caseNum + "# " + S + " -> ");
		}
		result.append(calculateOutput(S, K));
		System.out.println(result.toString());
		out.println(result.toString());
	}

	private String calculateOutput(String s, int k) {
		int ret = 0;
		int len = s.length();
		byte[] array = s.getBytes();
		for (int pos = 0; pos < len; pos++) {
			if (array[pos] == '-') {
				if (pos > len - k) {
					return "IMPOSSIBLE"; // flipper is longer then needed
				}
				flip(array, pos, k);
				ret++;
			}
		}
		return Integer.toString(ret);
	}

	private void flip(byte[] array, int pos, int k) {
		for (int i = 0; i < k; i++) {
			byte b = array[pos + i];
			array[pos + i] = (byte) (b == '-' ? '+' : '-');
		}
	}

}
