package hu.herba.codejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.Scanner;

/**
 *
 * @author csorbazoli
 *
 */
public class BathroomStalls {

	private static final BigInteger BIG_1 = BigInteger.valueOf(1);
	private static final BigInteger BIG_2 = BigInteger.valueOf(2);

	public static void main(String[] args) {
		if (args.length < 1) {
			// process all files in input folder
			for (File input : new File("./input").listFiles()) {
				if (input.getName().endsWith(".in")) {
					System.out.println("Processing: " + input.getName() + "...");
					new BathroomStalls().process(input);
				}
			}
		} else {
			File input = new File("./input", args[0]);
			if (!input.canRead()) {
				error("Input file not found: " + input.getAbsolutePath());
			}
			new BathroomStalls().process(input);
		}
		System.out.println("READY");
	}

	private static void error(String msg) {
		System.err.println(msg);
		System.exit(-1);

	}

	private void process(File input) {
		// process input file
		try {
			Scanner scan = new Scanner(input);
			// open output
			PrintWriter out = new PrintWriter(new File("./output", input.getName().replace(".in", ".out")));
			try {
				// number of test cases
				int T = scan.nextInt();
				for (int i = 0; i < T; i++) {
					processTestCase(i + 1, scan, out);
				}
			} finally {
				out.close();
			}
		} catch (FileNotFoundException e) {
			error(e.getMessage());
		}

	}

	protected void processTestCase(int caseNum, Scanner scan, PrintWriter out) {
		boolean debug = false;
		if (caseNum == 0) {
			debug = true;
		}
		// get input
		StringBuilder result = new StringBuilder("Case #" + caseNum + ": ");
		BigInteger N = scan.nextBigInteger(); // N number of stalls
		BigInteger K = scan.nextBigInteger(); // K number of users
		if (debug) {
			System.out.print(caseNum + "# " + N + " " + K + " -> ");
		}
		result.append(calculateOutput(N, K));
		System.out.println(result.toString());
		out.println(result.toString());
	}

	private class MinMax {
		BigInteger max;
		BigInteger min;
	}

	private class Gap {
		BigInteger max;
		BigInteger maxCnt;
		BigInteger min;
		BigInteger minCnt;
		BigInteger gapCnt;

		Gap(BigInteger n) {
			max = n;
			maxCnt = BIG_1;
			min = n;
			minCnt = BIG_1;
			gapCnt = BIG_1;
		}
	}

	private String calculateOutput(BigInteger n, BigInteger k) {
		StringBuilder ret = new StringBuilder();
		Gap gap = new Gap(n);
		MinMax m = calculateMinMax(gap, k);
		ret.append(m.max).append(" ").append(m.min);
		return ret.toString();
	}

	private MinMax calculateMinMax(Gap gap, BigInteger remaining) {
		BigInteger numOfGaps = gap.gapCnt;
		// last group of people
		if (remaining.compareTo(numOfGaps) <= 0) {
			// bigger gap
			if (remaining.compareTo(gap.maxCnt) <= 0) {
				return calculateMinMax(gap.max);
			} else { // smaller gap
				return calculateMinMax(gap.min);
			}
		}
		BigInteger newGap = gap.max.subtract(BIG_1);
		if (gap.max.equals(gap.min)) { // all gaps are equal sized
			if (newGap.remainder(BIG_2).intValue() == 0) {
				gap.max = gap.min = newGap.divide(BIG_2);
				gap.maxCnt = gap.maxCnt.multiply(BIG_2);
			} else {
				gap.min = newGap.divide(BIG_2);
				gap.max = gap.min.add(BIG_1);
				gap.minCnt = gap.maxCnt;
			}
		} else {
			if (newGap.remainder(BIG_2).intValue() == 0) {
				gap.max = newGap.divide(BIG_2);
				gap.min = gap.max.subtract(BIG_1);
				gap.maxCnt = gap.maxCnt.multiply(BIG_2).add(gap.minCnt);
				// minCnt remains the same
			} else {
				gap.min = newGap.divide(BIG_2);
				gap.max = gap.min.add(BIG_1);
				gap.minCnt = gap.minCnt.multiply(BIG_2).add(gap.maxCnt);
				// maxCnt remains the same
			}
		}
		gap.gapCnt = gap.gapCnt.shiftLeft(1);
		return calculateMinMax(gap, remaining.subtract(numOfGaps));
	}

	private MinMax calculateMinMax(BigInteger gap) {
		MinMax ret = new MinMax();
		BigInteger oneLess = gap.subtract(BIG_1);
		if (oneLess.remainder(BIG_2).intValue() == 0) {
			ret.max = ret.min = oneLess.divide(BIG_2);
		} else {
			ret.min = oneLess.divide(BIG_2);
			ret.max = ret.min.add(BIG_1);
		}
		return ret;
	}

}
