package hu.herba.codejam;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;

/**
 * 
 * @author csorbazoli
 * 
 */
public class Fractiles {

	public static void main(String[] args) {
		if (args.length < 1) {
			// process all files in input folder
			for (File input : new File("./input").listFiles()) {
				if (input.getName().endsWith(".in")) {
					System.out.println("Processing: " + input.getName() + "...");
					new Fractiles().process(input);
				}
			}
		} else {
			File input = new File("./input", args[0]);
			if (!input.canRead()) {
				error("Input file not found: " + input.getAbsolutePath());
			}
			new Fractiles().process(input);
		}
		System.out.println("READY");
	}

	private static void error(String msg) {
		System.err.println(msg);
		System.exit(-1);

	}

	private void process(File input) {
		// process input file
		try {
			Scanner scan = new Scanner(input);
			// open output
			PrintWriter out = new PrintWriter(new File("./output", input.getName().replace(".in", ".out")));
			try {
				// number of test cases
				int T = scan.nextInt();
				for (int i = 0; i < T; i++) {
					processTestCase(i + 1, scan, out);
				}
			} finally {
				out.close();
			}
		} catch (FileNotFoundException e) {
			error(e.getMessage());
		}

	}

	private void processTestCase(int caseNum, Scanner scan, PrintWriter out) {
		boolean debug = false;
		if (caseNum > 0) {
			debug = true;
		}
		// get K, C, S
		StringBuilder result = new StringBuilder("Case #" + caseNum + ":");
		int K = scan.nextInt(); // K original sequence length
		int C = scan.nextInt(); // C complexity
		int S = scan.nextInt(); // S available number of graduate students
		if (debug) {
			System.out.print(caseNum + "# " + K + " " + C + " " + S + " -> ");
		}
		result.append(calculateOutput(K, C, S));
		System.out.println(result.toString());
		out.println(result.toString());
	}

	private String calculateOutput(int k, int c, int s) {
		StringBuilder ret = new StringBuilder();
		if (s < k) {
			ret.append(" IMPOSSIBLE");
		} else {
			int idx = ((k > 1) && (c > 1)) ? 2 : 1;
			while (idx <= k) {
				ret.append(' ').append(idx);
				idx++;
			}
		}
		return ret.toString();
	}
}
