package googleCodeJam;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.StringTokenizer;

public class TrainTimetable {
	
	public static final int STATION_A = 1;
	public static final int STATION_B = 0;
	
	private BufferedReader in;
	private BufferedWriter out;
	private String inputFile;
	private String outputFile;
	private String line;
	private String output = "";
	private int cases;
	
	private StringTokenizer st;
	
	private int turnaround;
	private int na;
	private int nb;
	private Train[] allTrains;
	private int aStarts = 0;
	private int bStarts = 0;
	
	private static final boolean debug = true;
	
	public TrainTimetable(String inputFile){
		this.inputFile = inputFile;
		this.outputFile = this.inputFile.replace(".in", ".out");
		String output2 = "";
		try {
			in = new BufferedReader(new FileReader(this.inputFile));
			out = new BufferedWriter(new FileWriter(this.outputFile));
			
			cases = Integer.parseInt(in.readLine());
			int x;
			for(x=1;x<=cases;x++){
				init();
				//initialize some variables
				int i;
				String dep, arr;
				
				//get turnaround time
				line = in.readLine();
				turnaround = Integer.parseInt(line);
				
				//get na and nb
				line = in.readLine();
				st = new StringTokenizer(line);
				
				na = Integer.parseInt(st.nextToken());
				nb = Integer.parseInt(st.nextToken());
				
				int idx = 0;
				allTrains = new Train[na+nb];
				for(i=0;i<na;i++){
					line = in.readLine();
					st = new StringTokenizer(line);
					dep = st.nextToken();
					arr = st.nextToken();
					
					allTrains[idx] = new Train(dep,arr,Train.A_TO_B,turnaround);
					idx++;
				}
				
				for(i=0;i<nb;i++){
					line = in.readLine();
					st = new StringTokenizer(line);
					dep = st.nextToken();
					arr = st.nextToken();
					
					allTrains[idx] = new Train(dep,arr,Train.B_TO_A,turnaround);
					idx++;
				}

				Arrays.sort(allTrains);
				
				for(i=0;i<allTrains.length;i++){
					if(allTrains[i] == null)
						break;
					
					Train[] arrivals = arrivalsBefore(allTrains[i].getDeparture(),(allTrains[i].getDirection()+1)%2);
					Train bestArrival = null;
					if(arrivals != null){
						int j;
						for(j=0;j<arrivals.length;j++){
							if(arrivals[j].canReturn(allTrains[i]))
								break;
						}
						if(j<arrivals.length)
							bestArrival = arrivals[j];
					}
					
					if(bestArrival != null){
						bestArrival.setArrival(allTrains[i].getArrival());
						bestArrival.setDeparture(allTrains[i].getDeparture());
						bestArrival.setDirection(allTrains[i].getDirection());
						allTrains[i] = null;
						i--;
						output("Taking previous train back.");
					}
					else{
						if(allTrains[i].getDirection() == Train.A_TO_B){
							aStarts++;
							output("Train started at A");
						}
						else{
							bStarts++;
							output("Train started at B");
						}
					}
					Arrays.sort(allTrains,new TrainDepartureComparator());
				}
				
				output = "Case #" + x + ": "+aStarts+" "+bStarts;
				
				out.write(output);
				if(x != cases)
					out.newLine();
				
				output(output);
			}
			in.close();
			out.close();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	private void init(){
		aStarts = 0;
		bStarts = 0;
		na = 0;
		nb = 0;
		turnaround = 0;
		allTrains = null;
	}
	
	private void output(String out){
		if(TrainTimetable.debug){
			System.out.println(out);
		}
	}
	
	private Train[] arrivalsBefore(float time,int location){
		ArrayList<Integer> trains = new ArrayList<Integer>(allTrains.length);
		
		int idx = 0;
		for(Train train : allTrains){
			if(train == null)
				continue;
			if(train.getDirection() == location){
				if(train.getArrival() <= time){
					trains.add(idx);
				}
			}
			idx++;
		}
		
		if(trains.size() > 0){
			Train[] trainArray = new Train[trains.size()];
			
			for(int i=0;i<trains.size();i++){
				trainArray[i] = allTrains[trains.get(i)];
			}
			
			Arrays.sort(trainArray,new TrainArrivalComparator());
			
			return trainArray;
		}
		
		return null;
	}
	
	public static void main(String[] args){
		TrainTimetable gcj = new TrainTimetable("B-small-attempt1.in");
	}
}

class Train implements Comparable<Train>{
	public static final int A_TO_B = 0;
	public static final int B_TO_A = 1;
	
	private float departure;
	private float arrival;
	private int direction;
	private int turnaround;
	
	public Train(String departure, String arrival, int direction, int turnaround){
		String[] depHM = departure.split(":");
		String[] arrHM = arrival.split(":");
		
		this.departure = calcFloatTime(Integer.parseInt(depHM[0]),Integer.parseInt(depHM[1]));
		this.arrival = calcFloatTime(Integer.parseInt(arrHM[0]),Integer.parseInt(arrHM[1]));
		this.direction = direction;
		this.turnaround = turnaround;
	}
	
	private float calcFloatTime(int hour, int minute){
		return ((float)hour+((float)minute/60));
	}
	
	
	public float getDeparture() {
		return departure;
	}

	public float getArrival() {
		return arrival;
	}

	public int getDirection() {
		return direction;
	}

	public int getTurnaround() {
		return turnaround;
	}
	
	public void setDeparture(float departure) {
		this.departure = departure;
	}

	public void setArrival(float arrival) {
		this.arrival = arrival;
	}

	public void setDirection(int direction) {
		this.direction = direction;
	}

	public boolean canReturn(Train t){
		if(this.direction==t.direction || t.departure < this.arrival+((float)this.turnaround/60))
			return false;
		else
			return true;
	}
	
	@Override
	public int compareTo(Train o) {
		if (o==null)
			return -1;
		//if(o.getDirection()==this.direction){
		return (int)((this.departure-o.getDeparture())*100);
		/*}
		else{
			return (int)((this.arrival-o.getDeparture())*100);
		}*/
	}
}

class TrainArrivalComparator implements Comparator<Train>{

	@Override
	public int compare(Train o1, Train o2) {
		return (int)((o1.getArrival()-o2.getArrival())*100);
	}
	
}

class TrainDepartureComparator implements Comparator<Train>{

	@Override
	public int compare(Train o1, Train o2) {
		if(o1 == null)
			return 1;
		else if (o2 == null)
			return -1;
		
		return (int)((o1.getDeparture()-o2.getDeparture())*100);
	}
	
}