import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;


public class Main {

	private static final int BASE_PRODUCTION = 2;
	private static final long SECOND = 1_000_000_000;
	
	public static void main(String[] args) throws Exception {
		
		BufferedReader reader = new BufferedReader(new FileReader(new File(
				args[0])));
		BufferedWriter writer = new BufferedWriter(new FileWriter(new File(
				args[1])));
		
		int numCases = readNumberLine(reader);
		
		for (int caseIndex = 0; caseIndex < numCases; caseIndex ++)
		{
			double[] caseConf = readNumbersLine(reader);
			double farmPrice = caseConf[0];
			double farmProduction = caseConf[1];
			double goal = caseConf[2];
			
			double currentCookies = 0;
			int farms = 0;
			double time = 0;
			
			while (currentCookies < goal)
			{
				double timeToProduceFarm = timeToProduce(farmPrice, 0, farms, farmProduction);
				double timeToProduceGoal = timeToProduce(goal, 0, farms, farmProduction);
				double timeToProduceGoalWithExtraFarm = timeToProduce(goal, 0, farms + 1, farmProduction);
				
				if (timeToProduceFarm + timeToProduceGoalWithExtraFarm < timeToProduceGoal)
				{
					// buy farm
					farms ++;
					currentCookies -= farmPrice;
					time += timeToProduceFarm;
				}
				else
				{
					break;
				}
			}
			
			time += timeToProduce(goal, 0, farms, farmProduction);
			
			writer.write("Case #" + (caseIndex + 1) + ": " + Math.round(time * 10000000) / 10000000d + "\n");
		}
		
		reader.close();
		writer.close();
	}
	
	private static double timeToProduce(double goalCookies, double currentCookies, int numFarms, double farmProduction)
	{
	    return (goalCookies - currentCookies) / productionPerSecond(numFarms, farmProduction);
	}
	
	private static double cookiesInTime(double time, int numFarms, double farmProduction)
	{
		return time * productionPerSecond(numFarms, farmProduction);
	}
	
	private static double productionPerSecond(int numFarms, double farmProduction)
	{
		return BASE_PRODUCTION + numFarms * farmProduction;
	}

	private static int readNumberLine(BufferedReader reader) throws IOException {
		return Integer.parseInt(reader.readLine());
	}

	private static double[] readNumbersLine(BufferedReader reader)
			throws IOException {
		String line = reader.readLine();
		String lineParts[] = line.split(" ");
		double numbers[] = new double[lineParts.length];

		for (int i = 0; i < lineParts.length; i++) {
			numbers[i] = Double.parseDouble(lineParts[i]);
		}

		return numbers;
	}
}
