package com.ladro.google.al2;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.Set;

public class Entry {

    private final int L, D, N;

    private final Map<Integer, String> m_dictionaryHashCodes;
    private final List<List<Character>> m_validLetters;
    private final Map<Character, Integer> m_lettersToIndexPos;
    private final KnownWord[] m_knownWord;

    public static void main(String[] args) throws FileNotFoundException {
        new Entry(new Scanner(new File(args[0])));
    }

    public static void log(String format, Object... msg) {
        System.err.println(String.format(format, msg));
    }

    private String bitMaskMatrixToString(BitSet[] bsm) {
        log("size: %s", bsm.length);
        StringBuffer sb = new StringBuffer();
        for (int j = 0; j < m_lettersToIndexPos.size(); j++) {
            for (int i = 0; i < L; i++) {
                sb.append(bsm[i].get(j) ? "+" : ".");
            }
            sb.append('\n');
        }
        return sb.toString();
    }

    private class KnownWord {
        private final String m_word;
        private BitSet[] m_bitMask;

        private KnownWord(String word) {
            m_word = word;
        }

        @Override
        public String toString() {
            return bitMaskMatrixToString(m_bitMask);
        }

        public void initializeBitMask() {
            m_bitMask = new BitSet[L];
            for (int i = 0; i < m_bitMask.length; i++) {
                m_bitMask[i] = new BitSet();
            }
            for (int i = 0; i < L; i++) {
                m_bitMask[i].set(m_lettersToIndexPos.get(m_word.charAt(i)));
            }
        }
    }

    public Entry(Scanner scanner) {

        String[] parts = scanner.nextLine().split("\\s+");
        L = Integer.parseInt(parts[0]);
        D = Integer.parseInt(parts[1]);
        N = Integer.parseInt(parts[2]);
        log("L=%d,D=%d,N=%d", L, D, N);
        m_dictionaryHashCodes = new HashMap<Integer, String>();
        m_validLetters = new ArrayList<List<Character>>();
        m_lettersToIndexPos = new HashMap<Character, Integer>();
        m_knownWord = new KnownWord[D];
        Set<Character> kl = new HashSet<Character>();
        for (int lines = 0; lines < D; lines++) {
            String s = scanner.nextLine();
            for (int i = 0; i < s.length(); i++) {
                char c = s.charAt(i);
                while (m_validLetters.size() <= i) {
                    m_validLetters.add(new ArrayList<Character>());
                }
                if (!m_validLetters.get(i).contains(c)) {
                    m_validLetters.get(i).add(c);
                }
                kl.add(c);
            }
            m_knownWord[lines] = new KnownWord(s);
            m_dictionaryHashCodes.put(s.hashCode(), s);
            log("Line %d Inserted %s into dictionary", lines, s);
        }
        List<Character> kl2 = new ArrayList<Character>(kl);
        Collections.sort(kl2);
        int lp1 = 0;
        for (Character c : kl2) {
            m_lettersToIndexPos.put(c, lp1++);
        }
        log("Letter pos: %s", m_lettersToIndexPos);
        for (List<Character> list : m_validLetters) {
            Collections.sort(list);
        }
        for (int lines = 0; lines < D; lines++) {
            m_knownWord[lines].initializeBitMask();
            log("Word: %s", m_knownWord[lines].m_word);
            log("%s", m_knownWord[lines]);
        }
        log("Have %d hashcodes with %s letters", m_dictionaryHashCodes.size(), m_validLetters);
        int caseNumber = 1;
        for (int i = 0; i < N; i++) {
            String s = scanner.nextLine();
            BitSet[] row = readLine(s);
            if (row == null) {
                log("No match for %s", s);
                System.out.println(String.format("Case #%d: %d", caseNumber++, 0));
                continue;
            }
            log("Request %s", s);
            log(bitMaskMatrixToString(row));
            int count = 0;
            for (KnownWord kw : m_knownWord) {
                boolean missedCol = false;
                for (int col = 0; col < L; col++) {
                    if (!row[col].intersects(kw.m_bitMask[col])) {
                      //  log("Missed on col %d for %s", col, kw.m_word);
                        missedCol = true;
                        break;
                    }
                }
                if (!missedCol) {
                    count++;
                }
            }
            System.out.println(String.format("Case #%d: %d", caseNumber++, count));
        }
    }

    private String letterPossiblesToString(List<List<Character>> letterPossibles) {
        StringBuffer sb = new StringBuffer();
        for (int i = 0; i < letterPossibles.size(); i++) {
            if (letterPossibles.get(i).isEmpty()) {
                return "";
            }
            if (letterPossibles.get(i).size() == 1) {
                sb.append(letterPossibles.get(i).get(0));
            } else {
                sb.append("(");
                for (Character c : letterPossibles.get(i)) {
                    sb.append(c);
                }
                sb.append(")");
            }
        }
        return sb.toString();
    }

    private BitSet[] readLine(String alien) {
        StringBuffer inParen = new StringBuffer();
        boolean inParenBool = false;
        List<List<Character>> letterPossibles = new ArrayList<List<Character>>();
        log("Examing %s", alien);
        for (int i = 0; i < alien.length(); i++) {
            if (alien.charAt(i) == '(') {
                inParen.setLength(0);
                inParenBool = true;
            } else if (alien.charAt(i) == ')') {
                if (inParen.length() == 0) {
                    log("Invalid parent grouping");
                    return null;
                }
                letterPossibles.add(new ArrayList<Character>());
                for (int j = 0; j < inParen.length(); j++) {
                    letterPossibles.get(letterPossibles.size() - 1).add(inParen.charAt(j));
                }
                inParenBool = false;
            } else {
                char c = alien.charAt(i);
                if (inParenBool) {
                    if (m_validLetters.get(letterPossibles.size()).contains(c)) {
                        inParen.append(c);
                    }
                } else {
                    if (!m_validLetters.get(letterPossibles.size()).contains(c)) {
                        log("Invalid sole character %s at pos %d", c, i);
                        return null;
                    }
                    letterPossibles.add(new ArrayList<Character>());
                    if (!letterPossibles.get(letterPossibles.size() - 1).contains(c)) {
                        letterPossibles.get(letterPossibles.size() - 1).add(c);
                    }
                }
            }
        }
        log("IN  %s", alien);
        log("OUT %s", letterPossiblesToString(letterPossibles));

        BitSet[] ret = new BitSet[m_lettersToIndexPos.size()];
        for (int i = 0; i < ret.length; i++) {
            ret[i] = new BitSet();
        }
        for (int i = 0; i < L; i++) {
            for (Character c : letterPossibles.get(i)) {
                log("Setting ret %d char %s in pos %d", i, c, m_lettersToIndexPos.get(c));
                ret[i].set(m_lettersToIndexPos.get(c));
            }
        }

        return ret;
    }

    private static String logBoard(BitSet bs) {
        StringBuffer sb = new StringBuffer();
        for (int i = 0; i < bs.size(); i++) {
            if (bs.get(i)) {
                sb.append("+");
            } else {
                sb.append(".");
            }
        }
        return sb.toString();
    }
}
