package com.ladro.google.roller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Scanner;

public class Coaster {

	private static class NaiveWay implements Iterator<Long> {

		private final int[] m_groups;
		private final int m_r;
		private final int m_k;
		private int m_pos, m_numberTrips;

		private NaiveWay(int[] groups, int R, int k) {
			m_groups = groups;
			m_r = R;
			m_k = k;
		}

		@Override
		public boolean hasNext() {
			return m_numberTrips < m_r;
		}

		@Override
		public Long next() {
			long numberPeople = 0;
			int initial = m_pos;
			while (numberPeople + m_groups[m_pos] <= m_k) {
				numberPeople += m_groups[m_pos];
				m_pos++;
				if (m_pos >= m_groups.length) {
					m_pos = 0;
				}
				if (m_pos == initial) {
					break;
				}
			}
			m_numberTrips++;
			return numberPeople;
		}

		@Override
		public void remove() {
			throw new IllegalStateException();
		}

	}

	private static class AddingValues {
		private final List<Integer> m_tripPos;
		private final List<Long> m_euros;
		private final int m_repeatPos;
		private final long m_rosy;
		private final int m_ringSize;
		private final long m_ringValue;

		private int initialRingSize() {
			return m_tripPos.size();
		}

		private long initialRingValue() {
			return m_rosy;
		}

		private Iterator<Long> getAdditionalTrips() {
			return getTrips(m_repeatPos);
		}

		private Iterator<Long> getTrips(final int initialPos) {
			return new Iterator<Long>() {
				private int myPos;
				{
					myPos = 0;
					while (myPos < m_tripPos.size()) {
						if (m_tripPos.get(myPos) == initialPos) {
							break;
						}
						myPos++;
					}
					if (myPos == m_tripPos.size()) {
						throw new IllegalStateException();
					}
				}

				@Override
				public boolean hasNext() {
					return true;
				}

				@Override
				public Long next() {
					long ret = m_euros.get(myPos);
					myPos++;
					if (myPos >= m_euros.size()) {
						myPos = 0;
					}
					return ret;
				}

				@Override
				public void remove() {
					throw new IllegalStateException();
				}
			};
		}

		private AddingValues(int[] groups, int R, int k) {
			int pos = 0;
			int repeatPos = -1;
			long rosy = 0;
			log("Looking at R: %d, groups %s", R, Arrays.toString(groups));
			List<Integer> tripPos = new ArrayList<Integer>();
			List<Long> euros = new ArrayList<Long>();
			boolean overLimit = false;
			while (!tripPos.contains(pos)) {
				int initial = pos;
				long sum = 0;
				while (sum + groups[pos] <= k) {
					sum += groups[pos];
					pos++;
					if (pos >= groups.length) {
						pos = 0;
					}
					if (pos == initial) {
						break;
					}
				}
				if (sum == 0) {
					throw new IllegalStateException("Has value > k");
				}
				rosy += sum;
				tripPos.add(initial);
				euros.add(sum);
				if (euros.size() > R) {
					log("hit limit");
					overLimit = true;
					break;
				}
			}
			m_rosy = rosy;
			if (overLimit) {
				repeatPos = 0;
			} else {
				repeatPos = pos;
			}
			m_tripPos = Collections.unmodifiableList(tripPos);
			m_euros = Collections.unmodifiableList(euros);
			m_repeatPos = repeatPos;
			// now go through again to find repeating loop
			int rP = m_repeatPos;
			long rV = 0;
			int rS = 0;
			int miniK = 0;
			while (true) {
				if (miniK + groups[rP] > k) {
					rV += miniK;
					miniK = 0;
					rS++;
				}
				miniK += groups[rP];
				rP++;
				if (rP >= groups.length) {
					rP = 0;
				}
				if (rP == m_repeatPos) {
					break;
				}
			}
			if (miniK != 0) {
				rV += miniK;
				rS++;
			}
			m_ringSize = rS;
			m_ringValue = rV;
			log("Initial ring size: %d, initial value: %d, repeating ring size: %d, repeating value: %d, repeat pos: %d, k: %d, overlimit: %s",
					initialRingSize(), initialRingValue(), ringSize(), ringValue(), repeatPos, k, overLimit);
			for (int i = 0; i < tripPos.size(); i++) {
				log("%d : %d", tripPos.get(i), euros.get(i));
			}
		}

		private int ringSize() {
			return m_ringSize;
		}

		public long ringValue() {
			return m_ringValue;
		}

	}

	private static long solveNaive(int[] groups, int R, int k) {
		Iterator<Long> naiveWay = new NaiveWay(groups, R, k);
		long ret = 0;
		long numberTrips = 0;
		while (naiveWay.hasNext()) {
			ret += naiveWay.next();
			numberTrips++;
			// log("NAIVE: Trip # %d : %d", numberTrips, ret);
		}
		log("For naive did %d trips getting %d euros", numberTrips, ret);
		return ret;
	}

	private static long solve(int[] groups, int pR, int k) {
		AddingValues av = new AddingValues(groups, pR, k);
		int remainingTrips = pR;
		int euros = 0;
		if (remainingTrips > av.initialRingSize()) {
			remainingTrips -= av.initialRingSize();
			euros += av.initialRingValue();
		}
		log("Start with euros %d remainging trips %d", euros, remainingTrips);
		int loopCount = remainingTrips / av.ringSize();
		long numberTrips = loopCount * av.ringSize();
		euros += loopCount * av.ringValue();
		Iterator<Long> eurosCounter = av.getAdditionalTrips();
		remainingTrips -= numberTrips;
		log("Before final move.  Number loops: %d, trips: %d, euros: %d, remaining trips: %d", loopCount, numberTrips, euros, remainingTrips);
		while (remainingTrips > 0) {
			euros += eurosCounter.next();
			remainingTrips--;
		}
		log("returning %d", euros);
		return euros;
	}

	private static void log(String format, Object... args) {
		System.err.println(String.format(format, args));
	}

	private static int[] getInts(Scanner scanner) {
		String[] parts = scanner.nextLine().split("\\s+");
		int[] ret = new int[parts.length];
		for (int pos = 0; pos < ret.length; pos++) {
			ret[pos] = Integer.parseInt(parts[pos]);
		}
		return ret;
	}

	public static void main(String[] args) {
		Scanner s = new Scanner(System.in);
		int numberCases = Integer.parseInt(s.nextLine());
		for (int caseNumber = 1; caseNumber <= numberCases; caseNumber++) {
			StringBuffer output = new StringBuffer("Case #" + caseNumber + ": ");
			int[] RkN = getInts(s);
			int[] groups = getInts(s);
			long eurosNaive = solveNaive(groups, RkN[0], RkN[1]);
			long euros = solve(groups, RkN[0], RkN[1]);
			//output.append(eurosNaive + " " + euros);
			output.append(eurosNaive);
			System.out.println(output.toString());
		}
	}
}
