package com.ladro.google.watershed;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.concurrent.atomic.AtomicInteger;

public class Entry {

    private final int m_numberMaps;
    private int m_height, m_width;
    private int m_caseNumber;

    public static void main(String[] args) throws FileNotFoundException {
        new Entry(new Scanner(new File(args[0])));
    }

    public static void log(String format, Object... msg) {
        System.err.println(String.format(format, msg));
    }

    private Node[][] m_board;
    private final Scanner m_scanner;

    public Entry(Scanner scanner) {
        m_scanner = scanner;
        m_caseNumber = 1;
        m_numberMaps = Integer.parseInt(scanner.nextLine());
        log("Have %d maps", m_numberMaps);
        for (int i = 0; i < m_numberMaps; i++) {
            readMap();
            processMap();
            fixLowestLetters();
            caseOutput();
            m_caseNumber++;
        }
    }

    private final Map<Integer, Character> m_intBasinsToColor = new HashMap<Integer, Character>();

    private final String ALPHABET = "abcdefghijklmnopqrstuvwxyz";

    private void fixLowestLetters() {
        m_intBasinsToColor.clear();
        int alphaPos = 0;
        m_intBasinsToColor.put(m_board[0][0].getBasin(), ALPHABET.charAt(alphaPos++));
        log("Setting color %s to %s", m_board[0][0].getBasin(), m_intBasinsToColor.get(m_board[0][0].getBasin()));
        for (int row = 0; row < m_height; row++) {
            for (int col = 0; col < m_width; col++) {
                if (!m_intBasinsToColor.containsKey(m_board[row][col].getBasin())) {
                    m_intBasinsToColor.put(m_board[row][col].getBasin(), ALPHABET.charAt(alphaPos++));
                    log("Setting color %s to %s", m_board[row][col].getBasin(), m_intBasinsToColor.get(m_board[row][col].getBasin()));
                }
            }
        }
    }

    private void processMap() {
        log("xxxxxxxxxxxxxxxxxx");
        final List<Node> toProcess1 = new ArrayList<Node>();
        for (int row = 0; row < m_height; row++) {
            for (int col = 0; col < m_width; col++) {
                toProcess1.add(m_board[row][col]);
            }
        }
        Collections.sort(toProcess1, new Comparator<Node>() {

            @Override
            public int compare(Node o1, Node o2) {
                return new Integer(o2.getAltitude()).compareTo(o1.getAltitude());
            }
        });
        Iterator<Node> it = toProcess1.iterator();
        while (it.hasNext()) {
            Node node = it.next();
            log("in hopper %s", node);
            Node lowest = null;
            for (Node neighbor : node.getNeighbors()) {
                if (neighbor == null) {
                    continue;
                }
                if (neighbor.getAltitude() > node.getAltitude()) {
                    continue;
                }
                if (lowest == null) {
                    if (neighbor.getAltitude() >= node.getAltitude()) {
                        continue;
                    }
                    lowest = neighbor;
                } else {
                    if (lowest.getAltitude() > neighbor.getAltitude()) {
                        lowest = neighbor;
                    }
                }
            }
            log("For node %s have these lowest %s", node, lowest);
            if (lowest == null) {
                if (!node.isBasinSet()) {
                    node.setBasin(getNewBasinColor());
                    log("Since by self set color on %s", node);
                }
                continue;
            }
            Integer basinColor = node.getBasin();
            if (basinColor == null) { // should make a constant
                basinColor = lowest.getBasin();
            }
            if (basinColor == null) { // should make a constant
                basinColor = getNewBasinColor();
            }
            int change = floodBasin(node, lowest, basinColor);
            log("Flooding %s and %s flipped %d", node, lowest, change);
        }
    }

    private int floodBasin(Node node, Node neighborToUse, Integer basinColor) {
        int change = 0;
        if (node != null && !basinColor.equals(node.getBasin())) {
            for (Node other : getInBasin(node.getBasin())) {
                log("changing1 %s to %s", other, basinColor);
                change++;
                other.setBasin(basinColor);
            }
            change++;
            node.setBasin(basinColor);
        }
        if (neighborToUse != null && !basinColor.equals(neighborToUse.getBasin())) {
            for (Node other : getInBasin(neighborToUse.getBasin())) {
                log("changing2 %s to %s", other, basinColor);
                change++;
                other.setBasin(basinColor);
            }
            change++;
            neighborToUse.setBasin(basinColor);
        }
        return change;
    }

    private static final AtomicInteger m_basinIds = new AtomicInteger();

    private static int getNewBasinColor() {
        return m_basinIds.incrementAndGet();
    }

    private void readMap() {
        m_basinIds.set(0);
        String[] parts = m_scanner.nextLine().split("\\s+");
        m_height = Integer.parseInt(parts[0]);
        m_width = Integer.parseInt(parts[1]);
        m_board = new Node[m_height][m_width];
        log("H=%d,W=%d", m_height, m_width);
        for (int row = 0; row < m_height; row++) {
            if (! m_scanner.hasNext()) {
                throw new IllegalStateException("Problem on row " + row);
            }
            String[] parts2 = m_scanner.nextLine().split("\\s+");
            for (int col = 0; col < m_width; col++) {
                m_board[row][col] = new Node(row, col, Integer.parseInt(parts2[col]));
            }
        }
        log("Size h=%d,w=%d", m_height, m_width);
    }

    private static enum Direction {
        N(-1, 0), W(0, -1), E(0, 1), S(1, 0);
        private final int m_rowChange;
        private final int m_colChange;

        private Direction(int rowChange, int colChange) {
            m_rowChange = rowChange;
            m_colChange = colChange;
        }
    }

    private void caseOutput() {
        System.out.println("Case #" + m_caseNumber + ":");
        for (int row = 0; row < m_height; row++) {
            StringBuffer sb = new StringBuffer();
            for (int col = 0; col < m_width; col++) {
                if (sb.length() > 0) {
                    sb.append(" ");
                }
                sb.append(m_intBasinsToColor.get(m_board[row][col].getBasin()));
            }
            System.out.println(sb.toString());
        }
    }

    private class Coord {

        private final int m_row;
        private final int m_col;

        @Override
        public int hashCode() {
            final int prime = 31;
            int result = 1;
            result = prime * result + getOuterType().hashCode();
            result = prime * result + m_col;
            result = prime * result + m_row;
            return result;
        }

        @Override
        public boolean equals(Object obj) {
            if (this == obj)
                return true;
            if (obj == null)
                return false;
            if (getClass() != obj.getClass())
                return false;
            Coord other = (Coord) obj;
            if (!getOuterType().equals(other.getOuterType()))
                return false;
            if (m_col != other.m_col)
                return false;
            if (m_row != other.m_row)
                return false;
            return true;
        }

        public Coord(int row, int col) {
            m_row = row;
            m_col = col;
        }

        private Entry getOuterType() {
            return Entry.this;
        }

    }

    // more efficient ways to do this
    private List<Node> getInBasin(Integer basin) {
        List<Node> ret = new ArrayList<Node>();
        if (basin == null) {
            return ret;
        }
        for (int col = 0; col < m_width; col++) {
            for (int row = 0; row < m_height; row++) {
                if (basin.equals(m_board[row][col].getBasin())) {
                    ret.add(m_board[row][col]);
                }
            }
        }
        return ret;
    }

    private class Node {
        private final Coord m_coord;
        private final int m_altitude;
        private Integer m_basin = null;

        @Override
        public int hashCode() {
            final int prime = 31;
            int result = 1;
            result = prime * result + getOuterType().hashCode();
            result = prime * result + ((m_coord == null) ? 0 : m_coord.hashCode());
            return result;
        }

        @Override
        public boolean equals(Object obj) {
            if (this == obj)
                return true;
            if (obj == null)
                return false;
            if (getClass() != obj.getClass())
                return false;
            Node other = (Node) obj;
            if (!getOuterType().equals(other.getOuterType()))
                return false;
            if (m_coord == null) {
                if (other.m_coord != null)
                    return false;
            } else if (!m_coord.equals(other.m_coord))
                return false;
            return true;
        }

        private Node[] getNeighbors() {
            Node[] ret = new Node[4];
            int i = 0;
            for (Direction d : Direction.values()) {
                int newRow = m_coord.m_row + d.m_rowChange;
                int newCol = m_coord.m_col + d.m_colChange;
                if (newRow < 0 || newCol < 0 || newRow >= m_height || newCol >= m_width) {
                    ret[i++] = null;
                } else {
                    ret[i++] = m_board[newRow][newCol];
                }
            }
            return ret;
        }

        public Coord getCoords(Direction d) {
            return new Coord(m_coord.m_row + d.m_rowChange, m_coord.m_col + d.m_colChange);
        }

        private Node(int row, int col, int altitude) {
            m_coord = new Coord(row, col);
            m_altitude = altitude;
        }

        @Override
        public String toString() {
            return "(" + m_coord.m_row + "," + m_coord.m_col + ":" + getAltitude() + ":" + (isBasinSet() ? getBasin() : " ") + ")";
        }

        public boolean isBasinSet() {
            return getBasin() != null;
        }

        public Integer getBasin() {
            return m_basin;
        }

        public void setBasin(Integer basin) {
            m_basin = basin;
        }

        public int getAltitude() {
            return m_altitude;
        }

        private Entry getOuterType() {
            return Entry.this;
        }

    }
}
