/**
 * Google Code Jam 09
 */
package org.eu.cybot.gcj09.alienlanguage;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Stack;

/**
 * @author CyBot
 *Alien Language
 */
public class AlienLanguage {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		File in = new File("/tmp/A-large.in");
		File out = new File("out.txt");
		BufferedReader br = null;
		BufferedWriter bw = null;
		Letter start = new Letter('!');

		try
		{
			br = new BufferedReader(new FileReader(in));
			bw = new BufferedWriter(new FileWriter(out));
		}
		catch (Exception e) {
			System.err.println("Unable to open file: " + e);
			return;
		}
		try {
			// Parse first line
			String line = br.readLine();

			String[] tokens = line.split(" ");
			if (tokens.length != 3)
			{
				System.err.println("Invalid file format (first line)");
				return;
			}
			int l = Integer.parseInt(tokens[0]);
			int d = Integer.parseInt(tokens[1]);
			int n = Integer.parseInt(tokens[2]);

			// Read dictionary, build parse tree
			for (int i = 0; i < d; ++i)
			{
				line = br.readLine();
				Letter node = start;
				
				if (line.length() != l)
				{
					System.err.println("Invalid file format (dictionary word length)");
					return;
				}

				for (int j = 0; j < line.length(); ++j)
				{
					node = node.addNext(line.charAt(j));
				}
			}

			// Read wordlist
			for (int i = 0; i < n; ++i)
			{
				line = br.readLine();
				Stack<Letter> matches = new Stack<Letter>();
				matches.push(start);

				for (int j = 0; j < line.length(); ++j)
				{
					if (matches.isEmpty())
						break;

					char c = line.charAt(j);

					if (c == '(')
					{
						// List of possibilities

						// Build string of possibilities
						String possibilities = new String();
						for (;;)
						{
							if (++j == line.length())
							{
								System.err.println("Invalid file format (Missing closing Parenthesis)");
								return;
							}
							c = line.charAt(j);
							if (c == '(')
							{
								System.err.println("Invalid file format (Unmatched Parenthesis)");
								return;
							}
							if (c == ')')
								break;
							possibilities += c;
						}
						// Now find matches
						Stack<Letter> new_matches = new Stack<Letter>();

						while (!matches.empty())
						{
							Letter current = matches.pop();
							for (int k = 0; k < possibilities.length(); ++k)
							{
								c = possibilities.charAt(k);
								Letter next = current.getNext(c);
								if (next != null)
									new_matches.push(next);
							}
						}
						matches = new_matches;
					}
					else
					{
						// Single character

						Stack<Letter> new_matches = new Stack<Letter>();
						while (!matches.empty())
						{
							Letter next = matches.pop().getNext(c);
							if (next != null)
								new_matches.push(next);
						}
						matches = new_matches;
					}
				}

				bw.write("Case #" + (i+1) + ": " + matches.size() + "\n");
			}
			br.close();
			bw.close();
		} catch (IOException e) {
			e.printStackTrace();
			return;
		}
	}
}
