/**
 * Google Code Jam 09
 */
package org.eu.cybot.gcj09.watersheds;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

/**
 * @author cybot
 * Watersheds
 */
public class Watersheds {

	/**
	 * Set a label in the given map, on given cell and all following cells.
	 * 
	 * Following cells means cells to which water would flow from this cell.
	 * @param map the map
	 * @param x x-coordinate of the cell
	 * @param y y-coordinate of the cell
	 * @param label proposed label (if no other label is hit)
	 */
	public static char setLabels(Map map, int x, int y, char label)
	{
		if (map.getLabel(x, y) != '!')
			return map.getLabel(x, y);

		int lowest = map.getAltitude(x, y);

		int altitude, new_x = 0, new_y = 0;
		if (y > 0)
		{
			altitude = map.getAltitude(x, y-1);
			if (altitude < lowest)
			{
				lowest = altitude;
				new_x = x;
				new_y = y-1;
			}
		}
		if (x > 0)
		{
			altitude = map.getAltitude(x-1, y);
			if (altitude < lowest)
			{
				lowest = altitude;
				new_x = x-1;
				new_y = y;
			}
		}
		if (x < (map.getWidth()-1))
		{
			altitude = map.getAltitude(x+1, y);
			if (altitude < lowest)
			{
				lowest = altitude;
				new_x = x+1;
				new_y = y;
			}
		}
		if (y < (map.getHeight()-1))
		{
			altitude = map.getAltitude(x, y+1);
			if (altitude < lowest)
			{
				lowest = altitude;
				new_x = x;
				new_y = y+1;
			}
		}

		if (lowest == map.getAltitude(x, y))
		{
			// Sink
			map.setLabel(x, y, label);
			return label;
		}

		label = setLabels(map, new_x, new_y, label);
		map.setLabel(x, y, label);
		return label;
	}

	/**
	 * main
	 * @param args
	 */
	public static void main(String[] args) {
		// TODO Auto-generated method stub
		File in = new File("/tmp/B-small-attempt0.in");
		File out = new File("out_ws.txt");
		BufferedReader br = null;
		BufferedWriter bw = null;

		try
		{
			br = new BufferedReader(new FileReader(in));
			bw = new BufferedWriter(new FileWriter(out));
		}
		catch (Exception e) {
			System.err.println("Unable to open file: " + e);
			return;
		}
		try {
			// Parse first line
			String line = br.readLine();

			int T = Integer.parseInt(line);
			for (int m = 0; m < T; ++m)
			{
				// Parse first line of the map
				line = br.readLine();
				String[] tokens = line.split(" ");
				if (tokens.length != 2)
				{
					System.err.println("Invalid file format (map " + m + " header)");
					return;
				}
				int H = Integer.parseInt(tokens[0]);
				int W = Integer.parseInt(tokens[1]);

				// Build map
				Map map = new Map(W,H);

				for (int y = 0; y < H; ++y)
				{
					line = br.readLine();
					tokens = line.split(" ");
					if (tokens.length != W)
					{
						System.err.println("Invalid file format (map " + m + "line " + y + ")");
						return;
					}

					for (int x = 0; x < W; ++x)
					{
						map.addCell(x, y, Integer.parseInt(tokens[x]));
					}
				}
				
				bw.write("Case #" + (m+1) + ":\n");

				// Label map
				char label = 'a';

				for (int y = 0; y < H; ++y)
				{
					for (int x = 0; x < W; ++x)
					{
						if (map.getLabel(x, y) == '!')
						{
							char new_label = setLabels(map, x, y, label);
							if (new_label == label)
								label++;
						}
					}
				}
				bw.write(map.toString());
			}
			
			br.close();
			bw.close();
		} catch (IOException e) {
			e.printStackTrace();
			return;
		}
	}

}
