/**
 * Google Code Jam 09
 */
package org.eu.cybot.gcj09.alienlanguage;

import java.util.Iterator;
import java.util.Vector;

/**
 * @author cybot
 * A letter of the alien language
 * Has a list of possible successors
 */
public class Letter
{
	private Vector<Letter> next;
	private char letter;

	/**
	 * Create a new letter
	 * @param c character code for this letter
	 */
	public Letter(char c)
	{
		letter = c;
		next = new Vector<Letter>();
	}

	/**
	 * Return the character code for the stored letter
	 * @return the char
	 */
	public char get()
	{
		return letter;
	}

	/**
	 * Add a new successor
	 * @param next the successor letter
	 */
	public void addNext(Letter next) {
		this.next.add(next);
	}

	/**
	 * Add a new successor
	 * @param next the character code of the successor letter
	 * @return the successor letter
	 */
	public Letter addNext(char next) {
		Letter l = getNext(next);
		if (l  == null)
		{
			l = new Letter(next);
			this.next.add(l);
		}
		return l;
	}

	/**
	 * Return whether this letter has a given successor
	 * @param c Successor letter to look for
	 * @return true if successor found
	 */
	public boolean hasNext(char c)
	{
		for (Iterator<Letter> it = next.iterator(); it.hasNext();)
		{
			if (it.next().get() == c)
				return true;
		}
		return false;
	}

	/**
	 * Return given successor letter, or null if not found
	 * @param c Successor letter to look for
	 * @return the successor or null
	 */
	public Letter getNext(char c)
	{
		for (Iterator<Letter> it = next.iterator(); it.hasNext();)
		{
			Letter l = it.next();

			if (l.get() == c)
				return l;
		}
		return null;
	}

	public String toString()
	{
		return this.toString("");
	}

	private String toString(String prefix)
	{
		String ret = prefix + letter + "\n";

		prefix += ' ';
		for (Iterator<Letter> it = next.iterator(); it.hasNext();)
		{
			ret += it.next().toString(prefix);
		}
		return ret;
	}
}
