/**
 * Google Code Jam 09
 */
package org.eu.cybot.gcj09.watersheds;

/**
 * @author cybot
 * A map of cells
 */
public class Map {
	private int height, width;
	private Cell[][] map;

	/**
	 * Create a Map with the given height and width
	 * @param width width
	 * @param height height
	 */
	public Map(int width, int height)
	{
		this.height = height;
		this.width = width;
		map = new Cell[height][width];
	}

	/**
	 * Return the height of the map
	 * @return the height
	 */
	public int getHeight()
	{
		return height;
	}

	/**
	 * Return the width of the map
	 * @return the width
	 */
	public int getWidth()
	{
		return width;
	}


	/**
	 * Add a new cell to the map
	 * @param x x-coordinate of the cell
	 * @param y y-coordinate of the cell
	 * @param altitude the altitude
	 */
	public void addCell(int x, int y, int altitude)
	{
		map[y][x] = new Cell(altitude);
	}

	/**
	 * Get the altitude of the given cell
	 * @param x x-coordinate of the cell
	 * @param y y-coordinate of the cell
	 * @return the altitude
	 */
	public int getAltitude(int x, int y)
	{
		return map[y][x].getAltitude();
	}

	/**
	 * Get the label of the given cell
	 * @param x x-coordinate of the cell
	 * @param y y-coordinate of the cell
	 * @return the label
	 */
	public char getLabel(int x, int y)
	{
		return map[y][x].getLabel();
	}

	/**
	 * Set the label of the given cell
	 * @param x x-coordinate of the cell
	 * @param y y-coordinate of the cell
	 * @param label the new label
	 */
	public void setLabel(int x, int y, char label)
	{
		map[y][x].setLabel(label);
	}

	/**
	 * Return a string representing the map
	 * Every cell is represented by its label
	 * @return string representation of the map
	 */
	public String toString()
	{
		String ret = new String();

		for (int h = 0; h < height; ++h)
		{
			for (int w = 0; w < width; ++w)
			{
				ret += map[h][w].getLabel();
				if (w < (width-1))
					ret += ' ';
			}
			ret += '\n';
		}
		return ret;
	}

	/**
	 * Return a string representing the map
	 * Every cell is represented by its altitude
	 * @return string representation of the map
	 */
	public String toStringAltitudes()
	{
		String ret = new String();

		for (int h = 0; h < height; ++h)
		{
			for (int w = 0; w < width; ++w)
			{
				ret += map[h][w].getAltitude();
				if (w < (width-1))
					ret += ' ';
			}
			ret += '\n';
		}
		return ret;
	}
}
