import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Scanner;

public class Main {

	private static final String aFileName = "input.in";
	final static Charset ENCODING = StandardCharsets.UTF_8;

	private static int[][] board;
	private static int cases;
	private static int[] winner;
	private static int r;

	public static void main(String[] args) {
		Path path = Paths.get(aFileName);
		try (Scanner scanner = new Scanner(path, ENCODING.name())) {

			cases = scanner.nextInt();

			winner = new int[cases];
			for (int h = 0; h < cases; h++)
				winner[h] = 0;

			for (r = 0; r < cases; r++) {

				board = new int[4][4];
				Boolean hasEmpty = false;
				for (int a = 0; a < 4; a++) {
					String c = scanner.next();
					for (int b = 0; b < 4; b++) {
						board[a][b] = function(c.charAt(b));
						if (!hasEmpty)
							if (board[a][b] == 0)
								hasEmpty = true;
					}
				}
				decideWinner(hasEmpty);
				System.out.println("Case #" + Integer.toString(r + 1)
						+ ": Winner" + Integer.toString(winner[r]));

			}

			writeToFile();

		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	private static void writeToFile() {

		File file = new File("output.txt");

		// if file doesnt exists, then create it
		try {
			if (!file.exists()) {
				
					file.createNewFile();
			}
			FileWriter fw = new FileWriter(file.getAbsoluteFile());
			BufferedWriter bw = new BufferedWriter(fw);
			for (int k = 0; k < cases; k++) {
				String content = "Case #" + Integer.toString(k + 1)
						+ winner(k);
				bw.write(content);
			}
			bw.close();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

	private static String winner(int k) {

		switch (winner[k]) {
		case 2:
			return ": Game has not completed\n";
		case 1:
			return ": X won\n";
		case 0:
			return ": Draw\n";
		case -1:
			return ": O won\n";
		}

		return null;
	}

	private static void decideWinner(Boolean hasEmpty) {

		for (int k = 0; k < 4; k++) {
			int sum = board[k][0] + board[k][1] + board[k][2] + board[k][3];
			Boolean hasT = false;
			for (int j = 0; j < 4; j++) {
				if (board[k][j] == 2)
					hasT = true;
			}
			if (sumToWinner(sum, hasT))
				return;
		}

		for (int k = 0; k < 4; k++) {
			int sum = board[0][k] + board[1][k] + board[2][k] + board[3][k];
			Boolean hasT = false;
			for (int j = 0; j < 4; j++) {
				if (board[j][k] == 2)
					hasT = true;
			}
			if (sumToWinner(sum, hasT))
				return;
		}

		int sum = board[0][0] + board[1][1] + board[2][2] + board[3][3];
		Boolean hasT = false;
		for (int j = 0; j < 4; j++) {
			if (board[j][j] == 2)
				hasT = true;
		}
		if (sumToWinner(sum, hasT))
			return;

		sum = board[0][3] + board[1][2] + board[2][1] + board[3][0];
		hasT = false;
		for (int j = 0; j < 4; j++) {
			if (board[j][3 - j] == 2)
				hasT = true;
		}
		if (sumToWinner(sum, hasT))
			return;

		if (hasEmpty) {
			winner[r] = 2; // not completed
		}

	}

	private static Boolean sumToWinner(int sum, Boolean hasT) {
		if (sum >= 4) {
			winner[r] = 1;
			return true;
		} else {
			if (sum == -4) {
				winner[r] = -1;
				return true;
			} else {
				if (sum == -1) {
					if (hasT) {
						winner[r] = -1;
						return true;
					}
				}
			}
		}
		return false;
	}

	private static int function(char c) {
		switch (c) {
		case 'X':
			return 1;
		case 'T':
			return 2;
		case 'O':
			return -1;
		case '.':
			return 0;

		}
		return 0;
	}
}
