package com.tagliola.codejam2014.qualify.cookieclicker;

import java.math.*;

class CookieClickerCase
{
    private static final BigDecimal DEFAULT_RATE = BigDecimal.valueOf(2);
    private static final MathContext MATH_CONTEXT = new MathContext(32, RoundingMode.UP);
    private final BigDecimal theFarmCost;
    private final BigDecimal theFactoryRate;
    private final BigDecimal theTarget;
    
    private BigDecimal theNumberOfFactories = BigDecimal.ZERO;
    private BigDecimal theTime = BigDecimal.ZERO;

    public CookieClickerCase(BigDecimal aFarmCost, BigDecimal aFactoryRate, BigDecimal aTarget)
    {
        theFarmCost = aFarmCost;
        theFactoryRate = aFactoryRate;
        theTarget = aTarget;
    }

    public BigDecimal calculate()
    {
        return solve().setScale(7, RoundingMode.UP);
    }

    private BigDecimal solve()
    {
        BigDecimal myCurrentRate = getCurrentRate();
        BigDecimal myTimeToTarget = theTarget.divide(myCurrentRate, MATH_CONTEXT);
        BigDecimal myTimeToFactory = theFarmCost.divide(myCurrentRate, MATH_CONTEXT);
        BigDecimal myTimeToTargetWithFactory = newTimeToTarget(myCurrentRate).add(myTimeToFactory);

        if (myTimeToTarget.compareTo(myTimeToTargetWithFactory) <= 0)
        {
            return theTime.add(myTimeToTarget);
        }
        theTime = theTime.add(myTimeToFactory);
        theNumberOfFactories = theNumberOfFactories.add(BigDecimal.ONE);
        
        return solve();
    }

    private BigDecimal newTimeToTarget(BigDecimal aCurrentRate)
    {
        BigDecimal myNewRate = aCurrentRate.add(theFactoryRate);
        BigDecimal myNewTimeToTarget = theTarget.divide(myNewRate, MATH_CONTEXT);
        return myNewTimeToTarget;
    }

    private BigDecimal getCurrentRate()
    {
        BigDecimal myMultiply = theFactoryRate.multiply(theNumberOfFactories);
        return myMultiply.add(DEFAULT_RATE);
    }
}
