package com.tagliola.codejam2014.qualify.mineweeper;

import static java.lang.Math.*;

import com.google.common.base.Strings;

class MineSweeperCase
{
    private static final String CLICK = "c";
    private static final String EMPTY = ".";
    private static final String MINE = "*";
    private static final String IMPOSSIBLE = "Impossible";
    private final int theRows;
    private final int theCells;
    private final int theMines;

    public MineSweeperCase(int aRows, int aCells, int aMines)
    {
        theRows = aRows;
        theCells = aCells;
        theMines = aMines;
    }

    public String calculate()
    {
        return solver();
    }

    private String solver()
    {
        int myReservedCells = (theRows == 1 || theCells == 1) ? 2 : 4;
        if (theMines > (theCells * theRows) - myReservedCells)
        {
            return System.lineSeparator() + IMPOSSIBLE;
        }
        
        int myEmptyCells = (theRows * theCells) - theMines - myReservedCells;
        
        StringBuilder myResult = new StringBuilder();
        
        for(int myRow = 1; myRow <= theRows; myRow++)
        {
            StringBuilder myLine = new StringBuilder();
            
            int myCells = theCells;
            if (myRow == 1)
            {
                myLine.append(CLICK).append(EMPTY);
                myCells -= 2;
            }
            if (myRow == 2)
            {
                myLine.append(EMPTY).append(EMPTY);
                myCells -= 2;
            }
            
            int myEmptyCellsOnCurrentLine = min(myEmptyCells, myCells);
            
            if (myEmptyCellsOnCurrentLine > 0)
            {
                myEmptyCells -= myEmptyCellsOnCurrentLine;
                myLine.append(Strings.repeat(EMPTY, myEmptyCellsOnCurrentLine));
            }
            
            int myMinesOnCurrentLine = theCells - myLine.length();
            if (myMinesOnCurrentLine > 0)
            {
                myLine.append(Strings.repeat(MINE, myMinesOnCurrentLine));
            }
            
            if (myLine.length() > theCells)
            {
                myLine.setLength(theCells);
            }
            
            myResult.append(System.lineSeparator() + myLine);
        }
        
        return myResult.toString();
    }
}
