package com.forthgo.google;

import com.forthgo.math.ArrayPartitionIterator;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.StringTokenizer;

/**
 * Created by Xan Gregg.
 * Date: 5/7/11
 */
public class GoroSort {
    public static void main(String[] args) {
        try {
            BufferedReader in = new BufferedReader(new FileReader("../euler/src/com/forthgo/google/goro.in"));
            String line = in.readLine();
            int t = Integer.parseInt(line);
            for (int i = 0; i < t; i++) {
                line = in.readLine();
                int n = Integer.parseInt(line);
                line = in.readLine();
                double y = solve(line, n);
                System.out.printf("Case #%d: %.6f%n", i + 1, y);
            }

        } catch (IOException e) {
            throw new RuntimeException();
        }

    }

    private static double solve(String line, int n) {
        Arrays.fill(memo, -1);
        memo[0] = 0;
        memo[1] = 0;
        StringTokenizer st = new StringTokenizer(line);
        int[] a = new int[n];
        for (int i = 0; i < n; i++) {
            a[i] = Integer.parseInt(st.nextToken()) - 1;
        }
        double e = 0;
        boolean[] visited = new boolean[n];
        for (int i = 0; i < n; i++) {
            if (visited[i])
                continue;
            int count = 0;
            for (int j = i; !visited[j]; j = a[j]) {
                visited[j] = true;
                count++;
            }
            e += expectedSort(count);
        }
        return e;
    }

    static double[] memo = new double[1001];

    private static double expectedSort(int count) {
        if (memo[count] < 0) {
            double e = 0;
            ArrayPartitionIterator it = new ArrayPartitionIterator(count);
            double pSelf = 0;
            while (it.hasNext()) {
                int[] perm = it.next();
                if (perm.length == 1) {
                    pSelf = probability(count, perm);
                    continue;
                }
                double ee = 0;
                for (int i = 0; i < perm.length; i++) {
                    ee += expectedSort(perm[i]);
                }
                e += probability(count, perm) * ee;
            }
            memo[count] = (e + 1) / (1 - pSelf);
        }
        return memo[count];
    }

    private static double probability(int n, int[] perm) {
        BigInteger denom = factorial(n);
        BigInteger numer = BigInteger.ONE;
        int m = n;
        for (int i = 0; i < perm.length; i++) {
            numer = numer.multiply(choose(m, perm[i]));
            if (perm[i] > 2)
                numer = numer.multiply(factorial(perm[i] - 1));
//            denom = denom.multiply(BigInteger.valueOf(perm[i]));
            m -= perm[i];

        }
        double r = ratio(numer, denom);
        if (r > 1)
            throw new RuntimeException();
        return r;
    }

    private static BigInteger factorial(int n) {
        BigInteger f = BigInteger.ONE;
        for (int i = 0; i < n; i++) {
            f = f.multiply(BigInteger.valueOf(i + 1));
        }
        return f;
    }

    private static double ratio(BigInteger a, BigInteger b) {
        double r = ratio(a, b, 10);
        return r;
    }

    private static double ratio(BigInteger a, BigInteger b, int depth) {
        BigInteger[] divrem = a.divideAndRemainder(b);
        double r = divrem[0].doubleValue();
        if (depth > 0 && !divrem[1].equals(BigInteger.ZERO)) {
            r += 1 / ratio(b, divrem[1], depth - 1);
        }
        return r;
    }

    private static BigInteger choose(int a, int b) {
        BigInteger f = BigInteger.ONE;
        b = Math.min(b, a - b);
        for (int i = 0; i < b; i++) {
            f = f.multiply(BigInteger.valueOf(a - i));
        }
        for (int i = 0; i < b; i++) {
            f = f.divide(BigInteger.valueOf(i + 1));
        }
        return f;
    }
}
