package com.forthgo.google.g2011r1a;

import com.forthgo.math.Helper;

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigDecimal;
import java.math.MathContext;
import java.util.Scanner;

/**
 * Created by Xan Gregg.
 * Date: 5/20/11
 */
public class A {
    public static void main(String[] args) {
        try {
            Scanner in = new Scanner(new File("A.in"));
            //PrintWriter out = new PrintWriter(new FileWriter("A.out"));
            PrintWriter out = new PrintWriter(System.out);
            int n = in.nextInt();
            for (int i = 0; i < n; i++) {
                long nn = in.nextLong();
                long pd = in.nextLong();
                long pg = in.nextLong();
                String s = solve(nn, pd, pg);
                out.printf("Case #%d: %s%n", i + 1, s);
                out.flush();
            }

        } catch (IOException e) {
            throw new RuntimeException();
        }

    }

    private static String solve(long n, long pd, long pg) {
        LongFraction fd = new LongFraction(100, pd);
        LongFraction fg = new LongFraction(100, pg);
        if (fd.getNumerator() <= n && (pg > 0 || pd == 0) && (pg < 100 || pd == 100))
            return "Possible";
        return "Broken";
    }

}

class LongFraction implements Comparable<LongFraction> {
    private long m_numerator;
    private long m_denominator;
    static long s_maxNumer = 0;
    static long s_maxDenom = 0;

    public static LongFraction ZERO = new LongFraction(0, 1);
    public static LongFraction ONE = new LongFraction(1, 1);


    public LongFraction(long numerator) {
        m_numerator = numerator;
        m_denominator = 1;
    }

    public LongFraction(long numerator, long denominator) {
        m_numerator = numerator;
        m_denominator = denominator;
        reduceUpdate();
    }

    public LongFraction() {
        m_numerator = 0;
        m_denominator = 1;
    }

    @Override
    public String toString() {
        if (m_denominator == 1)
            return Long.toString(m_numerator);
        else {
            String s = Long.toString(m_numerator) + "/" + Long.toString(m_denominator);
            s += " = ";
            BigDecimal d = new BigDecimal(m_numerator, MathContext.DECIMAL128);
            //d = d.setScale(44, BigDecimal.ROUND_HALF_UP);
            d = d.divide(new BigDecimal(m_denominator), MathContext.DECIMAL128);
            s += d.toString();
            return s;
        }
    }

    @Override
    public Object clone() {
        return new LongFraction(m_numerator, m_denominator);
    }

    @Override
    public boolean equals(Object obj) {
        if (!(obj instanceof LongFraction))
            return false;
        LongFraction other = (LongFraction) obj;
        return m_numerator == other.m_numerator && m_denominator == other.m_denominator;
    }

    @Override
    public int hashCode() {
        return new Long(m_numerator).hashCode() ^ new Long(m_denominator).hashCode();
    }

    public long getNumerator() {
        return m_numerator;
    }

    public long getDenominator() {
        return m_denominator;
    }

    public LongFraction add(LongFraction b) {
        LongFraction f = (LongFraction) clone();
        f.addUpdate(b);
        return f;
    }


    public void addUpdate(LongFraction b) {
        addUpdate(b.m_numerator, b.m_denominator);
    }

    public void addUpdate(long x) {
        addUpdate(x, 1);
    }

    public void addUpdate(long numer, long denom) {
        long p = m_numerator * denom;
        long q = m_denominator * numer;
        long r = m_denominator * denom;
        if (p / denom == m_numerator && q / m_denominator == numer && r / m_denominator == denom
            && ((p >= 0 && q >= 0 && p + q >= 0) || (p <= 0 && q <= 0 && p + q <= 0)
                || p <= 0 && q >= 0 || p >= 0 && q <= 0)) {
            // every product and sum fits in scalar
            m_numerator = p + q;
            m_denominator = r;
            reduceUpdate();
            return;
        }
        // try smarter mutliplies
        long g = Helper.gcd(m_denominator, denom);
        if (g > 1) {
            p = m_numerator * (denom / g);
            q = (m_denominator / g) * numer;
            r = (m_denominator / g) * denom;
            if (p / (denom / g) == m_numerator && q / (m_denominator / g) == numer
                && r / (m_denominator / g) == denom
                && ((p >= 0 && q >= 0 && p + q >= 0) || (p <= 0 && q <= 0 && p + q <= 0)
                    || p <= 0 && q >= 0 || p >= 0 && q <= 0)) {
                // every product and sum fits in scalar
                m_numerator = p + q;
                m_denominator = r;
                reduceUpdate();
                return;
            }
        }
        // fall back to big version
        throw new RuntimeException("multiply");
    }

    public LongFraction subtract(LongFraction b) {
        LongFraction f = (LongFraction) clone();
        f.subtractUpdate(b);
        return f;
    }

    public void subtractUpdate(LongFraction b) {
        addUpdate(b.negate());
    }

    public void subtractUpdate(long x) {
        addUpdate(-x);
    }

    public LongFraction multiply(LongFraction b) {
        LongFraction f = (LongFraction) clone();
        f.multiplyUpdate(b);
        return f;
    }

    public void multiplyUpdate(LongFraction b) {
        long p = m_numerator * b.m_numerator;
        long q = m_denominator * b.m_denominator;
        if (p == 0 || p / b.m_numerator == m_numerator && q / m_denominator == b.m_denominator) {
            // every product and sum fits in scalar
            m_numerator = p;
            m_denominator = q;
            reduceUpdate();
            return;
        }
        // try smarter mutliplies
        long g = Helper.gcd(m_denominator, b.m_numerator);
        if (g > 1) {
            p = m_numerator * (b.m_numerator / g);
            q = (m_denominator / g) * b.m_denominator;
            if (p / (b.m_numerator / g) == m_numerator && q / (m_denominator / g) == b.m_denominator) {
                // every product and sum fits in scalar
                m_numerator = p;
                m_denominator = q;
                reduceUpdate();
                return;
            }
        }
        g = Helper.gcd(b.m_denominator, m_numerator);
        if (g > 1) {
            p = b.m_numerator * (m_numerator / g);
            q = (b.m_denominator / g) * m_denominator;
            if (p / (m_numerator / g) == b.m_numerator && q / (b.m_denominator / g) == m_denominator) {
                // every product and sum fits in scalar
                m_numerator = p;
                m_denominator = q;
                reduceUpdate();
                return;
            }
        }
        throw new RuntimeException();

    }

    public LongFraction multiply(long x) {
        LongFraction f = (LongFraction) clone();
        f.multiplyUpdate(x);
        return f;
    }


    public void multiplyUpdate(long x) {
        long p = m_numerator * x;
        long r = m_denominator;
        if (p == 0 || p / x == m_numerator) {
            // every product and sum fits in scalar
            m_numerator = p;
            m_denominator = r;
            reduceUpdate();
            return;
        }
        // try smarter mutliplies
        long g = Helper.gcd(m_denominator, x);
        if (g > 1) {
            p = m_numerator * (x / g);
            r = m_denominator / g;
            if (p / (x / g) == m_numerator) {
                // every product and sum fits in scalar
                m_numerator = p;
                m_denominator = r;
                reduceUpdate();
                return;
            }
        }
        throw new RuntimeException();
    }

    public LongFraction divide(LongFraction b) {
        return multiply(b.reciprocal());
    }

    public LongFraction divide(long x) {
        LongFraction f = (LongFraction) clone();
        f.divideUpdate(x);
        return f;
    }


    public void divideUpdate(long x) {
        long p = m_numerator;
        long r = m_denominator * x;
        if (r / m_denominator == x) {
            // every product and sum fits in scalar
            m_numerator = p;
            m_denominator = r;
            reduceUpdate();
            return;
        }
        // try smarter mutliplies
        long g = Helper.gcd(x, m_numerator);
        if (g > 1) {
            p = m_numerator / g;
            r = (x / g) * m_denominator;
            if (r / (x / g) == m_denominator) {
                // every product and sum fits in scalar
                m_numerator = p;
                m_denominator = r;
                reduceUpdate();
                return;
            }
        }
        throw new RuntimeException();
    }

    public LongFraction negate() {
        LongFraction f = (LongFraction) clone();
        f.negateUpdate();
        return f;
    }

    public void negateUpdate() {
        assert m_numerator != Long.MIN_VALUE;
        m_numerator = -m_numerator;
    }

    private void reduceUpdate() {
        if (m_numerator > s_maxNumer) {
            s_maxNumer = m_numerator;
        }
        if (m_denominator > s_maxDenom) {
            s_maxDenom = m_denominator;
        }

        long g = Helper.gcd(Math.abs(m_numerator), m_denominator);

        if (g != 1) {
            m_numerator /= g;
            m_denominator /= g;
        }
    }

    public LongFraction reciprocal() {
        if (m_numerator == 0)
            throw new ArithmeticException("divide by zero");
        if (m_numerator < 0)
            return new LongFraction(-m_denominator, -m_numerator);
        else
            return new LongFraction(m_denominator, m_numerator);

    }

    public double doubleValue() {
        return m_numerator * 1.0d / m_denominator;
    }

    public int compareTo(LongFraction b) {
        long p = m_numerator * b.m_denominator;
        long q = m_denominator * b.m_numerator;
        if (p == 0 || q == 0 || p / b.m_denominator == m_numerator && q / m_denominator == b.m_numerator) {
            // every product and sum fits in scalar
            return p < q ? -1 : (p == q ? 0 : 1);
        }
        long d1 = Helper.gcd(m_numerator, b.m_numerator);
        long d2 = Helper.gcd(m_denominator, b.m_denominator);
        if (d1 > 1 || d2 > 1) {
            p = (m_numerator / d1) * (b.m_denominator / d2);
            q = (m_denominator / d2) * (b.m_numerator / d1);
            if (p == 0 || q == 0 || p / (b.m_denominator / d2) == (m_numerator / d1) && q / (m_denominator / d2) == (b.m_numerator / d1)) {
                // every product and sum fits in scalar
                return p < q ? -1 : (p == q ? 0 : 1);
            }
        }
        double zp = (1.0 * m_numerator / d1) * (b.m_denominator / d2);
        double zq = (1.0 * m_denominator / d2) * (b.m_numerator / d1);
        if ((Math.abs(zp - zq) / zq) > 1e-10) {
            return zp < zq ? -1 : 1;
        }
        throw new RuntimeException();
    }

    public int compareTo(int b) {
        long p = m_numerator;
        long q = m_denominator * b;
        if (p == 0 || q == 0 || q / m_denominator == b) {
            // every product and sum fits in scalar
            return p < q ? -1 : (p == q ? 0 : 1);
        }
        long d1 = Helper.gcd(m_numerator, b);
        if (d1 > 1) {
            p = m_numerator / d1;
            q = m_denominator * b / d1;
            if (p == 0 || q == 0 || q / m_denominator == b / d1) {
                // every product and sum fits in scalar
                return p < q ? -1 : (p == q ? 0 : 1);
            }
        }
        throw new RuntimeException();
    }
}