import java.math.BigInteger;
import java.util.ArrayDeque;
import java.util.Deque;
import java.util.Map;
import java.util.Scanner;
import java.util.SortedMap;
import java.util.TreeMap;


public class GCJ2013Round2A {

    public static void main(String[] args) throws Exception {
        Scanner sc = new Scanner(System.in);
        int t = sc.nextInt();
        for (int i = 1; i <= t; i++) {
            System.out.printf("Case #%d: %s%n", i, new GCJ2013Round2A().solve(sc));
        }
    }

    static class PeepFlow {
        long inc, dec;
    }

    static class OriginState {
        long pos;
        long numInc;

        public OriginState(long pos, long numInc) {
            this.pos = pos;
            this.numInc = numInc;
        }

    }

    static long calcCost(long n, long dist) {
        //        System.out.println("GCJ2013Round2A.calcCost()" + dist);
        //        System.out.println("the cost is: " + (n * dist + dist - dist * (dist + 1) / 2));
        if ( n * dist + dist - dist * (dist + 1) / 2 < 0) throw new IllegalStateException();
        return n * dist - dist * (dist - 1) / 2;
    }

    private String solve(Scanner sc) {
        long n = sc.nextInt();
        int m = sc.nextInt();
        int[] o = new int[m];
        int[] e = new int[m];
        int[] p = new int[m];

        BigInteger origAns = BigInteger.ZERO;
        SortedMap<Integer, PeepFlow> changes = new TreeMap<Integer, PeepFlow>();
        for (int i = 0; i < m; i++) {
            o[i] = sc.nextInt();
            e[i] = sc.nextInt();
            p[i] = sc.nextInt();
            long dist = e[i] - o[i];
            origAns = origAns.add(BigInteger.valueOf(calcCost(n, dist)).multiply(
                    BigInteger.valueOf(p[i])));
            getDefault(o[i], changes).inc += p[i];
            getDefault(e[i], changes).dec += p[i];
        }

        Deque<OriginState> curPeeps = new ArrayDeque<>();
        BigInteger minAns = BigInteger.ZERO;

        for (Map.Entry<Integer, PeepFlow> entry : changes.entrySet()) {
            long pos = entry.getKey();
            PeepFlow flow = entry.getValue();
            if (flow.inc > 0) curPeeps.push(new OriginState(pos, flow.inc));
            long dec = flow.dec;
            while (dec > 0) {
                OriginState prevJoin = curPeeps.pop();
                if (prevJoin.numInc > dec) {
                    minAns = minAns.add(BigInteger.valueOf(
                            calcCost(n, pos - prevJoin.pos)).multiply(
                            BigInteger.valueOf(dec)));
                    prevJoin.numInc -= dec;
                    dec = 0;
                    curPeeps.push(prevJoin);
                    break;
                }
                else {
                    minAns = minAns.add(BigInteger.valueOf(
                            calcCost(n, pos - prevJoin.pos)).multiply(
                            BigInteger.valueOf(prevJoin.numInc)));
                    dec -= prevJoin.numInc;
                }
            }
//            System.out.println(pos + ", " + minAns);
        }
        //        System.out.println(origAns);
        //        System.out.println(minAns);

        return origAns.subtract(minAns).toString();
    }

    private PeepFlow getDefault(int n, SortedMap<Integer, PeepFlow> changes) {
        PeepFlow v = changes.get(n);
        if (v == null) {
            v = new PeepFlow();
            changes.put(n, v);
        }
        return v;
    }

}
