
import java.io.*;
import java.util.*;
import static java.lang.Math.*;

/**
 * Google Code Jam 2011
 * Round 2
 * Problem B
 * 
 * @author dalex
 */
public class B implements Runnable {
	
	BufferedReader in;
	PrintWriter out;
	StringTokenizer tok = new StringTokenizer("");
	
	String readString() throws IOException {
		while (!tok.hasMoreTokens()) {
			tok = new StringTokenizer(in.readLine());
		}
		return tok.nextToken();
	}
	
	int readInt() throws IOException {
		return Integer.parseInt(readString());
	}
	
	long readLong() throws IOException {
		return Long.parseLong(readString());
	}
	
	double readDouble() throws IOException {
		return Double.parseDouble(readString());
	}
	
	@Override
	public void run() {
		try {
			long t1 = System.currentTimeMillis();
			in = new BufferedReader(new FileReader("input.txt"));
			out = new PrintWriter("output.txt");
			Locale.setDefault(Locale.US);
			int tests = readInt();
			int p = max(1, tests / 10);
			for (int t = 1; t <= tests; t++) {
				out.printf("Case #%d: ", t);
				solve();
				if (t % p == 0) System.err.println("Test " + t + " of " + tests + " completed");
			}
			in.close();
			out.close();
			long t2 = System.currentTimeMillis();
			System.err.println("Time = " + (t2 - t1));
		} catch (Throwable e) {
			e.printStackTrace(System.err);
			System.exit(-1);
		}
	}
	
	public static void main(String[] args) {
		new Thread(null, new B(), "", 256 * (1L << 20)).start();
	}
	
	// solution
	
	int n,m;
	long[][] a;
	
	void solve() throws IOException {
		n = readInt();
		m = readInt();
		long d = readLong();
		a = new long[n][m];
		for (int i = 0; i < n; i++) {
			String s = readString();
			for (int j = 0; j < m; j++) {
				a[i][j] = d + s.charAt(j) - '0';
			}
		}
		
		long odd = 0;
		for (int x = 0; x < n; x++) {
			for (int y = 0; y < m; y++) {
				odd = max(odd, getOddAnswer(x, y));
			}
		}
		long even = 0;
		for (int x = 0; x < n; x++) {
			for (int y = 0; y < m; y++) {
				even = max(even, getEvenAnswer(x, y));
			}
		}
		
		long ans = max(odd*2+1, even*2);
		if (ans >= 3) {
			out.println(ans);
		} else {
			out.println("IMPOSSIBLE");
		}
	}
	
	boolean check(int x, int y) {
		return x >= 0 && y >= 0 && x < n && y < m;
	}
	
	long getOddAnswer(int x, int y) {
		int ans = 1;
		int best = 0;
		while (true) {
			if (!check(x - ans, y - ans) || !check(x + ans, y + ans)) break;
			long sum = 0;
			long mx = 0;
			long my = 0;
			for (int i = x - ans; i <= x + ans; i++) {
				for (int j = y - ans; j <= y + ans; j++) {
					if (i == x - ans && j == y - ans) continue;
					if (i == x + ans && j == y - ans) continue;
					if (i == x - ans && j == y + ans) continue;
					if (i == x + ans && j == y + ans) continue;
					mx += i * a[i][j];
					my += j * a[i][j];
					sum += a[i][j];
				}
			}
			if (mx == x * sum && my == y * sum) {
				best = ans;
			}
			ans++;
		}
		return best;
	}
	
	long getEvenAnswer(int x, int y) {
		if (x == 2 && y == 2) {
			System.err.println();
		}
		int ans = 2;
		int best = 0;
		while (true) {
			if (!check(x - ans, y - ans) || !check(x + ans-1, y + ans-1)) break;
			double sum = 0;
			double mx = 0;
			double my = 0;
			for (int i = x - ans; i < x + ans; i++) {
				for (int j = y - ans; j < y + ans; j++) {
					if (i == x - ans   && j == y - ans)   continue;
					if (i == x + ans-1 && j == y - ans)   continue;
					if (i == x - ans   && j == y + ans-1) continue;
					if (i == x + ans-1 && j == y + ans-1) continue;
					mx += i * a[i][j];
					my += j * a[i][j];
					sum += a[i][j];
				}
			}
			if (mx == (x-0.5) * sum && my == (y-0.5) * sum) {
				best = ans;
			}
			ans++;
		}
		return best;
	}
	
}
