
import java.io.*;
import java.util.*;
import static java.lang.Math.*;

/**
 * Google Code Jam 2011
 * Round 2
 * Problem A
 * 
 * @author dalex
 */
public class A implements Runnable {
	
	BufferedReader in;
	PrintWriter out;
	StringTokenizer tok = new StringTokenizer("");
	
	String readString() throws IOException {
		while (!tok.hasMoreTokens()) {
			tok = new StringTokenizer(in.readLine());
		}
		return tok.nextToken();
	}
	
	int readInt() throws IOException {
		return Integer.parseInt(readString());
	}
	
	long readLong() throws IOException {
		return Long.parseLong(readString());
	}
	
	double readDouble() throws IOException {
		return Double.parseDouble(readString());
	}
	
	@Override
	public void run() {
		try {
			long t1 = System.currentTimeMillis();
			in = new BufferedReader(new FileReader("input.txt"));
			out = new PrintWriter("output.txt");
			Locale.setDefault(Locale.US);
			int tests = readInt();
			int p = max(1, tests / 10);
			for (int t = 1; t <= tests; t++) {
				out.printf("Case #%d: ", t);
				solve();
				if (t % p == 0) System.err.println("Test " + t + " of " + tests + " completed");
			}
			in.close();
			out.close();
			long t2 = System.currentTimeMillis();
			System.err.println("Time = " + (t2 - t1));
		} catch (Throwable e) {
			e.printStackTrace(System.err);
			System.exit(-1);
		}
	}
	
	public static void main(String[] args) {
		new Thread(null, new A(), "", 256 * (1L << 20)).start();
	}
	
	// solution
	
	class Walkway implements Comparable<Walkway> {
		long left, right, speed;

		public Walkway(int left, int right, int speed) {
			super();
			this.left = left;
			this.right = right;
			this.speed = speed;
		}

		@Override
		public int compareTo(Walkway o) {
			return (int) (this.speed - o.speed);
		}
		
		double getTime() {
			double ans = 0;
			long xlen = right - left;
			if (xlen >= runTime * (v2 + speed)) { // run not all time
				double runLen = runTime * (v2 + speed);
				double walkLen = xlen - runLen;
				ans = runTime + (walkLen / (v1 + speed));
				runTime = 0;
			} else { // only run
				ans = ((double) xlen) / (v2 + speed);
				runTime -= ans;
			}
			return ans;
		}
		
	}
	
	double ans = 0.0; // time
	double runTime;
	long v1,v2,x;
	
	void solve() throws IOException {
		x = readInt();
		v1 = readInt();
		v2 = readInt();
		runTime = readInt();
		int n = readInt();
		Walkway[] w = new Walkway[n];
		for (int i = 0; i < n; i++) {
			w[i] = new Walkway(readInt(), readInt(), readInt());
		}
		int wlen = 0;
		for (Walkway z : w) {
			wlen += (z.right - z.left);
		}
		
		long xlen = x - wlen;
		if (xlen >= runTime * v2) { // run not all time
			double runLen = runTime * v2;
			double walkLen = xlen - runLen;
			ans = runTime + (walkLen / v1);
			runTime = 0;
		} else { // only run
			ans = ((double) xlen) / v2;
			runTime -= ans;
		}
		
		Arrays.sort(w);
		for (Walkway z : w) {
			ans += z.getTime();
		}
		
		out.printf("%.12f\n", ans);
	}
	
}
