package uk.co.damon_hall.pancakes;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStreamReader;
import java.util.Scanner;

public class Main {
    public static void main(String[] args) {
        // Use file or piped input
        if(args.length > 0)
        {
            try
            {
                System.setIn(new FileInputStream(args[0]));
            }
            catch (FileNotFoundException ex)
            {
                System.out.println("FAILED TO LOAD PROVIDED FILE: " + args[0]);
            }

        }
        // Use a scanner to read the input
        Scanner in = new Scanner(new BufferedReader(new InputStreamReader(System.in)));
        int t = in.nextInt();  // Scanner has functions to read ints, longs, strings, chars, etc.
        for (int i = 1; i <= t; ++i) {
            // Read in grid size and prepare our grid
            int n = in.nextInt();
            char[] grid = new char[n * n];
            // Get number of provided models
            int m = in.nextInt();
            // And read each one in to our grid
            for(int j = 0; j < m; j++)
            {
                char model = in.next().charAt(0);
                // Get row and column and convert to grid index
                int row = (in.nextInt() - 1) * n;
                int col = in.nextInt() - 1;
                grid[row + col] = model;
            }
            Main.solve(i, n, grid);
        }
    }

    private static int rowStart(int index, int size){
        return index - (index % size);
    }

    private static int forRow(int index, int size, char[] grid){
        // Then loop through each item in the row
        int start = rowStart(index, size);
        for(int i = start; i < start + size; i += 1)
        {
            if(i != index && grid[i] != '+' && grid[i] != '\0')
            {
                return 2;
            }
        }
        // Otherwise allow any value
        return 3;
    }

    private static int columnStart(int index, int size){
        return index % size;
    }

    private static int forColumn(int index, int size, char[] grid){
        // Then loop through each item in the column
        for(int i = columnStart(index, size); i < grid.length; i += size)
        {
            if(i != index && grid[i] != '+' && grid[i] != '\0')
            {
                return 2;
            }
        }
        // Otherwise allow any value
        return 3;
    }

    private static int diagonalLeftStart(int index, int size){
        int a = index % size;
        int b = index / size;
        if(a > b)
        {
            a = b;
        }
        return index - a * (size + 1);
    }

    private static int diagonalRightStart(int index, int size){
        int a = (size - 1) - (index % size);
        int b = index / size;
        if(a > b)
        {
            a = b;
        }
        return index - a * (size - 1);
    }

    private static int forDiagonal(int index, int size, char[] grid){
        if(size <= 1)
        {
            return 3;
        }

        // Check the left diagonal
        for(int i = diagonalLeftStart(index, size); i < grid.length; i += size + 1)
        {
            if(i != index && grid[i] != 'x' && grid[i] != '\0')
            {
                return 1;
            }
        }
        // Check the right diagonal
        for(int i = diagonalRightStart(index, size); i < grid.length; i += size - 1)
        {
            if(i != index && grid[i] != 'x' && grid[i] != '\0')
            {
                return 1;
            }
        }
        // Otherwise allow any
        return 3;
    }

    private static int columnNumber(int index, int size){
        return index % size + 1;
    }

    private static int rowNumber(int index, int size){
        return index / size + 1;
    }

    private static void solve(int caseNumber, int size, char[] grid) {
        // Register changes
        boolean[] changes = new boolean[grid.length];
        int changeCount = 0;
        // Track score
        int score = 0;

        // Loop through every item in the grid
        // Loop through every row in the grid
        int low = 0;
        int high = size - 1;
        for(int r = 0; r < size; r++)
        {
            int row = low;
            if(r % 2 == 0)
            {
                low++;
            }
            else
            {
                row = high;
                high--;
            }
            for(int j = 0; j < size; j++)
            {
                int i = (row * size) + j;
                //System.out.println(rowNumber(i, size) + ":" + columnNumber(i, size) + " -> c: " + Main.forColumn(i, size, grid) + " r: " + Main.forRow(i, size, grid) + " d: " + Main.forDiagonal(i, size, grid));
                // Determine what to place at this position
                int model = Main.forColumn(i, size, grid) &
                        Main.forRow(i, size, grid) &
                        Main.forDiagonal(i, size, grid);

                // And place it if not already placed
                if(model == 3)
                {
                    if(grid[i] != 'o')
                    {
                        grid[i] = 'o';
                        changes[i] = true;
                        changeCount += 1;
                    }
                }
                else if(grid[i] == '\0')
                {
                    if(model == 2)
                    {
                        grid[i] = '+';
                        changes[i] = true;
                        changeCount += 1;
                    }
                    else if(model == 1)
                    {
                        grid[i] = 'x';
                        changes[i] = true;
                        changeCount += 1;
                    }
                }

                // Sum the score
                if(grid[i] == 'o')
                {
                    score += 2;
                }
                else if(grid[i] == 'x' || grid[i] == '+')
                {
                    score += 1;
                }
            }
        }

        // Then print out the changes for this case
        System.out.println("Case #" + caseNumber + ": " + score + " " + changeCount);
        for(int i = 0; i < changes.length; i++)
        {
            if(changes[i])
            {
                System.out.println(grid[i] + " " + rowNumber(i, size) + " " + columnNumber(i, size));
            }
        }
    }
}
