package cn.cdn;

import java.io.*;
import java.util.*;

class Pair implements Comparable {		
	public int first;
	public int second;
	
	@Override
	public int compareTo(Object o) {
		return ((Pair)o).first - this.first;
	}
}

public class TrainTimetable {

	public enum State {TA_TIME, NUM, AB, BA}
	
	public Vector<String> readFile(String filename)	{
		
		Vector<String> items = new Vector<String>();
		
		try{
			File infile = new File(filename);
			BufferedReader br = new BufferedReader(new FileReader(infile));

			String buf = null;
			buf = br.readLine();

			while(buf != null) {
				items.add(buf);
				buf = br.readLine();
			}
			br.close();

		}catch(FileNotFoundException e) {
			e.printStackTrace();
		}catch(IOException e) {
			e.printStackTrace();
		}
		
		return items;
		
	}
	
	public Pair arrangeTrain(Vector<Pair> ABs, Vector<Pair> BAs) {
		
		int numAB = ABs.size();
		int numBA = BAs.size(); 

		Pair numTrains = new Pair();
		numTrains.first = numAB;
		numTrains.second = numBA;
		
		Collections.sort(ABs);
		Collections.sort(BAs);
		
		for(int i=0; i<numAB; i++)
		{
			int nearestIndex = -1;
			int nearestDistance = Integer.MAX_VALUE;
			for(int j=0; j<numBA; j++)
			{
				int distance = ABs.elementAt(i).first - BAs.elementAt(j).second;
				if(distance>=0 && distance<=nearestDistance)
				{
					nearestIndex = j;
					nearestDistance = distance;
				}
			}
			
			if(nearestIndex != -1)
			{
				BAs.elementAt(nearestIndex).second = Integer.MAX_VALUE;
				numTrains.first--;
			}
		}
		
		for(int i=0; i<numBA; i++)
		{
			int nearestIndex = -1;
			int nearestDistance = Integer.MAX_VALUE;
			for(int j=0; j<numAB; j++)
			{
				int distance = BAs.elementAt(i).first - ABs.elementAt(j).second;
				if(distance>=0 && distance<=nearestDistance)
				{
					nearestIndex = j;
					nearestDistance = distance;
				}
			}
			
			if(nearestIndex != -1)
			{
				ABs.elementAt(nearestIndex).second = Integer.MAX_VALUE;
				numTrains.second--;
			}
		}
		
		return numTrains;
	}
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {

		
		TrainTimetable tt = new TrainTimetable();
		Vector<String> items = tt.readFile("B-small-attempt2.in");
		
		try {
			BufferedWriter out = new BufferedWriter(
					new OutputStreamWriter(
							new FileOutputStream("out.txt")));
			
			int testCaseID  = 1;
			
			int numAB=0, numBA=0;
			State state = State.TA_TIME;
			Vector<Pair> ABs, BAs;
			
			ABs 	= new Vector<Pair>();
			BAs 	= new Vector<Pair>();
			
			boolean testcaseReady = false;
			int turnaroundTime = 0;
			boolean firstTime = true;
			int itemLen = items.size();
			for(int i=1; i<itemLen; i++)
			{				
				if(state==State.TA_TIME)
				{
					turnaroundTime = Integer.parseInt(items.elementAt(i));
					
					ABs.clear();
					BAs.clear();
					
					state = State.NUM;
				}
				else if(state==State.NUM)
				{
					String[] nums = items.elementAt(i).split(" ");
					numAB = Integer.parseInt(nums[0]);
					numBA = Integer.parseInt(nums[1]);

					if(numAB>0)
						state = State.AB;
					else 
						state = State.BA;
				}
				else if(state==State.AB || state==State.BA)
				{
					Pair record = new Pair();
					String[] timeStrings = items.elementAt(i).split(" ");
					for(int k=0; k<2; k++)
					{
						String [] digits = timeStrings[k].split(":");
						int hour, minute;
						hour   = Integer.parseInt(digits[0]);
						minute = Integer.parseInt(digits[1]);
						int time = hour*60+minute;
						
						if(k==0)
							record.first = time;
						else
							record.second = time + turnaroundTime;
					}
					
					if(state==State.AB)
					{					
						ABs.add(record);
						
						if(ABs.size() >= numAB)
						{
							if(numBA > 0)
								state = State.BA;
							else
								testcaseReady = true;
						}
					}
					else
					{					
						BAs.add(record);
						
						if(BAs.size() >= numBA)
							testcaseReady = true;
					}
				}

				if(testcaseReady)
				{
					state = State.TA_TIME;
					
					Pair trainNums = tt.arrangeTrain(ABs, BAs);
					out.write("Case #"+testCaseID+": "+trainNums.first+" "+trainNums.second+"\r\n");
					System.out.print("Case #"+testCaseID+": "+trainNums.first+" "+trainNums.second+"\r\n");
					testCaseID++;
					
					testcaseReady = false;
				}
			}
			

			if(testcaseReady)
			{
				state = State.TA_TIME;
				
				Pair trainNums = tt.arrangeTrain(ABs, BAs);
				out.write("Case #"+testCaseID+": "+trainNums.first+" "+trainNums.second+"\r\n");
				System.out.print("Case #"+testCaseID+": "+trainNums.first+" "+trainNums.second+"\r\n");
				testCaseID++;
				
				testcaseReady = false;
			}
			
			out.close();
			
		} catch (IOException e) {
			e.printStackTrace();
		}

	}

}
