import java.io.*;
import java.util.*;
import java.math.BigInteger;

public class Main{

    String inputFile = "C-small-attempt0.in";
    ArrayList<Task> tasks;
    ArrayList<String> answers;
    int solved = 0;
    int taskNum = 0;
    PrintStream output;
    Scanner fileScanner;
    double start = System.currentTimeMillis();
    
    public void createTasksList(){
        // create a list of Tasks 
    	tasks = new ArrayList<Task>();
        int taskId = 1;
    	fileScanner.nextLine();
        
        while (fileScanner.hasNextLine()){
            String line = fileScanner.nextLine();
            Scanner scanner = new Scanner(line);
            
            String A = scanner.next();
            String B = scanner.next();
            
            tasks.add(new Task(taskId++, A, B));
        }
    }
    
    
    
    
    public class Task{
    	// this class is just used to store the input data for one test case
    	int taskId;
    	
    	BigInteger A;
    	BigInteger B;
    	
    	public Task(int taskId, String A, String B){
    		this.taskId = taskId;
    		this.A = new BigInteger(A);
    		this.B = new BigInteger(B);
    	}
    	
    	public void solve(){
    		int ans = 0;

    		BigInteger start = sqrt(A);
    		if (A.compareTo(start.pow(2)) == 1)
    		{
    			start = start.add(BigInteger.ONE);
    		}
    		
    		BigInteger end = sqrt(B);
    		if (B.compareTo(end.pow(2)) == -1)
    		{
    			end = end.subtract(BigInteger.ONE);
    		}

    		for (BigInteger b = start; b.compareTo(end) != 1; b = b.add(BigInteger.ONE))
    		{
    			if (isPalindrome(b.toString()) && isPalindrome(b.pow(2).toString()))
				{
    				ans++;
				}
    		}
    		
        	submitAnswer(taskId, ans +"");
    	}
    	
    	
    } // end Task
 
    
    private boolean isPalindrome(String s)
	{
		int len = s.length();
    	for (int i=0; i<len; i++)
    	{
    		if (s.charAt(i) != s.charAt(len-1-i))
    		{
    			return false;
    		}
    	}
    	return true;
	}
    
    private BigInteger sqrt(BigInteger b)
	{
		String s = b.toString();
		int n;
		BigInteger b1, b2;
		BigInteger TWO = new BigInteger("2");
		
		if (b.testBit(0)){
			n = (s.length() - 1) / 2;
			b1 = new BigInteger("2").multiply(BigInteger.TEN.pow(n));
		}else{
			n = (s.length() - 2) / 2;
			b1 = new BigInteger("6").multiply(BigInteger.TEN.pow(n));
		}

		b2 = b.divide(b1).add(b1).divide(TWO);

		int i = 0;
		while (b1.compareTo(b2) != 0 && i<100)
		{
			i++;
			b1 = b2;
			b2 = b.divide(b1).add(b1).divide(TWO);
		}
		
		return b2;
	}
    
    
    
    
    // CodeJam Generic Utility Methods:
    
    public static void main(String[] args){
    	new Main();
    }
    
    
    public Main(){
        newCodeJam();
        createTasksList();
        createAnswersList();
        solveAllTasks();
        createOutputFile();
        System.out.println("Finished.");
        System.out.println("Time Taken: " + ((System.currentTimeMillis()-start)/1000) + " seconds.");
    }
    
    
    public void newCodeJam(){
    	String outputFile = inputFile.substring(0, inputFile.length()-3) + "-OUTPUT.out";
        System.out.print("\f");
        try {
            fileScanner = new Scanner(new File(inputFile)); // open input file
        }catch(IOException e) {
        	System.out.println("ERROR: Input File (" + inputFile + ") Not Found!");
        }
        try {
            output = new PrintStream(new File(outputFile)); // open output file
        }catch(IOException ex) {}
    }
    

    public void createAnswersList(){
    	answers = new ArrayList<String>();
    	int size = tasks.size();
    	for (int x=0; x<size; x++){
    		answers.add("");
    	}
    }
    
    
    public void solveAllTasks(){
    	SolverThread thread1 = new SolverThread();
    	SolverThread thread2 = new SolverThread();
    	//SolverThread thread3 = new SolverThread();
    	//SolverThread thread4 = new SolverThread();
    	thread1.start();
    	thread2.start();
    	//thread3.start();
    	//thread4.start();
    	try{
    		thread1.join();
    		thread2.join();
    		//thread3.join();
    		//thread4.join();
    	}catch (InterruptedException e) {}
    }
    
    
    public void createOutputFile(){
    	if (inputFile.charAt(1) == 'e'){ // "Test" input
    		System.out.println();
        	for (int x=0; x<answers.size(); x++){
        		System.out.println("Case #" + (x+1) + ": " + answers.get(x));
            }
        	System.out.println();
    	}
    	// create Output file
    	for (int x=0; x<answers.size(); x++){
    		output.println("Case #" + (x+1) + ": " + answers.get(x));
        }
        output.close();
    }
    
    
    public synchronized Task getNewTask(){
    	// returns an uncompleted Task else null
    	if (taskNum < tasks.size()){
    		return tasks.get(taskNum++);
    	}else{
    		return null;
    	}
    }
    
    
    public synchronized void submitAnswer(int taskId, String ans){
    	answers.set(taskId-1, ans);
    	solved++;
    	if ((System.currentTimeMillis()-start)/1000 > 10){
    		System.out.println((solved*100/answers.size()) + "% Complete. Time Taken: " + ((System.currentTimeMillis()-start)/1000) + " seconds.");
    	}
    }
    
    
    public class SolverThread extends Thread{
    	public SolverThread(){}
    	public void run(){
    		Task task = getNewTask();
    		while (task != null){
    			task.solve(); // solve the Task
    			task = getNewTask(); // get next Task to start
    		}
    	}    	
    }
}