import java.io.IOException;
import java.io.PrintWriter;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.*;

/**
 * Created by Daniel on 4/11/2015.
 */
public class q3 {
    enum E {O, i, j, k };
    enum Quaternion {
          O(E.O, false), i(E.i, false), j(E.j, false), k(E.k, false),
         _O(E.O, true), _i(E.i, true), _j(E.j, true), _k(E.k, true);

        static Quaternion[][] table = {
            { O,  i,  j,  k },
            { i, _O,  k, _j },
            { j, _k, _O,  i  },
            { k,  j, _i, _O },
        };

        final E q;
        final boolean negated;
        Quaternion(E q, boolean negated) {
            this.q = q; this.negated = negated;
        }

        Quaternion mul( Quaternion rhs ) {
            Quaternion result = table[this.q.ordinal()][rhs.q.ordinal()];
            if( this.negated ^ rhs.negated )
                result = result.negate();
            return result;
        }

        Quaternion mulByWhat( Quaternion givesYouThis ) {
            for( Quaternion result : Quaternion.values() ) {
                if( this.mul(result) == givesYouThis )
                    return result;
            }
            throw new IllegalStateException();
        }

        Quaternion pow(int n) {
            if( n == 0 ) {
                return O;
            }

            n--;
            Quaternion result = this;

            n = n % 4;

            for( int i = 0; i < n; i++ ) {
                result = result.mul(this);
            }
            return result;
        }

        Quaternion negate() {
            switch (this) {
                case O: return _O;
                case i: return _i;
                case j: return _j;
                case k: return _k;

                case _O: return O;
                case _i: return i;
                case _j: return j;
                case _k: return k;
            }
            throw new IllegalStateException();
        }
    }

    public static void main(String[] args) throws IOException {
        Iterator<String> input = Files.readAllLines(Paths.get("input.in")).iterator();
        PrintWriter out = new PrintWriter("output.out");

        int t = Integer.valueOf(input.next());
        System.out.println("Tests: " + t);

        for( int testCase = 1; testCase <= t; testCase++ ) {
            System.out.println("Test: " + testCase);
            StringTokenizer tokenizer = new StringTokenizer(input.next());
            int L = Integer.parseInt(tokenizer.nextToken());
            System.out.println("L: " + L);
            int X = Integer.parseInt(tokenizer.nextToken());
            System.out.println("X: " + X);
            Quaternion[] group = new Quaternion[L];
            int i = 0;
            for( char c : input.next().toCharArray() ) {
                group[i++] = Quaternion.valueOf(String.valueOf(c));
            }

            List<Quaternion> groupList = Arrays.asList(group);
            Quaternion groupResult = calculate(groupList);

            Quaternion[] firstN = calculateFirstN(groupList);
            Quaternion[] lastN = calculateLastN(groupList);
            Map<Quaternion,Quaternion> oneSplit = oneSplit(firstN,lastN);
            Map<Quaternion,Quaternion> twoSplit = twoSplit(groupList,firstN,lastN);

            System.out.println("Group result: " + groupResult);

            boolean answer = false;
            // 2 Break
            for( int n = 0; n < X; n++ ) {
                int m = X - n - 1;
                Quaternion nValue = groupResult.pow(n);
                Quaternion need = nValue.mulByWhat(Quaternion.i);
                Quaternion nextGroup = twoSplit.get(need);
                if( nextGroup == null )
                    continue;
                if( nextGroup.mul(groupResult.pow(m)) == Quaternion.k ) {
                    answer = true;
                    System.out.printf("2 Split in group %d\n", n);
                    break;
                }
            }
            loop:
            if( !answer ) {
                for (int n = 0; n < X - 2; n ++ ) {
                    Quaternion nValue = groupResult.pow(n);
                    Quaternion need = nValue.mulByWhat(Quaternion.i);
                    Quaternion nextGroup = oneSplit.get(need);
                    if( nextGroup == null )
                        continue;


                    for( int m = n + 1; m<X-1;m++ ) {
                        int mSize = m - (n + 1);
                        Quaternion need2 = nextGroup.mul(groupResult.pow(mSize)).mulByWhat(Quaternion.j);
                        Quaternion nextGroup2 = oneSplit.get(need2);
                        if( nextGroup2 == null )
                            continue;

                        int p = X - m - 1;
                        if( nextGroup2.mul(groupResult.pow(p)) == Quaternion.k) {
                            answer = true;
                            break loop;
                        }
                    }
                }
            }

            String answerString = String.format("Case #%d: %s", testCase, answer ? "YES" : "NO");
            System.out.println("> " + answerString);
            out.println(answerString);
        }

        out.close();
    }

    private static Quaternion[] calculateFirstN(List<Quaternion> groupList) {
        Quaternion[] result = new Quaternion[groupList.size()+1];
        result[0] = Quaternion.O;
        for( int i = 0; i < groupList.size(); i++ ) {
            result[i+1] = result[i].mul(groupList.get(i));
        }
        return result;
    }
    private static Quaternion[] calculateLastN(List<Quaternion> groupList) {
        Quaternion[] result = new Quaternion[groupList.size()+1];
        result[groupList.size()] = Quaternion.O;
        for( int i = 0; i < groupList.size(); i++ ) {
            int index = groupList.size() - i - 1;
            result[index ] = result[index + 1].mul(groupList.get(index));
        }
        return result;
    }

    private static Map<Quaternion, Quaternion> twoSplit(List<Quaternion> group,Quaternion[] first, Quaternion[] last) {
        Map<Quaternion,Quaternion> result = new EnumMap<>(Quaternion.class);
        for( int i = 0; i < group.size(); i++ ) {
            Quaternion midResult = Quaternion.O;
            for( int j = i; j < group.size(); j++ ) {
                midResult = midResult.mul(group.get(j));
                if( midResult == Quaternion.j ) {
                    result.put(first[i], last[j+1]);
                }
            }
        }
        return result;
    }

    private static Map<Quaternion, Quaternion> oneSplit(Quaternion[] first, Quaternion[] last) {
        Map<Quaternion,Quaternion> result = new EnumMap<>(Quaternion.class);
        for( int i = 0; i < first.length; i++ ) {
            result.put(first[i], last[i]);
        }
        return result;
    }

    private static Quaternion calculate(List<Quaternion> group) {
        if (group.isEmpty())
            return Quaternion.O;

        Quaternion result = group.get(0);
        for (int i = 1; i < group.size(); i++) {
            result = result.mul(group.get(i));
        }
        return result;
    }
}
