import java.text.DecimalFormat;
import java.util.Currency;
import java.util.HashSet;
import java.util.Locale;
import java.util.Scanner;


public class DecisionTree {
	
	static class Animal {
		String name;
		HashSet<String> features;

		public Animal(String name, HashSet<String> features) {
			this.name = name;
			this.features = features;
		}
	}
	
	static class Node {
		String name;
		Node subLeft, subRight;
		double prob;
		boolean isLeaf;
		
		public Node(String name, Node subLeft, Node subRight, double prob,
				boolean isLeaf) {
			super();
			this.name = name;
			this.subLeft = subLeft;
			this.subRight = subRight;
			this.prob = prob;
			this.isLeaf = isLeaf;
		}		
		
		public String toString() {
			if (isLeaf) return prob+"";
			return "name = " + name + ", p = " + prob + ", [" + subLeft.toString() + "], [" + subRight.toString() + "]";
		}
	}
	
	static StringBuilder treeStr;
	static int index;
	static Scanner treeReader;
	public static void main(String[] args) {
		
		Scanner sc = new Scanner(System.in);
		StringBuilder out = new StringBuilder();
		
		int testCases = sc.nextInt();
		for (int i = 0; i < testCases; i++) {
			int linesOfTree = sc.nextInt();
			sc.nextLine();
			treeStr = new StringBuilder();
			for (int l = 0; l < linesOfTree; l++) {
				treeStr.append(sc.nextLine());
			}
			index = 0;
			treeReader = new Scanner(treeStr.toString().replace("(", " ( ").replace(")", " ) "));
			treeReader.useLocale(Locale.ENGLISH);
			Node decisionTree = makeTree();
			
			
			int numAnimals = sc.nextInt();
			sc.nextLine();
			Animal[] animals = new Animal[numAnimals];
			for (int k = 0; k < numAnimals; k++) {
				String name = sc.next();
				int numFeatures = sc.nextInt();
				HashSet<String> features = new HashSet<String>();
				for (int l = 0; l < numFeatures; l++) {
					features.add(sc.next());
				}
				if (sc.hasNext()) sc.nextLine();
				animals[k] = new Animal(name, features);
			}
			
			out.append("Case #" + (i+1) + ":\n");
			for (int k = 0; k < numAnimals; k++) {
				double p = calcProb(decisionTree, animals[k]);
				DecimalFormat df = new DecimalFormat("0.0000000");
				out.append(df.format(p).replace(",", ".")+"\n");
			}
		}
		System.out.print(out);
	}

	private static double calcProb(Node node, Animal animal) {
		double currProb = node.prob;
		if (!node.isLeaf) {
			if (animal.features.contains(node.name)) {
				currProb *= calcProb(node.subLeft, animal);
			} else {
				currProb *= calcProb(node.subRight, animal);
			}
		}
		return currProb;
	}

	private static Node makeTree() {
		readOpen();
		double prob = readDouble();
		String name = readToken();
		if (name.equals(")")) {
			return new Node("", null, null, prob, true);
		}
		Node left = makeTree();
		Node right = makeTree();
		next();
		return new Node(name, left, right, prob, false);	
	}
	
	private static String next() {
		return treeReader.next();
	}

	private static String readToken() {
		return next();
	}

	private static double readDouble() {
		return treeReader.nextDouble();
	}

	private static void readOpen() {
		String next = next();
		while (!next.equals("(")) {
			next = next();
		}
	}

}
