import java.io.BufferedInputStream;
import java.text.DecimalFormat;
import java.util.LinkedList;
import java.util.List;
import java.util.Scanner;

public class WateringPlants {

	private static final int INF = Integer.MAX_VALUE;
	private static final double EPSILON = 1e-6;
	static final double PI = Math.PI;

	
	static class Line {
		double a, b, c;

		public Line(double a, double b, double c) {
			super();
			this.a = a;
			this.b = b;
			this.c = c;
		}

	}

	static class Point {
		double x, y;

		public Point(double x, double y) {
			super();
			this.x = x;
			this.y = y;
		}

		public String toString() {
			return x + "," + y;
		}
	}

	static class Circle {
		double radius;
		Point center;

		public Circle(Point center, double radius) {
			super();
			this.center = center;
			this.radius = radius;
		}

		public Circle(double radius) {
			super();
			this.center = new Point(0, 0);
			this.radius = radius;
		}
	}

	public static void main(String[] args) {

		Scanner sc = new Scanner(new BufferedInputStream(System.in));
		StringBuilder out = new StringBuilder();
		
		int testCases = sc.nextInt();
		for (int m = 0; m < testCases; m++) {
			int n = sc.nextInt();
			if (n == 0)
				break;

			Circle[] plants = new Circle[n];

			for (int i = 0; i < n; i++) {
				plants[i] = new Circle(new Point(sc.nextInt(), sc.nextInt()), sc.nextInt());
			}

			double radius;
			if (plants.length == 1) {
				radius = plants[0].radius;
			} else {
				radius = findMinRadius(plants);
			}
			out.append("Case #" + (m+1) + ": ");
			
			DecimalFormat df = new DecimalFormat("0.0000000");
			out.append(df.format(radius).replace(",", ".") + "\n");


		}
		System.out.print(out);
	}

	private static double findMinRadius(Circle[] plants) {
		double minRadius = INF;
		for (int i = 0; i < plants.length; i++) {
			for (int j = i+1; j < plants.length; j++) {
				Circle c = new Circle(mediumPoint(plants[i].center, plants[j].center), (distance(plants[i].center,plants[j].center) + plants[i].radius + plants[j].radius)/2.0);
				Circle[] restante = outOfCircle(plants, c);
				double radius = minRadius(restante, 0, restante.length-1);
				minRadius = Math.min(Math.max(c.radius, radius), minRadius);
				
				for (int k = j+1; k < plants.length; k++) {
					c = points2Circle(plants[i].center, plants[j].center, plants[k].center);
					restante = outOfCircle(plants, c);
					radius = minRadius(restante, 0, restante.length-1);
					minRadius = Math.min(Math.max(c.radius, radius), minRadius);
				}
				
			}
		}
		return minRadius;
	}

	private static Circle[] outOfCircle(Circle[] plants, Circle c) {
		List<Circle> out = new LinkedList<Circle>();
		for (int m = 0; m < plants.length; m++) {
			if (!in_circle(c, plants[m])) {
				out.add(plants[m]);
			}
		}
		Circle[] restante = out.toArray(new Circle[]{});
		return restante;
	}


	private static double minRadius(Circle[] points, int inicio, int fim) {

		Circle c = new Circle(-INF);
		for (int i = inicio; i <= fim; i++) {
			if (!in_circle(c, points[i])) {
				c = new Circle(points[i].center, 0);
				for (int j = inicio; j < i; j++) {
					if (!in_circle(c, points[j])) {
						c = new Circle(mediumPoint(points[i].center, points[j].center),
								(distance(points[i].center, points[j].center) + points[i].radius + points[j].radius) / 2);
						for (int k = inicio; k < j; k++)
							if (!in_circle(c, points[k])) {
								Point o = circumcenter(points[i].center, points[j].center,
										points[k].center);
								c = new Circle(o, distance(o, points[k].center) + points[k].radius);
							}

					}
				}
			}
		}
		return c.radius;
	}

	private static Point mediumPoint(Point p1, Point p2) {
		return new Point((p1.x + p2.x) / 2.0, (p1.y + p2.y) / 2.0);
	}

	private static Point circumcenter(Point p1, Point p2, Point p3) {
		Point a = diff(p1, p3);
		Point b = diff(p2, p3);
		Point c = new Point(times(a, sum(p1, p3)) / 2.0,
				times(b, sum(p2, p3)) / 2.0);
		return div(new Point(mod(c, new Point(a.y, b.y)), mod(new Point(a.x,
				b.x), c)), mod(a, b));
	}

	private static Point div(Point p, double d) {
		return new Point(p.x / d, p.y / d);
	}

	private static double mod(Point p1, Point p2) {
		return p1.x * p2.y - p2.x * p1.y;
	}

	private static double times(Point p1, Point p2) {
		return p1.x * p2.x + p1.y * p2.y;
	}

	private static Point sum(Point p1, Point p2) {
		return new Point(p1.x + p2.x, p1.y + p2.y);
	}

	private static Point diff(Point p1, Point p2) {
		return new Point(p1.x - p2.x, p1.y - p2.y);
	}

	private static boolean in_circle(Circle c, Circle plants) {
		return Double.compare(distance(c.center, plants.center) + plants.radius, c.radius) <= EPSILON;
	}

	private static double distance(Point p1, Point p2) {
		return Math.sqrt(Math.pow(p1.x - p2.x, 2) + Math.pow(p1.y - p2.y, 2));
	}
	
	static Line point_and_slope_to_line(Point p, double m) {
		double a= -m;
		double b = 1;
		double c = -((a* p.x) + (b*p.y));
		Line l = new Line(a, b, c);
		return l;
	}
	
	private static Circle points2Circle(Point p1, Point p2, Point p3) {
	
		Line l1 = makeLine(p1,p2);
		Line l2 = makeLine(p1,p3);
		if (same_lineQ(l1, l2) || parallelQ(l1, l2)) return new Circle(-INF);
		Point center = intersection_point(l1, l2);
		
		Circle c = new Circle(center, distance(p1,center));
		return c;
	}
	
	private static Point intersection_point(Line l1, Line l2) {
		double x = (l2.b * l1.c - l1.b*l2.c) / (l2.a*l1.b - l1.a*l2.b);
		double y;
		if (Math.abs(l1.b) <= EPSILON) {
			y = - (l2.a * x + l2.c) / l2.b;
		} else {
			y = - (l1.a * x + l1.c) / l1.b;
		}
		return new Point(x,y);
	}

	private static boolean same_lineQ(Line l1, Line l2) {
		return parallelQ(l1,l2) && (Math.abs(l1.c-l2.c) <= EPSILON); 
	}

	private static boolean parallelQ(Line l1, Line l2) {
		return ( ( Math.abs(l1.a - l2.a) <= EPSILON) && (Math.abs(l1.b - l2.b) <= EPSILON));
	}

	private static Line makeLine(Point p1, Point p2) {
		
		if (p1.y == p2.y) {
			double c = (p1.x + p2.x) / 2.0;
			Line l = new Line(1,0,-c);
			return l;
		}
		double m =  - (p2.x - p1.x) / (p2.y - p1.y);
		Point pm = mediumPoint(p1,p2);
		Line l = point_and_slope_to_line(pm, m);
		return l;
	}

}
