package us.drob;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.util.HashMap;
import java.util.Map;
import java.util.Scanner;

public class Main {

    public static int removeAll(Map<Character, Integer> counts, Character uniqueChar, String digitString) {
        Integer numToRemoveObj = counts.get(uniqueChar);
        int numToRemove;
        if (numToRemoveObj == null) {
            numToRemove = 0;
        } else {
            numToRemove = numToRemoveObj;
        }
        if (numToRemove == 0) {
            return 0;
        }

//        System.out.println("Removing all from " + digitString);
        for (char ch : digitString.toCharArray()) {
//            System.out.println("Removing all of " + ch);
            int prev = counts.get(ch);
            counts.put(ch, prev - numToRemove);
        }

        return numToRemove;
    }

    public static String computePhoneNum(String digitString) {
//        System.out.println("All digits string: " + digitString);
        Map<Character, Integer> letterCounts = new HashMap<Character, Integer>();
        for (int i = 0; i < digitString.length(); i++) {
            char next = digitString.charAt(i);
            Integer count = letterCounts.get(next);
            if (count == null) {
                count = 0;
            }
            count++;
            letterCounts.put(next, count);
        }

        int[] digitCounts = new int[10];

        // These strings each have a uniquely-identifying character.
        digitCounts[0] = removeAll(letterCounts, 'Z', "ZERO");
        digitCounts[2] = removeAll(letterCounts, 'W', "TWO");
        digitCounts[4] = removeAll(letterCounts, 'U', "FOUR");
        digitCounts[6] = removeAll(letterCounts, 'X', "SIX");
        digitCounts[8] = removeAll(letterCounts, 'G', "EIGHT");

        // Any remaining 'O's have to be from "ONE".
        digitCounts[1] = removeAll(letterCounts, 'O', "ONE");

        // Any remaining 'T's have to be from "THREE".
        digitCounts[3] = removeAll(letterCounts, 'T', "THREE");

        // Any remaining 'F's have to be from "FIVE".
        digitCounts[5] = removeAll(letterCounts, 'F', "FIVE");

        // Any remaining 'V's have to be from "SEVEN".
        digitCounts[7] = removeAll(letterCounts, 'V', "SEVEN");

        // Any remaining 'I's have to be from "NINE".
        digitCounts[9] = removeAll(letterCounts, 'I', "NINE");

        int stringLength = 0;
        for (int digitCount : digitCounts) {
            stringLength += digitCount;
        }
        StringBuilder builder = new StringBuilder(stringLength);

        for (int i = 0; i < digitCounts.length; i++) {
            for (int j = 0; j < digitCounts[i]; j++) {
                builder.append(Integer.toString(i));
            }
        }

        return builder.toString();
    }


    public static void main(String[] args) {
        if (args.length != 2) {
            System.out.println("Usage: java digits inputfile outputfile");
            System.exit(1);
        }
        String inputFile = args[0];
        String outputFile = args[1];

        Scanner scanner = null;
        try {
            scanner = new Scanner(new File(inputFile));
        } catch (FileNotFoundException e) {
            System.out.println(String.format("Unable to open test file: %s", inputFile));
            e.printStackTrace();
            System.exit(1);
        }
        scanner.useDelimiter(System.getProperty("line.separator"));
        if (!scanner.hasNext()) {
            System.out.println(String.format("Empty input file: %s", inputFile));
            System.exit(1);
        }

        PrintWriter output = null;
        try {
            output = new PrintWriter(outputFile, "UTF-8");
        } catch (FileNotFoundException e) {
            System.out.println(String.format("Unable to open test file: %s", outputFile));
            e.printStackTrace();
            System.exit(1);
        } catch (UnsupportedEncodingException e) {
            System.out.println("Can't find UTF-8 encoding.");
            e.printStackTrace();
            System.exit(1);
        }

        // Assuming here that the file is formatted as specified in the problem statement.
        int numCases = Integer.parseInt(scanner.next());
        for (int i = 0; i < numCases; i++) {
            String nextCase = scanner.next();
            String phoneNum = computePhoneNum(nextCase);
            output.println(String.format("Case #%d: %s", i + 1, phoneNum));
        }
        output.flush();
        output.close();
    }
}
