package us.drob;

import java.math.BigInteger;

public class Main {
    // Assuming only one test case, not bothering with parsing input.
    public static final int JAMCOIN_LENGTH = 32;
    public static final int NUM_JAMCOINS = 500;

    // Returns a nontrivial divisor of `candidate`, but might give up and return 0.
    public static BigInteger getDivisor(BigInteger candidate) {
        // Give up if we've tried this many divisors and not found one.
        BigInteger maxCheck = BigInteger.valueOf(1000000);
        for (BigInteger i = BigInteger.valueOf(2); i.compareTo(maxCheck) < 0; i = i.add(BigInteger.ONE)) {
            if (candidate.mod(i).equals(BigInteger.ZERO)) {
                return i;
            }
        }
        return BigInteger.ZERO;
    }

    // Returns an array of 9 nontrivial divisors (one for each base) if
    // candidate is a jamcoin. Returns null if candidate is a jamcoin *or*
    // if we give up on it.
    public static BigInteger[] checkJamcoin(String candidate) {
        BigInteger[] divisors = new BigInteger[9];
        for (int base = 2; base <= 10; base++) {
            BigInteger parsed = new BigInteger(candidate, base);
            BigInteger divisor = getDivisor(parsed);
            if (divisor.equals(BigInteger.ZERO)) {
                return null;
            } else {
                divisors[base - 2] = divisor;
            }
        }
        return divisors;
    }

    public static String padLeft(String toPad, int desiredLength) {
        for (int i = toPad.length(); i < desiredLength; i++) {
            toPad = '0' + toPad;
        }
        return toPad;
    }

    public static void main(String[] args) {
        int numJamcoinsFound = 0;
        int candidateNumber = 0;

        // Assuming only one case.
        System.out.println("Case #1:");

        while (numJamcoinsFound < NUM_JAMCOINS) {
            String toPad = Integer.toString(candidateNumber, 2);
            String candidateJamcoin = String.format("1%s1", padLeft(toPad, JAMCOIN_LENGTH - 2));
            candidateNumber++;
            BigInteger[] result = checkJamcoin(candidateJamcoin);
            if (result == null) {
                continue;
            }
            String output = candidateJamcoin;
            for (BigInteger divisor : result) {
                output += String.format(" %s", divisor.toString());
            }
            System.out.println(output);
            numJamcoinsFound++;
        }
    }
}
