package us.drob;

public class Main {
    // Assuming only one test case, not bothering with parsing input.
    public static final int JAMCOIN_LENGTH = 16;
    public static final int NUM_JAMCOINS = 50;

    // Returns a nontrivial divisor of `candidate`, unless `candidate`
    // is prime, in which case returns 0.
    public static long getDivisor(long candidate) {
        double upperBound = Math.sqrt(candidate) + 1;
        for (long i = 2; i <= upperBound && i < candidate; i++) {
            if (candidate % i == 0) {
                return i;
            }
        }
        return 0;
    }

    // Returns an array of 9 nontrivial divisors (one for each base) if
    // candidate is a jamcoin. Otherwise, returns null.
    public static long[] checkJamcoin(String candidate) {
        long[] divisors = new long[9];
        for (int base = 2; base <= 10; base++) {
            long divisor = getDivisor(Long.parseLong(candidate, base));
            if (divisor == 0) {
                return null;
            } else {
                divisors[base - 2] = divisor;
            }
        }
        return divisors;
    }

    public static String padLeft(String toPad, int desiredLength) {
        for (int i = toPad.length(); i < desiredLength; i++) {
            toPad = '0' + toPad;
        }
        return toPad;
    }

    public static void main(String[] args) {
        int numJamcoinsFound = 0;
        int candidateNumber = 0;

        // Assuming only one case.
        System.out.println("Case #1:");

        while (numJamcoinsFound < NUM_JAMCOINS) {
            String toPad = Integer.toString(candidateNumber, 2);
            String candidateJamcoin = String.format("1%s1", padLeft(toPad, JAMCOIN_LENGTH - 2));
            candidateNumber++;
            long[] result = checkJamcoin(candidateJamcoin);
            if (result == null) {
                continue;
            }
            String output = candidateJamcoin;
            for (long divisor : result) {
                output += String.format(" %d", divisor);
            }
            System.out.println(output);
            numJamcoinsFound++;
        }
    }
}
