package us.drob;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.util.Scanner;

public class Main {
    // Assumes pancakeStack is made up of `+` and `-` only.
    public static int computeNumFlips(String pancakeStack) {
        int numFlips = 0;
        char prevPancake = '+';
        for (int i = pancakeStack.length() - 1; i >= 0; i--) {
            if (pancakeStack.charAt(i) != prevPancake) {
                numFlips++;
                prevPancake = pancakeStack.charAt(i);
            }
        }
        return numFlips;
    }

    public static void main(String[] args) {
        if (args.length != 2) {
            System.out.println("Usage: java pancakes inputfile outputfile");
            System.exit(1);
        }
        String inputFile = args[0];
        String outputFile = args[1];

        Scanner scanner = null;
        try {
            scanner = new Scanner(new File(inputFile));
        } catch (FileNotFoundException e) {
            System.out.println(String.format("Unable to open test file: %s", inputFile));
            e.printStackTrace();
            System.exit(1);
        }
        scanner.useDelimiter(System.getProperty("line.separator"));
        if (!scanner.hasNext()) {
            System.out.println(String.format("Empty input file: %s", inputFile));
            System.exit(1);
        }

        PrintWriter output = null;
        try {
            output = new PrintWriter(outputFile, "UTF-8");
        } catch (FileNotFoundException e) {
            System.out.println(String.format("Unable to open test file: %s", outputFile));
            e.printStackTrace();
            System.exit(1);
        } catch (UnsupportedEncodingException e) {
            System.out.println("Can't find UTF-8 encoding.");
            e.printStackTrace();
            System.exit(1);
        }

        // Assuming here that the file is formatted as specified in the problem statement.
        int numCases = Integer.parseInt(scanner.next());
        for (int i = 0; i < numCases; i++) {
            String nextCase = scanner.next();
            int numFlips = computeNumFlips(nextCase);
            output.println(String.format("Case #%d: %d", i + 1, numFlips));
        }
        System.out.println(String.format("Processed %d cases.", numCases));
        output.flush();
        output.close();
    }
}
