package roundtwo.a;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;

import roundtwo.util.CodeJam;

public class Main extends CodeJam {
	public static final String FILE_IN = "A/A-small-attempt0.in";

	private static final int MAX_NODES = 10000;
	private Node tree[] = new Node[MAX_NODES];
	enum Gate {AND, OR}
	
	public class Node {
		public Gate type;
		public boolean changable;
		public boolean flip;
		public int value;

		private Gate getGate() {
			if (flip) {
				if (type == Gate.AND) {
					return Gate.OR;
				}
				return Gate.AND;
			}
			return type;
		}
		
		public void operate(Node left, Node right) {
			if (getGate() == Gate.AND) {
				value = left.value & right.value; 
			} else {
				value = left.value | right.value;
			}
		}
	}
	
	static int leftChild(int node) {
		return (node + 1) * 2 - 1;
	}
	
	static int rightChild(int node) {
		return (node + 1) * 2;
	}
	
	static int parent(int node) {
	    return (node - 1) / 2; 
	}
	
	boolean evaluate() {
		for (int i = interiorNodes - 1; i >= 0; i--) {
			tree[i].operate(tree[leftChild(i)], tree[rightChild(i)]);
		}
		return tree[0].value == desiredValue;
	}

	boolean evaluate(boolean changedState[]) {
		for (int i = 0; i < changedState.length; i++) {
			tree[changeable.get(i)].flip = changedState[i];
		}
		for (int i = interiorNodes - 1; i >= 0; i--) {
			tree[i].operate(tree[leftChild(i)], tree[rightChild(i)]);
		}
		return tree[0].value == desiredValue;
	}
	
	static int count(boolean changedState[]) {
		int count = 0;
		for (int i = 0; i < changedState.length; i++) {
			if (changedState[i]) {
				count++;
			}
		}
		return count;
	}
	
	ArrayList<boolean[]> queue = new ArrayList<boolean[]>();
	int bfs(int canChange) {
		queue.clear();
		queue.add(new boolean[canChange]);
		
		while (queue.size() != 0) {
			boolean changedState[] = queue.remove(0);

			for (int i = 0; i < changedState.length; i++) {
				tree[changeable.get(i)].flip = changedState[i];
			}

			for (int i = 0; i < changedState.length; i++) {
				if (!changedState[i]) {
					boolean nextState[] = Arrays.copyOf(changedState, changedState.length);
					nextState[i] = true;

					if (evaluate(nextState)) {
						return count(nextState);
					}

					queue.add(nextState);
				}
			}
		}
		
		return -1;
	}
	
	int interiorNodes;
	int desiredValue;
	ArrayList<Integer> changeable = new ArrayList<Integer>();
	
	@Override
	public String go() throws IOException {
		int nodeCount = scanner.nextInt();
		desiredValue = scanner.nextInt();
		changeable.clear();
		
		interiorNodes = (nodeCount - 1) / 2;
		for (int i = 0; i < interiorNodes; i++) {
			tree[i] = new Node();
			if (scanner.nextInt() == 1) {
				tree[i].type = Gate.AND;
			} else {
				tree[i].type = Gate.OR;
			}
			
			if (scanner.nextInt() == 1) {
				changeable.add(i);
				tree[i].changable = true;
			} else {
				tree[i].changable = false;
			}
		}

		for (int i = interiorNodes; i < nodeCount; i++) {
			tree[i] = new Node();
			tree[i].value = scanner.nextInt();
		}

		if (evaluate()) {
			return "0";
		}
		int result = bfs(changeable.size());

		if (result == -1) {
			return "IMPOSSIBLE";
		}
		
		return Integer.toString(result);
	}

	protected Main() throws IOException {
		super(FILE_IN);
	}
	
	public static void main(String args[]) {
		try {
			new Main().run();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
