package com.danwainwright.java.codejam.y2017.pancake.main;

import com.danwainwright.java.codejam.y2016.main.Pancakes.Pancake;

import java.util.ArrayList;
import java.util.List;

public class Row {
    private List<Pancake> row;
    private final int flipSize;
    private int flips;
    private int leftDone;
    private int rightDone;

    public Row(List<Pancake> row, int flipSize){
        this.row = row;
        this.flipSize = flipSize;
        this.flips = 0;
        this.leftDone = 0;
        this.rightDone = 0;
    }

    public Row(String row, int flipSize){
        this.row = new ArrayList<>();
        for (char c : row.toCharArray())
            this.row.add(new Pancake(c));
        this.flipSize = flipSize;
        this.flips = 0;
        this.leftDone = 0;
        this.rightDone = 0;
    }

    public void flip(int fromLeft){
        this.flips++;
        assert fromLeft >= 0;
        assert row.size() - fromLeft >= flipSize;
        for (int i = fromLeft; i < fromLeft + flipSize; i++)
            row.get(i).flip();
    }

    public List<Pancake> getRow(){
        return row;
    }

    private boolean solved(){
        for (Pancake p : this.row){
            if (p.getTop() == Pancake.Side.BLANK)
                return false;
        }
        return true;
    }

    private void flipLeft() throws NotPossible{
        for (int i = leftDone; i < this.row.size(); i++) {
            if (this.row.get(i).getTop() == Pancake.Side.HAPPY)
                leftDone++;
            else
                break;
        }
        if (row.size() - leftDone - rightDone >= flipSize){
            flip(leftDone);
        } else
            throw new NotPossible();
    }

    private void flipRight() throws NotPossible{
        for (int i = row.size() - rightDone; i > 0; i++) {
            if (this.row.get(i).getTop() == Pancake.Side.HAPPY)
                rightDone++;
            else
                break;
        }
        if (row.size() - leftDone - rightDone >= flipSize){
            flip(row.size() - rightDone);
        } else
            throw new NotPossible();
    }

    private void flipEnds() throws NotPossible{
        flipLeft();
        //flipRight();
    }

    public void solve() throws NotPossible{
        while (!solved()){
            flipLeft();
        }
    }

    public int getFlips(){
        return flips;
    }

    @Override
    public String toString() {
        StringBuilder pancakes = new StringBuilder("Row: ");
        for (Pancake p : row)
            pancakes.append(p.toString());
        pancakes.append(" flip: ");
        pancakes.append(flipSize);
        return pancakes.toString();
    }
}
