package com.danwainwright.java.codejam.y2017.bathroom.main;

import java.util.PriorityQueue;

public class Room {
    private PriorityQueue<Space> spaces;
    private int lastAdded;
    private int size;

    public Room(int size){
        spaces = new PriorityQueue<>(size);
        spaces.add(new Space(1, size));
        this.size = size;
    }

    private Space max(){
        assert !spaces.isEmpty();
        return spaces.poll();
    }

    private void largestSpace(){
        Space space = max();
        assert space != null;
        int location = (int) Math.ceil((double)space.size / 2.0) + space.start - 1;
        lastAdded = location;
        int left = location - space.start;
        int right = space.size - left -1;
        if (left > 0)
            spaces.add(new Space(space.start, left));
        if (right > 0)
            spaces.add(new Space(location + 1, right));
    }

    public void test(int amount){
        assert amount <= size;
        for (int i = 0; i < amount ; i++) {
            largestSpace();
        }
    }

    public int getLeftSpace(int position){
        return spaces.stream().filter(x-> x.end == position -1).findFirst().orElse(new Space(0,0)).size;
    }

    public int getRightSpace(int position){
        return spaces.stream().filter(x-> x.start == position + 1).findFirst().orElse(new Space(0,0)).size;
    }

    public int getLastAdded(){
        return lastAdded;
    }



    public class Space implements Comparable<Space> {
        public final int size;
        public final int start;
        public final int end;

        public Space(int start, int size){
            this.start = start;
            this.end = start + size - 1;
            this.size = size;
        }

        @Override
        public int compareTo(Space space) {
            int sizeCompare =  Integer.compare(space.size, size);
            if (sizeCompare == 0)
                return Integer.compare(start,space.start);
            else
                return sizeCompare;
        }
    }
}
