import java.util.PriorityQueue;
import java.util.Arrays;
import java.util.Comparator;
import java.io.*;

/**
 * Create on 17/07/2008.
 */
public class Trains
{
    public static class Ride
    {
        int start;
        int end;
        boolean fromA;


        public String toString ()
        {
            return formatTime(start) + " " + formatTime(end) + " " +
                    (fromA ? "A" : "B");
        }

    }

    public static int trainsA;
    public static int trainsB;

    public static void solve (Ride[] rides, boolean trace)
    {
        // all the trains in station a and the time of their availablity
        PriorityQueue<Integer> a = new PriorityQueue<Integer>(rides.length);
        // and for b
        PriorityQueue<Integer> b = new PriorityQueue<Integer>(rides.length);

        trainsA = 0;
        trainsB = 0;

        for (Ride next : rides)
        {
            if (next.fromA)
            {
                if (a.size() > 0 && next.start >= a.peek())
                    a.poll();       // use the available train
                else
                    trainsA++;       // get another train
                // now add a train to station b at the end of this travel
                b.add(next.end);
            }
            else
            {
                if (b.size() > 0 && next.start >= b.peek())
                    b.poll();
                else
                    trainsB++;
                a.add(next.end);
            }
        }
    }


    public static int parseTime (String timeString)
    {
        return Integer.parseInt(timeString.substring(0,2)) * 60 +
                Integer.parseInt(timeString.substring(3));
    }

    public static String formatTime (int time)
    {
        StringBuilder sb = new StringBuilder();
        sb.append(time / 60);
        sb.append(":");
        sb.append(time % 60);
        return sb.toString();
    }

    public static void main(String[] args) throws IOException
    {
        String filename = args[0];

        boolean trace = (args.length > 1) && Boolean.parseBoolean(args[1]);

        BufferedReader reader = new BufferedReader(new FileReader(filename));


        BufferedWriter writer = new BufferedWriter(new FileWriter("B.out.txt"));

        int nCases = Integer.parseInt(reader.readLine());
        for (int i = 0; i < nCases; i++)
        {
            int T = Integer.parseInt(reader.readLine());

            String line = reader.readLine();
            String[] tokens = line.split("\\s+");

            int nA = Integer.parseInt(tokens[0]);
            int nB = Integer.parseInt(tokens[1]);

            Ride[] rides = new Ride[nA+nB];

            for (int j = 0; j < rides.length; j++)
            {
                line = reader.readLine();
                tokens = line.split("\\s+");

                rides[j] = new Ride();
                rides[j].fromA = (j < nA);
                rides[j].start = parseTime(tokens[0]);
                rides[j].end = parseTime(tokens[1]) + T;
            }

            Arrays.sort(rides, new Comparator<Ride>()
            {
                public int compare(Ride o1, Ride o2)
                {
                    return o1.start - o2.start;
                }
            });

            if (trace)
                for (Ride ride : rides )
                    System.out.println(ride);

            solve(rides, trace);

            String resString =  "Case #" +  (i+1) + ": " + trainsA + " " + trainsB;
            System.out.println(resString);
            writer.write(resString + "\n");

        }

        writer.close();




    }
}
