public class Watersheds {

    public static int index(int i, int j, int W)
    { return i * W + j; }
    
    public static boolean north(int[][] map, int i, int j) {
        return ((map[i-1][j] < map[i][j]) && (map[i-1][j] <= map[i][j-1]) && 
                (map[i-1][j] <= map[i][j+1]) && (map[i-1][j] <= map[i+1][j]));
    }
    
    public static boolean west(int[][] map, int i, int j) {
        return ((map[i][j-1] < map[i][j]) && (map[i][j-1] < map[i-1][j]) && 
                (map[i][j-1] <= map[i][j+1]) && (map[i][j-1] <= map[i+1][j]));
    }
    
    public static boolean east(int[][] map, int i, int j) {
        return ((map[i][j+1] < map[i][j]) && (map[i][j+1] < map[i-1][j]) && 
                (map[i][j+1] < map[i][j-1]) && (map[i][j+1] <= map[i+1][j]));
    }
    
    public static boolean south(int[][] map, int i, int j) {
        return ((map[i+1][j] < map[i][j]) && (map[i+1][j] < map[i-1][j]) && 
                (map[i+1][j] < map[i][j-1]) && (map[i+1][j] < map[i][j+1]));
    }
        
    
    public static void analyseMap(int[][] map, int H, int W) {
        
         String basinname = "abcdefghijklmnopqrstuvwxyz";
        
         char[][] outmap = new char[H][W];
         
         QuickUWPC analyser = new QuickUWPC(H * W);
         
         for (int i = 1; i <= H; i++)
             for (int j = 1; j <= W; j++)
         {
             if (north(map, i, j)) analyser.unite(index(i-1, j-1, W), index(i-2, j-1, W));
             else if (west(map, i, j)) analyser.unite(index(i-1, j-1, W), index(i-1, j-2, W));
             else if (east(map, i, j)) analyser.unite(index(i-1, j-1, W), index(i-1, j, W));
             else if (south(map, i, j)) analyser.unite(index(i-1, j-1, W), index(i, j-1, W));
         }
         
         boolean[][] marked = new boolean[H][W];
         for (int i = 0; i < H; i++) for (int j = 0; j < W; j++) marked[i][j] = false;
         
         //System.out.println("*********** component: " + analyser.components());
         //System.out.println("(0, 0) connected to (0, 1)?: " + analyser.find(0, 1));
         
         int color = 0;
         for (int i = 0; i < H; i++)
             for (int j = 0; j < W; j++)
             if (!marked[i][j])
         {
             outmap[i][j] = basinname.charAt(color); marked[i][j] = true;
             for (int p = 0; p < H; p++)
                 for (int q = 0; q < W; q++)
             {
                 //System.out.println("("+p+","+q+") connected to ("+i+","+j+")?: " + analyser.find(index(p, q, W), index(i, j, W)));
                 if (analyser.find(index(p, q, W), index(i, j, W))) 
                 { 
                     outmap[p][q] = basinname.charAt(color); 
                     marked[p][q] = true; 
                     //System.out.println("("+p+","+q+") is " +outmap[p][q]);
                 }
             }
             
             color++;
         }
         
             
         for (int i = 0; i < H; i++)
         {
             for (int j = 0; j < W; j++) 
             {
                 System.out.print(outmap[i][j]);
                 if (j < W - 1) System.out.print(" ");
             }
             System.out.println();
         }
         
         
    }
    
    public static void main(String[] args) {
        
        int T;
        T = StdIn.readInt();
        int[][] dimension = new int[T][2];        
        int[][][] maps = new int[T][][];
        for (int i = 0; i < T; i++)
        {
            dimension[i][0] = StdIn.readInt();
            dimension[i][1] = StdIn.readInt();
            maps[i] = new int[dimension[i][0]+2][dimension[i][1]+2];
            for (int j = 0; j < (dimension[i][0]+2); j++) for (int k = 0; k < (dimension[i][1]+2); k++) 
            {
                if ((j == 0) || (j == dimension[i][0]+1)) maps[i][j][k] = 999999;
                else if ((k == 0) || (k == dimension[i][1]+1)) maps[i][j][k] = 999999;
                else maps[i][j][k] = StdIn.readInt();
            }
        }
        
        //Test correct input
//        System.out.println(T);
//        for (int i = 0; i < T; i++)
//        {
//            System.out.println(dimension[i][0] + " " + dimension[i][1]);
//            for (int j = 0; j < dimension[i][0]+2; j++) 
//            {
//                for (int k = 0; k < dimension[i][1]+2; k++) System.out.print(maps[i][j][k] + " ");
//                System.out.println();
//            }
//        }
        
        for (int i = 0; i < T; i++)
        {
            System.out.println("Case #" + (i+1) + ":");
            analyseMap(maps[i], dimension[i][0], dimension[i][1]);
        }
        
    }
    
}