import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Locale;
import java.util.StringTokenizer;
import java.util.TreeSet;

public class Solution implements Runnable {
	
	private PrintStream out;
	private BufferedReader in;
	private StringTokenizer st;
	
	public void solve() throws IOException {
		long time0 = System.currentTimeMillis();
		
		int t = nextInt();
		for (int test = 1; test <= t; test++) {
			int n = nextInt();
			int k = nextInt();
			int[] r = new int[n];
			int[] h = new int[n];
			for (int i = 0; i < n; i++) {
				r[i] = nextInt();
				h[i] = nextInt();
			}
			double answer = solve(n, k, r, h);
			out.println("Case #" + test + ": " + answer);
		}
		
		System.err.println("time: " + (System.currentTimeMillis() - time0) + " ms.");
	}
	
	private double solve(int n, int k, int[] r, int[] h) {
		Pancake[] p = new Pancake[n];
		for (int i = 0; i < n; i++) {
			p[i] = new Pancake(i, r[i], h[i]);
		}
		Arrays.sort(p, new Comparator<Pancake>() {
			@Override
			public int compare(Pancake o1, Pancake o2) {
				if (o1.r < o2.r) {
					return -1;
				}
				if (o1.r > o2.r) {
					return 1;
				}
				return 0;
			}
		});
		TreeSet<Pancake> a = new TreeSet<>(new Comparator<Pancake>() {
			@Override
			public int compare(Pancake o1, Pancake o2) {
				if (o1.sideSquare < o2.sideSquare) {
					return -1;
				}
				if (o1.sideSquare > o2.sideSquare) {
					return 1;
				}
				if (o1.id < o2.id) {
					return -1;
				}
				if (o1.id > o2.id) {
					return 1;
				}
				return 0;
			}
		});
		double answer = 0;
		double sideSum = 0;
		for (int i = 0; i < n; i++) {
			a.add(p[i]);
			sideSum += p[i].sideSquare;
			if (a.size() == k) {
				int ansr = p[i].r;
				double s = Math.PI * ansr * ansr + sideSum;
				answer = Math.max(answer, s);
				
				Pancake last = a.pollFirst();
				sideSum -= last.sideSquare;
			}
		}
		return answer;
	}
	
	private static class Pancake {
		public int id;
		public int r;
		public double sideSquare;
		public Pancake(int id, int r, int h) {
			this.id = id;
			this.r = r;
			this.sideSquare = 2 * Math.PI * r * h;
		}
	}

	public double nextDouble() throws IOException {
		return Double.parseDouble(next());
	}
	
	public long nextLong() throws IOException {
		return Long.parseLong(next());
	}
	
	public int nextInt() throws IOException {
		return Integer.parseInt(next());
	}
	
	public String next() throws IOException {
		while (!st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}
	
	@Override
	public void run() {
		try {
			solve();
			out.close();
		} catch (Throwable e) {
			throw new RuntimeException(e);
		}
	}
	
	public Solution(String name) throws IOException {
		Locale.setDefault(Locale.US);
		if (name == null) {
			in = new BufferedReader(new InputStreamReader(System.in));
			out = new PrintStream(new BufferedOutputStream(System.out));
		} else {
			in = new BufferedReader(new InputStreamReader(new FileInputStream(name + ".in")));
			out = new PrintStream(new BufferedOutputStream(new FileOutputStream(name + ".out")));
		}
		st = new StringTokenizer("");
	}
	
	public static void main(String[] args) throws IOException {
		new Thread(new Solution(null)).start();
	}
}
