import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Locale;
import java.util.StringTokenizer;

public class Solution implements Runnable {
	
	private static final int MOD = 1000000007;
	
	private BufferedReader in;
	private StringTokenizer st;
	private PrintWriter out;
	
	private void solve() throws IOException {
		int t = nextInt();
		for (int test = 1; test <= t; test++) {
			int m = nextInt();
			int n = nextInt();
			String[] s = new String[m];
			for (int i = 0; i < m; i++) {
				s[i] = next();
			}
			out.println("Case #" + test + ": " + solve(s, n));
		}
	}
	
	private String solve(String[] s, int n) {
		int[] mask = new int[n];
		int[] answer = new int[] {0, 1};
		solve(s, 0, mask, 0, n, answer);
		return answer[0] + " " + answer[1];
	}

	private void solve(String[] s, int used, int[] mask, int done, int n, int[] answer) {
		if (done == n) {
			update(s, mask, answer);
			return;
		}
		for (int i = (1 << s.length) - 1; i > 0; i--) {
			if ((used & i) == 0) {
				mask[done] = i;
				solve(s, used | i, mask, done + 1, n, answer);
			}
		}
	}

	private void update(String[] s, int[] mask, int[] answer) {
		int size = measure(s, mask);
		if (answer[0] < size) {
			answer[0] = size;
			answer[1] = 1;
		} else if (answer[0] == size) {
			answer[1] = (answer[1] + 1) % MOD;
		}
	}

	private int measure(String[] s, int[] mask) {
		int answer = 0;
		for (int i = 0; i < mask.length; i++) {
			answer += measure(s, mask[i]);
		}
		return answer;
	}

	private int measure(String[] s, int mask) {
		int result = 1;
		ArrayList<String> tree = new ArrayList<String>();
		for (int i = 0; i < s.length; i++) {
			if ((mask & (1 << i)) != 0) {
				result += addString(s[i], tree);
			}
		}
		return result;
	}

	private int addString(String s, ArrayList<String> tree) {
		int max = 0;
		for (String s1 : tree) {
			int common = common(s, s1);
			max = Math.max(max, common);
		}
		tree.add(s);
		return s.length() - max;
	}

	private int common(String s1, String s2) {
		int i = 0;
		while (i < s1.length() && i < s2.length() && s1.charAt(i) == s2.charAt(i)) {
			i++;
		}
		return i;
	}

	@Override
	public void run() {
		try {
			solve();
		} catch (Throwable e) {
			e.printStackTrace();
			System.exit(1);
		} finally {
			out.close();
		}
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(next());
	}
	
	private String next() throws IOException {
		while (!st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}
	
	public Solution(String filename) {
		try {
			in = new BufferedReader(new FileReader(filename + ".in"));
			st = new StringTokenizer("");
			out = new PrintWriter(new FileWriter(filename + ".out"));
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
	
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new Solution("data").run();
	}
}
