import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.StringTokenizer;


public class Solution implements Runnable {
	
	private static final String IMPOSSIBLE = "Impossible";
	private static final int MAXH = 1000000000;
	
	private BufferedReader in;
	private StringTokenizer st;
	private PrintWriter out;
	
	private String solve(int[] v) {
		int n = v.length + 1;
		int[] x = new int[n];
		x[n - 1] = MAXH;
		for (int i = 0; i < n - 1; i++) {
			if (v[i] <= i) {
				return IMPOSSIBLE;
			}
			x[i] = -1;
		}
		for (int tan = 0; tan < n; tan++) {
			for (int i = n - 2; i >= 0; i--) {
				if (i == 0 || (x[i - 1] >= 0 && x[i] == -1)) {
					int[] path = findPath(v, i, x);
					int ep = path.length - 1;
					int last = path[ep];
					for (int j = 0; j < ep; j++) {
						int u = path[j];
						x[u] = x[last] - tan * (last - u);
						if (x[u] < 0) {
							return IMPOSSIBLE;
						}
					}
				}
			}
		}
		return check(x, v);
	}
	
	private int[] findPath(int[] v, int start, int[] used) {
		int cnt = 1;
		int i = start;
		while (used[i] == -1) {
			i = v[i];
			cnt++;
		}
		int[] result = new int[cnt];
		cnt = 0;
		result[cnt++] = start;
		i = start;
		while (used[i] == -1) {
			i = v[i];
			result[cnt++] = i;
		}
		return result;
	}

	private String check(int[] x, int[] vis) {
		int n = x.length;
		for (int u = 0; u < n - 1; u++) {
			int v = vis[u];
			for (int i = u + 1; i < v; i++) {
				long idx = i - u;
				long idy = x[i] - x[u];
				long vdx = v - u;
				long vdy = x[v] - x[u];
				if (idy * vdx - idx * vdy >= 0) {
					return IMPOSSIBLE;
				}
			}
			for (int i = v + 1; i < n; i++) {
				long idx = i - u;
				long idy = x[i] - x[u];
				long vdx = v - u;
				long vdy = x[v] - x[u];
				if (idy * vdx - idx * vdy > 0) {
					return IMPOSSIBLE;
				}
			}
		}
		
		StringBuilder buf = new StringBuilder();
		for (int i = 0; i < x.length; i++) {
			if (i > 0) {
				buf.append(" ");
			}
			buf.append(x[i]);
		}
		return buf.toString();
	}

	private void solve() throws IOException {
		int t = nextInt();
		for (int test = 1; test <= t; test++) {
			int n = nextInt();
			int[] v = new int[n - 1];
			for (int i = 0; i < n - 1; i++) {
				v[i] = nextInt() - 1;
			}
			String answer = solve(v);
			out.println("Case #" + test + ": " + answer);
		}
	}

	@Override
	public void run() {
		try {
			solve();
		} catch (Throwable e) {
			apstenu(e);
		} finally {
			out.close();
		}
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(next());
	}
	
	private String next() throws IOException {
		while (!st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}
	
	private void apstenu(Throwable e) {
		e.printStackTrace();
		System.exit(1);
	}
	
	public Solution(String filename) {
		try {
			in = new BufferedReader(new FileReader(filename + ".in"));
			st = new StringTokenizer("");
			out = new PrintWriter(new FileWriter(filename + ".out"));
		} catch (IOException e) {
			apstenu(e);
		}
	}
	
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new Solution("data").run();
	}
	
}
