import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.Random;
import java.util.StringTokenizer;


public class Solution implements Runnable {
	
	private static final double mult = 1.01;
	
	private BufferedReader in;
	private StringTokenizer st;
	private PrintWriter out;
	
	private Random rnd;
	
	private double[][] solve(int w, int h, int[] r) {
		rnd = new Random();
		int n = r.length;
		double[][] result = new double[n][2];
		while (!good(result, r)) {
			normalPairs(result, r, w, h);
			normalBorder(result, w, h);
		}
		return result;
	}
	
	private void normalPairs(double[][] result, int[] r, int w, int h) {
		int n = result.length;
		for (int i = 0; i < n; i++) {
			for (int j = 0; j < n; j++) {
				if (i == j) {
					continue;
				}
				while (result[i][0] == result[j][0] && result[i][1] == result[j][1]) {
					result[j][0] = rnd.nextDouble() * w;
					result[j][1] = rnd.nextDouble() * h;
				}
				double d1 = Math.hypot(result[i][0] - result[j][0], result[i][1] - result[j][1]);
				double d2 = r[i] + r[j];
				if (d1 < d2) {
					double m = (d2 / d1) * mult;
					double xm = (result[i][0] + result[j][0]) / 2;
					double ym = (result[i][1] + result[j][1]) / 2;
					result[i][0] = xm + (result[i][0] - xm) * m;
					result[i][1] = ym + (result[i][1] - ym) * m;
					result[j][0] = xm + (result[j][0] - xm) * m;
					result[j][1] = ym + (result[j][1] - ym) * m;
				}
			}
		}
	}

	private void normalBorder(double[][] result, int w, int h) {
		for (int i = 0; i < result.length; i++) {
			if (result[i][0] < 0) {
				result[i][0] = 0;
			}
			if (result[i][1] < 0) {
				result[i][1] = 0;
			}
			if (result[i][0] > w) {
				result[i][0] = w;
			}
			if (result[i][1] > h) {
				result[i][1] = h;
			}
		}
	}

	private boolean good(double[][] result, int[] r) {
		int n = r.length;
		for (int i = 0; i < n; i++) {
			for (int j = 0; j < i; j++) {
				if (Math.hypot(result[i][0] - result[j][0], result[i][1] - result[j][1]) < r[i] + r[j]) {
					return false;
				}
			}
		}
		return true;
	}

	private void solve() throws IOException {
		int t = nextInt();
		for (int test = 1; test <= t; test++) {
			int n = nextInt();
			int w = nextInt();
			int h = nextInt();
			int[] r = new int[n];
			for (int i = 0; i < n; i++) {
				r[i] = nextInt();
			}
			double[][] answer = solve(w, h, r);
			StringBuilder buf = new StringBuilder();
			for (int i = 0; i < n; i++) {
				buf.append(" " + answer[i][0] + " " + answer[i][1]);
			}
			out.println("Case #" + test + ":" + buf.toString());
			out.flush();
		}
	}

	@Override
	public void run() {
		try {
			solve();
		} catch (Throwable e) {
			apstenu(e);
		} finally {
			out.close();
		}
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(next());
	}
	
	private String next() throws IOException {
		while (!st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}
	
	private void apstenu(Throwable e) {
		e.printStackTrace();
		System.exit(1);
	}
	
	public Solution(String filename) {
		try {
			in = new BufferedReader(new FileReader(filename + ".in"));
			st = new StringTokenizer("");
			out = new PrintWriter(new FileWriter(filename + ".out"));
		} catch (IOException e) {
			apstenu(e);
		}
	}
	
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new Solution("data").run();
	}
	
}
