import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.StringTokenizer;

public class Solution implements Runnable {
	
	private static final int MAXKN = 200;

	private static final String NO_SOLUTION = "IMPOSSIBLE";
	
	private BufferedReader in;
	private StringTokenizer st;
	private PrintWriter out;
	
	private String solve(int[] keys, int[] type, int[][] inside) {
		int n = type.length;
		
		int[][] was = new int[1 << n][];
		int[][] seq = new int[was.length][];
		
		was[0] = initKeyCollection(keys);
		seq[0] = new int[0];
		
		for (int mask = 0; mask < was.length; mask++) {
			if (was[mask] == null) {
				continue;
			}
			for (int next = 0; next < n; next++) {
				if ((mask & (1 << next)) == 0) {
					if (was[mask][type[next]] > 0) {
						int nextMask = mask | (1 << next);
						int[] nextSeq = append(seq[mask], next);
						if (better(nextSeq, seq[nextMask])) {
							was[nextMask] = open(was[mask], type[next], inside[next]);
							seq[nextMask] = nextSeq;
						}
					}
				}
			}
		}
		
		int end = was.length - 1;
		if (was[end] == null) {
			return NO_SOLUTION;
		}
		StringBuilder result = new StringBuilder();
		for (int i = 0; i < n; i++) {
			if (i != 0) {
				result.append(" ");
			}
			result.append(seq[end][i] + 1);
		}
		return result.toString();
	}
	
	private boolean better(int[] s1, int[] s2) {
		if (s2 == null) {
			return true;
		}
		for (int i = 0; i < s1.length; i++) {
			if (s1[i] < s2[i]) {
				return true;
			}
			if (s1[i] > s2[i]) {
				return false;
			}
		}
		return false;
	}

	private int[] append(int[] seq, int next) {
		int[] result = new int[seq.length + 1];
		for (int i = 0; i < seq.length; i++) {
			result[i] = seq[i];
		}
		result[seq.length] = next;
		return result;
	}

	private int[] open(int[] kc, int k, int[] inside) {
		int[] result = new int[kc.length];
		for (int i = 0; i < result.length; i++) {
			result[i] = kc[i];
		}
		result[k]--;
		for (int i = 0; i < inside.length; i++) {
			result[inside[i]]++;
		}
		return result;
	}

	private int[] initKeyCollection(int[] keys) {
		int[] result = new int[MAXKN + 1];
		for (int i = 0; i < keys.length; i++) {
			result[keys[i]]++;
		}
		return result;
	}
	
	private void solve() throws IOException {
		int t = nextInt();
		for (int test = 1; test <= t; test++) {
			System.out.println(test);
			int k = nextInt();
			int n = nextInt();
			int[] init = new int[k];
			for (int i = 0; i < k; i++) {
				init[i] = nextInt();
			}
			int[] type = new int[n];
			int[][] inside = new int[n][];
			for (int i = 0; i < n; i++) {
				type[i] = nextInt();
				int ki = nextInt();
				inside[i] = new int[ki];
				for (int j = 0; j < ki; j++) {
					inside[i][j] = nextInt();
				}
			}
			String answer = solve(init, type, inside);
			out.println("Case #" + test + ": " + answer);
		}
	}

	@Override
	public void run() {
		try {
			solve();
		} catch (Throwable e) {
			e.printStackTrace();
			System.exit(1);
		} finally {
			out.close();
		}
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(next());
	}
	
	private String next() throws IOException {
		while (!st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}
	
	public Solution(String filename) {
		try {
			in = new BufferedReader(new FileReader(filename + ".in"));
			st = new StringTokenizer("");
			out = new PrintWriter(new FileWriter(filename + ".out"));
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
	
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new Solution("data").run();
	}
}
