import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.StringTokenizer;


public class Solution implements Runnable {
	
	private static final char X = 'X';
	private static final char O = 'O';
	private static final char DOT = '.';
	private static final String[] WIN = {
		"X won",
		"O won"
	};
	private static final String DRAW = "Draw";
	private static final String NC = "Game has not completed";
	
	private BufferedReader in;
	private StringTokenizer st;
	private PrintWriter out;
	
	private String solve(char[][] a) {
		int ret;
		ret = ddiag(a);
		if (ret != -1) {
			return WIN[ret];
		}
		ret = rdiag(a);
		if (ret != -1) {
			return WIN[ret];
		}
		for (int i = 0; i < a.length; i++) {
			ret = hline(a, i);
			if (ret != -1) {
				return WIN[ret];
			}
			ret = vline(a, i);
			if (ret != -1) {
				return WIN[ret];
			}
		}
		if (hasDot(a)) {
			return NC;
		} else {
			return DRAW;
		}
	}
	
	private boolean hasDot(char[][] a) {
		for (int i = 0; i < a.length; i++) {
			for (int j = 0; j < a[i].length; j++) {
				if (a[i][j] == DOT) {
					return true;
				}
			}
		}
		return false;
	}

	private int hline(char[][] a, int i) {
		boolean hasX = false;
		boolean hasO = false;
		boolean hasDot = false;
		for (int j = 0; j < a[i].length; j++) {
			if (a[i][j] == X) {
				hasX = true;
			} else if (a[i][j] == O) {
				hasO = true;
			} else if (a[i][j] == DOT) {
				hasDot = true;
			}
		}
		if (hasX & !hasO & !hasDot) {
			return 0;
		}
		if (hasO & !hasX & !hasDot) {
			return 1;
		}
		return -1;
	}
	
	private int vline(char[][] a, int j) {
		boolean hasX = false;
		boolean hasO = false;
		boolean hasDot = false;
		for (int i = 0; i < a[j].length; i++) {
			if (a[i][j] == X) {
				hasX = true;
			} else if (a[i][j] == O) {
				hasO = true;
			} else if (a[i][j] == DOT) {
				hasDot = true;
			}
		}
		if (hasX & !hasO & !hasDot) {
			return 0;
		}
		if (hasO & !hasX & !hasDot) {
			return 1;
		}
		return -1;
	}
	
	private int ddiag(char[][] a) {
		boolean hasX = false;
		boolean hasO = false;
		boolean hasDot = false;
		for (int i = 0; i < a.length; i++) {
			if (a[i][i] == X) {
				hasX = true;
			} else if (a[i][i] == O) {
				hasO = true;
			} else if (a[i][i] == DOT) {
				hasDot = true;
			}
		}
		if (hasX & !hasO & !hasDot) {
			return 0;
		}
		if (hasO & !hasX & !hasDot) {
			return 1;
		}
		return -1;
	}
	
	private int rdiag(char[][] a) {
		boolean hasX = false;
		boolean hasO = false;
		boolean hasDot = false;
		for (int i = 0; i < a.length; i++) {
			if (a[i][a.length - 1 - i] == X) {
				hasX = true;
			} else if (a[i][a.length - 1 - i] == O) {
				hasO = true;
			} else if (a[i][a.length - 1 - i] == DOT) {
				hasDot = true;
			}
		}
		if (hasX & !hasO & !hasDot) {
			return 0;
		}
		if (hasO & !hasX & !hasDot) {
			return 1;
		}
		return -1;
	}
	
	private void solve() throws IOException {
		int t = nextInt();
		for (int test = 1; test <= t; test++) {
			char[][] field = new char[4][];
			for (int i = 0; i < field.length; i++) {
				String next = next();
				field[i] = next.toCharArray();
			}
			String answer = solve(field);
			out.println("Case #" + test + ": " + answer);
		}
	}

	@Override
	public void run() {
		try {
			solve();
		} catch (Throwable e) {
			e.printStackTrace();
			System.exit(1);
		} finally {
			out.close();
		}
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(next());
	}
	
	private String next() throws IOException {
		while (!st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}
	
	public Solution(String filename) {
		try {
			in = new BufferedReader(new FileReader(filename + ".in"));
			st = new StringTokenizer("");
			out = new PrintWriter(new FileWriter(filename + ".out"));
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
	
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new Solution("data").run();
	}
}
