import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.StringTokenizer;


public class Solution implements Runnable {
	
	private static final int NONE = Integer.MAX_VALUE;
	
	private static final int[] DX = {1, 0, -1, -1, 0, 1};
	private static final int[] DY = {1, 1, 0, -1, -1, 0};
	
	private BufferedReader in;
	private StringTokenizer st;
	private PrintWriter out;
	
	private String solve(int s, int[][] moves) {
		int b = findFirstBridge(s, moves);
		int f = findFirstFork(s, moves);
		int r = findFirstRing(s, moves);
		int min = Math.min(b, Math.min(f, r));
		if (min == NONE) {
			return "none";
		}
		if (b == min && f != min && r != min) {
			return "bridge in move " + min;
		}
		if (b != min && f == min && r != min) {
			return "fork in move " + min;
		}
		if (b != min && f != min && r == min) {
			return "ring in move " + min;
		}
		if (b == min && f == min && r != min) {
			return "bridge-fork in move " + min;
		}
		if (b == min && f != min && r == min) {
			return "bridge-ring in move " + min;
		}
		if (b != min && f == min && r == min) {
			return "fork-ring in move " + min;
		}
		return "bridge-fork-ring in move " + min;
	}
	
	private int findFirstBridge(int s, int[][] moves) {
		int scnt = 2 * s + 1;
		int[][] f = init(scnt * scnt);
		boolean[] stone = new boolean[f.length];
		
		int[] corners = new int[6];
		
		corners[0] = encode(scnt, 0, 0);
		stone[corners[0]] = true;
		
		corners[1] = encode(scnt, 0, s);
		stone[corners[1]] = true;
		
		corners[2] = encode(scnt, s, 2 * s);
		stone[corners[2]] = true;
		
		corners[3] = encode(scnt, 2 * s, 2 * s);
		stone[corners[3]] = true;
		
		corners[4] = encode(scnt, 2 * s, s);
		stone[corners[4]] = true;
		
		corners[5] = encode(scnt, s, 0);
		stone[corners[5]] = true;
		
		for (int i = 0; i < moves.length; i++) {
			int u = encode(scnt, moves[i][0], moves[i][1]);
			stone[u] = true;
			for (int d = 0; d < DX.length; d++) {
				int nx = moves[i][0] + DX[d];
				int ny = moves[i][1] + DY[d];
				if (nx >= 0 && nx < scnt && ny >= 0 && ny < scnt) {
					int v = encode(scnt, nx, ny);
					if (stone[v]) {
						join(f, u, v);
					}
				}
			}
			for (int c1 = 0; c1 < corners.length; c1++) {
				for (int c2 = 0; c2 < c1; c2++) {
					if (same(f, corners[c1], corners[c2])) {
						return i + 1;
					}
				}
			}
		}
		
		return NONE;
	}

	private int findFirstFork(int s, int[][] moves) {
		if (s <= 2) {
			return NONE;
		}
		
		int scnt = 2 * s + 1;
		int[][] f = init(scnt * scnt);
		boolean[] stone = new boolean[f.length];
		int[] edges = new int[6];
		
		if (s > 3) {
			for (int i = 2; i + 1 < s - 1; i++) {
				int u = encode(scnt, 0, i);
				int v = encode(scnt, 0, i + 1);
				join(f, u, v);
				stone[u] = true;
				stone[v] = true;
			}
			edges[0] = encode(scnt, 0, 2);
			stone[edges[0]] = true;
			for (int i = 2; i + 1 < s - 1; i++) {
				int u = encode(scnt, i, s + i);
				int v = encode(scnt, i + 1, s + i + 1);
				join(f, u, v);
				stone[u] = true;
				stone[v] = true;
			}
			edges[1] = encode(scnt, 2, s + 2);
			stone[edges[1]] = true;
			for (int i = 2; i + 1 < s - 1; i++) {
				int u = encode(scnt, s + i, 2 * s);
				int v = encode(scnt, s + i + 1, 2 * s);
				join(f, u, v);
				stone[u] = true;
				stone[v] = true;
			}
			edges[2] = encode(scnt, s + 2, 2 * s);
			stone[edges[2]] = true;
			for (int i = 2; i + 1 < s - 1; i++) {
				int u = encode(scnt, i, 0);
				int v = encode(scnt, i + 1, 0);
				join(f, u, v);
				stone[u] = true;
				stone[v] = true;
			}
			edges[3] = encode(scnt, 2, 0);
			stone[edges[3]] = true;
			for (int i = 2; i + 1 < s - 1; i++) {
				int u = encode(scnt, s + i, i);
				int v = encode(scnt, s + i + 1, i + 1);
				join(f, u, v);
				stone[u] = true;
				stone[v] = true;
			}
			edges[4] = encode(scnt, s + 2, 2);
			stone[edges[4]] = true;
			for (int i = 2; i + 1 < s - 1; i++) {
				int u = encode(scnt, 2 * s, s + i);
				int v = encode(scnt, 2 * s, s + i + 1);
				join(f, u, v);
				stone[u] = true;
				stone[v] = true;
			}
			edges[5] = encode(scnt, 2 * s, s + 2);
			stone[edges[5]] = true;
		} else {
			edges[0] = encode(scnt, 1, 2);
			edges[1] = encode(scnt, 2, 4);
			edges[2] = encode(scnt, 4, 5);
			edges[3] = encode(scnt, 2, 1);
			edges[4] = encode(scnt, 4, 2);
			edges[5] = encode(scnt, 5, 4);
		}
		
		for (int i = 0; i < moves.length; i++) {
			int u = encode(scnt, moves[i][0], moves[i][1]);
			stone[u] = true;
			for (int d = 0; d < DX.length; d++) {
				int nx = moves[i][0] + DX[d];
				int ny = moves[i][1] + DY[d];
				if (nx >= 0 && nx < scnt && ny >= 0 && ny < scnt) {
					int v = encode(scnt, nx, ny);
					if (stone[v]) {
						join(f, u, v);
					}
				}
			}
			for (int e1 = 0; e1 < edges.length; e1++) {
				for (int e2 = 0; e2 < e1; e2++) {
					if (same(f, edges[e1], edges[e2])) {
						for (int e3 = 0; e3 < e2; e3++) {
							if (same(f, edges[e2], edges[e3])) {
								return i + 1;
							}
						}
					}
				}
			}
		}
		
		return NONE;
	}

	private int findFirstRing(int s, int[][] moves) {
		int scnt = 2 * s + 1;
		int[][] f = init(scnt * scnt);
		
		boolean[] stone = new boolean[f.length];
		for (int i = 0; i < moves.length; i++) {
			int j = encode(scnt, moves[i][0], moves[i][1]);
			stone[j] = true;
		}
		
		for (int i = 0; i < scnt; i++) {
			for (int j = 0; j < scnt; j++) {
				for (int d = 0; d < DX.length; d++) {
					int u = encode(scnt, i, j);
					int ii = i + DX[d];
					int jj = j + DY[d];
					if (ii >= 0 && ii < scnt && jj >= 0 && jj < scnt) {
						int v = encode(scnt, ii, jj);
						if (!stone[u] && !stone[v]) {
							join(f, u, v);
						}
					}
				}
			}
		}
		
		int result = NONE;
		
		for (int i = moves.length - 1; i >= 0; i--) {
			int root = father(f, encode(scnt, 0, 0));
			int stones = i + 1;
			int outerAndStones = f[root][1] + stones;
			boolean hasRing = outerAndStones < f.length;
			if (hasRing) {
				result = i + 1;
			}
			
			int u = encode(scnt, moves[i][0], moves[i][1]);
			stone[u] = false;
			for (int d = 0; d < DX.length; d++) {
				int nx = moves[i][0] + DX[d];
				int ny = moves[i][1] + DY[d];
				if (nx >= 0 && nx < scnt && ny >= 0 && ny < scnt) {
					int v = encode(scnt, nx, ny);
					if (!stone[v]) {
						join(f, u, v);
					}
				}
			}
		}
		
		return result;
	}
	
	private boolean same(int[][] f, int i1, int i2) {
		return father(f, i1) == father(f, i2);
	}

	private void join(int[][] f, int i1, int i2) {
		i1 = father(f, i1);
		i2 = father(f, i2);
		if (i1 == i2) {
			return;
		}
		if (f[i1][1] < f[i2][1]) {
			f[i1][0] = f[i2][0];
			f[i2][1] = f[i2][1] + f[i1][1];
		} else {
			f[i2][0] = f[i1][0];
			f[i1][1] = f[i1][1] + f[i2][1];
		}
	}

	private int father(int[][] f, int i) {
		if (f[i][0] == i) {
			return i;
		}
		f[i][0] = father(f, f[i][0]);
		return f[i][0];
	}

	private int encode(int scnt, int x, int y) {
		return scnt * x + y;
	}

	private int[][] init(int cnt) {
		int[][] f = new int[cnt][2];
		for (int i = 0; i < cnt; i++) {
			f[i][0] = i;
			f[i][1] = 1;
		}
		return f;
	}
	
	private void solve() throws IOException {
		int t = nextInt();
		for (int test = 1; test <= t; test++) {
			int s = nextInt();
			int m = nextInt();
			int[][] moves = new int[m][2];
			for (int i = 0; i < m; i++) {
				moves[i][0] = nextInt();
				moves[i][1] = nextInt();
			}
			String answer = solve(s, moves);
			out.println("Case #" + test + ": " + answer);
		}
	}

	@Override
	public void run() {
		try {
			solve();
		} catch (Throwable e) {
			apstenu(e);
		} finally {
			out.close();
		}
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(next());
	}
	
	private String next() throws IOException {
		while (!st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}
	
	private void apstenu(Throwable e) {
		e.printStackTrace();
		System.exit(1);
	}
	
	public Solution(String filename) {
		try {
			in = new BufferedReader(new FileReader(filename + ".in"));
			st = new StringTokenizer("");
			out = new PrintWriter(new FileWriter(filename + ".out"));
		} catch (IOException e) {
			apstenu(e);
		}
	}
	
	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new Solution("data").run();
	}
	
}
