package round1.train;

import java.io.IOException;
import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;

import practice.DaRosIO;

public class Train
{
	private static final String FILENAME = "train_lg";
	
	private DaRosIO io = new DaRosIO();

	public static void main(String[] args)
	{
		try
		{
			new Train().run();
		} catch (IOException e)
		{
			e.printStackTrace();
		}
	}

	private List<String> outputLines = new LinkedList<String>();

	private void run() throws IOException
	{
		List<String> lines = io.readInput(FILENAME);

		int numInputs = Integer.parseInt(lines.get(0));
		
		int inputStart = 1;
		for (int i = 0; i < numInputs; i++)
		{
			int turnTime = Integer.parseInt(lines.get(inputStart));
			
			String[] numTrips = lines.get(inputStart + 1).split(" ");
			
			int numTripAB = Integer.parseInt(numTrips[0]);
			int numTripBA = Integer.parseInt(numTrips[1]);
			
			int depA[] = new int[numTripAB];
			int arrB[] = new int[numTripAB];
			
			int depB[] = new int[numTripBA];
			int arrA[] = new int[numTripBA];
			
			for (int j = 0; j < numTripAB; j++)
			{
				String[] times = lines.get(inputStart + 2 + j).split(" ");
				
				String[] hourMinDepA = times[0].split(":");
				String[] hourMinArrB = times[1].split(":");
				
				int hourDepA = Integer.parseInt(hourMinDepA[0]);
				int minDepA = Integer.parseInt(hourMinDepA[1]);
				
				int hourArrB = Integer.parseInt(hourMinArrB[0]);
				int minArrB = Integer.parseInt(hourMinArrB[1]);
				
				depA[j] = getMinutes(hourDepA, minDepA);
				arrB[j] = getMinutes(hourArrB, minArrB);
			}
			
			for (int j = 0; j < numTripBA; j++)
			{
				String[] times = lines.get(inputStart + numTripAB + 2 + j).split(" ");
				
				String[] hourMinDepB = times[0].split(":");
				String[] hourMinArrA = times[1].split(":");
				
				int hourDepB = Integer.parseInt(hourMinDepB[0]);
				int minDepB = Integer.parseInt(hourMinDepB[1]);
				
				int hourArrA = Integer.parseInt(hourMinArrA[0]);
				int minArrA = Integer.parseInt(hourMinArrA[1]);
				
				depB[j] = getMinutes(hourDepB, minDepB);
				arrA[j] = getMinutes(hourArrA, minArrA);
			}
			
			inputStart += (numTripAB + numTripBA + 2);
			
			int trainsA = 0;
			int trainsB = 0;
			int minTrainsA = 0;
			int minTrainsB = 0;
			
			Arrays.sort(depA);
			Arrays.sort(depB);
			Arrays.sort(arrA);
			Arrays.sort(arrB);
			
			while (hasElements(depA, arrA))
			{
				int nextDepA = getNextElem(depA);
				int nextArrA = getNextElem(arrA);
				
				if (nextDepA >= 0)
				{
					if (nextArrA < 0 || nextDepA < nextArrA + turnTime)
					{
						trainsA--;
						deleteNextElem(depA);
					}
					else
					{
						trainsA++;
						deleteNextElem(arrA);
					}
				}
				else
				{
					if (nextArrA >= 0)
					{
						trainsA++;
						deleteNextElem(arrA);
					}
				}
				
				if (trainsA < minTrainsA)
					minTrainsA = trainsA;
			}
			
			while (hasElements(depB, arrB))
			{
				int nextDepB = getNextElem(depB);
				int nextArrB = getNextElem(arrB);
				
				if (nextDepB >= 0)
				{
					if (nextArrB < 0 || nextDepB < nextArrB + turnTime)
					{
						trainsB--;
						deleteNextElem(depB);
					}
					else
					{
						trainsB++;
						deleteNextElem(arrB);
					}
				}
				else
				{
					if (nextArrB >= 0)
					{
						trainsB++;
						deleteNextElem(arrB);
					}
				}
				
				if (trainsB < minTrainsB)
					minTrainsB = trainsB;
			}
			
			outputLines.add("Case #" + (i+1) + ": " + (-minTrainsA) + " " + (-minTrainsB) + "\n");
		}
		
		io.buildOutput(FILENAME, outputLines);
	}

	private void deleteNextElem(int[] array)
	{
		for (int i = 0; i < array.length; i++)
		{
			if (array[i] >= 0)
			{
				array[i] = -1;
				return;
			}
		}
	}

	private int getNextElem(int[] array)
	{
		for (int i = 0; i < array.length; i++)
		{
			if (array[i] >= 0)
			{
				return array[i];
			}
		}
		
		return -1;
	}

	private boolean hasElements(int[] arrayA, int[] arrayB)
	{
		if (getNextElem(arrayA) >= 0)
			return true;
		
		if (getNextElem(arrayB) >= 0)
			return true;
		
		return false;
	}

	private int getMinutes(int hour, int min)
	{
		return (hour * 60 + min);
	}

	private int findOcurr(String[] engines, String query)
	{
		for (int i = 0; i < engines.length; i++)
		{
			if (engines[i].equals(query))
				return i;
		}
		
		return -1;
	}

}
