package codejam;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.util.ArrayList;
import java.util.Scanner;

public class Minesweeper {
	
	public static ArrayList<Pair> clicked = new ArrayList<Pair>();
	public static Pair[] cleared;
	public static int currentClear = 0;
	public static boolean foundSoln = false;
	
	public static void main(String[] args){
			
			Scanner in = null;
			try {
				in = new Scanner(new FileReader("input.in"));
			} catch (FileNotFoundException e) {
				e.printStackTrace();
			}
			
			int numTestCases = Integer.parseInt(in.nextLine());
			for(int i = 1; i <= numTestCases; i++) {
				int R = in.nextInt();
				int C = in.nextInt();
				int M = in.nextInt();
				in.nextLine();

				cleared = new Pair[(R*C)-M+1];
				foundSoln = false;
				if(R*C < M+1)
					System.out.printf("\nCase #%d:\nImpossible");
				else if (M == 0)
				{
					System.out.printf("\nCase #%d:\n", i);
					for(int j = 1; j <= R; j++)
					{
						for(int k = 1; k <= C; k++)
						{
							if(j==1 && k == 1)
								System.out.printf("c ");
							else
								System.out.printf(". ");
						}
						if( j < R)
							System.out.printf("\n");
					}
					foundSoln = true;
				}
				else {
					System.out.printf("\nCase #%d:\n", i);
					build(R,C,M, 0);
					if(foundSoln == false)
						System.out.printf("Impossible");
				}
			}
		}
	
	public static void build(int r, int c, int m, int index)
	{
		for(int i = 1; i <= r; i++)
		{
			for(int j = 1; j <= c; j++)
			{
				Pair origin = new Pair(i,j);
				cleared[0] = origin;	
				if(index == ((r*c)-m) || foundSoln == true)
					return;
				else
				{
					buildFromOrigin(r,c, m, origin, index + 1);
				}
			}
		}
	}
	
	public static void buildFromOrigin(int r, int c, int m, Pair origin, int index)
	{
		if(foundSoln == true)
			return;
		
		ArrayList<Pair> allAdj = getAllAdjacent(r,c,index);
		for(int i = 0; i < allAdj.size(); i++)
		{
				cleared[index] = allAdj.get(i);
				if(((r*c)-m) == index)
				{	
					if(checkBoard(r,c,index,cleanBoard(r,c,index)))
					{
						printBoard(r,c,cleanBoard(r,c,index));
						foundSoln = true;
						return;
					}
					else
						continue;
				}
				else
				{
					buildFromOrigin(r,c,m,origin,index+1);
				}
		}
	}
	
	public static String[][] cleanBoard(int r, int c, int index)
	{
		String[][] board = new String[r+1][c+1];
		for(int i = 1; i <= r; i++)
			for(int j = 1; j <= c; j++)
				board[i][j] = "*";
		
		board[cleared[0].x][cleared[0].y] = "c"; 
		for(int i = 1; i < index; i++)
			board[cleared[i].x][cleared[i].y] = "."; 
		return board;
	}
	
	public static ArrayList<Pair> getAllAdjacent(int r, int c, int index)
	{
		ArrayList<Pair> allAdj = new ArrayList<Pair>();
		String[][] board = cleanBoard(r,c,index);
		for(int i = 1; i <= r; i++)
			for(int j = 1; j <= c; j++)
				if(!board[i][j].equals("*"))
				{
					ArrayList<Pair> adj = getAdjacent(i,j,r,c);
					for(int k = 0; k < adj.size(); k++)
					{
						if((board[adj.get(k).x][adj.get(k).y].equals("*")) && (!allAdj.contains(adj.get(k))))
						{
							allAdj.add(adj.get(k));
						}
					}
					
				}
		return allAdj;
	}
	
	public static ArrayList<Pair> getAdjacent(int x, int y, int r, int c)
	{
		ArrayList<Pair> adjacent = new ArrayList<Pair>();
		
		if(x+1 <= r)
		{
			Pair p = new Pair(x+1,y);
			adjacent.add(p);
		}
		
		if(y+1 <= c)
		{
			Pair p = new Pair(x,y+1);
			adjacent.add(p);
		}
		
		if(x+1 <= r && y+1 <= c)
		{
			Pair p = new Pair(x+1,y+1);
			adjacent.add(p);
		}
		
		if(x+1 <= r && y-1 >= 1)
		{
			Pair p = new Pair(x+1,y-1);
			adjacent.add(p);
		}
		
		if(y-1 >= 1)
		{
			Pair p = new Pair(x,y-1);
			adjacent.add(p);
		}

		if(x-1 >= 1)
		{
			Pair p = new Pair(x-1,y);
			adjacent.add(p);
		}
		
		if(x-1 >= 1 && y-1 >= 1)
		{
			Pair p = new Pair(x-1,y-1);
			adjacent.add(p);
		}

		if(x-1 >= 1 && y+1 <= c)
		{
			Pair p = new Pair(x-1,y+1);
			adjacent.add(p);
		}
	
		return adjacent;
		
	}
	
	public static boolean checkBoard(int r, int c, int index, String[][] board)
	{
		for(int i = 1; i <= r; i++)
			for(int j = 1; j <= c; j++)
				if(board[i][j].equals(".") || board[i][j].equals("c"))
				{
					ArrayList<Pair> adj = getAdjacent(i,j,r,c);
					int mines = 0;
					for(int k = 0; k < adj.size(); k++){
						if(board[adj.get(k).x][adj.get(k).y].equals("*"))
							mines++;
					}
					board[i][j] = Integer.toString(mines); 
				}

		int x = cleared[0].x;
		int y = cleared[0].y;
		
		if(!board[x][y].equals("0"))
			return false;
		else {
			return true;
		}

	}


	public static void printBoard(int r, int c, String[][] board)
	{
		//System.out.println("=================================\n");
		for(int i = 1; i <= r; i++)
		{
			for(int j = 1; j <= c; j++)
				System.out.printf("%s ",board[i][j]);
			if(i < r)
				System.out.printf("\n");
		}
		//System.out.println("\n=================================\n");
	}
}

class Pair {
	public int x;
	public int y;
	
	Pair(int X, int Y){
		x = X;
		y = Y;
	}
}
