import java.math.BigInteger;
import java.util.Map;
import java.util.HashMap;
import edu.princeton.cs.algs4.StdIn;
import edu.princeton.cs.algs4.StdOut;
import edu.princeton.cs.algs4.StdRandom;

public class Coinjam {
    private static int N = 32;
    private static int J = 500;

    private static String getRandomJamcoin() {
        String coin = "1";
        for (int i = 0; i < N-2; i++) coin += StdRandom.uniform(2);
        coin += "1";
        return coin;
    }

    private static BigInteger getValue(String coin, String base) {
        BigInteger b = new BigInteger(base);
        BigInteger number = new BigInteger("1");
        BigInteger power = new BigInteger("1");
        for (int i = N-2; i >= 0; i--) {
            power = power.multiply(b);
            if (coin.charAt(i) == '1')
                number = number.add(power);
        }
        return number;
    }

    private static boolean mayNotBeJamcoin(String coin) {
        BigInteger value;
        for (int b = 2; b <=10; b++) {
            value = getValue(coin, Integer.toString(b));
            if (value.isProbablePrime(1))  return true;
        }
        return false;
    }

    private static String getProof(String coin) {
        String proof = "";
        BigInteger number, d;
        for (int b = 2; b <=10; b++) {
            number = getValue(coin, Integer.toString(b));
            d = getDivisor(number);
            if (d.compareTo(BigInteger.ONE) == 0) return "";
            proof += " " + d;
        }
        return proof;
    }

    private static BigInteger getDivisor(BigInteger number) {
        BigInteger d = BigInteger.ONE;
        BigInteger limit = new BigInteger("10000000");
        while (d.compareTo(limit) == -1) {
            d = d.add(BigInteger.ONE);
            if (number.remainder(d).equals(BigInteger.ZERO)) return d;
        }
        return BigInteger.ONE;
    }

    public static void main(String[] args) {
        Map<String, String> coins = new HashMap<String, String>();
        String jc, proof;
        while (coins.size() < J) {
            jc = getRandomJamcoin();
            if (coins.containsKey(jc)) continue;
            if (mayNotBeJamcoin(jc)) continue;
            proof = getProof(jc);
            if (proof != "") coins.put(jc, proof);
            //if (proof != "") StdOut.println(jc + proof);
        }

        StdOut.println("Case #1:");
        for (Map.Entry<String, String> entry : coins.entrySet()) {
            jc = entry.getKey();
            proof = entry.getValue();
            StdOut.println(jc + proof);
        }
    }
}
