package gcj;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class FileHandler {
	BufferedWriter writer = null;
	BufferedReader reader = null;

	public static void main(String[] args) {
		FileHandler handler = new FileHandler();
		try {
			handler.prepareOutput("output.txt");
			handler.processInput("inputs.txt");
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			handler.closeFiles();
		}
	}

	/**
	 * Prepare the output file writer
	 * @param fileName
	 * @throws IOException
	 */
	private void prepareOutput(String fileName) throws IOException {
		File file = new File(fileName);
		FileWriter fw = new FileWriter(file.getAbsoluteFile());
		writer = new BufferedWriter(fw);
	}

	/**
	 * Process an input file
	 * @param fileName
	 * @throws IOException 
	 */
	private void processInput(String fileName) throws IOException  {
		InputStream in = this.getClass().getClassLoader().getResourceAsStream(fileName);
		reader = new BufferedReader(new InputStreamReader(in));
		final int testCount = getInt();
		for (int test = 0; test < testCount; test++) {
			TestCase testCase = new TestCase(writer);
			String[] input = readLines(TestCase.LINES_PER_TEST);
			testCase.process(input);
		}
	}
	
	/**
	 * Read lines from the file and return in a String array
	 * @param count - number of lines to read
	 * @return String array
	 * @throws IOException
	 */
	private String[] readLines(int count) throws IOException {
		String[] result = new String[count];
		for (int i = 0; i < count; i++) {
			result[i] = reader.readLine();
			if (result[i]==null)
				throw new IOException("Unexpected end of file");
		}
		return result;
	}

	/**
	 * Read and parse the next line, which is expected to contain a single integer
	 * @param reader
	 * @return single integer contained on the line
	 * @throws IOException 
	 */
	private int getInt() throws IOException {
		String line = reader.readLine();
		if (line == null)
			throw new IOException("Unexpected end of file");
		int result = Integer.parseInt(line);
		return result;
	}
	
	/**
	 * Close the file reader and writer
	 */
	protected void closeFiles() {
		try {
			if (reader!=null) {
				reader.close();
				reader=null;
			}
			if (writer!=null) {
				writer.flush();
				writer.close();
				writer=null;
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
