package gcj.b;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class CookieClicker {

	public static void main(String[] args) {
		CookieClicker trick = new CookieClicker();
		trick.processFile("inputs.txt");
	}

	/**
	 * Process an input file
	 * @param fileName
	 */
	private void processFile(String fileName)  {
		InputStream in = this.getClass().getClassLoader().getResourceAsStream(fileName);
		BufferedReader reader = new BufferedReader(new InputStreamReader(in));
		try {
			final int testCount = getInt(reader);
			for (int test = 0; test < testCount; test++) {
				TestCase testCase = new TestCase();
				List<BigDecimal> values = getValues(reader);
				testCase.process(values);
			}
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			try {
				if (reader!=null) reader.close();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
	}
	
	/**
	 * Read and parse the next line
	 * @param reader - file reader
	 * @return a list of BigDecimal values
	 * @throws IOException
	 */
	private List<BigDecimal> getValues(BufferedReader reader) throws IOException {
		List<BigDecimal> result = new ArrayList<BigDecimal>();
		String line = reader.readLine();
		if (line==null)
			throw new IOException("Unexpected end of file");
		final String[] stringValues = line.split(" ");
		for (int i = 0; i < stringValues.length; i++) {
			result.add(new BigDecimal(stringValues[i]));
		}
		return result;
	}

	/**
	 * Read and parse the next line, which is expected to contain a single integer
	 * @param reader
	 * @return single integer contained on the line
	 * @throws IOException 
	 */
	private int getInt(BufferedReader reader) throws IOException {
		String line = reader.readLine();
		if (line == null)
			throw new IOException("Unexpected end of file");
		int result = Integer.parseInt(line);
		return result;
	}
	
	

}
