package gcj.b;

import java.math.BigDecimal;
import java.math.MathContext;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;

public class TestCase {
	private static AtomicInteger lastCaseNumber = new AtomicInteger(0);
	
	public TestCase() {
		this.caseNumber = lastCaseNumber.incrementAndGet();
	}
	private int caseNumber;
	
	//cost per farm (C)
	private BigDecimal c;
	//cookies per farm (F)
	private BigDecimal f;
	//cookies needed to win (X)
	private BigDecimal x;
	
	private BigDecimal currentCookies = BigDecimal.ZERO;
	private BigDecimal cookiesPerSecond = new BigDecimal("2");
	private BigDecimal totalTime = BigDecimal.ZERO;


	/**
	 * Print a precisely formatted result message
	 */
	public void printResult() {
		String message = format(totalTime);
		
		StringBuilder builder = new StringBuilder();
		builder.append("Case #");
		builder.append(caseNumber);
		builder.append(": ");
		builder.append(message);
		System.out.println(builder.toString());
	}

	private String format(BigDecimal value) {
		DecimalFormat formatter = new DecimalFormat("#.#######");
		return formatter.format(value);
	}

	/**
	 * Process a list of inputs
	 * @param values
	 */
	public void process(List<BigDecimal> values) {
		if ((values==null) || (values.size() != 3))
			throw new Error("Invalid input");
		
		c=values.get(0);
		f=values.get(1);
		x=values.get(2);
		solve();
	}

	private void solve() {
		while (currentCookies.compareTo(x) <0) {
			BigDecimal timeAtCurrentRate = timeUntil(x, currentCookies, cookiesPerSecond);
			BigDecimal timeUntilNextFarm = timeUntil(c, currentCookies, cookiesPerSecond);
			BigDecimal timeWithNextFarm = timeWithNextFarm(timeUntilNextFarm);
			if (timeAtCurrentRate.compareTo(timeWithNextFarm) <= 0) {
				runFor(timeAtCurrentRate);
			} else {
				runFor(timeUntilNextFarm);
				buyFarm();
			}
		}
		printResult();
	}

	private BigDecimal timeWithNextFarm(BigDecimal timeUntilNextFarm) {
		BigDecimal hypotheticalCount = currentCookies.add(timeUntilNextFarm.multiply(cookiesPerSecond, MathContext.DECIMAL64)).subtract(c, MathContext.DECIMAL64);
		BigDecimal hypotheticalRate = cookiesPerSecond.add(f, MathContext.DECIMAL64);
		return timeUntilNextFarm.add(timeUntil(x, hypotheticalCount, hypotheticalRate), MathContext.DECIMAL64);
	}

	private void buyFarm() {
		currentCookies=currentCookies.subtract(c, MathContext.DECIMAL64);
		cookiesPerSecond=cookiesPerSecond.add(f, MathContext.DECIMAL64);
	}

	private void runFor(BigDecimal seconds) {
		final BigDecimal increment = seconds.multiply(cookiesPerSecond, MathContext.DECIMAL64);
		currentCookies=currentCookies.add(increment, MathContext.DECIMAL64);
		totalTime=totalTime.add(seconds, MathContext.DECIMAL64);
	}

	private BigDecimal timeUntil(BigDecimal target, BigDecimal start, BigDecimal rate) {
		final BigDecimal seconds = target.subtract(start, MathContext.DECIMAL64).divide(rate, MathContext.DECIMAL64);
		return seconds;
	}
}
