package exercices;

import java.io.*;
import java.util.*;
import java.util.Scanner;

public class Main {

	private final static int MAX_SIZE = 100;
	
	//The element returned is a vector of object:
	// - In the first position we will find the lawn, in the second
	// an array with the number of positions which have a concrete desired height.
	// in the third position we will find the bigger desired height in this lawn.
	private static Vector<Object> readInput(Scanner capt) {
		
		int n = capt.nextInt();
		int m = capt.nextInt();
		
		Vector<Object> result = new Vector<Object>();
		
		int[] heightsQuantity = new int[MAX_SIZE]; 
		//Initialization.
		for (int i = 0; i < MAX_SIZE; i++) heightsQuantity[i] = 0;
		
		int[][] lawn = new int[n][m];
		int auxInt;
		Integer maxHeight = 0;
		for(int i = 0; i < n; ++i) {
			for (int j = 0; j < m; ++j) {
				auxInt = capt.nextInt();
				lawn[i][j] = auxInt;
				++heightsQuantity[auxInt - 1];
				
				if(maxHeight < auxInt) maxHeight = auxInt;
			}
		}
		
		result.add(lawn);
		result.add(heightsQuantity);
		result.add(maxHeight);
		
		return result;
	}
	
	//mode true => rows; mode false => columns.
	private static int cutRecursiveHeight(int[][] lawn, int i, int j, boolean mode, int currentNum, int total, int currentHeight) {
		if(!mode && lawn.length == i) return total - currentNum;
		//We finished the row and the machine can cut the current number of positions.
		if(mode && lawn[0].length == j) return total - currentNum;
		if(lawn[i][j] <= currentHeight) {
			if (lawn[i][j] == currentHeight) ++currentNum;
			
			int currentTotal;
			
			if (mode) currentTotal = cutRecursiveHeight(lawn, i, j + 1, mode, currentNum, total, currentHeight);
			else currentTotal = cutRecursiveHeight(lawn, i + 1, j, mode, currentNum, total, currentHeight);
			if(currentTotal < total && lawn[i][j] == currentHeight) lawn[i][j] = 0;
			
			return currentTotal;
		}
		return total;
	}
	
	
	private static int[][] cutHeight(int height, int numPositions, int[][] lawn) {
		for (int i = 0; i < lawn.length; ++i) {
			numPositions = cutRecursiveHeight(lawn, i, 0, true, 0, numPositions, height);
			
			if (numPositions == 0) return lawn;
		}
		
		for (int i = 0; i < lawn[0].length; ++i) {
			numPositions = cutRecursiveHeight(lawn, 0, i, false, 0, numPositions, height);
			
			if (numPositions == 0) return lawn;
		}
		
		return null;
	}
	
	
	private static String calculateResult(Vector<Object> input) {
		int[][] lawn = (int[][]) ( input.get(0));
		int[] numHeights = (int[]) ( input.get(1));
		Integer maxHeight = (Integer) (input.get(2));
		
		for (int i = 1; i <= maxHeight; ++i) {
			lawn = cutHeight(i, numHeights[i - 1], lawn);
			
			if(lawn == null) return "NO";
		}
		
		return "YES";
	}
	
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		
		Locale.setDefault(Locale.US);
		
		Scanner capt = new Scanner(System.in);
		
		//At first we read the number of cases.
		int numCases = capt.nextInt();
		
		//For every case we'll calculate the result and we'll print it.
		for (int i = 0; i < numCases; ++i) {
			
			//There are an empty line between games.
			capt.nextLine();
		
			//Read input.
			Vector<Object> input = readInput(capt);
			
			//Calculate result.
			String result = calculateResult(input);
			
			//Print result.
			System.out.println("Case #" + (i+1) + ": " + result);
		}

	}

}
