import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Scanner;


public class TrainTimetable {
	
	static final String[] types = {"Arrive A ", "Arrive B ", "Depart A ", "Depart B "};
	static final int ARRIVE_A = 0, ARRIVE_B = 1, DEPART_A = 2, DEPART_B = 3;
	
	static class TrainEvent implements Comparable<TrainEvent>{
		int type;
		int time;
		int rawTime;
		
		public TrainEvent(String timeStr, int type, int turnaroundTime){
			this.time = time(timeStr);
			this.type = type;
			this.rawTime = time;
			if(type < 2) time += turnaroundTime;
		}
		
		public int compareTo(TrainEvent other) {
			int thisTime = (time << 2) + type;
			int otherTime = (other.time << 2) + other.type;
//			System.out.println("Comparing " + time(time) + " to " + time(other.time));
//			System.out.println("(" + time + " " + other.time + ")");
//			System.out.println("(" + type + " " + other.type + ")");
//			System.out.println("(" + thisTime + " " + otherTime + ")");
			if(thisTime < otherTime) return -1;
			if(thisTime > otherTime) return 1;
			return 0;
		}
	}
	
	public static void main(String[] args) throws IOException {
//		
//		for(int i = 0; i < time("23:59"); i+= 15){
//			System.out.println(time(i));
//		}
//		System.exit(0);
		
		PrintWriter out = new PrintWriter(new FileWriter(new File("trainTimetable.out")));
		Scanner in = new Scanner(new File("B-large.in"));
		
		int testCases = in.nextInt();
		
		for(int testCase = 1; testCase <= testCases; testCase++){
			int turnaroundTime = in.nextInt(); 
			int nA = in.nextInt();
			int nB = in.nextInt();
			ArrayList<TrainEvent> events = new ArrayList<TrainEvent>();
			
			for(int i = 0; i < nA; i++){
				events.add(new TrainEvent(in.next(), DEPART_A, turnaroundTime));
				events.add(new TrainEvent(in.next(), ARRIVE_B, turnaroundTime));
			}
			
			for(int i = 0; i < nB; i++){
				events.add(new TrainEvent(in.next(), DEPART_B, turnaroundTime));
				events.add(new TrainEvent(in.next(), ARRIVE_A, turnaroundTime));
			}
			
			Collections.sort(events);
			
			
//			System.out.println("0,0 => " + tryTrains(0, 0, events));
//			System.out.println("0,1 => " + tryTrains(0, 1, events));
//			System.out.println("1,0 => " + tryTrains(1, 0, events));
//			System.out.println("1,1 => " + tryTrains(1, 1, events));
//			System.out.println("0,2 => " + tryTrains(0, 2, events));
//			System.out.println("2,0 => " + tryTrains(2, 0, events));
//			System.out.println("2,2 => " + tryTrains(2, 2, events));
//			System.out.println("9,9 => " + tryTrains(9, 9, events));
			
			int A = 1 << 30;
			int B = 1 << 30;
			
			for(int search = 1 << 29; search != 0; search >>= 1){
				if(tryTrains(A-search, B, events)) A -= search;
			}
			for(int search = 1 << 29; search != 0; search >>= 1){
				if(tryTrains(A, B - search, events)) B -= search;
			}
			
			if(A==1 && tryTrains(0, B, events)) A = 0;
			if(B==1 && tryTrains(A, 0, events)) B = 0;
			
			String solution = "Case #" + testCase + ": " + A + " " + B;
			System.out.println(solution);
			out.println(solution);
		}
		
		out.close();
	}
	
	
	
	static boolean tryTrains(int initialA, int initialB, ArrayList<TrainEvent> events){
		int A = initialA;
		int B = initialB;
//		System.out.println();
//		System.out.println("Initial: " + A + " " + B);
		for(TrainEvent event : events){
			switch(event.type){
				case ARRIVE_A: 
					A++;
//					System.out.println("Train arrives at A at " + time(event.rawTime) + ", will be ready to depart at " + time(event.time));
//					System.out.println("Remaining: " + A + " " + B);
					break;
				case ARRIVE_B: 
					B++;
//					System.out.println("Train arrives at B at " + time(event.rawTime) + ", will be ready to depart at " + time(event.time));
//					System.out.println("Remaining: " + A + " " + B);
					break;
				case DEPART_A: 
					A--; 
//					System.out.println("Train departs A at " + time(event.rawTime));
//					System.out.println("Remaining: " + A + " " + B);
					if(A < 0) return false;
					break;
				case DEPART_B: 
					B--; 
//					System.out.println("Train departs A at " + time(event.rawTime));
//					System.out.println("Remaining: " + A + " " + B);
					if(B < 0) return false; 
					break;
			}
		}
		return true;
	}
	
	
	private static int time(String s ){
		String[] tok = s.split(":");
		return 60 * Integer.parseInt(tok[0]) + Integer.parseInt(tok[1]);
	}
	
	private static String time(int i){
		int hours = i/60;
		int minutes = i % 60;
		return (hours<10?"0":"") + (i/60) + ":" + (minutes<10?"0":"")+ minutes;
	}
}
