package qualification;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;
import java.util.TreeSet;

public class Watersheds {
	
	static class Pair<A extends Comparable<A>,B extends Comparable<B>> implements Comparable<Pair<A,B>>{
		public A a;
		public B b;
		public Pair( A _a, B _b ){
			a = _a;
			b = _b;
		}
		public int compareTo(Pair<A, B> o) {
			int r = a.compareTo( o.a );
			return r == 0 ? b.compareTo(o.b) : r;
		}
		public String toString(){
			return "("+a+","+b+")";
		}
	}
	
	private static int calcFlowDirection(int[][] map, int i, int j){
		int min = map[i][j];
		int ret = 0;
		if(i > 0 && map[i-1][j] < min){ //NORTH
			ret = 1;
			min = map[i-1][j];
		}
		if(j > 0 && map[i][j-1] < min) {//WEST
			ret = 2;
			min = map[i][j-1];
		}
		if(j < map[0].length-1 && map[i][j+1] < min) {//EAST
			ret = 3;
			min = map[i][j+1];
		}
		if(i < map.length-1 && map[i+1][j] < min) {//SOUTH
			ret = 4;
			min = map[i+1][j];
		}
		return ret;
	}
	
	private static void retSearch(Set<Pair<Integer,Integer>> set, int i, int j, int[][] marker){
		if(i > 0 && marker[i-1][j] == 4 ) {//NORTH
			set.add(new Pair<Integer, Integer>( i-1, j) );
			retSearch(set, i-1, j, marker );
		}
		if(j > 0 && marker[i][j-1] == 3) {//WEST
			set.add(new Pair<Integer, Integer>( i, j-1) );
			retSearch(set, i, j-1, marker );
		}
		if(j < marker[0].length-1 && marker[i][j+1] == 2) {//EAST
			set.add(new Pair<Integer, Integer>( i, j+1) );
			retSearch(set, i, j+1, marker );
		}
		if(i < marker.length-1 && marker[i+1][j] == 1) {//SOUTH
			set.add(new Pair<Integer, Integer>( i+1, j) );
			retSearch(set, i+1, j, marker );
		}
	}
	
	private static Character[][] calcBasins(int[][] map) { // 'a' == 97
		int[][] marker = new int[ map.length ][map[0].length ];
		List<TreeSet<Pair<Integer,Integer>>> basins = new LinkedList<TreeSet<Pair<Integer,Integer>>>();
		for( int i = 0; i < map.length; i++ ){
			for( int j = 0; j < map[0].length; j++ ){
				marker[i][j] = calcFlowDirection(map,i,j);
			}
		}
		for(int i = 0; i < marker.length; i++){
			for(int j = 0; j < marker[0].length; j++){
				if( marker[i][j] == 0){
					TreeSet<Pair<Integer,Integer>> set = new TreeSet<Pair<Integer,Integer>>();
					set.add(new Pair<Integer, Integer>( i, j));
					retSearch(set,i,j,marker);
					basins.add(set);
				}
			}
		}
		Character[][] ret = new Character[ map.length ][map[0].length ];
		for(int i = 0; !basins.isEmpty(); i++ ){
			TreeSet<Pair<Integer,Integer>> smallest = getFirstBasin(basins);
			basins.remove( smallest );
			for(Pair<Integer, Integer> pair : smallest )
				ret[pair.a][pair.b] = (char)(97 + i);
		}
		return ret;
	}
	
	private static TreeSet<Pair<Integer, Integer>> getFirstBasin(
			List<TreeSet<Pair<Integer, Integer>>> basins) {
		Pair<Integer, Integer> min = new Pair<Integer, Integer>( Integer.MAX_VALUE, Integer.MAX_VALUE ); 
		TreeSet<Pair<Integer, Integer>> ret = null;
		for( TreeSet<Pair<Integer, Integer>> basin : basins ){
			if( min.compareTo(basin.first()) > 0 ){
				ret = basin;
				min = basin.first();
			}
		}
		return ret;
	}

	private static<A> String mapToString(A[][] map){
		String output = "";
		boolean oflag = true;
		for( A[] ca: map ){
			if( oflag )
				oflag = false;
			else
				output += "\n";
			boolean iflag = true;
			for( A c : ca ){
				if( iflag )
					iflag = false;
				else
					output += " ";
				output += c.toString();
			}
		}
		return output;
	}

///////////////////static/////////////////////////////////
	private static FileWriter fw = null;
	
	public static void main(String[] args) {
		String task = "B-large";
		try { fw = new FileWriter( "Qualification/Outputs/" + task + ".out" );
		} catch (IOException e) { e.printStackTrace(); }
		String[] input = readFromFile( "Qualification/Inputs/" + task + ".in" );
		int maps = new Integer( input[0] );
		int row = 1;
		for(int i = 1; i <= maps; i++ ){
			String[] s = input[row].split(" ");
			row++;
			int h = new Integer( s[0] );
			int w = new Integer( s[1] );
			int[][] map = new int[h][w];
			for( int j = row; j < row + h; j++ ){
				String[] s1 = input[j].split(" ");
				for( int k = 0; k < w; k++ )
					map[j-row][k] = new Integer(s1[k]);
			}
			row += h;
			Character[][] result = calcBasins( map );			
			writeToFile("Case #" + i + ":");
			writeToFile( mapToString( result ) );
			
		}
		if ( fw != null ) 
		    try { fw.close(); } catch ( IOException e ) { } 
	}

	private static String[] readFromFile( String fileName ){
		List<String> rows = new LinkedList<String>();
		try {
			BufferedReader in = new BufferedReader(new FileReader(fileName));
			String zeile = null;
			while ((zeile = in.readLine()) != null) {
				rows.add( zeile );
			}
		} catch (IOException e) { e.printStackTrace(); }
		return rows.toArray( new String[ rows.size() ] );
	}
	
	private static void writeToFile( String line ){
		try { fw.write( line + "\n" );
		} catch (IOException e) {e.printStackTrace();}
		System.out.println( line );
	}
}
