import java.util.*;
import java.io.*;

public class Magicka {
    public static void main(String[] args) throws Exception {
        long startTime = System.currentTimeMillis();
        if(args.length<1) {
            System.out.println("No input filename");
            System.exit(1);
        }

        String outputFilename;
        
        try {
            FileReader fReader = new FileReader(args[0]);
            BufferedReader bReader = new BufferedReader(fReader);
            
            int maxCase = 0;
            
            // get number of case
            String tempLine = bReader.readLine().trim();
            
            maxCase = toInt(tempLine);

            if (!(maxCase>=1 && maxCase<=100)) {
                System.err.println("Invalid number of case.");
                System.exit(6);
            }

            if (args[0].lastIndexOf('.')!=-1) {
                outputFilename = args[0].substring(0,args[0].lastIndexOf('.'))+".out";
            } else {
                outputFilename = args[0] + ".out";
            }
            FileWriter fWriter = new FileWriter(outputFilename);
            BufferedWriter bWriter = new BufferedWriter(fWriter);

            String caseLine;
            int nComb;
            int nOpps;
            int nInvk;
            for (int currentCase=1; currentCase<=maxCase; currentCase++) {
                caseLine = bReader.readLine().trim();

                String[] rawCaseData = caseLine.split("\\s+");
                
                nComb = toInt(rawCaseData[0]);
                if (!(nComb>=0 && nComb<=36)) {
                    System.err.println("Invalid number of combinations.");
                    System.exit(9);
                }

                nOpps = toInt(rawCaseData[nComb+1]);
                if (!(nOpps>=0 && nOpps<=28)) {
                    System.err.println("Invalid number of oppositions.");
                    System.exit(19);
                }

                nInvk = toInt(rawCaseData[nComb+1+nOpps+1]);
                if (!(nInvk>=1 && nInvk<=100)) {
                    System.err.println("Invalid number of invocations.");
                    System.exit(19);
                }

                HashMap<String,String> comb = new HashMap<String,String>();
                for (int curComb=1; curComb<=nComb; curComb++) {
                    comb.put(rawCaseData[curComb].substring(0,2),rawCaseData[curComb].substring(2));
                    comb.put(new StringBuffer(rawCaseData[curComb].substring(0,2)).reverse().toString(),rawCaseData[curComb].substring(2));
                }

                HashMap<String,Boolean> opps = new HashMap<String,Boolean>();
                for (int curOpps=nComb+1+1; curOpps<=nComb+1+1+nOpps; curOpps++) {
                    opps.put(rawCaseData[curOpps],true);
                    opps.put(new StringBuffer(rawCaseData[curOpps]).reverse().toString(),true);
                }

                char tmp;
                String subst;
                StringBuffer invk = new StringBuffer();
                for (int curInvk=0; curInvk<nInvk; curInvk++) {
                    tmp = rawCaseData[nComb+1+nOpps+1+1].charAt(curInvk);

                    if (invk.length()==0) {
                        invk.append(tmp);
                    } else {
                        // check for comb
                        subst = comb.get(invk.charAt(invk.length()-1)+""+tmp);
                        if (subst!=null) {
                            invk.setCharAt(invk.length()-1,subst.charAt(0));
                        } else {
                            // check for removal
                            for (int i=0; i<invk.length(); i++) {
                                if (opps.get(invk.charAt(i)+""+tmp)!=null) {
                                    invk.setLength(0);
                                    break;
                                }
                            }

                            if (invk.length()>0) {
                                invk.append(tmp);
                            }
                        }
                    }
                }

                StringBuffer caseResult = new StringBuffer("Case #"+currentCase+": [");
                for (int i=0;i<invk.length();i++) {
                    if (i>0) caseResult.append(", ");
                    caseResult.append(invk.charAt(i));
                }
                caseResult.append("]");
                System.out.println(caseResult.toString());
                bWriter.write(caseResult.toString(),0,caseResult.length());
                bWriter.newLine();
            }

            bReader.close();
            bWriter.close();
        } catch (IOException e) {
            System.err.println(e.toString());
            System.exit(2);
        }

        long endTime = System.currentTimeMillis();
        System.err.println((endTime-startTime)+"ms");
    }

    public static int toInt(String input) {
        int res = 0;
        try {
            res = Integer.parseInt(input);
        } catch (NumberFormatException e) {
            System.err.println(e.toString());
            System.exit(3);
        }
        return res;
    }

}
