import java.util.*;
import java.io.*;
import java.lang.Math;

public class CandySplitting {
    public static void main(String[] args) throws Exception {
        long startTime = System.currentTimeMillis();
        if(args.length<1) {
            System.out.println("No input filename");
            System.exit(1);
        }

        String outputFilename;
        
        try {
            FileReader fReader = new FileReader(args[0]);
            BufferedReader bReader = new BufferedReader(fReader);
            
            int maxCase = 0;
            
            // get number of case
            String tempLine = bReader.readLine().trim();
            
            maxCase = toInt(tempLine);

            if (!(maxCase>=1 && maxCase<=100)) {
                System.err.println("Invalid number of case.");
                System.exit(6);
            }

            if (args[0].lastIndexOf('.')!=-1) {
                outputFilename = args[0].substring(0,args[0].lastIndexOf('.'))+".out";
            } else {
                outputFilename = args[0] + ".out";
            }
            FileWriter fWriter = new FileWriter(outputFilename);
            BufferedWriter bWriter = new BufferedWriter(fWriter);

            String caseLine;
            int numOfCandy=0;
            for (int currentCase=1; currentCase<=maxCase; currentCase++) {
                numOfCandy = toInt(bReader.readLine().trim());
                if (!(numOfCandy>=2 && numOfCandy<=1000)) {
                    System.err.println("Invalid number of candy.");
                    System.exit(9);
                }

                caseLine = bReader.readLine().trim();

                String[] ns = caseLine.split("\\s+");
                
                Integer[] rawCaseData=new Integer[ns.length];
                
                for (int i=0;i<ns.length;i++) {
                	rawCaseData[i]=toInt(ns[i]);
                }
                Arrays.sort(rawCaseData);
                
                
                if (rawCaseData.length != numOfCandy) {
                    System.err.println("Invalid case line");
                    System.exit(4);
                }
                
                int best=Integer.MIN_VALUE;
                int sumA=0;
                int sumB=0;
                int realSumA=0;
                int realSumB=0;
                int max=Integer.MIN_VALUE;
                Boolean found=new Boolean(false);
                int res=0;
                for (int i=1;i<rawCaseData.length;i++) {
                    sumA=0;
                    sumB=0;
                    realSumA=0;
                    realSumB=0;
                    for (int j=0;j<i;j++) {
                        sumA^=rawCaseData[j];
                        realSumA+=rawCaseData[j];
                    }                
                    for (int j=i;j<rawCaseData.length;j++) {
                        sumB^=rawCaseData[j];
                        realSumB+=rawCaseData[j];
                    }                
                    
                    if (sumA==sumB) {
                        found=true;
                        if (realSumA>realSumB) {
                            res=realSumA;
                        } else {
                            res=realSumB;
                        }
                        if (res>best) {
                        	best=res;
                        }
                    }
                }

                String x;
                if (!found) {
                    x="NO";
                } else {
                    x=Integer.toString(best);
                }

                String caseResult = "Case #"+currentCase+": "+x;
                System.out.println(caseResult);
                bWriter.write(caseResult,0,caseResult.length());
                bWriter.newLine();
            }

            bReader.close();
            bWriter.close();
        } catch (IOException e) {
            System.err.println(e.toString());
            System.exit(2);
        }

        long endTime = System.currentTimeMillis();
        System.err.println((endTime-startTime)+"ms");
    }

    public static int toInt(String input) {
        int res = 0;
        try {
            res = Integer.parseInt(input);
        } catch (NumberFormatException e) {
            System.err.println(e.toString());
            System.exit(3);
        }
        return res;
    }
}
