import java.util.*;
import java.io.*;
import java.lang.Math;


public class Freecell {
    public static void main(String[] args) throws Exception {
        long startTime = System.currentTimeMillis();
        if(args.length<1) {
            System.out.println("No input filename");
            System.exit(1);
        }

        String outputFilename;
        
        try {
            FileReader fReader = new FileReader(args[0]);
            BufferedReader bReader = new BufferedReader(fReader);
            
            int maxCase = 0;
            
            // get number of case
            String tempLine = bReader.readLine().trim();
            
            maxCase = toInt(tempLine);

            if (!(maxCase>=1 && maxCase<=2000)) {
                System.err.println("Invalid number of case.");
                System.exit(6);
            }

            if (args[0].lastIndexOf('.')!=-1) {
                outputFilename = args[0].substring(0,args[0].lastIndexOf('.'))+".out";
            } else {
                outputFilename = args[0] + ".out";
            }
            FileWriter fWriter = new FileWriter(outputFilename);
            BufferedWriter bWriter = new BufferedWriter(fWriter);

            String caseLine;
            long N;
            int PG;
            int PD;

            for (int currentCase=1; currentCase<=maxCase; currentCase++) {
                caseLine = bReader.readLine().trim();
                
                String[] rawCaseData = caseLine.split("\\s+");
                
                if (rawCaseData.length != 3) {
                    System.err.println("Invalid case line");
                    System.exit(4);
                }
                
                N = toLong(rawCaseData[0]);
                
                if (!(N>=1 && N<=1000000000000000L)) {
                    System.err.println("Invalid N.");
                    System.exit(7);
                }

                PD = toInt(rawCaseData[1]);
                
                if (!(PD>=0 && PD<=100)) {
                    System.err.println("Invalid PD.");
                    System.exit(7);
                }

                PG = toInt(rawCaseData[2]);
                
                if (!(PG>=0 && PG<=100)) {
                    System.err.println("Invalid PG.");
                    System.exit(7);
                }

                Boolean possible=new Boolean(false);

                if ((PG==100)&&(PD!=100)) {
                    possible = false;
                } else if ((PG==0)&&(PD!=0)) {
                    possible = false;
                } else {
                    for (long i=N; i>0; i--) {
                        long res=i*PD;
                        if (res%100==0) {
                            possible=true;
                            break;
                        }
                    }
                }

                String caseResult = "Case #"+currentCase+": "+ (possible ? "Possible":"Broken");
                System.out.println(caseResult);
                bWriter.write(caseResult,0,caseResult.length());
                bWriter.newLine();
            }

            bReader.close();
            bWriter.close();
        } catch (IOException e) {
            System.err.println(e.toString());
            System.exit(2);
        }

        long endTime = System.currentTimeMillis();
        System.err.println((endTime-startTime)+"ms");
    }

    public static int toInt(String input) {
        int res = 0;
        try {
            res = Integer.parseInt(input);
        } catch (NumberFormatException e) {
            System.err.println(e.toString());
            System.exit(3);
        }
        return res;
    }

    public static long toLong(String input) {
        long res = 0;
        try {
            res = Long.parseLong(input);
        } catch (NumberFormatException e) {
            System.err.println(e.toString());
            System.exit(3);
        }
        return res;
    }
}
