import java.util.*;
import java.io.*;
import java.lang.Math;


public class BotTrust {
    public static void main(String[] args) throws Exception {
        long startTime = System.currentTimeMillis();
        if(args.length<1) {
            System.out.println("No input filename");
            System.exit(1);
        }

        String outputFilename;
        
        try {
            FileReader fReader = new FileReader(args[0]);
            BufferedReader bReader = new BufferedReader(fReader);
            
            int maxCase = 0;
            
            // get number of case
            String tempLine = bReader.readLine().trim();
            
            maxCase = toInt(tempLine);

            if (!(maxCase>=1 && maxCase<=100)) {
                System.err.println("Invalid number of case.");
                System.exit(6);
            }

            String caseLine;
            int botBPosition = 0;
            int botOPosition = 0;
            int maxCmd = 0;
            int time = 0;
            String bot;
            String prevBot;
            int button;
            int position;

            int lastB;
            int lastO;
            int last;

            if (args[0].lastIndexOf('.')!=-1) {
                outputFilename = args[0].substring(0,args[0].lastIndexOf('.'))+".out";
            } else {
                outputFilename = args[0] + ".out";
            }
            FileWriter fWriter = new FileWriter(outputFilename);
            BufferedWriter bWriter = new BufferedWriter(fWriter);

            for (int currentCase=1; currentCase<=maxCase; currentCase++) {
                maxCmd = 0;
                time = 0;
                botBPosition = 1;
                botOPosition = 1;
                prevBot="";
                lastB=0;
                lastO=0;
                last=0;

                caseLine = bReader.readLine().trim();
                
                String[] rawCaseData = caseLine.split("\\s+");
                
                if (rawCaseData.length % 2 != 1) {
                    System.err.println("Invalid case line");
                    System.exit(4);
                }
                
                maxCmd = toInt(rawCaseData[0]);
                
                if (!(maxCmd>=1 && maxCmd<=100)) {
                    System.err.println("Invalid number of button to press.");
                    System.exit(7);
                }

                for (int currentCmd = 1; currentCmd <= maxCmd; currentCmd++) {
                    bot = rawCaseData[currentCmd*2-1];
                    
                    if ( ! (bot.compareTo("B")==0 || bot.compareTo("O")==0)) {
                        System.err.println("Invalid bot name.");
                        System.exit(5);
                    }
                    
                    button = toInt(rawCaseData[currentCmd*2]);
                    
                    if (!((button>=1) && (button<=100))) {
                        System.err.println("Invalid button number.");
                        System.exit(8);
                    }
                    
                    position = bot.compareTo("B")==0 ? botBPosition : botOPosition;
                    last = bot.compareTo("B")==0 ? lastB : lastO;

                    if (!prevBot.isEmpty() && bot.compareTo(prevBot)!=0) {
                        if (Math.abs(button-position) + last < time) {
                            time++;
                        } else {
                            time += Math.abs(button-position) + last - time + 1;
                        }
                    } else {
                        time += Math.abs(button-position) + 1;
                    }

                    if (bot.compareTo("B")==0) {
                        botBPosition = button;
                        lastB=time;
                        prevBot = "B";
                    } else {
                        botOPosition = button;
                        lastO=time;
                        prevBot = "O";
                    }
                }

                String caseResult = "Case #"+currentCase+": "+time;
                System.out.println(caseResult);
                bWriter.write(caseResult,0,caseResult.length());
                bWriter.newLine();
            }

            bReader.close();
            bWriter.close();
        } catch (IOException e) {
            System.err.println(e.toString());
            System.exit(2);
        }

        long endTime = System.currentTimeMillis();
        System.err.println((endTime-startTime)+"ms");
    }

    public static int toInt(String input) {
        int res = 0;
        try {
            res = Integer.parseInt(input);
        } catch (NumberFormatException e) {
            System.err.println(e.toString());
            System.exit(3);
        }
        return res;
    }
}
