import java.util.*;
import java.io.*;
import java.lang.Math;
import java.text.*;


public class RPI {
    public static void main(String[] args) throws Exception {
        long startTime = System.currentTimeMillis();
        if(args.length<1) {
            System.out.println("No input filename");
            System.exit(1);
        }

        String outputFilename;
        
        try {
            FileReader fReader = new FileReader(args[0]);
            BufferedReader bReader = new BufferedReader(fReader);
            
            int maxCase = 0;
            
            // get number of case
            String tempLine = bReader.readLine().trim();
            
            maxCase = toInt(tempLine);

            if (!(maxCase>=1 && maxCase<=20)) {
                System.err.println("Invalid number of case.");
                System.exit(6);
            }

            if (args[0].lastIndexOf('.')!=-1) {
                outputFilename = args[0].substring(0,args[0].lastIndexOf('.'))+".out";
            } else {
                outputFilename = args[0] + ".out";
            }
            FileWriter fWriter = new FileWriter(outputFilename);
            BufferedWriter bWriter = new BufferedWriter(fWriter);

            String caseLine;

            int team=0;

            Integer[][] data;

            for (int currentCase=1; currentCase<=maxCase; currentCase++) {
                caseLine = bReader.readLine().trim();
                
                String[] rawCaseData = caseLine.split("\\s+");
                
                if (rawCaseData.length != 1) {
                    System.err.println("Invalid case line");
                    System.exit(4);
                }
                
                team = toInt(rawCaseData[0]);
                
                if (!(team>=1 && team<=100)) {
                    System.err.println("Invalid number of team.");
                    System.exit(7);
                }

                data = new Integer[team][team];

                for (int i=0; i<team; i++) {
                    caseLine = bReader.readLine().trim();
                    if (caseLine.length() != team) {
                        System.err.println("Invalid team data");
                        System.exit(4);
                    }
                    for (int j=0;j<team;j++) {
                        if (caseLine.substring(j,j+1).equals(".")) {
                            data[i][j]=-1;
                        } else {
                            data[i][j]=toInt(caseLine.substring(j,j+1));
                        }
                    }
                    
                }

                String hasil="Case #"+currentCase+":\n";

                for (int i=0; i<team; i++) {
                    //WP
                    Double wp = countWP(data,i,-1);

                    //OWP
                    Double owp = countOWP(data,i);
                    
                    //OOWP
                    Double oowp = countOOWP(data,i);

                    Double res = 0.25*wp + 0.5*owp + 0.25*oowp;

                    hasil = hasil + String.format("%.12f",res) + "\n";
                }

                System.out.print(hasil);
                bWriter.write(hasil,0,hasil.length());
                bWriter.newLine();
            }

            bReader.close();
            bWriter.close();
        } catch (IOException e) {
            System.err.println(e.toString());
            System.exit(2);
        }

        long endTime = System.currentTimeMillis();
        System.err.println((endTime-startTime)+"ms");
    }

    public static Double countWP(Integer[][] data,int i,int x) {
        int team=data.length;
        Double n=new Double(0);
        Double sum=new Double(0);
        for (int j=0;j<team;j++) {
            if (x!=-1) {
                if (j==x) 
                    continue;
            }
            if (data[i][j]==-1) 
                continue;
            sum+=data[i][j];
            n++;
        }
        return new Double(sum/n);
    }

    public static Double countOWP(Integer[][] data,int i) {
        int team=data.length;
        Double t=new Double(0);
        Double osum=new Double(0);
        for (int k=0;k<team;k++) {
            if (k==i) 
                continue;
            if (data[k][i]==-1) 
                continue;
            t++;
            osum = osum+(countWP(data,k,i));
        }
        return new Double (osum/t);
    }

    public static Double countOOWP(Integer[][] data,int i) { 
        int team=data.length;
        Double sum=new Double(0);
        Double n=new Double(0);
        for (int j=0;j<team;j++) {
            if (j==i) 
                continue;
            if (data[j][i]==-1) 
                continue;
            sum+=countOWP(data,j);
            n++;
        }
        return new Double(sum/n);
    }    

    public static int toInt(String input) {
        int res = 0;
        try {
            res = Integer.parseInt(input);
        } catch (NumberFormatException e) {
            System.err.println(e.toString());
            System.exit(3);
        }
        return res;
    }
}
