import java.util.*;
import java.io.*;
import java.lang.Math;
import java.text.*;


public class Square {
    public static void main(String[] args) throws Exception {
        long startTime = System.currentTimeMillis();
        if(args.length<1) {
            System.out.println("No input filename");
            System.exit(1);
        }

        String outputFilename;
        
        try {
            FileReader fReader = new FileReader(args[0]);
            BufferedReader bReader = new BufferedReader(fReader);
            
            int maxCase = 0;
            
            // get number of case
            String tempLine = bReader.readLine().trim();
            
            maxCase = toInt(tempLine);

            if (!(maxCase>=1 && maxCase<=50)) {
                System.err.println("Invalid number of case.");
                System.exit(6);
            }

            if (args[0].lastIndexOf('.')!=-1) {
                outputFilename = args[0].substring(0,args[0].lastIndexOf('.'))+".out";
            } else {
                outputFilename = args[0] + ".out";
            }
            FileWriter fWriter = new FileWriter(outputFilename);
            BufferedWriter bWriter = new BufferedWriter(fWriter);

            String caseLine;

            int R=0;
            int C=0;

            Integer[][] data;

            for (int currentCase=1; currentCase<=maxCase; currentCase++) {
                caseLine = bReader.readLine().trim();
                
                String[] rawCaseData = caseLine.split("\\s+");
                
                if (rawCaseData.length != 2) {
                    System.err.println("Invalid case line");
                    System.exit(4);
                }
                
                R= toInt(rawCaseData[0]);
                C= toInt(rawCaseData[1]);
                
                data = new Integer[R][C];

                Boolean containBlue= new Boolean("false");

                for (int i=0; i<R; i++) {
                    caseLine = bReader.readLine().trim();
                    for (int j=0;j<C;j++) {
                        String x=caseLine.substring(j,j+1);
                        if (x.equals(".")) {
                            data[i][j]=-1;
                        } else if (x.equals("#")) {
                            data[i][j]=1;
                            containBlue=true;
                        } 
                    }
                }

                Boolean overlap=new Boolean(false);

                for (int i=0; i<R && !overlap; i++) {
                    for (int j=0;j<C && !overlap;j++) {
                        if (data[i][j]==1) {
                            if (convert(data,i,j)==0) {
                                overlap=true;
                            }
                        }
                    }
                }

                String hasil="Case #"+currentCase+":\n";

                if (!containBlue) {
                    for (int i=0; i<R; i++) {
                        for (int j=0;j<C;j++) {
                            if (data[i][j]==-1) {
                                hasil=hasil+".";
                            } else if (data[i][j]==1) {
                            }
                        }
                        hasil=hasil+"\n";
                    }
                } else if (overlap) {
                    hasil=hasil+"Impossible\n";
                } else {
                    for (int i=0; i<R; i++) {
                        for (int j=0;j<C;j++) {
                            if (data[i][j]==-1) {
                                hasil=hasil+".";
                            } else if (data[i][j]==2) {
                                hasil=hasil+"/";
                            } else if (data[i][j]==3) {
                                hasil=hasil+"\\";
                            } else if (data[i][j]==4) {
                                hasil=hasil+"\\";
                            } else if (data[i][j]==5) {
                                hasil=hasil+"/";
                            }
                        }
                        hasil=hasil+"\n";
                    }
                }

                System.out.print(hasil);
                bWriter.write(hasil,0,hasil.length());
                bWriter.newLine();
            }

            bReader.close();
            bWriter.close();
        } catch (IOException e) {
            System.err.println(e.toString());
            System.exit(2);
        }

        long endTime = System.currentTimeMillis();
        System.err.println((endTime-startTime)+"ms");
    }

    public static int convert(Integer[][] data,int i, int j) {
        if ((data.length == i+1) || (data[0].length == j+1) ) {
            return 0;
        }
        if ((data[i][j+1]==1) &&
            (data[i+1][j]==1) &&
            (data[i+1][j+1]==1)
            ) {
            data[i][j]=2;
            data[i][j+1]=3;
            data[i+1][j]=4;
            data[i+1][j+1]=5;

            return 1;
        }
        return 0;
    }

    public static Double countWP(Integer[][] data,int i,int x) {
        int team=data.length;
        Double n=new Double(0);
        Double sum=new Double(0);
        for (int j=0;j<team;j++) {
            if (x!=-1) {
                if (j==x) 
                    continue;
            }
            if (data[i][j]==-1) 
                continue;
            sum+=data[i][j];
            n++;
        }
        return new Double(sum/n);
    }

    public static Double countOWP(Integer[][] data,int i) {
        int team=data.length;
        Double t=new Double(0);
        Double osum=new Double(0);
        for (int k=0;k<team;k++) {
            if (k==i) 
                continue;
            if (data[k][i]==-1) 
                continue;
            t++;
            osum = osum+(countWP(data,k,i));
        }
        return new Double (osum/t);
    }

    public static Double countOOWP(Integer[][] data,int i) { 
        int team=data.length;
        Double sum=new Double(0);
        Double n=new Double(0);
        for (int j=0;j<team;j++) {
            if (j==i) 
                continue;
            if (data[j][i]==-1) 
                continue;
            sum+=countOWP(data,j);
            n++;
        }
        return new Double(sum/n);
    }    

    public static int toInt(String input) {
        int res = 0;
        try {
            res = Integer.parseInt(input);
        } catch (NumberFormatException e) {
            System.err.println(e.toString());
            System.exit(3);
        }
        return res;
    }
}
