package home;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Scanner;

/**
 * CodeJam Qualification Round. 
 * Problem B. Revenge of the Pancakes
 * @author alexandrpiskun@gmail.com
 * 
 * */
public class RevengeOfThePancakes {
	/**
	 * Internal class for solving particular pancake case.
	 * */
	private static class PancakeCase{
		/**
		 * Keep number of swaps for case.
		 * */
		private  int number_of_swaps = 0;
		
		/**
		 * Keep information about pancakes as array  
		 */
		boolean  pancakeStack[] = null;
		
		/**
		 * @param case_task  String representation of the case. Example "--+--"
		 * */
		public PancakeCase(String case_task){
			this.pancakeStack = new boolean[case_task.length()];
			int i = 0;
			for(char c :case_task.toCharArray()){
				if(c=='+'){
					this.pancakeStack[i] = true;
				}
				i++;
			}
		}
		
		/**
		 * Swap  pancakes from top to index
		 * @param index  Index of the pancake from top for swapping/ 
		 * */
		private void swap(int index){
			this.number_of_swaps++;
			int left = 0; 
			int  right = index; 
			while(left<=right){
				boolean  temp = this.pancakeStack[left];
				this.pancakeStack[left]  = !this.pancakeStack[right];
				this.pancakeStack[right] = !temp;
				left++; right--;
			}
		}
		/**
		 * @return   number of manipulations for this case.
		 * */
		public int solve(){
			
			int bottom = this.pancakeStack.length-1;
			int index = 0;
			boolean happiness = pancakeStack[0];
			while(index <= bottom){
				if(happiness == pancakeStack[index]){
					index++;
				} else{
					index++;
					this.number_of_swaps++;
					happiness = ! happiness;
				}
			}
			if (happiness == false){
				this.number_of_swaps++;
			}
			
			return this.number_of_swaps;
		}
		
	}
											    	
	private static String CASE_OUTPUT_FORMAT = "Case #%d: %d";
	
	/**
	 * Main method the class.
	 * @param Name of file in resources.
	 * */
	public void process(Scanner input){
		int T = input.nextInt();
		for(int case_number=1;case_number <= T;case_number++){
			String case_string = input.next();			
			System.out.println(String.format(CASE_OUTPUT_FORMAT, case_number,
								new PancakeCase(case_string).solve(), case_string));	
		}
		
	}
	
	public static void main(String[] args) {
		
		if (args!=null && args.length > 1 && "-d".equals(args[0]) ){
			try(Scanner input = new Scanner(new File(args[1]))){
				new RevengeOfThePancakes().process(input);
			} catch(Exception e){
				System.out.println("Exception during attempt to read file.");
				System.out.println("Exception " + e.getMessage());
			}
		}else{
			Scanner input = new Scanner(new BufferedReader(new InputStreamReader(System.in)));
			new RevengeOfThePancakes().process(input);
		}
		
	}

}
