package home;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.Set;
import java.util.TreeSet;

/**
 * CodeJam Qualification Round. 
 * Problem B. Coin Jam
 * @author alexandrpiskun@gmail.com
 * 
 * */
public class CoinJam {
	  	
	private static String CASE_OUTPUT_FORMAT = "Case #%d:";
	
	private Set<Long> primeset = new TreeSet<Long>();
	
	public Set<Long> getPrimesCache(){
		
		int boundary = 0xFFFF;
		boolean isTrivial[] = new boolean[boundary];
		isTrivial[0]= true;
		isTrivial[1]= true;
		for(int i = 2; i < boundary;i++){
			if(isTrivial[i] == true){
				continue;
			}
			for(int j = 2*i; j<boundary;j+=i){
				isTrivial[j]=true;
			}
		}
		
		for(int i = 2; i < boundary;i++){
			if(isTrivial[i]==false){
				primeset.add((long)i);
			}
		}
		return primeset;
	}
	
	private void generate(String s, int len, List<String> collect){
		if (len ==0) {
			collect.add("1"+s+"1");
		}else{
			generate(s+"0", len-1, collect);
			generate(s+"1", len-1, collect);
		}
	}
	
	public List<String> generateNumbers(int N){
		List<String> numbers = new ArrayList<String>();
		generate("", N-2, numbers);
		return numbers;
	}
	
	public long getTrivialDivisorFor(long number){
		long result = 0;
		for(int div=2; div <= number/2;div++){
			if(number % div == 0){
				result = div;
				break;
			}
		}
		return result;
	}
	
	/**
	 * Main method the class.
	 * @param Name of file in resources.
	 * */
	public void process(Scanner input){
		int T = input.nextInt();
		for(int case_number=1;case_number <= T;case_number++){
			int N = input.nextInt();
			int J = input.nextInt();
			
			try{
				this.getPrimesCache();
				this.generateNumbers(N).stream().filter(e -> {
							for (int i=2;i<=10;i++){
								long v = Long.valueOf(e, i);
								if (primeset.contains(v)){
									return false;
								}
							}
							return true ;
						}) 
						.map(e -> 
							{   
								long  notTrivialDivisors[] = new long[10];
								boolean isJamCoin = true;
								for(int i=1;i<10;i++){
									notTrivialDivisors[i] = getTrivialDivisorFor(Long.valueOf(e, i+1));
									//if (notTrivialDivisors[i]==-1){
										//System.out.println("error e="+e+" i="+i+"  l="+Long.valueOf(e, i));
									//}
									if(notTrivialDivisors[i] <= 1){
										isJamCoin = false;
										break;
									}
								}
								if(isJamCoin){
									String r = String.format("%s %d %d %d %d %d %d %d %d %d", e, notTrivialDivisors[1], notTrivialDivisors[2],
											 									  notTrivialDivisors[3], notTrivialDivisors[4],
											 									  notTrivialDivisors[5], notTrivialDivisors[6],
											 								      notTrivialDivisors[7], notTrivialDivisors[8],
											 								      notTrivialDivisors[9] );
									return r;
								} else {
									return e+" NA";
								}
							})
							.filter(e -> {
								return !e.contains("NA");
							})
							//.limit(J)
							.forEach( e -> { 
											System.out.println(e);
										   } );
						    
										
			} catch(Exception e){
				e.printStackTrace();
			}
		}
		
	}
	
	public static void main(String[] args) {
		
		if (args!=null && args.length > 1 && "-d".equals(args[0]) ){
			try(Scanner input = new Scanner(new File(args[1]))){
				new CoinJam().process(input);
			} catch(Exception e){
				System.out.println("Exception during attempt to read file.");
				System.out.println("Exception " + e.getMessage());
			}
		}else{
			Scanner input = new Scanner(new BufferedReader(new InputStreamReader(System.in)));
			new CoinJam().process(input);
		}
		
	}

}
