import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Scanner;
import java.util.Vector;

public class TrainTimetable {
   /**
    * @param args Filename of Input File.
    */
   public static void main(String[] args) {
      new TrainTimetable(args[0]);
   }
   
   /**
    * Constructor.
    * @param filename   Filename of input file to open.
    */
   public TrainTimetable(String filename){
      File f = new File(filename);
      
      if (!f.exists()){
         System.out.println("Cannot Find File. Exiting");
         System.exit(0);
      }
      
      String[] result = parseFile(f);
      
      try{
         PrintWriter output = new PrintWriter(new BufferedWriter(new FileWriter(new File("output.txt"))));
         
         for (String s : result){
            output.println(s);
         }
         
         output.close();
      }catch(IOException e){
      }
      
   }
   
   
   public String[] parseFile(File f){
      Scanner input = null;
      String output[] = null;
      
      int testCount;
      
      /* Open File */
      try{
         input = new Scanner(f);
      }catch(FileNotFoundException e){
      }
      
      testCount = Integer.parseInt(input.nextLine());
      System.out.println(testCount + " Tests");
      output = new String[testCount];

      for (int i = 0; i < testCount; i++){
         int turnAroundTime = Integer.parseInt(input.nextLine());
         int tripsFromA = input.nextInt();
         int tripsFromB = input.nextInt();
         input.nextLine();
         
         System.out.printf("Turnaround: %d From A: %d From B: %d \n", turnAroundTime,tripsFromA, tripsFromB);
         
         Trip[] trips = new Trip[tripsFromA + tripsFromB];
         Vector<Trip> trainsFromA = new Vector<Trip>();
         Vector<Trip> trainsFromB = new Vector<Trip>();
         
         for (int o = 0; o < tripsFromA; o++){
            trips[o] = new Trip(input.nextLine(), turnAroundTime,'A');
         }
         for (int o = 0; o < tripsFromB; o++){
            trips[o + tripsFromA] = new Trip(input.nextLine(),turnAroundTime,'B');
         }
         
         /* Arrange in Order of Departure Time */
         Arrays.sort(trips);
         
         tripsFromA = 0;
         tripsFromB = 0;
         
         for (int o = 0; o < trips.length; o++){
            Trip current = trips[o];
            System.out.println(current);
            
            if (trips[o].fromA()){
               /* Check for Incoming Trains */
               if (trainsFromB.size() == 0){
                  trainsFromA.add(trips[o]);
                  tripsFromA ++;
               }else{
                  boolean found = false;
                  
                  /* Check for available Train arrival */
                  for (Trip trip : trainsFromB){
                     if (current.getStart().compareTo(trip.getEnd()) >= 0){
                        trainsFromB.remove(trip);
                        trainsFromA.add(current);
                        found = true;
                        break;
                     }
                  }
                  
                  if (!found){
                     trainsFromA.add(trips[o]);
                     tripsFromA ++;
                  }
               }
            }else{
               /* Check for Incoming Trains */
               if (trainsFromA.size() == 0){
                  trainsFromB.add(trips[o]);
                  tripsFromB ++;
               }else{
                  boolean found = false;
                  
                  /* Check for available Train arrival */
                  for (Trip trip : trainsFromA){
                     if (current.getStart().compareTo(trip.getEnd()) >= 0){
                        trainsFromA.remove(trip);
                        trainsFromB.add(current);
                        found = true;
                        break;
                     }
                  }
                  
                  if (!found){
                     trainsFromB.add(trips[o]);
                     tripsFromB ++;
                  }
               }
            }
         }
         
         output[i] = "Case #" + (i+1) + ": " + tripsFromA + " " + tripsFromB;
         
      }
      
      return output;
   }
}


class Trip implements Comparable<Trip>{
   private Date start;
   private Date end;
   private int turnAroundTime;
   
   private char origin = 'A';
   
   public Trip (String times, int turnAround, char origin){
      this.turnAroundTime = turnAround;
      this.origin = origin;
      
      String[] temp = times.split(" ");
      try{
         start = new SimpleDateFormat("H:m").parse(temp[0]);
         end = new SimpleDateFormat("H:m").parse(temp[1]);
         end = new Date(end.getTime() + (turnAroundTime * 60 * 1000));
         
//         System.out.println(start);
//         System.out.println(end);
      }catch(Exception e){
         e.printStackTrace();
      }
   }
   
   public int compareTo(Trip t){
      return start.compareTo(t.start);
   }
   
   public String toString(){
      return "Origin: " + origin + " From: " + start + " To: " + end;
   }
   
   public boolean fromA(){
      return origin == 'A';
   }
   public boolean fromB(){
      return origin == 'B';
   }

   public Date getStart() {
      return start;
   }

   public Date getEnd() {
      return end;
   }
}