import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.NumberFormat;
import java.util.ArrayList;

public class CookieClickerAlpha extends Thread {

	public static NumberFormat FORMATTER = NumberFormat.getInstance();
	static {
		FORMATTER.setGroupingUsed(false);
	}

	public int idThread;

	private CookieClickerAlpha(int idThread) {
		this.idThread = idThread;
	}

	// When the first thread start the process
	public static long START_PROCESS;

	// The number of test processed
	public static int NB_OK = 0;

	// The current test
	public static int ID_TEST = -1;

	// The number of running thread
	public static int NB_RUNNING_THREAD = 0;

	// All the test to do
	private static ArrayList<Data> TESTS = new ArrayList<Data>();

	// The current test
	private Data data = null;

	@Override
	public void run() {
		getNextDataToProcess(this);
		while (data != null) {

			solve();

			// Read the next test
			getNextDataToProcess(this);
		}
		if (NB_RUNNING_THREAD == 0) {
			try {
				FileWriter fw = new FileWriter("res-" + inFileName);

				for (int j = 0; j < TESTS.size(); j++) {
					Data d = TESTS.get(j);
					fw.write("Case #" + d.id + ": " + d.result + "\n");
					System.out.print("Case #" + d.id + ": " + d.result + "\n");
				}
				fw.close();
			} catch (IOException e) {
				e.printStackTrace();
			}

		}
	}

	/**
	 * @param ct
	 *            The calcul thread
	 */
	private static synchronized void getNextDataToProcess(CookieClickerAlpha ct) {

		if (ct.data != null) {

			// A process is OK
			NB_OK++;
			System.out.println(NB_OK + "/" + TESTS.size() + " in " + getProcessTime(START_PROCESS) + " " + ct.data.result);
		} else {

			// A new thread start
			System.out.println("THREAD " + ct.idThread + " [START]");
			NB_RUNNING_THREAD++;
		}

		if (ID_TEST + 1 < TESTS.size()) {

			// New process for the thread
			ID_TEST++;
			ct.data = TESTS.get(ID_TEST);
		} else {

			// Nothing else to process (Stop the process)
			NB_RUNNING_THREAD--;
			ct.data = null;
			System.out.println("THREAD " + ct.idThread + " [STOP]");
		}

	}

	/**
	 * @param sinceTime
	 *            the start date
	 * @return Get the process time
	 */
	private static String getProcessTime(long sinceTime) {
		// Show the time of process
		long duree = System.currentTimeMillis() - sinceTime;
		long nbSec = duree / 1000;
		long nbMin = nbSec / 60;
		if (nbMin > 0) {
			nbSec = nbSec - (nbMin * 60);
		}
		return (nbMin > 0 ? nbMin + " min" : "") + " " + (nbSec > 0 ? nbSec + " sec" : "0 sec");
	}

	public static void main(String[] args) throws IOException {

		START_PROCESS = System.currentTimeMillis();

		try (// Load the file
		BufferedReader buffer = new BufferedReader(new FileReader(inFileName));) {

			load(buffer);

			// TODO (4) Active multi-threading
			// for (int i = 0; i < TESTS.size() / 2; i++) {
			// for (int i = 0; i < TESTS.size(); i++) {
			// for (int i = 0; i < 10; i++) {
			for (int i = 0; i < 1; i++) {
				new CookieClickerAlpha(i).start();
			}

		}

	}

	static void load(BufferedReader buffer) throws IOException {
		String line = buffer.readLine();
		int tId = 1;
		line = buffer.readLine();
		while (line != null) {

			Data d = new Data();

			String[] elems = line.split(" ");
			d.C = Double.parseDouble(elems[0]);
			d.F = Double.parseDouble(elems[1]);
			d.X = Double.parseDouble(elems[2]);

			d.id = tId;
			TESTS.add(d);
			tId++;
			line = buffer.readLine();
		}
		buffer.close();
	}

	// Representation of the test case
	// -------------------------------------------
	static class Data {

		// The identify of the test
		int id;
		// The result
		String result;

		double C;
		double F;
		double X;

		@Override
		public String toString() {
			return "Data [id=" + id + ", C=" + C + ", F=" + F + ", X=" + X + "]";
		}

	}

	// The file to load
	private static String inFileName = "B-small-attempt0.in";

	/**
	 * The method to solve to problem
	 */
	void solve() {

		// Display test input
		System.out.println(data);

		double time = 0;
		boolean optimalProcessFound = false;
		double currentProduction = 2;
		double timeToGetAFactory;
		double timeToGetXCookiesWithCurrentProduction;
		double timeToGetAFactoryAndXCookiesNext;

		while (!optimalProcessFound) {

			timeToGetAFactory = (data.C) / currentProduction;
			timeToGetXCookiesWithCurrentProduction = (data.X) / currentProduction;
			timeToGetAFactoryAndXCookiesNext = timeToGetAFactory + (data.X / (currentProduction + data.F));
			if (timeToGetAFactoryAndXCookiesNext < timeToGetXCookiesWithCurrentProduction) {

				time += timeToGetAFactory;
				System.out.print(timeToGetAFactory);
				currentProduction += data.F;

			} else {
				time += timeToGetXCookiesWithCurrentProduction;
				optimalProcessFound = true;
				System.out.print(timeToGetXCookiesWithCurrentProduction);
			}

			if (!optimalProcessFound) {
				System.out.print(" + ");
			}
		}

		System.out.println(" = " + time);

		// Save the result
		data.result = "" + time;

	}
}
