import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

public class DeceitfulWar extends Thread {

	public static NumberFormat FORMATTER = NumberFormat.getInstance();
	static {
		FORMATTER.setGroupingUsed(false);
	}

	public int idThread;

	private DeceitfulWar(int idThread) {
		this.idThread = idThread;
	}

	// When the first thread start the process
	public static long START_PROCESS;

	// The number of test processed
	public static int NB_OK = 0;

	// The current test
	public static int ID_TEST = -1;

	// The number of running thread
	public static int NB_RUNNING_THREAD = 0;

	// All the test to do
	private static ArrayList<Data> TESTS = new ArrayList<Data>();

	// The current test
	private Data data = null;

	@Override
	public void run() {
		getNextDataToProcess(this);
		while (data != null) {

			solve();

			// Read the next test
			getNextDataToProcess(this);
		}
		if (NB_RUNNING_THREAD == 0) {
			try {
				FileWriter fw = new FileWriter("res-" + inFileName);

				for (int j = 0; j < TESTS.size(); j++) {
					Data d = TESTS.get(j);
					fw.write("Case #" + d.id + ": " + d.result + "\n");
					System.out.print("Case #" + d.id + ": " + d.result + "\n");
				}
				fw.close();
			} catch (IOException e) {
				e.printStackTrace();
			}

		}
	}

	/**
	 * @param ct
	 *            The calcul thread
	 */
	private static synchronized void getNextDataToProcess(DeceitfulWar ct) {

		if (ct.data != null) {

			// A process is OK
			NB_OK++;
			System.out.println(NB_OK + "/" + TESTS.size() + " in " + getProcessTime(START_PROCESS) + " " + ct.data.result);
		} else {

			// A new thread start
			System.out.println("THREAD " + ct.idThread + " [START]");
			NB_RUNNING_THREAD++;
		}

		if (ID_TEST + 1 < TESTS.size()) {

			// New process for the thread
			ID_TEST++;
			ct.data = TESTS.get(ID_TEST);
		} else {

			// Nothing else to process (Stop the process)
			NB_RUNNING_THREAD--;
			ct.data = null;
			System.out.println("THREAD " + ct.idThread + " [STOP]");
		}

	}

	/**
	 * @param sinceTime
	 *            the start date
	 * @return Get the process time
	 */
	private static String getProcessTime(long sinceTime) {
		// Show the time of process
		long duree = System.currentTimeMillis() - sinceTime;
		long nbSec = duree / 1000;
		long nbMin = nbSec / 60;
		if (nbMin > 0) {
			nbSec = nbSec - (nbMin * 60);
		}
		return (nbMin > 0 ? nbMin + " min" : "") + " " + (nbSec > 0 ? nbSec + " sec" : "0 sec");
	}

	public static void main(String[] args) throws IOException {

		START_PROCESS = System.currentTimeMillis();

		try (// Load the file
		BufferedReader buffer = new BufferedReader(new FileReader(inFileName));) {

			load(buffer);

			// TODO (4) Active multi-threading
			// for (int i = 0; i < TESTS.size() / 2; i++) {
			// for (int i = 0; i < TESTS.size(); i++) {
			// for (int i = 0; i < 10; i++) {
			for (int i = 0; i < 1; i++) {
				new DeceitfulWar(i).start();
			}

		}

	}

	static void load(BufferedReader buffer) throws IOException {
		String line = buffer.readLine();
		int tId = 1;
		line = buffer.readLine();
		while (line != null) {

			Data d = new Data();

			line = buffer.readLine();
			for (String elem : line.split(" ")) {
				d.naomiMasses.add(Double.parseDouble(elem));
			}

			line = buffer.readLine();
			for (String elem : line.split(" ")) {
				d.kenMasses.add(Double.parseDouble(elem));
			}

			d.id = tId;
			TESTS.add(d);
			tId++;
			line = buffer.readLine();
		}
		buffer.close();
	}

	// Representation of the test case
	// -------------------------------------------
	static class Data {

		// The identify of the test
		public int id;
		// The result
		public String result;

		List<Double> naomiMasses = new ArrayList<Double>();
		List<Double> kenMasses = new ArrayList<Double>();

		@Override
		public String toString() {
			return "Data [id=" + id + ", naomiMasses=" + naomiMasses + ", kenMasses=" + kenMasses + "]";
		}

	}

	/**
	 * The method to solve to problem
	 */
	void solve() {

		// Display test input
		System.out.println(data);

		List<Double> nSmallToTallAlgo1 = new ArrayList<Double>(data.naomiMasses);
		Collections.sort(nSmallToTallAlgo1);
		List<Double> nTallToSmallAlgo1 = new ArrayList<Double>(data.naomiMasses);
		Collections.sort(nTallToSmallAlgo1);
		Collections.reverse(nTallToSmallAlgo1);
		List<Double> kSmallToTallAlgo1 = new ArrayList<Double>(data.kenMasses);
		Collections.sort(kSmallToTallAlgo1);

		List<Double> nSmallToTallAlgo2 = new ArrayList<Double>(data.naomiMasses);
		Collections.sort(nSmallToTallAlgo2);
		List<Double> kSmallToTallAlgo2 = new ArrayList<Double>(data.kenMasses);
		Collections.sort(kSmallToTallAlgo2);
		List<Double> nTallToSmallAlgo2 = new ArrayList<Double>(data.naomiMasses);
		Collections.sort(nTallToSmallAlgo2);
		Collections.reverse(nTallToSmallAlgo2);
		List<Double> kTallToSmallAlgo2 = new ArrayList<Double>(data.kenMasses);
		Collections.sort(kTallToSmallAlgo2);
		Collections.reverse(kTallToSmallAlgo2);

		int resWar = 0;
		double nChoice;
		double kChoice;

		// ---- WAR ALGO
		while (nTallToSmallAlgo1.size() > 0) {
			nChoice = nTallToSmallAlgo1.remove(0);
			boolean kenWin = false;
			for (Iterator<Double> it = kSmallToTallAlgo1.iterator(); !kenWin && it.hasNext();) {
				kChoice = it.next();
				if (kChoice > nChoice) {
					kenWin = true;
					it.remove();
				}
			}
			if (!kenWin) {
				resWar++;
				kSmallToTallAlgo1.remove(0);
			}
		}

		int resDeceitfulWar = 0;
		// ---- DECEITFUL ALGO

		while (nSmallToTallAlgo2.size() > 0) {
//			System.out.println("----------------------------");
//			System.out.println("naomi: " + nSmallToTallAlgo2);
//			System.out.println("ken: " + kSmallToTallAlgo2);

			nChoice = nSmallToTallAlgo2.remove(0);
			if (nChoice > kSmallToTallAlgo2.get(0)) {
				kChoice = kSmallToTallAlgo2.remove(0);
			} else {
				kChoice = kSmallToTallAlgo2.remove(kSmallToTallAlgo2.size() - 1);
			}

			if (nChoice > kChoice) {
				resDeceitfulWar++;
			}
		}

		// Save the result
		data.result = resDeceitfulWar + " " + resWar;

	}

	// The file to load
	private static String inFileName = "D-large.in";
}
