import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.NumberFormat;
import java.util.ArrayList;

public class MinesweeperMaster extends Thread {

	public static NumberFormat FORMATTER = NumberFormat.getInstance();
	static {
		FORMATTER.setGroupingUsed(false);
	}

	public int idThread;

	private MinesweeperMaster(int idThread) {
		this.idThread = idThread;
	}

	// When the first thread start the process
	public static long START_PROCESS;

	// The number of test processed
	public static int NB_OK = 0;

	// The current test
	public static int ID_TEST = -1;

	// The number of running thread
	public static int NB_RUNNING_THREAD = 0;

	// All the test to do
	private static ArrayList<Data> TESTS = new ArrayList<Data>();

	// The current test
	private Data data = null;

	@Override
	public void run() {
		getNextDataToProcess(this);
		while (data != null) {

			solve();

			// Read the next test
			getNextDataToProcess(this);
		}
		if (NB_RUNNING_THREAD == 0) {
			try {
				FileWriter fw = new FileWriter("res-" + inFileName);

				for (int j = 0; j < TESTS.size(); j++) {
					Data d = TESTS.get(j);
					fw.write("Case #" + d.id + ":\n" + d.result + "\n");
					System.out.print("Case #" + d.id + ":\n" + d.result + "\n");
				}
				fw.close();
			} catch (IOException e) {
				e.printStackTrace();
			}

		}
	}

	/**
	 * @param ct
	 *            The calcul thread
	 */
	private static synchronized void getNextDataToProcess(MinesweeperMaster ct) {

		if (ct.data != null) {

			// A process is OK
			NB_OK++;
			System.out.println(NB_OK + "/" + TESTS.size() + " in " + getProcessTime(START_PROCESS) + "\n" + ct.data.result);
		} else {

			// A new thread start
			System.out.println("THREAD " + ct.idThread + " [START]");
			NB_RUNNING_THREAD++;
		}

		if (ID_TEST + 1 < TESTS.size()) {

			// New process for the thread
			ID_TEST++;
			ct.data = TESTS.get(ID_TEST);
		} else {

			// Nothing else to process (Stop the process)
			NB_RUNNING_THREAD--;
			ct.data = null;
			System.out.println("THREAD " + ct.idThread + " [STOP]");
		}

	}

	/**
	 * @param sinceTime
	 *            the start date
	 * @return Get the process time
	 */
	private static String getProcessTime(long sinceTime) {
		// Show the time of process
		long duree = System.currentTimeMillis() - sinceTime;
		long nbSec = duree / 1000;
		long nbMin = nbSec / 60;
		if (nbMin > 0) {
			nbSec = nbSec - (nbMin * 60);
		}
		return (nbMin > 0 ? nbMin + " min" : "") + " " + (nbSec > 0 ? nbSec + " sec" : "0 sec");
	}

	public static void main(String[] args) throws IOException {

		START_PROCESS = System.currentTimeMillis();

		try (// Load the file
		BufferedReader buffer = new BufferedReader(new FileReader(inFileName));) {

			load(buffer);

			// TODO (4) Active multi-threading
			// for (int i = 0; i < TESTS.size() / 2; i++) {
			// for (int i = 0; i < TESTS.size(); i++) {
			// for (int i = 0; i < 10; i++) {
			for (int i = 0; i < 1; i++) {
				new MinesweeperMaster(i).start();
			}

		}

	}

	static void load(BufferedReader buffer) throws IOException {
		String line = buffer.readLine();
		int tId = 1;
		line = buffer.readLine();
		while (line != null) {

			Data d = new Data();

			String[] elems = line.split(" ");
			d.R = Integer.parseInt(elems[0]);
			d.C = Integer.parseInt(elems[1]);
			d.M = Integer.parseInt(elems[2]);

			d.id = tId;
			TESTS.add(d);
			tId++;
			line = buffer.readLine();
		}
		buffer.close();
	}

	// Representation of the test case
	// -------------------------------------------
	static class Data {

		// The identify of the test
		int id;
		// The result
		String result;

		int R;
		int C;
		int M;

		@Override
		public String toString() {
			return "Data [id=" + id + ", R=" + R + ", C=" + C + ", M=" + M + "]";
		}

	}

	// The file to load
	private static String inFileName = "C-small-attempt12.in";

	/**
	 * The method to solve to problem
	 */
	void solve() {

		// Display test input
		System.out.println(data);

		int totCells = data.R * data.C;
		int totEmptyCells = totCells - data.M;
		boolean onlyOnceCell = totCells - data.M == 1;
		boolean clickFound = false;

		String[][] grid = new String[data.R][data.C];
		boolean placeBomb = data.M > 0;
		int elemPlaced = 0;

		int iR = 0;
		int iC = 0;

		// ----------- ALGO 6 (By empty Square)
		if (!clickFound) {

			grid = new String[data.R][data.C];
			placeBomb = data.M > 0;
			elemPlaced = 0;

			double sqrt = Math.sqrt(totCells - data.M);
			int dimSquare = (int) sqrt;
			if (Math.sqrt(totCells - data.M) > dimSquare) {
				dimSquare++;
			}
			dimSquare = Math.min(dimSquare, data.R);
			dimSquare = Math.min(dimSquare, data.C);

			for (iR = 0; iR < data.R; iR++) {
				for (iC = 0; iC < data.C; iC++) {
					grid[iR][iC] = "*";
				}
			}

			for (iR = 0; elemPlaced < totEmptyCells && iR < dimSquare; iR++) {
				for (iC = 0; elemPlaced < totEmptyCells && iC < dimSquare; iC++) {
					grid[iR][iC] = ".";
					elemPlaced++;
				}

				// System.out.println("-----------------------------");
				// for (int r = 0; r < data.R; r++) {
				// for (int c = 0; c < data.C; c++) {
				// System.out.print(grid[r][c] != null ? grid[r][c] : "?");
				// }
				// System.out.println();
				// }
				// System.out.println("-----------------------------");
			}

			if (elemPlaced == totEmptyCells) {
				System.out.println("################ (CHECK ALGO 6) #######################");
				clickFound = checkPlacement(onlyOnceCell, grid);
			}
		}

		// ---- ALGO 1 - Circular placement
		if (!clickFound) {

			grid = new String[data.R][data.C];
			placeBomb = data.M > 0;
			elemPlaced = 0;
			iR = 0;
			iC = 0;
			int dR = 0;
			int dC = 1;
			int nbPlaced = 0;
			while (nbPlaced < totCells) {

				if (grid[iR][iC] == null) {
					if (placeBomb) {
						grid[iR][iC] = "*";
						elemPlaced++;
					} else {
						grid[iR][iC] = ".";
					}
					if (elemPlaced == data.M) {
						placeBomb = false;
					}
				}
				boolean keepDir = iR + dR > -1 && iR + dR < data.R && iC + dC > -1 && iC + dC < data.C && grid[iR + dR][iC + dC] == null;
				if (!keepDir) {
					// Move right
					if (dR == 0 && dC == 1) {
						// Change to move bottom
						dR = 1;
						dC = 0;

						// Move bottom
					} else if (dR == 1 && dC == 0) {
						// Change to move left
						dR = 0;
						dC = -1;

						// Move left
					} else if (dR == 0 && dC == -1) {
						// Change to move up
						dR = -1;
						dC = 0;

						// Move up
					} else if (dR == -1 && dC == 0) {
						// Change to move right
						dR = 0;
						dC = 1;
					}
				}

				iR += dR;
				iC += dC;
				nbPlaced++;
			}

			System.out.println("################ (CHECK ALGO 1) #######################");
			clickFound = checkPlacement(onlyOnceCell, grid);
		}

		// ----------- ALGO 2 (Bomb Top to Down)
		if (!clickFound) {

			grid = new String[data.R][data.C];
			placeBomb = data.M > 0;
			elemPlaced = 0;

			iR = 0;
			iC = 0;

			for (iR = 0; iR < data.R; iR++) {
				for (iC = 0; iC < data.C; iC++) {
					if (grid[iR][iC] == null) {
						if (placeBomb) {
							grid[iR][iC] = "*";
							elemPlaced++;
						} else {
							grid[iR][iC] = ".";
						}
						if (elemPlaced == data.M) {
							placeBomb = false;
						}
					}
				}
			}

			System.out.println("################ (CHECK ALGO 2) #######################");
			clickFound = checkPlacement(onlyOnceCell, grid);

		}

		// ----------- ALGO 2bis (Bomb Left to Right)
		if (!clickFound) {

			grid = new String[data.R][data.C];
			placeBomb = data.M > 0;
			elemPlaced = 0;

			iR = 0;
			iC = 0;

			for (iC = 0; iC < data.C; iC++) {
				for (iR = 0; iR < data.R; iR++) {
					if (grid[iR][iC] == null) {
						if (placeBomb) {
							grid[iR][iC] = "*";
							elemPlaced++;
						} else {
							grid[iR][iC] = ".";
						}
						if (elemPlaced == data.M) {
							placeBomb = false;
						}
					}
				}
			}

			System.out.println("################ (CHECK ALGO 2bis) #######################");
			clickFound = checkPlacement(onlyOnceCell, grid);

		}

		// ----------- ALGO 3 (Bomb By Diag left to right)
		if (!clickFound) {

			grid = new String[data.R][data.C];
			placeBomb = data.M > 0;
			elemPlaced = 0;

			iR = 0;
			iC = 0;

			for (int iDiag = 0; iDiag < data.R + data.C - 1; iDiag++) {
				iC = 0;
				iR = iDiag;
				if (iR >= data.R) {
					iR = data.R - 1;
					iC = iDiag - iR;
				}
				while (iR > -1 && iC < data.C) {
					if (grid[iR][iC] == null) {
						if (placeBomb) {
							grid[iR][iC] = "*";
							elemPlaced++;
						} else {
							grid[iR][iC] = ".";
						}
						if (elemPlaced == data.M) {
							placeBomb = false;
						}
					}
					iC++;
					iR--;
				}

				// System.out.println("-----------------------------");
				// for (int r = 0; r < data.R; r++) {
				// for (int c = 0; c < data.C; c++) {
				// System.out.print(grid[r][c] != null ? grid[r][c] : "?");
				// }
				// System.out.println();
				// }
				// System.out.println("-----------------------------");
			}

			System.out.println("################ (CHECK ALGO 3) #######################");
			clickFound = checkPlacement(onlyOnceCell, grid);
		}

		// ----------- ALGO 4 (By Square Bomb)
		if (!clickFound) {

			grid = new String[data.R][data.C];
			placeBomb = data.M > 0;
			elemPlaced = 0;

			double sqrt = Math.sqrt(data.M);
			int dimSquare = (int) sqrt;
			if (Math.sqrt(data.M) > dimSquare) {
				dimSquare++;
			}
			dimSquare = Math.min(dimSquare, data.R);
			dimSquare = Math.min(dimSquare, data.C);

			for (iR = 0; iR < data.R; iR++) {
				for (iC = 0; iC < data.C; iC++) {
					grid[iR][iC] = ".";
				}
			}

			for (iR = 0; elemPlaced < data.M && iR < dimSquare; iR++) {
				for (iC = 0; elemPlaced < data.M && iC < dimSquare; iC++) {
					grid[iR][iC] = "*";
					elemPlaced++;
				}

				// System.out.println("-----------------------------");
				// for (int r = 0; r < data.R; r++) {
				// for (int c = 0; c < data.C; c++) {
				// System.out.print(grid[r][c] != null ? grid[r][c] : "?");
				// }
				// System.out.println();
				// }
				// System.out.println("-----------------------------");
			}

			if (elemPlaced == data.M) {
				System.out.println("################ (CHECK ALGO 4) #######################");
				clickFound = checkPlacement(onlyOnceCell, grid);
			}
		}

		// ----------- ALGO 5 (Bomb alternate UP/DOWN)
		if (!clickFound) {

			grid = new String[data.R][data.C];
			placeBomb = data.M > 0;
			elemPlaced = 0;

			boolean up = true;
			int iRUp = 0;
			int iCUp = 0;
			int iRDown = data.R - 1;
			int iCDown = data.C - 1;

			for (iR = 0; iR < data.R; iR++) {
				for (iC = 0; iC < data.C; iC++) {
					grid[iR][iC] = ".";
				}
			}

			while (elemPlaced < data.M) {
				if (up) {
					grid[iRUp][iCUp] = "*";
					iCUp++;
					if (iCUp >= data.C) {
						iCUp = 0;
						iRUp++;
					}
				} else {
					grid[iRDown][iCDown] = "*";
					iCDown--;
					if (iCDown < 0) {
						iCDown = data.C - 1;
						iRDown--;
					}
				}
				elemPlaced++;
				up = !up;

				// System.out.println("-----------------------------");
				// for (int r = 0; r < data.R; r++) {
				// for (int c = 0; c < data.C; c++) {
				// System.out.print(grid[r][c] != null ? grid[r][c] : "?");
				// }
				// System.out.println();
				// }
				// System.out.println("-----------------------------");
			}

			System.out.println("################ (CHECK ALGO 5) #######################");
			clickFound = checkPlacement(onlyOnceCell, grid);
		}

		if (clickFound) {
			StringBuilder res = new StringBuilder();
			for (int r = 0; r < data.R; r++) {
				for (int c = 0; c < data.C; c++) {
					res.append(grid[r][c]);
				}
				if (r + 1 < data.R) {
					res.append("\n");
				}
			}
			data.result = res.toString();
		} else {
			data.result = "Impossible";
		}
	}

	private boolean checkPlacement(boolean onlyOnceCell, String[][] grid) {

		boolean clickFound = true;
		int[][] tmpGrid = new int[data.R][data.C];
		for (int r = 0; r < data.R; r++) {
			for (int c = 0; c < data.C; c++) {
				if (".".equals(grid[r][c])) {
					int nb = 0;
					if (r - 1 > -1) {
						if (c - 1 > -1 && "*".equals(grid[r - 1][c - 1])) {
							nb++;
						}
						if ("*".equals(grid[r - 1][c])) {
							nb++;
						}
						if (c + 1 < data.C && "*".equals(grid[r - 1][c + 1])) {
							nb++;
						}
					}

					if (c - 1 > -1 && "*".equals(grid[r][c - 1])) {
						nb++;
					}

					if (c + 1 < data.C && "*".equals(grid[r][c + 1])) {
						nb++;
					}

					if (r + 1 < data.R) {
						if (c - 1 > -1 && "*".equals(grid[r + 1][c - 1])) {
							nb++;
						}
						if ("*".equals(grid[r + 1][c])) {
							nb++;
						}
						if (c + 1 < data.C && "*".equals(grid[r + 1][c + 1])) {
							nb++;
						}
					}

					tmpGrid[r][c] = nb;
					System.out.print(nb);
				} else {
					System.out.print("*");
					tmpGrid[r][c] = -1;
				}
			}
			System.out.print("\n");
		}

		for (int r = 0; r < data.R; r++) {
			for (int c = 0; c < data.C; c++) {
				if (tmpGrid[r][c] > 0) {
					boolean foundEmptySpace = false;
					if (r - 1 > -1) {
						if (c - 1 > -1 && tmpGrid[r - 1][c - 1] == 0) {
							foundEmptySpace = true;
						}
						if (tmpGrid[r - 1][c] == 0) {
							foundEmptySpace = true;
						}
						if (c + 1 < data.C && tmpGrid[r - 1][c + 1] == 0) {
							foundEmptySpace = true;
						}
					}

					if (c - 1 > -1 && tmpGrid[r][c - 1] == 0) {
						foundEmptySpace = true;
					}

					if (c + 1 < data.C && tmpGrid[r][c + 1] == 0) {
						foundEmptySpace = true;
					}

					if (r + 1 < data.R) {
						if (c - 1 > -1 && tmpGrid[r + 1][c - 1] == 0) {
							foundEmptySpace = true;
						}
						if (tmpGrid[r + 1][c] == 0) {
							foundEmptySpace = true;
						}
						if (c + 1 < data.C && tmpGrid[r + 1][c + 1] == 0) {
							foundEmptySpace = true;
						}
					}

					if (!foundEmptySpace) {
						clickFound = false;
					}
				}
			}

		}

		if (clickFound || onlyOnceCell) {
			if (onlyOnceCell) {
				for (int r = 0; r < data.R; r++) {
					for (int c = 0; c < data.C; c++) {
						if (!"*".equals(grid[r][c])) {
							grid[r][c] = "c";
							return true;
						}
					}
				}
			} else {
				if (!"*".equals(grid[data.R - 1][data.C - 1])) {
					grid[data.R - 1][data.C - 1] = "c";
				} else {
					for (int r = 0; r < data.R; r++) {
						for (int c = 0; c < data.C; c++) {
							if (tmpGrid[r][c] == 0) {
								grid[r][c] = "c";
								return true;
							}
						}
					}
				}
			}
		}

		return clickFound;
	}
}
