import java.io.BufferedReader;
import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.List;

public class InfiniteHousePancakes {

	private static final String CHARSET = "US-ASCII";
	private static final String PATH_IN = "B-small-attempt0.in";
	private static final String PATH_OUT = "InfiniteHousePancakes.out";
	private static final String SPLITTER = " ";
	private static Path pathIn = Paths.get(PATH_IN);
	private static Path pathOut = Paths.get(PATH_OUT);

	public static void main(String[] args) throws IOException {
		long startTime = System.currentTimeMillis();
		try {
			Files.delete(pathOut);
		} catch (IOException e) {
		}

		Charset charset = Charset.forName(CHARSET);
		try (BufferedReader reader = Files.newBufferedReader(pathIn, charset)) {

			solveInfiniteHousePancakes(reader);

		} catch (IOException x) {
			System.err.format("IOException: %s%n", x);
			throw x;
		}

		long duration = System.currentTimeMillis() - startTime;
		System.out.println(duration + " milliseconds to run");

	}

	private static void solveInfiniteHousePancakes(BufferedReader reader)
			throws NumberFormatException, IOException {
		int menor, primo, specialMinutes = 0, plateInt, plateMax = 0, nonEmptyPlates, numberOfTests = Integer
				.parseInt(reader.readLine());

		String[] caseSplit;
		List<Integer> fillPlates = new ArrayList<Integer>();

		for (int i = 0; i < numberOfTests; i++) {
			nonEmptyPlates = Integer.parseInt(reader.readLine());
			caseSplit = reader.readLine().split(SPLITTER);

			for (String plate : caseSplit) {
				plateInt = Integer.parseInt(plate);
				
				if (plateInt > plateMax)
					plateMax = plateInt;
					

				fillPlates.add(plateInt);
			}
			
			menor = plateMax;

			while (plateMax > 3) {

				for (int j = 0; j < nonEmptyPlates; j++) {
					Integer integer = fillPlates.get(j);
					if (integer == plateMax) {
						fillPlates.remove(j);

						if ( ( primo = numeroDivisiblePrimo(integer) ) != -1) {
							fillPlates.add(integer - primo);
							fillPlates.add(primo);
							nonEmptyPlates++;
							specialMinutes++;
						} else {
							if (plateMax % 2 == 0) {

								fillPlates.add(integer / 2);
								fillPlates.add(integer / 2);
								specialMinutes++;
								nonEmptyPlates++;
							} else {
								fillPlates.add(integer / 2);
								fillPlates.add(integer / 2 + 1);
								specialMinutes++;
								nonEmptyPlates++;
							}
						}

					}
				}

				plateMax = 0;

				for (Integer integer : fillPlates) {
					if (integer > plateMax)
						plateMax = integer;
				}
				
				if ( plateMax + specialMinutes < menor )
					menor = plateMax + specialMinutes;

			}

			output(i + 1, menor);

			fillPlates.clear();
			plateMax = 0;
			specialMinutes = 0;
			menor = 0;

		}
	}




	private static int numeroDivisiblePrimo(Integer integer) {
		int retorno = -1;
		for (int i = 2; i < integer; i++) {
			if (integer%i==0 && i*i==integer)
			{
				retorno = i;
			}
			if(retorno != -1)
				break;
		}
		
		return retorno;
	}

	private static void output(int number, int result) throws IOException {
		output(number, "" + result);
	}

	private static void output(int number, String result) throws IOException {
		String format = MessageFormat.format("Case #{0}: {1}", number, result);
		System.out.println(format);
		try {
			if (Files.exists(pathOut))
				Files.write(pathOut, "\n".getBytes(), StandardOpenOption.APPEND);
			Files.write(pathOut, format.getBytes(), StandardOpenOption.CREATE,
					StandardOpenOption.APPEND);
		} catch (IOException e) {
			System.err.format("IOException: %s%n", e);
			throw e;
		}
	}

}
