package watersheds;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

public class Watersheds {

	private static final int DUMMY = 100000;
	
	private static BufferedReader in;
	private static FileWriter out;
	private static int t; // # maps
	private static int h;
	private static int w;
	private static String[] chunks;
	private static int[][] map;
	private static int[][][] flow;

	private static char[][] labels;

	private static char nextLabel;

	public static void main(String[] args) throws IOException {
		String dir = "src/watersheds/";
		in = new BufferedReader(new FileReader(dir + "B-small-attempt0.in"));
		out = new FileWriter(dir + "B-small-attempt0.out");
		chunks = in.readLine().split(" ");
		t = Integer.parseInt(chunks[0]);
		
		log(t + " maps");
		
		for (int i = 1; i <= t; i++) {
			doCase(i);
		}
		
		out.close();
	}

	private static void doCase(int i) throws IOException {
		log("\nCase " + i);
		readMap();
		computeFlow();
		label();
		out("Case #" + i + ":");
		for (int row = 1; row <= h; row++) {
			for (int col = 1; col <= w; col++) {
				out2(labels[row][col] + " ");
			}
			out("");
		}
	}

	private static void label() {
		nextLabel = 'a';
		labels = new char[h + 2][w + 2];
		for (int row = 1; row <= h; row++) {
			for (int col = 1; col <= w; col++) {
				labels[row][col] = ' ';
			}
		}
		for (int row = 1; row <= h; row++) {
			for (int col = 1; col <= w; col++) {
				label(row, col);
			}
		}
	}

	private static char label(int row, int col) {
		if (labels[row][col] != ' ') { // already labeled
			return labels[row][col];
		} else {
			int flowsToRow = flow[row][col][0];
			int flowsToCol = flow[row][col][1];
			if (flowsToRow == row && flowsToCol == col) { // unlabeled sink
				labels[row][col] = nextLabel;
				nextLabel = (char)((int)nextLabel + 1);
			} else {
				labels[row][col] = label(flowsToRow, flowsToCol);
			}
			log("Labeled " + row + "," + col + " as " + labels[row][col]);
			return labels[row][col];
		}
	}

	private static void computeFlow() {
		flow = new int[h + 2][w + 2][2];
		log("Flow:");
		for (int row = 1; row <= h; row++) {
			for (int col = 1; col <= w; col++) {
				int lowest = map[row][col];
				int bestRow = row, bestCol = col;
				if (map[row - 1][col] < lowest) {
					bestRow = row - 1;
					bestCol = col;
					lowest = map[row - 1][col];
				}
				if (map[row][col - 1] < lowest) {
					bestRow = row;
					bestCol = col - 1;
					lowest = map[row][col - 1];
				}
				if (map[row][col + 1] < lowest) {
					bestRow = row;
					bestCol = col + 1;
					lowest = map[row][col + 1];
				}
				if (map[row + 1][col] < lowest) {
					bestRow = row + 1;
					bestCol = col;
					lowest = map[row + 1][col];
				}
				flow[row][col][0] = bestRow;
				flow[row][col][1] = bestCol;
				log2(bestRow + "," + bestCol + " ");
			}
			log("");
		}
	}

	private static void readMap() throws IOException {
		chunks = in.readLine().split(" ");
		h = Integer.parseInt(chunks[0]);
		w = Integer.parseInt(chunks[1]);
		log("Map has " + h + " rows and " + w + " cols");
		map = new int[h + 2][w + 2];
		for (int row = 0; row < h + 2; row++) {
			map[row][0] = DUMMY; // left
			map[row][w + 1] = DUMMY; // right
		}
		for (int col = 0; col < w + 2; col++) {
			map[0][col] = DUMMY; // top
			map[h + 1][col] = DUMMY; // bottom
		}
		for (int row = 1; row <= h; row++) {
			chunks = in.readLine().split(" ");
			for (int col = 1; col <= w; col++) {
				map[row][col] = Integer.parseInt(chunks[col - 1]);
			}
		}
		for (int row = 0; row < h + 2; row++) {
			for (int col = 0; col < w + 2; col++) {
				log2(map[row][col] + " ");
			}
			log("");
		}
	}

	private static void out(String string) throws IOException {
		System.out.println(string);
		out.write(string + "\n");
	}

	private static void out2(String string) throws IOException {
		System.out.print(string);
		out.write(string);
	}

	private static void log(String string) {
//		System.out.println(string);
	}

	private static void log2(String string) {
//		System.out.print(string);
	}
}
