package round1b.a;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;

class Tree {

	public double val;
	public String feat;
	public Tree left;
	public Tree right;
	
}

class Animal {

	public String name;
	public HashSet<String> feats;
	
}

public class A {

	private static BufferedReader in;
	private static FileWriter out;
	private static int n;
	private static String[] chunks;
	private static String line;
	private static StringBuilder text;
	private static DecimalFormat df;

	public static void main(String[] args) throws Exception {
		String dir = "src/round1b/a/";
		in = new BufferedReader(new FileReader(dir + "A-small-attempt0.in"));
		out = new FileWriter(dir + "A-small-attempt0.out");
		chunks = in.readLine().split(" ");
		n = Integer.parseInt(chunks[0]);
		
		log(n + " cases");
		
		setup();
		
		for (int i = 1; i <= n; i++) {
			doCase(i);
		}
		
		out.close();
	}

	private static void setup() {
		df = new DecimalFormat("0.0000000");
	}

	private static void doCase(int i) throws Exception {
		log("\nCase " + i);

		Tree tree = parseTree();
		List<Animal> animals = parseAnimals();
		
		out(String.format("Case #%d:", i));
		for (Animal animal : animals) {
			double p = getProb(animal, tree);
			out(df.format(p));
		}
		
	}

	private static double getProb(Animal animal, Tree tree) {
		double p = 1;
		while (tree != null) {
			p *= tree.val;
//			if (tree.feat != null) {
				if (animal.feats.contains(tree.feat)) {
					tree = tree.left;
				} else {
					tree = tree.right;
				}
//			}
		}
		return p;
	}

	private static List<Animal> parseAnimals() throws NumberFormatException, IOException {
		int lines = Integer.parseInt(in.readLine().trim());
		log(lines + " lines of animals");
		
		ArrayList<Animal> list = new ArrayList<Animal>();
		for (int i = 0; i < lines; i++) {
			line = in.readLine().trim();
			chunks = line.split(" ");
			Animal a = new Animal();
			a.name = chunks[0];
			int feats = Integer.parseInt(chunks[1]);
			a.feats = new HashSet<String>();
			for (int j = 0; j < feats; j++) {
				a.feats.add(chunks[2 + j]);
			}
			list.add(a);
		}
		for (Animal animal : list) {
			log2("Animal " + animal.name + ":");
			for (String f : animal.feats) {
				log2(" " + f);
			}
			log("");
		}
		
		return list;
	}

	private static Tree parseTree() throws Exception {
		int lines = Integer.parseInt(in.readLine().trim());
		log("tree is " + lines + " lines");
		text = new StringBuilder();
		for (int i = 0; i < lines; i++) {
			text.append(in.readLine());
		}
		Tree t = tree();
		return t;
	}

	private static Tree tree() throws Exception {
		Tree t = new Tree();
		getWhite();
		if (getch() != '(') {
			throw new Exception("parse error");
		}
		getWhite();
		t.val = getReal();
		getWhite();
		if (peekch() == ')') { // leaf
			getch();
		} else {
			t.feat = getWord();
			t.left = tree();
			t.right = tree();
			getWhite();
			if (getch() != ')') {
				throw new Exception("parse error");
			}
		}
		return t;
	}

	private static void getWhite() {
		while (text.charAt(0) == ' ' || text.charAt(0) == '\n') {
			text.deleteCharAt(0);
		}
	}
	
	private static String getWord() {
		StringBuilder w = new StringBuilder();
		while ((int)(text.charAt(0)) >= 'a' && (int)(text.charAt(0)) <= 'z') {
			w.append(text.charAt(0));
			text.deleteCharAt(0);
		}
		log("got word " + w);
		return w.toString();
	}

	private static char getch() {
		char c = text.charAt(0);
		text.deleteCharAt(0);
		return c;
	}

	private static char peekch() {
		char c = text.charAt(0);
		return c;
	}

	private static double getReal() {
		StringBuilder w = new StringBuilder();
		while (((int)(text.charAt(0)) >= '0' && (int)(text.charAt(0)) <= '9') || text.charAt(0) == '.') {
			w.append(text.charAt(0));
			text.deleteCharAt(0);
		}
		log("got real " + w);
		return Double.parseDouble(w.toString());
	}

	private static void out(String string) throws IOException {
		out2(string + "\n");
	}

	private static void out2(String string) throws IOException {
		System.out.print(string);
		out.write(string);
	}

	private static void log(String string) {
		log2(string + "\n");
	}

	private static void log2(String string) {
//		System.out.print(string);
	}
}
