package qual;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;

public class TicTacToe {
  final BufferedReader reader;
  final BufferedWriter writer;

  public static void main(String[] args) {
    new TicTacToe().run();
  }

  TicTacToe() {
    URL inputUrl = getClass().getResource("A-large.in");
    String outUrl = inputUrl.getPath().replace(".in", ".out");
    try {
      reader = new BufferedReader(new InputStreamReader(inputUrl.openStream()));
      writer = new BufferedWriter(new FileWriter(outUrl));
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
  }
  
  void run() {
    int nprobs = readInt();
    for (int i = 1; i <= nprobs; i++) {
      char[][] board = new char[4][];
      for (int j = 0; j < 4; j++) {
        board[j] = readLine().toUpperCase().toCharArray();
      }
      readLine();
      write("Case #%d: %s", i, solve(board));
    }

    try {
      reader.close();
      writer.close();
    } catch (IOException e) {
      throw new RuntimeException();
    }
  }

  String solve(char[][] board) {
    char win;
    int[][] dirs = {
        {0, 0, 0, 1},
        {1, 0, 0, 1},
        {2, 0, 0, 1},
        {3, 0, 0, 1},
        {0, 0, 1, 0},
        {0, 1, 1, 0},
        {0, 2, 1, 0},
        {0, 3, 1, 0},
        {0, 0, 1, 1},
        {0, 3, 1, -1},
    };

    for (int i = 0; i < dirs.length; i++) {
      win = fourInARow(board,
          dirs[i][0], dirs[i][1], dirs[i][2], dirs[i][3]);
      if (win != '.') {
        return win + " won";
      }
    }

    // neither won
    for (int i = 0; i < 4; i++) {
      for (int j = 0; j < 4; j++) {
        if (board[i][j] == '.') {
          return "Game has not completed";
        }
      }
    }
    return "Draw";
  }

  char fourInARow(char[][] board, int x, int y, int dx, int dy) {
    char win = 'T';
    for (int i = 0; i < 4; i++) {
      char piece = board[x + i * dx][y + i * dy];
      if (win == 'T') {
        win = piece;
      } else if (piece != 'T' && piece != win) {
        return '.';
      }
    }
    return win;
  }

  void check(boolean expr) {
    if (!expr) {
      throw new RuntimeException("not cool");
    }
  }

  void write(String msg, Object... args) {
    System.out.println(String.format(msg, args));
    try {
      writer.write(String.format(msg, args) + "\n");
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  String readLine() {
    try {
      return reader.readLine();
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  int readInt() {
    return Integer.parseInt(readLine());
  }
}
