package qual;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.math.BigInteger;
import java.net.URL;

public class FairSquare {
  final BufferedReader reader;
  final BufferedWriter writer;

  public static void main(String[] args) {
    new FairSquare().run();
  }

  FairSquare() {
    URL inputUrl = getClass().getResource("C-large-2.in");
    String outUrl = inputUrl.getPath().replace("/bin/", "/src/").replace(".in", ".out");
    try {
      reader = new BufferedReader(new InputStreamReader(inputUrl.openStream()));
      writer = new BufferedWriter(new FileWriter(outUrl));
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
  }
  
  void run() {
    int nprobs = readInt();
    for (int i = 1; i <= nprobs; i++) {
      String[] parts = readLine().split(" ");
      BigInteger a = new BigInteger(parts[0]);
      BigInteger b = new BigInteger(parts[1]);
      write("Case #%d: %s", i, solve(a, b));
    }

    try {
      reader.close();
      writer.close();
    } catch (IOException e) {
      throw new RuntimeException();
    }
  }

  String solve(BigInteger a, BigInteger b) {
    int count = 0;
    digits = new int[100];
    digits[0] = 1;
    count += numPalinRec(a, b, 1);
    digits = new int[100];
    digits[0] = 2;
    count += numPalinRec(a, b, 1);
    digits = new int[100];
    digits[0] = 3;
    count += numPalinRec(a, b, 1);

    // long min = a.longValue();
    // long max = b.longValue();
    // for (long h = 1; h < 10000000; h++) {
    // if (!isPalindrome(h) || !isPalindrome(h * h)) {
    // continue;
    // }
    // System.out.println("Found " + h + " -> " + (h * h));
    // if ((h * h >= min) && (h * h <= max)) {
    // count++;
    // }
    // }
    return "" + count;
  }

  int maxDig = 50;
  int[] digits = new int[100];
  int numPalinRec(BigInteger min, BigInteger max, int ndig) {
    // palindrome minus one (eg 12 -> 121)
    /*
     * int nhalfdig = ndig / 2;
     * for (int i = 0; i < ndig; i++) {
     * int sum = 0;
     * for (int j = 0; j <= i; j++) {
     * sum += digits[j] * digits[i];
     * if (sum > 10) {
     * return 0; // overflow
     * }
     * }
     * }
     */
    int sum = 0;
    for (int i = 0; i < ndig; i++) {
      int ix;
      if (i < ndig / 2) {
        ix = i;
      } else {
        ix = ndig - 1 - i;
      }
      sum += digits[ix] * digits[ix];
    }
    if (sum > 10) {
      return 0; // overflow;
    }

    // found a palindrome that squares to another palindrome!
    char[] palind = new char[ndig];
    for (int i = 0; i < ndig; i++) {
      if (i < ndig / 2) {
        palind[i] = (char) ('0' + digits[i]);
      } else {
        palind[i] = (char) ('0' + digits[ndig - 1 - i]);
      }
    }

    // is it enough?
    BigInteger smallPalin = new BigInteger(new String(palind));
    BigInteger bigPalin = smallPalin.multiply(smallPalin);
    int ntot;
    if (bigPalin.compareTo(min) < 0) {
      ntot = 0;
    } else if (bigPalin.compareTo(max) > 0) {
      return 0;
    } else {
      ntot = 1;
    }

    // recurse
    if (ndig % 2 == 1) {
      ntot += numPalinRec(min, max, ndig + 1);
    } else if (ndig <= maxDig) {
      for (int i = 0; i < 3; i++) {
        digits[ndig / 2] = i;
        ntot += numPalinRec(min, max, ndig + 1);
      }
    }
    return ntot;
  }

  boolean isPalindrome(long l) {
    int i = 0;
    while (l > 0) {
      digits[i++] = (int) (l % 10);
      l /= 10;
    }
    for (int j = 0; j < i / 2; j++) {
      if (digits[j] != digits[i - j - 1]) {
        return false;
      }
    }
    return true;
  }

  void check(boolean expr) {
    if (!expr) {
      throw new RuntimeException("not cool");
    }
  }

  void write(String msg, Object... args) {
    System.out.println(String.format(msg, args));
    try {
      writer.write(String.format(msg, args) + "\n");
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  String readLine() {
    try {
      return reader.readLine();
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  int readInt() {
    return Integer.parseInt(readLine());
  }

  int[] readInts() {
    String[] parts = readLine().trim().split(" ");
    int[] arr = new int[parts.length];
    for (int i = 0; i < arr.length; i++) {
      arr[i] = Integer.parseInt(parts[i]);
    }
    return arr;
  }
}
