package qual;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;

public class Lawnmower {
  final BufferedReader reader;
  final BufferedWriter writer;

  public static void main(String[] args) {
    new Lawnmower().run();
  }

  Lawnmower() {
    URL inputUrl = getClass().getResource("B-large.in");
    String outUrl = inputUrl.getPath().replace("/bin/", "/src/").replace(".in", ".out");
    try {
      reader = new BufferedReader(new InputStreamReader(inputUrl.openStream()));
      writer = new BufferedWriter(new FileWriter(outUrl));
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
  }
  
  void run() {
    int nprobs = readInt();
    for (int i = 1; i <= nprobs; i++) {
      int[] dims = readInts();
      int h = dims[0], w = dims[1];
      int[][] lawn = new int[h][];
      for (int j = 0; j < h; j++) {
        lawn[j] = readInts();
        check(lawn[j].length == w);
      }
      write("Case #%d: %s", i, solve(lawn));
    }

    try {
      reader.close();
      writer.close();
    } catch (IOException e) {
      throw new RuntimeException();
    }
  }

  String solve(int[][] lawn) {
    int h = lawn.length, w = lawn[0].length;
    int[] px = new int[w], py = new int[h];
    for (int i = 0; i < w; i++) {
      for (int j = 0; j < h; j++) {
        px[i] = Math.max(px[i], lawn[j][i]);
        py[j] = Math.max(py[j], lawn[j][i]);
      }
    }
    for (int i = 0; i < w; i++) {
      for (int j = 0; j < h; j++) {
        if (lawn[j][i] < Math.min(px[i], py[j])) {
          return "NO";
        }
      }
    }
    return "YES";
  }

  char fourInARow(char[][] board, int x, int y, int dx, int dy) {
    char win = 'T';
    for (int i = 0; i < 4; i++) {
      char piece = board[x + i * dx][y + i * dy];
      if (win == 'T') {
        win = piece;
      } else if (piece != 'T' && piece != win) {
        return '.';
      }
    }
    return win;
  }

  void check(boolean expr) {
    if (!expr) {
      throw new RuntimeException("not cool");
    }
  }

  void write(String msg, Object... args) {
    System.out.println(String.format(msg, args));
    try {
      writer.write(String.format(msg, args) + "\n");
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  String readLine() {
    try {
      return reader.readLine();
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  int readInt() {
    return Integer.parseInt(readLine());
  }

  int[] readInts() {
    String[] parts = readLine().trim().split(" ");
    int[] arr = new int[parts.length];
    for (int i = 0; i < arr.length; i++) {
      arr[i] = Integer.parseInt(parts[i]);
    }
    return arr;
  }
}
