package qual;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

public class Treasure {
  final BufferedReader reader;
  final BufferedWriter writer;

  public static void main(String[] args) {
    new Treasure().run();
  }

  Treasure() {
    URL inputUrl = getClass().getResource("D-small-attempt1.in");
    String outUrl = inputUrl.getPath().replace("/bin/", "/src/").replace(".in", ".out");
    try {
      reader = new BufferedReader(new InputStreamReader(inputUrl.openStream()));
      writer = new BufferedWriter(new FileWriter(outUrl));
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
  }
  
  void run() {
    int nprobs = readInt();
    for (int i = 1; i <= nprobs; i++) {
      int[] dims = readInts();
      int k = dims[0], n = dims[1];
      int[] keys = readInts();
      check(keys.length == k);
      int[] chestTypes = new int[n];
      int[][] chestKeys = new int[n][];
      for (int j = 0; j < n; j++) {
        int[] temp = readInts();
        chestTypes[j] = temp[0];
        check(temp.length == temp[1] + 2);
        chestKeys[j] = Arrays.copyOfRange(temp, 2, temp.length);
      }
      write("Case #%d: %s", i, solve(keys, chestTypes, chestKeys));
    }

    try {
      reader.close();
      writer.close();
    } catch (IOException e) {
      throw new RuntimeException();
    }
  }

  String solve(int[] keys, int[] chestTypes, int[][] chestKeys) {
    keyCounts = new int[1000];
    for (int i = 0; i < keys.length; i++) {
      keyCounts[keys[i]]++;
    }
    order = new int[chestTypes.length];
    chestT = chestTypes;
    chestK = chestKeys;
    chestsOpened = new boolean[chestTypes.length];
    failBoxes = new HashSet<Integer>();
    if (recSolve(0)) {
      String msg = "";
      for (int i = 0; i < order.length; i++) {
        msg += (i > 0 ? " " : "") + (order[i] + 1);
      }
      return msg;
    } else {
      return "IMPOSSIBLE";
    }
  }

  boolean[] chestsOpened;
  int maxKeyType;
  int[] keyCounts;
  int[] order;
  int[] chestT;
  int[][] chestK;
  Set<Integer> failBoxes;
  boolean recSolve(int ix) {
    if (ix == order.length) {
      return true; // done
    }
    // have we already tries this set of boxes
    int boxes = 0;
    for (int i = 0; i < ix; i++) {
      boxes |= order[i];
    }
    if (failBoxes.contains(boxes)) {
      return false;
    }

    for (int chestIx = 0; chestIx < chestT.length; chestIx++) {
      if (keyCounts[chestT[chestIx]] == 0) {
        continue; // can't open
      }
      if (chestsOpened[chestIx]) {
        continue; // already opened
      }

      // recurse
      keyCounts[chestT[chestIx]]--;
      order[ix] = chestIx;
      int[] chestIxKs = chestK[chestIx];
      for (int j = 0; j < chestIxKs.length; j++) {
        keyCounts[chestIxKs[j]]++;
      }
      chestsOpened[chestIx] = true;
      // (track optimization stuff)
      if (recSolve(ix + 1)) {
        return true;
      }
      // oops, didn't work, put everything back
      chestsOpened[chestIx] = false;
      for (int j = 0; j < chestIxKs.length; j++) {
        keyCounts[chestIxKs[j]]--;
      }
      keyCounts[chestT[chestIx]]++;
    }

    // this set of boxes is wrong
    failBoxes.add(boxes);
    return false;
  }

  void check(boolean expr) {
    if (!expr) {
      throw new RuntimeException("not cool");
    }
  }

  void write(String msg, Object... args) {
    System.out.println(String.format(msg, args));
    try {
      writer.write(String.format(msg, args) + "\n");
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  String readLine() {
    try {
      return reader.readLine();
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  int readInt() {
    return Integer.parseInt(readLine());
  }

  int[] readInts() {
    String[] parts = readLine().trim().split(" ");
    int[] arr = new int[parts.length];
    for (int i = 0; i < arr.length; i++) {
      arr[i] = Integer.parseInt(parts[i]);
    }
    return arr;
  }
}
