import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.math.BigInteger;
import java.util.HashSet;

/**
 * Google Code Jam - 2009/1B/A
 */
public class DecisionTree {

	public static class Tree {
		private double probability;
		
		private String feature;
		
		private Tree yesTree;
		
		private Tree noTree;
		
		public Tree(String treeAsText) {
			this(addSpacesToParentheses(treeAsText).split("\\s+"));
		}
		
		private static String addSpacesToParentheses(String treeAsText) {
			StringBuffer buf = new StringBuffer();
			for (int i=0; i < treeAsText.length(); i++) {
				char c = treeAsText.charAt(i);
				if (c == '(' || c == ')') {
					buf.append(' ').append(c).append(' ');
				} else {
					buf.append(c);
				}
			}
			return buf.toString();
		}

		public Tree(String[] tokens) {
			this(tokens, 0, tokens.length);
		}

		public Tree(String[] tokens, int beginIndex, int endIndex) {
			if ("".equals(tokens[beginIndex])) {
				beginIndex++;
			}
			this.probability = Double.parseDouble(tokens[beginIndex + 1]);
			if (!")".equals(tokens[beginIndex + 2])) {
				this.feature = tokens[beginIndex + 2];
				int closingIndex = afterClosingParenthesis(tokens, beginIndex + 3);
				yesTree = new Tree(tokens, beginIndex + 3, closingIndex);
				noTree = new Tree(tokens, closingIndex, endIndex);
			}
		}

		private static int afterClosingParenthesis(String[] tokens, int beginIndex) {
			int index = beginIndex;
			int count = 0;
			do {
				if ("(".equals(tokens[index])) {
					count++;
				} else if (")".equals(tokens[index])) {
					count--;
				}
				index++;
			} while (count != 0);
			return index;
		}

		public double computeProbability(HashSet<String> features) {
			double p = 1;
			p *= this.probability;
			if (this.feature == null) {
				return p;
			}
			if (features.contains(this.feature)) {
				p *= yesTree.computeProbability(features);
			} else {
				p *= noTree.computeProbability(features);
			}
			return p;
		}
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		BufferedReader in = new BufferedReader(new InputStreamReader(System.in));

		try {
			int numCases = Integer.parseInt(in.readLine());
			for (int i=1; i <= numCases; i++) {
				int numLines = Integer.parseInt(in.readLine());
				StringBuffer treeAsText = new StringBuffer();
				for (int l=0; l < numLines; l++) {
					treeAsText.append(in.readLine());
				}
				Tree tree = new Tree(treeAsText.toString());
				int numAnimals = Integer.parseInt(in.readLine());
				System.out.println("Case #" + i + ":");
				for (int a=0; a < numAnimals; a++) {
					HashSet<String> features = getFeatures(in.readLine());
					System.out.println(tree.computeProbability(features));
				}
			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	private static HashSet<String> getFeatures(String line) {
		String[] tokens = line.split("\\s+");
		HashSet<String> features = new HashSet<String>();
		for (String token : tokens) {
			features.add(token);
		}
		return features;
	}

}
