import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.HashMap;


/**
 * Google Code Jam Qualification Round 2009
 * B. Watersheds
 */
public class Watersheds {

	private enum Direction {
		NOWHERE, NORTH, WEST, EAST, SOUTH
	}

	int[][] map;
	
	char[][] basins;

	public Watersheds(int[][] map) {
		this.map = map;
	}

	public char[][] getBasins() {
		if (basins == null) {
			findBasins();
		}
		
		return basins;
	}

	private void findBasins() {
		basins = new char[map.length][map[0].length];
		findSinks();
		fillBasins();
		fixOrder();
	}

	private void findSinks() {
		// Mark sinks
		char current = 'a';
		for (int i=0; i < map.length; i++) {
			for (int j=0; j < map[0].length; j++) {
				if (flowsTo(i, j) == Direction.NOWHERE) {
					basins[i][j] = current++;
				}
			}
		}
	}

	private int getNorth(int i, int j) {
		return i > 0 ? map[i-1][j] : Integer.MAX_VALUE;
	}
	
	private int getWest(int i, int j) {
		return j > 0 ? map[i][j-1] : Integer.MAX_VALUE;
	}

	private int getEast(int i, int j) {
		return j < map[0].length - 1 ? map[i][j+1] : Integer.MAX_VALUE;
	}
	
	private int getSouth(int i, int j) {
		return i < map.length - 1 ? map[i+1][j] : Integer.MAX_VALUE;
	}
	
	private int min(int a, int b, int c, int d) {
		return min(min(a, b), min(c, d));
	}

	private int min(int a, int b) {
		return a < b ? a : b;
	}

	private Direction flowsTo(int i, int j) {
		int north = getNorth(i, j);
		int west = getWest(i, j);
		int east = getEast(i, j);
		int south = getSouth(i, j);
		int minimum = min(north, west, east, south);

		Direction direction = Direction.NOWHERE;
		if (map[i][j] <= minimum) {
			direction = Direction.NOWHERE;
		} else if (minimum == north) {
			direction = Direction.NORTH;
		} else if (minimum == west) {
			direction = Direction.WEST;
		} else if (minimum == east) {
			direction = Direction.EAST;
		} else if (minimum == south) {
			direction = Direction.SOUTH;
		}

		return direction;
	}

	private void fillBasins() {
		
		boolean hasChanged;
		do {
			hasChanged = false;
			for (int i=0; i < map.length; i++) {
				for (int j=0; j < map[0].length; j++) {
					if (basins[i][j] == 0) {
						Direction direction = flowsTo(i, j);
						if (direction == Direction.NORTH) {
							basins[i][j] = basins[i-1][j];
						} else if (direction == Direction.WEST) {
							basins[i][j] = basins[i][j-1];
						} else if (direction == Direction.EAST) {
							basins[i][j] = basins[i][j+1];
						} else if (direction == Direction.SOUTH) {
							basins[i][j] = basins[i+1][j];
						}
						hasChanged |= basins[i][j] != 0;
					}
				}
			}
		} while (hasChanged);

	}

	private void fixOrder() {
		// Map letters according to lexicographical order
		char current = 'a';
		HashMap<Character, Character> mapping = new HashMap<Character, Character>();
		for (int i=0; i < map.length; i++) {
			for (int j=0; j < map[0].length; j++) {
				if (mapping.get(basins[i][j]) == null) {
					mapping.put(basins[i][j], current++);
				}
			}
		}
		
		// Replace letters by the correct ones
		for (int i=0; i < map.length; i++) {
			for (int j=0; j < map[0].length; j++) {
				basins[i][j] = mapping.get(basins[i][j]);
			}
		}
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		BufferedReader in = new BufferedReader(new InputStreamReader(System.in));

		try {
			int t = Integer.parseInt(in.readLine());
			for (int i=1; i <= t; i++) {
				String line = in.readLine();
				String[] tokens = line.split("\\s+");
				int h = Integer.parseInt(tokens[0]);
				int w = Integer.parseInt(tokens[1]);
				int[][] map = readMap(in, h, w);
				Watersheds waterSheds = new Watersheds(map);
				char[][] basins = waterSheds.getBasins();
				printBasins(i, basins);
			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	private static int[][] readMap(BufferedReader in, int h, int w) throws IOException {
		int[][] map = new int[h][w];
		for (int i=0; i < h; i++) {
			String line = in.readLine();
			String[] tokens = line.split("\\s+");
			for (int j=0; j < w; j++) {
				map[i][j] = Integer.parseInt(tokens[j]);
			}
		}
		return map;
	}

	private static void printBasins(int caseNum, char[][] basins) {
		System.out.println("Case #" + caseNum + ":");
		
		for (char[] row : basins) {
			for (char basin : row) {
				System.out.print(basin + " ");
			}
			System.out.println();
		}
	}

}
