import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.math.BigDecimal;
import java.math.MathContext;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

public class C {

	private static CodeJamIO io = new CodeJamIO();

	/**
	 * @param args
	 */
	public static void main(String[] args) {

		try {
			init();

			int numCases = Integer.parseInt(io.readNextLine()[0]);
			for (int i=1; i <= numCases; i++) {
				io.debug("Solving Case #" + i + "...");
				solveCase(i);
				io.debug("Case #" + i + " solved!");
			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	/**
	 * Performs initial computations
	 */
	private static void init() {
		
	}

	/**
	 * Solves a Test Case
	 * 
	 * @param caseNum
	 * @throws IOException
	 */
	private static void solveCase(int caseNum) throws IOException {
		// Read input
		String[] tokens = io.readNextLine();
		BigDecimal a = sqrt(new BigDecimal(tokens[0]), 100, RoundingMode.HALF_UP).setScale(0, RoundingMode.CEILING);
		io.debug("sqrt(a) = " + a.toPlainString());
		BigDecimal b = sqrt(new BigDecimal(tokens[1]), 100, RoundingMode.HALF_UP).setScale(0, RoundingMode.FLOOR);
		io.debug("sqrt(b) = " + b.toPlainString());
		
		// Do the work
		int count = 0;
		if (new BigDecimal(1).compareTo(a) >= 0 && new BigDecimal(1).compareTo(b) <= 0 ) {
			count++;
		}
		if (new BigDecimal(2).compareTo(a) >= 0 && new BigDecimal(2).compareTo(b) <= 0 ) {
			count++;
		}
		if (new BigDecimal(3).compareTo(a) >= 0 && new BigDecimal(3).compareTo(b) <= 0 ) {
			count++;
		}
		if (a.compareTo(new BigDecimal(10)) < 0) {
			a = new BigDecimal(10);
		}
		
		String astr = a.toPlainString();
		BigDecimal half = new BigDecimal(astr.substring(0, (astr.length() + 1) / 2));
		BigDecimal next;
		do {
			next = next(half);
			half = half.add(new BigDecimal(1));
		} while (next.compareTo(a) < 0);
		
		while (next.compareTo(b) <= 0) {
			count++;
			next = next(half);
			half = half.add(new BigDecimal(1));
		}
		
		// Print results
		io.printCase(caseNum).println(count);

	}

	private static BigDecimal sqrt(BigDecimal in, int scale, RoundingMode mode){
	    BigDecimal sqrt = new BigDecimal(1);
	    sqrt.setScale(scale + 3, mode);
	    BigDecimal store = new BigDecimal(in.toString());
	    boolean first = true;
	    do{
	        if (!first){
	            store = new BigDecimal(sqrt.toString());
	        }
	        else first = false;
	        store.setScale(scale + 3, mode);
	        sqrt = in.divide(store, scale + 3, mode).add(store).divide(
	                BigDecimal.valueOf(2), scale + 3, mode);
	    }while (!store.equals(sqrt));
	    return sqrt.setScale(scale, mode);
	}
	
	private static BigDecimal next(BigDecimal half) {
		BigDecimal next;
		do {
			next = reflect(half);
			half = half.add(new BigDecimal(1));
		} while (!isPalindrome(next.multiply(next)));
		io.debug("Next acceptable palindrome of " + half.toPlainString() + " is " + next.toPlainString());
		return next;
	}

	private static boolean isPalindrome(BigDecimal big) {
		boolean isPalindrome = true;
		String bigstr = big.toPlainString();
		for (int i=0; i <= bigstr.length() / 2; i++) {
			if (bigstr.charAt(i) != bigstr.charAt(bigstr.length()-1-i)) {
				isPalindrome = true;
				break;
			}
		}
		io.debug(bigstr + " is a palindrome: " + isPalindrome);
		return isPalindrome;
	}

	private static BigDecimal reflect(BigDecimal half) {
		String halfstr = half.toPlainString();
		StringBuffer reflectstr = new StringBuffer(halfstr);
		for (int i=halfstr.length() / 2; i>=0; i--) {
			reflectstr.append(halfstr.charAt(i));
		}
		io.debug("reflect of " + halfstr + " is " + reflectstr.toString());
		return new BigDecimal(reflectstr.toString());
	}

	/**
	 * Input and Output CodeJam style
	 *
	 */
	private static class CodeJamIO {
		private static BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
		private static PrintWriter out = new PrintWriter(System.out, true);
		private static PrintWriter err = new PrintWriter(System.err, true);

		public String[] readNextLine() throws IOException {
			String line = in.readLine();
			String[] tokens = line.split("\\s+");
			return tokens;
		}

		public CodeJamIO printCase(int caseNum) { return print("Case #" + caseNum + ": " ); }
		
		public CodeJamIO print(Object o) { out.print(o); return this; }

		public CodeJamIO print(Object o[]) { return print(concat(o)); }

		public CodeJamIO print(Object o[][]) { return print(concat(o)); }

		public CodeJamIO println() { out.println(); return this; }

		public CodeJamIO printlnCase(int caseNum) { return printCase(caseNum).println(); }
		
		public CodeJamIO println(Object o) { return print(o).println(); }

		public CodeJamIO println(Object o[]) { return print(o).println(); }

		public CodeJamIO println(Object o[][]) { return print(concat(o)).println(); }

		public CodeJamIO println(List<Integer[]> l) { return print(concat(l)).println(); }

		
		private String concat(Object[] o) {
			StringBuffer buf = new StringBuffer(10*o.length);
			
			String delim = "";
			for (int i=0; i < o.length; i++) {
				buf.append(delim).append(o[i]);
				delim = " ";
			}
			return buf.toString();
		}
		
		private String concat(Object[][] o) {
			StringBuffer buf = new StringBuffer(100*o.length);
			for (int i=0; i < o.length; i++) {
				buf.append(concat(o[i])).append("\n");
			}
			return buf.toString();
		}

		private String concat(List<Integer[]> list) {
			StringBuffer buf = new StringBuffer();
			String delim = "";
			for (Object[] elm : list) {
				buf.append(delim).append(concat(elm)).append("\n");
			}
			return buf.toString();
		}

		public void debug(String message) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
		}

		public void debug(String message, Object[] o) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			err.println("\t" + concat(o));
		}

		public void debug(String message, Object[][] o) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			String values = concat(o);
			err.println("\t" + values.replaceAll("\n", "\n\t"));
		}

		public void debug(String message, List<Integer[]> list) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			String values = concat(list);
			err.println("\t" + values.replaceAll("\n", "\n\t"));
		}

	}

}
