import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.*;

public class A {

	private static CodeJamIO io = new CodeJamIO();

	/**
	 * @param args
	 */
	public static void main(String[] args) {

		try {
			init();

			int numCases = Integer.parseInt(io.readNextLine()[0]);
			for (int i=1; i <= numCases; i++) {
				io.debug("Solving Case #" + i + "...");
				solveCase(i);
				io.debug("Case #" + i + " solved!");
			}

		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	/**
	 * Performs initial computations
	 */
	private static void init() {

	}

	/**
	 * Solves a Test Case
	 *
	 * @param caseNum
	 * @throws java.io.IOException
	 */
	private static void solveCase(int caseNum) throws IOException {
		// Read input
		int n = Integer.parseInt(io.readNextLine()[0]);
        String[] input = new String[n];
        for (int i=0; i<n; i++) {
            input[i] = io.readNextLine()[0];
        }
		
		// Do the work
        Set<String> reduced = new HashSet<String>();
        for (int i=0; i<n; i++) {
            reduced.add(reduce(input[i]));
        }
        io.debug("Number of reduced strings: " + reduced.size());

		String result = "Fegla Won";
        if (reduced.size() == 1) {
            String reducedInput = null;
            for (String s : reduced) {
                reducedInput = s;
                break;
            }
            io.debug("Reduced string: " + reducedInput);

            int[][] repeats = calcRepeats(input, n, reducedInput.length());
            io.debug("Repeat matrix: ", repeats);

            long moves = 0;
            for (int j=0; j<reducedInput.length(); j++) {
                double avg = calcAvg(repeats, n, j);
                io.debug("Average: " + avg);
                int closest = findClosest(repeats, n, j, avg);
                io.debug("Closest: " + closest);
                moves += calcMoves(repeats, n, j, closest);
                io.debug("Moves: " + moves);
            }
            result = String.valueOf(moves);
        }

		// Print results
		io.printCase(caseNum).println(result);

	}

    private static long calcMoves(int[][] repeats, int n, int j, int closest) {
        long moves = 0;
        for (int i=0; i<n; i++) {
            moves += Math.abs(repeats[i][j] - closest);
        }
        return moves;
    }

    private static int findClosest(int[][] repeats, int n, int j, double avg) {
        double distance = Double.MAX_VALUE;
        int closest = -1;
        for (int i=0; i<n; i++) {
            if (Math.abs(repeats[i][j] - avg) < distance) {
                closest = repeats[i][j];
                distance = Math.abs(repeats[i][j] - avg);
            }
        }
        return closest;
    }

    private static double calcAvg(int[][] repeats, int n, int j) {
        double avg = 0;
        for (int i=0; i<n; i++) {
            avg += repeats[i][j];
        }
        return avg / n;
    }

    private static int[][] calcRepeats(String[] input, int n, int size) {
        int[][] repeats = new int[n][size];
        for (int i=0; i<n; i++) {
            int k=-1;
            char current = '_';
            for (int j=0; j<input[i].length(); j++) {
                if (input[i].charAt(j) != current) {
                    k++;
                    current = input[i].charAt(j);
                    repeats[i][k] = 1;
                } else {
                    repeats[i][k]++;
                }
            }
        }
        return repeats;
    }

    private static String reduce(String s) {
        StringBuffer reduced = new StringBuffer(s.length());
        for (int i=0; i<s.length(); i++) {
            if (reduced.length() == 0 || reduced.charAt(reduced.length()-1) != s.charAt(i)) {
                reduced.append(s.charAt(i));
            }
        }
        return reduced.toString();
    }

    /**
	 * Input and Output CodeJam style
	 *
	 */
	private static class CodeJamIO {
		private static BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
		private static PrintWriter out = new PrintWriter(System.out, true);
		private static PrintWriter err = new PrintWriter(System.err, true);

		public String[] readNextLine() throws IOException {
			String line = in.readLine();
			String[] tokens = line.split("\\s+");
			return tokens;
		}

		public CodeJamIO printCase(int caseNum) { return print("Case #" + caseNum + ": " ); }
		
		public CodeJamIO print(Object o) { out.print(o); return this; }

		public CodeJamIO print(Object o[]) { return print(concat(o)); }

		public CodeJamIO print(Object o[][]) { return print(concat(o)); }

		public CodeJamIO println() { out.println(); return this; }

		public CodeJamIO printlnCase(int caseNum) { return printCase(caseNum).println(); }
		
		public CodeJamIO println(Object o) { return print(o).println(); }

		public CodeJamIO println(Object o[]) { return print(o).println(); }

		public CodeJamIO println(Object o[][]) { return print(concat(o)).println(); }

		public CodeJamIO println(List<Integer[]> l) { return print(concat(l)).println(); }

		
		private String concat(Object[] o) {
			StringBuffer buf = new StringBuffer(10*o.length);
			
			String delim = "";
			for (int i=0; i < o.length; i++) {
				buf.append(delim).append(o[i]);
				delim = " ";
			}
			return buf.toString();
		}
		
		private String concat(Object[][] o) {
			StringBuffer buf = new StringBuffer(100*o.length);
			for (int i=0; i < o.length; i++) {
				buf.append(concat(o[i])).append("\n");
			}
			return buf.toString();
		}

		private String concat(List<Integer[]> list) {
			StringBuffer buf = new StringBuffer();
			String delim = "";
			for (Object[] elm : list) {
				buf.append(delim).append(concat(elm)).append("\n");
			}
			return buf.toString();
		}

		public void debug(String message) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
		}

		public void debug(String message, Object[] o) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			err.println("\t" + concat(o));
		}

		public void debug(String message, Object[][] o) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			String values = concat(o);
			err.println("\t" + values.replaceAll("\n", "\n\t"));
		}

		public void debug(String message, List<Integer[]> list) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			String values = concat(list);
			err.println("\t" + values.replaceAll("\n", "\n\t"));
		}

	}

}
