import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.Calendar;
import java.util.ArrayList;
import java.util.List;

public class A {

	private static CodeJamIO io = new CodeJamIO();

	/**
	 * @param args
	 */
	public static void main(String[] args) {

		try {
			init();

			int numCases = Integer.parseInt(io.readNextLine()[0]);
			for (int i=1; i <= numCases; i++) {
				io.debug("Solving Case #" + i + "...");
				solveCase(i);
				io.debug("Case #" + i + " solved!");
			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	/**
	 * Performs initial computations
	 */
	private static void init() {
		
	}

	/**
	 * Solves a Test Case
	 * 
	 * @param caseNum
	 * @throws IOException
	 */
	private static void solveCase(int caseNum) throws IOException {
		// Read input
		String[] tokens = io.readNextLine();
		int N = Integer.parseInt(tokens[0]);
		List<Integer[]> orange = new ArrayList<Integer[]>(N);
		List<Integer[]> blue = new ArrayList<Integer[]>(N);
		for (int n=0; n < N; n++) {
			char color = tokens[2*n+1].charAt(0);
			Integer[] pair = new Integer[2];
			pair[0] = n+1;
			pair[1] = Integer.parseInt(tokens[2*n+2]);
			if (color == 'O') {
				orange.add(pair);
			} else {
				blue.add(pair);
			}
		}
		
		// Normalize input
		normalize(orange, "orange");
		normalize(blue, "blue");
		
		// Do the work
		long totalTime = 0;
		int currentButton = 1;
		while (!orange.isEmpty() && !blue.isEmpty()) {
			Integer[] orangePair = orange.get(0);
			Integer[] bluePair = blue.get(0);
			if (orangePair[0] == currentButton && orangePair[1] == 0) {
				// click
				orange.remove(0);
				totalTime++;
				if (bluePair[1] > 0) {
					// move other
					bluePair[1]--;
				}
				currentButton++;
			} else if (bluePair[0] == currentButton && bluePair[1] == 0){
				// click
				blue.remove(0);
				totalTime++;
				if (orangePair[1] > 0) {
					// move other
					orangePair[1]--;
				}
				currentButton++;
			} else if (orangePair[1] == 0) {
				// move and click other
				totalTime += bluePair[1] + 1;
				blue.remove(0);
				currentButton++;
			} else if (bluePair[1] == 0) {
				// move and click other
				totalTime += orangePair[1] + 1;
				orange.remove(0);
				currentButton++;
			} else {
				// move both
				int advanceBy = orangePair[1] < bluePair[1] ? orangePair[1] : bluePair[1];
				totalTime += advanceBy;
				orangePair[1] -= advanceBy;
				bluePair[1] -= advanceBy;
			}
		}
		// Will not execute if orange.isEmpty
		for (Integer[] pair : orange) {
			totalTime += pair[1] + 1;
		}
		// Will not execute if blue.isEmpty
		for (Integer[] pair : blue) {
			totalTime += pair[1] + 1;
		}
		io.debug("Computed totalTime: " + totalTime);
		
		// Print results
		io.printCase(caseNum).println(totalTime);

	}

	private static void normalize(List<Integer[]> robot, String color) {
		int lastButton = 1;
		for (Integer[] pair : robot) {
			int newTime = Math.abs(pair[1] - lastButton);
			lastButton = pair[1];
			pair[1] = newTime;
		}
		io.debug("Normalized " + color + " robot", robot);
	}

	/**
	 * Input and Output CodeJam style
	 *
	 */
	private static class CodeJamIO {
		private static BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
		private static PrintWriter out = new PrintWriter(System.out, true);
		private static PrintWriter err = new PrintWriter(System.err, true);

		public String[] readNextLine() throws IOException {
			String line = in.readLine();
			String[] tokens = line.split("\\s+");
			return tokens;
		}

		public CodeJamIO printCase(int caseNum) { return print("Case #" + caseNum + ": " ); }
		
		public CodeJamIO print(Object o) { out.print(o); return this; }

		public CodeJamIO print(Object o[]) { return print(concat(o)); }

		public CodeJamIO print(Object o[][]) { return print(concat(o)); }

		public CodeJamIO println() { out.println(); return this; }

		public CodeJamIO printlnCase(int caseNum) { return printCase(caseNum).println(); }
		
		public CodeJamIO println(Object o) { return print(o).println(); }

		public CodeJamIO println(Object o[]) { return print(o).println(); }

		public CodeJamIO println(Object o[][]) { return print(concat(o)).println(); }

		
		private String concat(Object[] o) {
			StringBuffer buf = new StringBuffer(10*o.length);
			
			String delim = "";
			for (int i=0; i < o.length; i++) {
				buf.append(delim).append(o[i]);
				delim = " ";
			}
			return buf.toString();
		}
		
		private String concat(Object[][] o) {
			StringBuffer buf = new StringBuffer(100*o.length);
			for (int i=0; i < o.length; i++) {
				buf.append(concat(o[i])).append("\n");
			}
			return buf.toString();
		}

		private String concat(List<Integer[]> list) {
			StringBuffer buf = new StringBuffer();
			String delim = "";
			for (Object[] elm : list) {
				buf.append(delim).append('[').append(concat(elm)).append(']');
			}
			return buf.toString();
		}

		public void debug(String message) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
		}

		public void debug(String message, Object[] o) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			err.println("\t" + concat(o));
		}

		public void debug(String message, Object[][] o) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			String values = concat(o);
			err.println("\t" + values.replaceAll("\n", "\n\t"));
		}

		public void debug(String message, List<Integer[]> list) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			String values = concat(list);
			err.println("\t" + values.replaceAll("\n", "\n\t"));
		}

	}

}
