import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

public class A {

	private static CodeJamIO io = new CodeJamIO();

	/**
	 * @param args
	 */
	public static void main(String[] args) {

		try {
			init();

			int numCases = Integer.parseInt(io.readNextLine()[0]);
			for (int i=1; i <= numCases; i++) {
				io.debug("Solving Case #" + i + "...");
				solveCase(i);
				io.debug("Case #" + i + " solved!");
			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	/**
	 * Performs initial computations
	 */
	private static void init() {
		
	}

	/**
	 * Solves a Test Case
	 * 
	 * @param caseNum
	 * @throws IOException
	 */
	private static void solveCase(int caseNum) throws IOException {
		// Read input
		int N = Integer.parseInt(io.readNextLine()[0]);
		int[][] results = new int[N][N];
		for (int i=0; i<N; i++) {
			String tokens = io.readNextLine()[0];
			for (int j=0; j<N; j++) {
				results[i][j] =
					tokens.charAt(j) == '.' ?
					-1 :
					Integer.parseInt(Character.toString(tokens.charAt(j)));
			}
		}
		
		// Compute WPs
		double[] wp = new double[N];
		int[] wpsum = new int[N];
		int[] wpcount = new int[N];
		for (int i=0; i<N; i++) {
			wpsum[i] = wpcount[i] = 0;
			for (int j=0; j<N; j++) {
				if (j == i || results[i][j] == -1) {
					continue;
				}
				wpsum[i] += results[i][j];
				wpcount[i]++;
			}
			wp[i] = wpsum[i] / (double) wpcount[i];
		}
		
		// Compute OWPs
		double[][] oppowp = new double[N][N];
		for (int i=0; i<N; i++) {
			for (int j=0; j<N; j++) {
				if (results[i][j] == -1) {
					oppowp[i][j] = -1;
				} else {
					oppowp[i][j] = (wpsum[i] - results[i][j]) / (double)(wpcount[i] - 1);
				}
			}
		}
		double[] owp = new double[N];
		double[] owpsum = new double[N];
		int[] owpcount = new int[N];
		for (int j=0; j<N; j++) {
			for (int i=0; i<N; i++) {
				if (results[i][j] == -1) {
					continue;
				}
				owpsum[j] += oppowp[i][j];
				owpcount[j]++;
			}
			owp[j] = owpsum[j] / owpcount[j];
		}
		
		// Compute OOWPs
		double[] oowp = new double[N];
		for (int i=0; i<N; i++) {
			double oowpsum = 0;
			int oowpcount = 0;
			for (int j=0; j<N; j++) {
				if (results[i][j] == -1) {
					continue;
				}
				oowpsum += owp[j];
				oowpcount++;
			}
			oowp[i] = oowpsum / oowpcount;
		}
		
		// Compute RPIs
		double[] rpi = new double[N];
		for (int i=0; i<N; i++) {
			rpi[i] = 0.25*wp[i] + 0.5*owp[i] + 0.25*oowp[i];
		}
		
		// Print results
		io.printCase(caseNum).println();
		for (int i=0; i<N; i++) {
			io.println(rpi[i]);
		}
	}

	/**
	 * Input and Output CodeJam style
	 *
	 */
	private static class CodeJamIO {
		private static BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
		private static PrintWriter out = new PrintWriter(System.out, true);
		private static PrintWriter err = new PrintWriter(System.err, true);

		public String[] readNextLine() throws IOException {
			String line = in.readLine();
			String[] tokens = line.split("\\s+");
			return tokens;
		}

		public CodeJamIO printCase(int caseNum) { return print("Case #" + caseNum + ": " ); }
		
		public CodeJamIO print(Object o) { out.print(o); return this; }

		public CodeJamIO print(Object o[]) { return print(concat(o)); }

		public CodeJamIO print(Object o[][]) { return print(concat(o)); }

		public CodeJamIO println() { out.println(); return this; }

		public CodeJamIO printlnCase(int caseNum) { return printCase(caseNum).println(); }
		
		public CodeJamIO println(Object o) { return print(o).println(); }

		public CodeJamIO println(Object o[]) { return print(o).println(); }

		public CodeJamIO println(Object o[][]) { return print(concat(o)).println(); }

		
		private String concat(Object[] o) {
			StringBuffer buf = new StringBuffer(10*o.length);
			
			String delim = "";
			for (int i=0; i < o.length; i++) {
				buf.append(delim).append(o[i]);
				delim = " ";
			}
			return buf.toString();
		}
		
		private String concat(Object[][] o) {
			StringBuffer buf = new StringBuffer(100*o.length);
			for (int i=0; i < o.length; i++) {
				buf.append(concat(o[i])).append("\n");
			}
			return buf.toString();
		}

		private String concat(List<Integer[]> list) {
			StringBuffer buf = new StringBuffer();
			String delim = "";
			for (Object[] elm : list) {
				buf.append(delim).append('[').append(concat(elm)).append(']');
			}
			return buf.toString();
		}

		public void debug(String message) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
		}

		public void debug(String message, Object[] o) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			err.println("\t" + concat(o));
		}

		public void debug(String message, Object[][] o) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			String values = concat(o);
			err.println("\t" + values.replaceAll("\n", "\n\t"));
		}

		public void debug(String message, List<Integer[]> list) {
			err.println(Calendar.getInstance().getTime() + ": " + message);
			String values = concat(list);
			err.println("\t" + values.replaceAll("\n", "\n\t"));
		}

	}

}
