package codejam.triangletrilemma;

import java.util.HashMap;
import java.util.Map;

public class Problem {

	private static final double TARGET_BASE = 3;
	long count = 0;
	static Map<Long, String> ternaryCache = new HashMap<Long, String>();

	public Problem(String digits) {
		int D = digits.length();
		Sign[] signs = new Sign[D-1];
		for (int i = 0; i < signs.length; i++) {
			signs[i] = Sign.nothing;
		}

		double threeToDMinus1 = Math.pow(3, D-1);
		for (long i = 0; i < threeToDMinus1; i++) {
			String ternaryNum = decimalToTarget(i);
			long sum = calculate(digits, ternaryNum);
			if (isUgly(sum)) {
				count++;
			}
		}
	}

	private long calculate(String digits, String signs) {
		int length = digits.length() - 1;
		assert signs.length() <= length;
		int paddingLength = digits.length() - 1 - signs.length();
		long total = 0;
		int calculatedDigits = 0;
		Sign lastSign = Sign.plus;
		int signLength = length - paddingLength;
		for (int i = 0; i < signLength; i++) {
			if (signs.charAt(i) != '0') {
				long num = Long.parseLong(digits.substring(calculatedDigits, paddingLength + i + 1));
				if (lastSign == Sign.plus) {
					total += num;
				} else {
					total -= num;
					assert lastSign == Sign.minus;
				}
				if (signs.charAt(i) == '1') {
					lastSign = Sign.plus;
				} else {
					assert signs.charAt(i) == '2';
					lastSign = Sign.minus;
				}
				calculatedDigits = paddingLength + i + 1;
			}
		}

		long num = Long.parseLong(digits.substring(calculatedDigits));
		if (lastSign == Sign.plus) {
			total += num;
		} else {
			total -= num;
			assert lastSign == Sign.minus;
		}

		return total;
	}

	public long getResult1() {
		return count;
	}

	private boolean isUgly(long num) {
		return num % 2 == 0 || num % 3 == 0 || num % 5 == 0 || num % 7 == 0;
	}

	private String decimalToTarget(long decimalValue) {
		if (ternaryCache.containsKey(decimalValue)) {
			return ternaryCache.get(decimalValue);
		}

		long remainder = decimalValue;

//		long remainder = decimalValue;
//		double f = Math.log(decimalValue) / Math.log(TARGET_BASE);
//		int maxPower = (int)Math.floor(f);
		int power = 0;
		long powerVal = 1;
		while (decimalValue >= powerVal) {
			power++;
			powerVal *= TARGET_BASE;
		}
		int maxPower = power - 1;

		String toReturn = "";
		for (int p = maxPower; p >= 0; p--) {
			double baseToP = Math.pow(TARGET_BASE, p);
			int val = (int)(remainder / baseToP);
			remainder -= val * baseToP;
			toReturn += Integer.toString(val);
		}
		assert remainder == 0;

		ternaryCache.put(decimalValue, toReturn);

		return toReturn;
	}}

enum Sign {
	plus, minus, nothing;
}