import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.FilenameFilter;
import java.io.IOException;
import java.io.InputStreamReader;

public class Main {
	public static void main(String [] args) {
		File curDir = new File(".");
		String [] inputFiles = curDir.list(new FilenameFilter() {
			@Override
			public boolean accept(File dir, String name) {
				return name.endsWith(".in");
			}
		});

		for (String inputFile : inputFiles) {
			try {
				System.out.println(time() + "Processing " + inputFile);
				processFile(inputFile);
				System.out.println(time() + "Finished " + inputFile);
			} catch (Exception e) {
				System.out.println("Error processing " + inputFile);
				e.printStackTrace();
			}
		}
	}
	
	public static long startup = System.currentTimeMillis();
	public static String time() {
		return ""+((System.currentTimeMillis() - startup) / 1000.0f) + " ";
	}
	
	public static void processFile(String inputFile) throws NumberFormatException, IOException {
		FileInputStream fis = new FileInputStream(inputFile);
		BufferedReader br = new BufferedReader(new InputStreamReader(fis));
		
		InputCase [] cases = null;
		cases = readTestCases(br);
		br.close();
		
		Object output [] = new Object[cases.length];
		
		for (int i=0; i<cases.length; i++) {
			output[i] = cases[i].solve();
			System.out.println("Case #" + (i+1) + ": " + output[i]);
		}
		
		String outputFile = inputFile.replaceAll(".in", ".out");
		BufferedWriter bw = new BufferedWriter(new FileWriter(outputFile, false));
		for (int i=0; i<output.length; i++) {
			
			bw.write("Case #" + (i+1) + ": " + output[i] + "\n");
		}
		bw.close();
	}


	private static InputCase [] readTestCases(BufferedReader br) throws NumberFormatException, IOException {
		int numCases = Integer.parseInt(br.readLine());
		InputCase [] cases = new InputCase[numCases];
		for (int i=0; i<numCases; i++) {
			cases[i] = new InputCase();
			cases[i].readCase(br);
		}
		return cases;
	}
}
