package problemSolutions;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

import common.ErrorLogger;

/**
 * @author Oliver
 * 
 */
public class MagicTrick {

	private static BufferedReader br;
	private static BufferedWriter bw;

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			// Open input file.
			br = new BufferedReader(new FileReader("A-small-attempt0.in"));

			// Open output file.
			bw = new BufferedWriter(new FileWriter("output.out"));
		} catch (FileNotFoundException e) {
			e.printStackTrace();
			return;
		} catch (IOException e) {
			e.printStackTrace();
		}

		try {
			// Initialise input and read number of cases.
			int testCases = Integer.parseInt(br.readLine());

			// For each test case.
			analyseTestCases(testCases);
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				br.close();
				bw.flush();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
	}

	private static void analyseTestCases(int testCases) throws IOException {
		for (int i = 1; i <= testCases; i++) {
			int row1 = Integer.parseInt(br.readLine());

			int[] numbers1 = getNumbers(row1);
			
			int row2 = Integer.parseInt(br.readLine());

			int[] numbers2 = getNumbers(row2);
			
			int result = getMatchingNumber(numbers1, numbers2);
			
			ErrorLogger.assertTrue(result != 0, "Malformed result.");
			
			String text;
			
			if (result == -1) {
				text = "Bad magician!";
			}
			else if (result == -2) {
				text = "Volunteer cheated!";
			}
			else {
				text = Integer.toString(result);
			}

			write("Case #" + i + ": " + text + "\n");
		}
	}

	private static int[] getNumbers(int row) throws IOException {
		int[] n = new int[4];

		for (int j = 1; j < row; j++) {
			br.readLine();
		}
		
		String[] s = br.readLine().split(" ");

		for (int i = 0; i < s.length; i++) {
			n[i] = Integer.parseInt(s[i]);
		}

		for (int j = row + 1; j <= 4; j++) {
			br.readLine();
		}

		return n;
	}
	
	/**
	 * Returns -1 for "Bad magician" and -2 for "Volunteer cheated".
	 * 
	 * @return
	 */
	private static int getMatchingNumber(int[] numbers1, int[] numbers2) {
		int count = 0;
		
		int commonNumber = 0;
		
		for (int i = 0; i < numbers1.length; i++) {
			int n = numbers1[i];
			
			for (int j = 0; j < numbers2.length; j++) {
				if (numbers2[j] == n) {
					commonNumber = n;
					
					if (count == 1) {
						return -1;
					}
					
					count ++;
				}
			}
		}
		
		if (count == 0) {
			return -2;
		}
		
		return commonNumber;
	}

	private static void write(String s) {
		try {
			bw.write(s);
			System.out.print(s);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
