import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import common.ErrorLogger;

/**
 * @author Oliver
 * 
 */
public class DeceitfulWar {

	private static BufferedReader br;
	private static BufferedWriter bw;

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			// Open input file.
			br = new BufferedReader(new FileReader("D-large.in"));

			// Open output file.
			bw = new BufferedWriter(new FileWriter("output.out"));
		} catch (FileNotFoundException e) {
			e.printStackTrace();
			return;
		} catch (IOException e) {
			e.printStackTrace();
		}

		try {
			// Initialise input and read number of cases.
			int testCases = Integer.parseInt(br.readLine());

			// For each test case.
			analyseTestCases(testCases);
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				br.close();
				bw.flush();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
	}

	private static void analyseTestCases(int testCases) throws IOException {
		for (int i = 1; i <= testCases; i++) {
			int n = Integer.parseInt(br.readLine());

			String[] naomiInput = br.readLine().split(" ");
			String[] kenInput = br.readLine().split(" ");

			ErrorLogger.assertTrue(naomiInput.length == n
					&& naomiInput.length > 0, "Naomi's weights are malformed.");
			ErrorLogger.assertTrue(kenInput.length == n && kenInput.length > 0,
					"Ken's weights are malformed.");

			int y = countDeceitfulWarWins(getWeights(naomiInput),
					getWeights(kenInput));

			int z = countWarWins(getWeights(naomiInput), getWeights(kenInput));

			write("Case #" + i + ": " + y + " " + z + "\n");
		}
	}

	private static List<Double> getWeights(String[] weightValues) {
		List<Double> weights = new ArrayList<Double>();

		for (String w : weightValues) {
			weights.add(Double.parseDouble(w));
		}

		Collections.sort(weights);

		return weights;
	}

	private static int countDeceitfulWarWins(List<Double> naomiWeights,
			List<Double> kenWeights) {
		/*
		 * Naomi plays lighter blocks first.
		 */

		int wins = 0;

		while (naomiWeights.size() > 0) {
			if (naomiWeights.get(0) > kenWeights.get(0)) {
				wins++;

				kenWeights.remove(0);
			} else {
				kenWeights.remove(kenWeights.size() - 1);
			}

			naomiWeights.remove(0);
		}

		return wins;
	}

	private static int countWarWins(List<Double> naomiWeights,
			List<Double> kenWeights) {
		/*
		 * Naomi plays heavier blocks first.
		 */

		int wins = 0;

		int s = naomiWeights.size();

		while (s > 0) {
			if (naomiWeights.get(s - 1) > kenWeights.get(s - 1)) {
				wins++;

				kenWeights.remove(0);
			} else {
				kenWeights.remove(kenWeights.size() - 1);
			}

			naomiWeights.remove(s - 1);

			s--;
		}

		return wins;
	}

	private static void write(String s) {
		try {
			bw.write(s);
			System.out.print(s);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
