public class SnapperChain {
	/**
	 * This method returns the final state of light whether it will be ON or
	 * OFF.
	 * 
	 * @param noOfDevices
	 *            each element denotes number of devices.
	 * @param noOfToggle
	 *            number of times toggled.
	 * @return an array with final state of the lamp either ON or OFF.
	 */
	public String[] getFinalState(int[] noOfDevices, int[] noOfToggle) {
		String[] result = new String[noOfDevices.length];

		for (int i = 0; i < noOfDevices.length; i++) {
			// Initially, all the Snappers are in the OFF state, so only the
			// first one is receiving power from the socket, and the light is
			// off.
			boolean[] state = new boolean[noOfDevices[i]];
			toggles(state, noOfToggle[i]);
			result[i] = getFinalState(state);
		}
		return result;
	}

	/**
	 * This toggles the snappers to the requested no. of times.
	 * 
	 * @param state
	 *            of Snappers
	 * @param toggleCount
	 *            no of time Snappers need to be toggled.
	 */
	private void toggles(boolean[] state, int toggleCount) {
		for (int i = 0; i < toggleCount; i++) {
			toggle(state);
		}

	}

	/**
	 * When a Snapper is in the ON state and is receiving power from its input
	 * plug, then the device connected to its output socket is receiving power
	 * as well. When you snap your fingers -- making a clicking sound -- any
	 * Snapper receiving power at the time of the snap toggles between the ON
	 * and OFF state.
	 * 
	 * Initially, all the Snappers are in the OFF state, so only the first one
	 * is receiving power from the socket, and the light is off.
	 * 
	 * @param state
	 */
	private void toggle(boolean[] state) {
		int index = 0;
		for (; index < state.length; index++) {
			if (!state[index]) {
				// go till there is power.
				break;
			}
		}
	
		// Got the point till there is power
		// now change state
		if (index >= state.length) {
			index = state.length - 1;
		}
		while (index > 0) {
			state[index] = !state[index];
			index--;
		}
		// first one is always connected to power and can change the state.
		state[0] = !state[0];
	}

	private String getFinalState(boolean[] state) {

		for (int i = 0; i < state.length; i++) {
//			System.out.print(state[i] + "\t");
			if (!state[i]) {
				return "OFF";
			}
		}
		return "ON";
	}

}
