package dfs.codejam;

import java.io.*;
import java.util.*;

import static java.util.stream.Collectors.toList;

public class HouseOfPancakes {

    private static final String FILE_NAME = "B-small-attempt0";
    private static final String INPUT_FILE_NAME = FILE_NAME + ".in";
    private static final String OUTPUT_FILE_NAME = FILE_NAME + ".out";

    public static void main(String[] args) throws Exception {
        try (BufferedReader reader = new BufferedReader(new FileReader(INPUT_FILE_NAME))) {
            try (BufferedWriter writer = new BufferedWriter(new FileWriter(OUTPUT_FILE_NAME))) {
                int numCases = Integer.parseInt(reader.readLine());
                for (int i = 0; i < numCases; i++) {
                    HouseOfPancakes solver = new HouseOfPancakes(reader);
                    writer.write(String.format("Case #%d: %d\n", i + 1, solver.solve()));
                }
            }
        }
    }

    private static final Map<List<Integer>, Integer> cache = new HashMap<>();
    private final int[] pancakesByDiner;

    public HouseOfPancakes(BufferedReader reader) throws IOException {
        reader.readLine();
        pancakesByDiner = Arrays.stream(reader.readLine().split(" ")).mapToInt(Integer::parseInt).toArray();
    }

    public int solve() {
        return solve(new ArrayList<>(Arrays.stream(pancakesByDiner).boxed().collect(toList())));
    }

    private int solve(List<Integer> pancakeCounts) {
        if (pancakeCounts.size() == 0) return 0;

        pancakeCounts.sort((x, y) -> Integer.compare(y, x));
        Integer maybeCached = cache.get(pancakeCounts);
        if (maybeCached != null) return maybeCached;

        int bestResult = regularMinute(pancakeCounts);

        int maxPancakeCount = pancakeCounts.get(0);
        for (int split = 1; split <= maxPancakeCount / 2; split++) {
            List<Integer> newPancakeCounts = new ArrayList<>(pancakeCounts.subList(1, pancakeCounts.size()));
            newPancakeCounts.add(split);
            newPancakeCounts.add(maxPancakeCount - split);
            bestResult = Math.min(bestResult, 1 + solve(newPancakeCounts));
        }

        cache.put(pancakeCounts, bestResult);
        return bestResult;
    }

    private int regularMinute(List<Integer> sortedPancakeCounts) {
        List<Integer> afterRegularMinute = sortedPancakeCounts.stream()
            .map(x -> x - 1)
            .filter(x -> x > 0)
            .collect(toList());
        return 1 + solve(afterRegularMinute);
    }
}
