import java.io.File;
import java.io.FilenameFilter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Scanner;

public class A {
	private final static String QUESTION_PREFIX = "A";
	
	private static Scanner scanner;
	private static PrintWriter outputFileWriter;
	private static int lineNo;
	
	public static void main(String[] args) throws IOException {
		setupIO (args.length == 0 ? null : args[0]);
		
		int totalTC = scanner.nextInt();
		
		for (int tcIdx = 0; tcIdx < totalTC; ++tcIdx) {
			// Read input						
			int P = scanner.nextInt();
			int K = scanner.nextInt();
			int L = scanner.nextInt();
			
			ArrayList<Letter> freq = new ArrayList();
			
			for (int i = 0; i < L; ++i) {
				freq.add (new Letter (i, scanner.nextInt()));
			}
			Collections.sort(freq);
			
			
			// Calculate			
			if (P * K < L) {
				println ("Impossible");
			} else {
				long keyPress = 0;
				
				for (int i = 1; i <= P; ++i) {
					if (freq.isEmpty())
						break;
					
					for (int j = 0; j < K; ++j) {
						if (freq.isEmpty())
							break;
						
						Letter l = freq.remove(0);
						keyPress += (long) l.frequency * i;
					}
				}								
				
				println ("" + keyPress);
			}
				
						
		}				

	}
	
	private static void setupIO (String inputFileName) throws IOException{
		if (inputFileName == null) {
			inputFileName = selectInputFile();
		}
		
		File inputFile = new File (inputFileName);
		scanner = new Scanner(inputFile);
		outputFileWriter = new PrintWriter(new File(inputFile.getName().replaceAll("\\..*", ".out")));
		lineNo = 1;
		
		Runtime.getRuntime().addShutdownHook(new Thread() {
			@Override
			public void run() {
				if (scanner != null) {
					scanner.close();					
				}
				
				if (outputFileWriter != null)
					outputFileWriter.close();
			}
			
		});		
	}
	
	private static String selectInputFile() {
		File[] files = new File (".").listFiles(new FilenameFilter() {
			@Override
			public boolean accept(File dir, String name) {
				if (name.endsWith(".in") && name.startsWith(QUESTION_PREFIX))
					return true;
				else
					return false;
			}			
		});
		
		if (files.length == 1)
			return files[0].getName();
		
		System.out.println ("Please choose a file below......");
		
		for (int i = 0; i < files.length; ++i) {
			File file = files[i];
			System.out.println (i + ". " + file.getName());
		}
		
		System.out.print("Your choice: ");
		Scanner in = new Scanner(System.in);
		int choice = in.nextInt();
		
		return files[choice].getName();		
	}
	
	private static void println (String s) throws IOException {
		outputFileWriter.write("Case #" + (lineNo++) + ": " + s + "\n");
	}
}

class Letter implements Comparable {
	public int letter;
	public int frequency;
	public Letter(int letter, int frequency) {
		super();
		this.frequency = frequency;
		this.letter = letter;
	}
	
	@Override
	public int compareTo(Object o) {
		Letter l2 = (Letter) o;
		
		if (frequency > l2.frequency)
			return -1;
		else if (frequency < l2.frequency)
			return 1;
		else 
			return new Integer (letter).compareTo(l2.letter);
	}
	
	
}