package com.gcj;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.HashSet;
import java.util.StringTokenizer;
import java.util.TreeSet;
import java.util.concurrent.atomic.AtomicInteger;

public class Train {
	private static BufferedReader inputFileReader;
	private static PrintWriter outputFileWriter;
	private static int lineNo;
	
	public static void main(String[] args) throws IOException {
		setupIO (args[0]);
		
		int totalTC = Integer.parseInt (readln());
		
		for (int tcIdx = 0; tcIdx < totalTC; ++tcIdx) {
			// Read input
			int turnaroundTime = Integer.parseInt (readln());
			StringTokenizer st = new StringTokenizer (readln(), " ");
			int totalATrips = Integer.parseInt(st.nextToken());
			int totalBTrips = Integer.parseInt(st.nextToken());
			
			TreeSet<Trip> aTrips = new TreeSet<Trip>();
			TreeSet<Trip> bTrips = new TreeSet<Trip>();
			
			for (int aIdx = 0; aIdx < totalATrips; ++aIdx) {
				String[] oneLine = readln().split(" ");
				String[] departTimeStr = oneLine[0].split(":");
				String[] arrivalTimeStr = oneLine[1].split(":");
				
				Trip trip = new Trip (Integer.parseInt(departTimeStr[0]) * 60 + Integer.parseInt(departTimeStr[1]), 
						              Integer.parseInt(arrivalTimeStr[0]) * 60 + Integer.parseInt(arrivalTimeStr[1]) + turnaroundTime);
				
				aTrips.add(trip);
			}
			
			for (int bIdx = 0; bIdx < totalBTrips; ++bIdx) {
				String[] oneLine = readln().split(" ");
				String[] departTimeStr = oneLine[0].split(":");
				String[] arrivalTimeStr = oneLine[1].split(":");
				
				Trip trip = new Trip (Integer.parseInt(departTimeStr[0]) * 60 + Integer.parseInt(departTimeStr[1]), 
						              Integer.parseInt(arrivalTimeStr[0]) * 60 + Integer.parseInt(arrivalTimeStr[1]) + turnaroundTime);
				
				bTrips.add(trip);
			}	
			
			// Calculate			
			int numOfATrips = 0;
			int numOfBTrips = 0;
				
 			
			while (aTrips.size() > 0 && bTrips.size() > 0) {
				if (aTrips.first().compareTo(bTrips.first()) < 0) {
					++numOfATrips;
					recursive(aTrips, bTrips, aTrips.first(), true);
				} else {
					++numOfBTrips;
					recursive(aTrips, bTrips, bTrips.first(), false);
				}
			}
		
			println(String.valueOf(numOfATrips + aTrips.size()) + " " + String.valueOf(numOfBTrips + bTrips.size()));	
		}				
	}
	
	private static void recursive (TreeSet<Trip> aTrips, TreeSet<Trip> bTrips, Trip curTrip, boolean isA) {
		if (isA) {
			aTrips.remove(curTrip);
			
			Trip bTrip = new Trip (curTrip.arrivalTime, -1);
			Trip nextTrip = bTrips.higher(bTrip);
			
			if (nextTrip != null)
				recursive (aTrips, bTrips, nextTrip, false);
		} else {
			bTrips.remove(curTrip);
			
			Trip aTrip = new Trip (curTrip.arrivalTime, -1);
			Trip nextTrip = aTrips.higher(aTrip);
			
			if (nextTrip != null)
				recursive (aTrips, bTrips, nextTrip, true);
		}
	}
	
	private static void setupIO (String inputFileName) throws IOException{
		File inputFile = new File (inputFileName);
		inputFileReader = new BufferedReader (new FileReader(inputFile));
		outputFileWriter = new PrintWriter(new File(inputFile.getName().replaceAll("\\..*", ".out")));
		lineNo = 1;
		
		Runtime.getRuntime().addShutdownHook(new Thread() {
			@Override
			public void run() {
				if (inputFileReader != null) {
					try {
						inputFileReader.close();
					} catch (IOException e) {
						e.printStackTrace();
					}
				}
				
				if (outputFileWriter != null)
					outputFileWriter.close();
			}
			
		});		
	}
	
	private static String readln() throws IOException {
		return inputFileReader.readLine();
	}
	
	private static void println (String s) throws IOException {
		outputFileWriter.write("Case #" + (lineNo++) + ": " + s + "\n");
	}
}

class Trip implements Comparable {
	public int departTime;
	public int arrivalTime;
	
	
	public Trip(int departTime, int arrivalTime) {
		super();
		this.arrivalTime = arrivalTime;
		this.departTime = departTime;
	}



	@Override
	public int compareTo(Object o) {
		Trip t2 = (Trip) o;
		if (departTime < t2.departTime)
			return -1;
		else if (departTime > t2.departTime)
			return 1;
		else if (arrivalTime < t2.arrivalTime)
			return -1;
		else if (arrivalTime > t2.arrivalTime)
			return 1;
		else
			return 0;
	}		
	
	public String toString() {
		return departTime + " " + arrivalTime;
	}
}
