package com.code.jam.candies;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

class Candies {

    List<Integer> seanPile    = new ArrayList<Integer>();
    List<Integer> patrickPile = new ArrayList<Integer>();

    public List<Integer> getSeanPile() {
        return seanPile;
    }

    public List<Integer> getPatrickPile() {
        return patrickPile;
    }

    public void setSeanPile(List<Integer> seanPile) {
        this.seanPile = seanPile;
        for (int i : seanPile) {
            seanValueAccS += i;
            seanValueAccP = MyMath.badMath(seanValueAccP, i);
        }
    }

    public void setPatrickPile(List<Integer> patrickPile) {
        this.patrickPile = patrickPile;
        for (int i : patrickPile) {
            patrickValueAccS += i;
            patrickValueAccP = MyMath.badMath(patrickValueAccP, i);
        }
    }

    int seanValueAccP;

    public int getSeanValueAccP() {
        return seanValueAccP;
    }

    public int getPatrickValueAccP() {
        return patrickValueAccP;
    }

    public int getSeanValueAccS() {
        return seanValueAccS;
    }

    public int getPatrickValueAccS() {
        return patrickValueAccS;
    }

    int patrickValueAccP;
    int seanValueAccS;
    int patrickValueAccS;
}


public class CandyShop {

    public static void main(String[] args) throws FileNotFoundException {
        CandyShop c = new CandyShop();
        c.runTestCases();
    }

    public void runTestCases() throws FileNotFoundException {
        try {

            DataInputStream in = new DataInputStream(this.getClass().getResourceAsStream("small.in"));
            BufferedReader br = new BufferedReader(new InputStreamReader(in));

            FileOutputStream fostream = new FileOutputStream("small_output.txt");
            DataOutputStream out = new DataOutputStream(fostream);
            BufferedWriter wr = new BufferedWriter(new OutputStreamWriter(out));
            String strLine;

            int T = 1;
            br.readLine(); // Skip the first line
            br.readLine(); // skip
            long value = -1;
            while ((strLine = br.readLine()) != null) {
                CandyShop c = new CandyShop();
                String[] candyList = strLine.split(" ");
                value = c.distributeCandies(candyList);
                StringBuffer outLine = new StringBuffer();
                if (value != -1) {
                    outLine.append("Case #").append(T).append(": ").append(value);
                }
                else {
                    outLine.append("Case #").append(T).append(": ").append("NO");
                }
                wr.write(outLine.toString());
                wr.newLine();
                T++;
                br.readLine(); // skip Nextline
            }

            in.close();
            wr.flush();
            wr.close();
        }
        catch (Exception e) {// Catch exception if any
            e.printStackTrace();
        }
    }

    public long distributeCandies(String[] candyList) {
        List<Candies> possiblePiles = new ArrayList<Candies>();
        int[] indices;

        for (int r = candyList.length - 1; r > 0; r--) {
            CombinationGenerator x = new CombinationGenerator(candyList.length, r);
            while (x.hasMore()) {
                Candies pile = new Candies();
                List<Integer> patrickList = pile.getPatrickPile();
                List<Integer> seanList = pile.getSeanPile();
                indices = x.getNext();
                for (int i = 0; i < indices.length; i++) {
                    patrickList.add(Integer.parseInt(candyList[indices[i]]));
                }
                seanList.addAll(MyMath.otherElements(Arrays.asList(candyList), indices));
                pile.setPatrickPile(patrickList);
                pile.setSeanPile(seanList);
                possiblePiles.add(pile);
            }
        }
        return (MyMath.filterPiles(possiblePiles));
    }
}


class MyMath {

    static long filterPiles(List<Candies> allPossiblePiles) {
        List<Candies> filteredPiles = new ArrayList<Candies>();
        for (Candies pile : allPossiblePiles) {
            if (pile.getPatrickValueAccP() == pile.getSeanValueAccP()) {
                filteredPiles.add(pile);
            }
        }

        long maxValue = -1;
        for (Candies pile : filteredPiles) {
            maxValue = Math.max(maxValue, pile.getSeanValueAccS());
        }
        return maxValue;
    }

    public static int badMath(int x, int y) {
        int z = x ^ y;
        return z;
    }

    public static List<Integer> otherElements(List<String> fullList, int[] filterList) {
        List<Integer> filteredList = new ArrayList<Integer>();
        for (int i = 0; i < fullList.size(); i++) {
            boolean found = false;
            for (int j = 0; j < filterList.length; j++) {
                if (filterList[j] == i) {
                    found = true;
                    break;
                }
            }
            if (!found) {
                filteredList.add(Integer.parseInt(fullList.get(i)));
            }
        }
        return filteredList;
    }
}


class CombinationGenerator {

    private int[]      a;
    private int        n;
    private int        r;
    private BigInteger numLeft;
    private BigInteger total;

    public CombinationGenerator(int n, int r) {
        if (r > n) {
            throw new IllegalArgumentException();
        }
        if (n < 1) {
            throw new IllegalArgumentException();
        }
        this.n = n;
        this.r = r;
        a = new int[r];
        BigInteger nFact = getFactorial(n);
        BigInteger rFact = getFactorial(r);
        BigInteger nminusrFact = getFactorial(n - r);
        total = nFact.divide(rFact.multiply(nminusrFact));
        reset();
    }

    public void reset() {
        for (int i = 0; i < a.length; i++) {
            a[i] = i;
        }
        numLeft = new BigInteger(total.toString());
    }

    public BigInteger getNumLeft() {
        return numLeft;
    }

    // -----------------------------
    // Are there more combinations?
    // -----------------------------

    public boolean hasMore() {
        return numLeft.compareTo(BigInteger.ZERO) == 1;
    }

    // ------------------------------------
    // Return total number of combinations
    // ------------------------------------

    public BigInteger getTotal() {
        return total;
    }

    // ------------------
    // Compute factorial
    // ------------------

    private static BigInteger getFactorial(int n) {
        BigInteger fact = BigInteger.ONE;
        for (int i = n; i > 1; i--) {
            fact = fact.multiply(new BigInteger(Integer.toString(i)));
        }
        return fact;
    }

    // --------------------------------------------------------
    // Generate next combination (algorithm from Rosen p. 286)
    // --------------------------------------------------------

    public int[] getNext() {

        if (numLeft.equals(total)) {
            numLeft = numLeft.subtract(BigInteger.ONE);
            return a;
        }

        int i = r - 1;
        while (a[i] == n - r + i) {
            i--;
        }
        a[i] = a[i] + 1;
        for (int j = i + 1; j < r; j++) {
            a[j] = a[i] + j - i;
        }

        numLeft = numLeft.subtract(BigInteger.ONE);
        return a;

    }
}
