/**
 * Copyright Yahoo! Inc.,  All rights reserved.
 */
package com.code.jam.robots;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;


/**
 * @author deepakkv
 */
public class RobotsTest {

    public static void main(String[] args) throws FileNotFoundException {
        RobotsTest tc = new RobotsTest();
        tc.runTestCases();
    }

    public void runTestCases() throws FileNotFoundException {
        try {

            DataInputStream in = new DataInputStream(this.getClass().getResourceAsStream("large.in"));
            BufferedReader br = new BufferedReader(new InputStreamReader(in));

            FileOutputStream fostream = new FileOutputStream("large_output.txt");
            DataOutputStream out = new DataOutputStream(fostream);
            BufferedWriter wr = new BufferedWriter(new OutputStreamWriter(out));
            String strLine;

            int T = 1;
            br.readLine(); // Skip the first line
            List<Robot> sequence = null;
            RobotTimer r = null;
            while ((strLine = br.readLine()) != null) {
                sequence = new ArrayList<Robot>();
                String[] inputLine = strLine.split(" ");
                // 4 O 2 B 1 B 2 O 4 //Skip 1st character
                for (int i = 1; i < inputLine.length; i += 2) {
                    Robot robot = new Robot(inputLine[i], inputLine[i + 1]);
                    sequence.add(robot);
                }
                r = new RobotTimer();
                int time = r.compute(sequence);
                StringBuffer outLine = new StringBuffer();
                outLine.append("Case #").append(T).append(": ").append(time);
                wr.write(outLine.toString());
                wr.newLine();
                System.out.println(outLine.toString());
                T++;
            }

            in.close();
            wr.flush();
            wr.close();
        }
        catch (Exception e) {// Catch exception if any
            e.printStackTrace();
        }
    }

    class Robot {

        char name;
        int  position;

        Robot(String robot, String time) {
            this.name = robot.charAt(0);
            this.position = Integer.parseInt(time);
        }

        public char getRobot() {
            return name;
        }

        public int getPosition() {
            return position;
        }

    }

    class RobotTimer {

        Robot         orangeMover   = null;
        Robot         blueMover     = null;
        AtomicInteger blueIndexer   = new AtomicInteger(-1);
        AtomicInteger orangeIndexer = new AtomicInteger(-1);
        Integer       totalTime     = 0;
        AtomicInteger cpOrange      = new AtomicInteger(1);
        AtomicInteger cpBlue        = new AtomicInteger(1);

        public int compute(List<Robot> pushSequence) {
            initializeMovers(pushSequence);
            boolean moveNext = true;
            Robot pusherRobot = null;
            for (int pIndex = 0; pIndex < pushSequence.size();) {
                if (moveNext) {
                    pusherRobot = pushSequence.get(pIndex);
                }
                if (pusherRobot.getRobot() == 'O') {
                    orangeMover = pushSequence.get(orangeIndexer.get());
                    int diff = pusherRobot.getPosition() - cpOrange.get();
                    if (diff != 0) { // Move in parallel
                        moveParallelIfEitherNotInPosition(cpOrange, cpBlue, orangeMover, blueMover);
                        moveNext = false;
                    }
                    else { // Move & Push parallel
                        totalTime++;
                        if (blueIndexer.get() >= 0 && blueIndexer.get() < pushSequence.size()) {
                            blueMover = pushSequence.get(blueIndexer.get());
                        }
                        if (blueMover != null && blueMover.getPosition() != cpBlue.get()) {
                            int bdiff = blueMover.getPosition() - cpBlue.get();
                            if (bdiff > 0) {
                                cpBlue.getAndIncrement();
                            }
                            else {
                                cpBlue.getAndDecrement();
                            }
                        }
                        resetIntializer(pushSequence, orangeIndexer, 'O');
                        orangeMover = pushSequence.get(orangeIndexer.get());
                        moveNext = true;
                        pIndex++;
                    }
                }
                else if (pusherRobot.getRobot() == 'B') {
                    int diff = pusherRobot.getPosition() - cpBlue.get();
                    blueMover = pushSequence.get(blueIndexer.get());
                    if (diff != 0) { // Move in parallel
                        moveParallelIfEitherNotInPosition(cpBlue, cpOrange, blueMover, orangeMover);
                        moveNext = false;
                    }
                    else { // Move & Push parallel
                        totalTime++;
                        if (orangeIndexer.get() >= 0 && orangeIndexer.get() < pushSequence.size()) {
                            orangeMover = pushSequence.get(orangeIndexer.get());
                        }
                        if (orangeMover != null && orangeMover.getPosition() != cpOrange.get()) {
                            int odiff = orangeMover.getPosition() - cpOrange.get();
                            if (odiff > 0) {
                                cpOrange.getAndIncrement();
                            }
                            else {
                                cpOrange.getAndDecrement();
                            }
                        }
                        resetIntializer(pushSequence, blueIndexer, 'B');
                        blueMover = pushSequence.get(blueIndexer.get());
                        moveNext = true;
                        pIndex++;
                    }
                }
            }
            return totalTime;
        }

        protected void resetIntializer(List<Robot> pushSequence, AtomicInteger robotIndexer, char robotType) {
            boolean moved = false;
            for (int i = robotIndexer.get() + 1; i < pushSequence.size(); i++) {
                Robot robot = pushSequence.get(i);
                if (robot.getRobot() == robotType) {
                    if (!moved) {
                        robotIndexer.set(i);
                        moved = true;
                    }
                }
                if (moved) {
                    break;
                }
            }
        }

        protected void initializeMovers(List<Robot> pushSequence) {
            boolean oMoved = false;
            boolean bMoved = false;
            for (int i = 0; i < pushSequence.size(); i++) {
                Robot robot = pushSequence.get(i);
                if (robot.getRobot() == 'O') {
                    if (!oMoved) {
                        this.orangeMover = robot;
                        orangeIndexer.set(i);
                        oMoved = true;
                    }
                }
                else if (robot.getRobot() == 'B') {
                    if (!bMoved) {
                        this.blueMover = robot;
                        blueIndexer.set(i);
                        bMoved = true;
                    }
                }
                if (bMoved && oMoved) {
                    break;
                }
            }
        }

        private void moveParallelIfEitherNotInPosition(AtomicInteger moveCPPosition, AtomicInteger optionalPosition,
                        Robot move, Robot optional) {
            while (true) {
                if (move.getPosition() != moveCPPosition.get()) {
                    int diff = move.getPosition() - moveCPPosition.get();
                    if (diff > 0) {
                        moveCPPosition.getAndIncrement();
                    }
                    else {
                        moveCPPosition.getAndDecrement();
                    }

                    if (optional != null && optional.getPosition() != optionalPosition.get()) {
                        int odiff = optional.getPosition() - optionalPosition.get();
                        if (odiff > 0) {
                            optionalPosition.getAndIncrement();
                        }
                        else {
                            optionalPosition.getAndDecrement();
                        }
                    }
                    totalTime++;
                }
                else {
                    break;
                }
            }
        }
    }

}
