import java.io.*;

/**
 * @author Delia David
 */
public class Watersheds {

    private static final String INPUT_FILE_NAME = "watersheds.in";

    private static final String OUTPUT_FILE_NAME = "watersheds.out";

    public static void main(String[] args) throws IOException {
        BufferedReader br = new BufferedReader(new FileReader(INPUT_FILE_NAME));
        PrintWriter pw = new PrintWriter(new FileWriter(OUTPUT_FILE_NAME));
        //number of maps
        int t = Integer.parseInt(br.readLine());
        for (int k = 0; k < t; k++) {
            //h, w
            String line = br.readLine();
            String[] dim = line.split(" ");
            int h = Integer.parseInt(dim[0]);
            int w = Integer.parseInt(dim[1]);

            //map
            int[][] map = new int[h][w];
            for (int i = 0; i < h; i++) {
                line = br.readLine();
                String[] row = line.split(" ");
                for (int j = 0; j < w; j++) {
                    map[i][j] = Integer.parseInt(row[j]);
                }
            }

            char[][] x = doLabel(h, w, map);
            String res = "Case #" + (k + 1) + ":\n";
            pw.write(res);
            //labeled map
            for (int i = 0; i < h; i++) {
                String resRow = "";
                for (int j = 0; j < w; j++) {
                    resRow = resRow + " " + x[i][j];
                }
                resRow = resRow.trim();
                pw.write(resRow);
                pw.write("\n");
            }


        }

        br.close();
        pw.close();
    }

    //positions
    //0 - current cell
    //1 - North, 2 - West, 3 - East, 4 - South
    private static char[][] doLabel(int n, int m, int[][] map) {
        int[][] mins = new int[n][m];
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                int min = map[i][j];
                int minPos = 0;

                //north
                if (i > 0 && map[i - 1][j] < min) {
                    min = map[i - 1][j];
                    minPos = 1;
                }
                //west
                if (j > 0 && map[i][j - 1] < min) {
                    min = map[i][j - 1];
                    minPos = 2;
                }
                //east
                if (j < m - 1 && map[i][j + 1] < min) {
                    min = map[i][j + 1];
                    minPos = 3;
                }
                //south
                if (i < n - 1 && map[i + 1][j] < min) {
                    minPos = 4;
                }

                mins[i][j] = minPos;
            }
        }

        char[][] x = new char[n][m];
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                x[i][j] = '_';
            }
        }


        char currentChar = 'a';

        int[] notFilled = getFirstNotFilled(n, m, x);
        int i = notFilled[0];
        int j = notFilled[1];
        boolean done = i == -1 && j == -1;
        while (!done) {
            flood(i, j, n, m, mins, x, currentChar);
            notFilled = getFirstNotFilled(n, m, x);
            i = notFilled[0];
            j = notFilled[1];
            done = i == -1 && j == -1;
            if (!done) {
                currentChar = (char) ((int) currentChar + 1);
            }
        }

        return x;
    }

    private static int[] getFirstNotFilled(int n, int m, char[][] x) {
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                if (x[i][j] == '_') {
                    return new int[]{i, j};
                }
            }
        }
        return new int[]{-1, -1};
    }

    private static void flood(int i, int j, int n, int m, int[][] mins, char[][] x, char c) {
        if (x[i][j] == '_') {
            x[i][j] = c;

            if (mins[i][j] != 0) {
                switch (mins[i][j]) {
                    case 1:
                        flood(i - 1, j, n, m, mins, x, c);
                        break;
                    case 2:
                        flood(i, j - 1, n, m, mins, x, c);
                        break;
                    case 3:
                        flood(i, j + 1, n, m, mins, x, c);
                        break;
                    default:
                        flood(i + 1, j, n, m, mins, x, c);
                }
            }

            if (i > 0 && mins[i - 1][j] == 4) {
                flood(i - 1, j, n, m, mins, x, c);
            }

            if (j > 0 && mins[i][j - 1] == 3) {
                flood(i, j - 1, n, m, mins, x, c);
            }

            if (j < m - 1 && mins[i][j + 1] == 2) {
                flood(i, j + 1, n, m, mins, x, c);
            }

            if (i < n - 1 && mins[i + 1][j] == 1) {
                flood(i + 1, j, n, m, mins, x, c);
            }
        }
    }
}
