import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Scanner;

public class Dijkstra {
    boolean negative;
    char digit;

    public Dijkstra(boolean negative, char digit) {
        this.negative = negative;
        this.digit = digit;
    }
    
    public Dijkstra multiply(Dijkstra other) {
        boolean isNegative = this.negative ^ other.negative;
        char newDigit = '1';
        
        switch (this.digit) {
        case '1':
            newDigit = other.digit;
            break;
        case 'i':
            switch (other.digit) {
            case '1':
                newDigit = 'i';
                break;
            case 'i':
                newDigit = '1';
                isNegative = !isNegative;
                break;
            case 'j':
                newDigit = 'k';
                break;
            case 'k':
                newDigit = 'j';
                isNegative = !isNegative;
                break;
            }
            break;
        case 'j':
            switch (other.digit) {
            case '1':
                newDigit = 'j';
                break;
            case 'i':
                newDigit = 'k';
                isNegative = !isNegative;
                break;
            case 'j':
                newDigit = '1';
                isNegative = !isNegative;
                break;
            case 'k':
                newDigit = 'i';
                break;
            }
            break;
        case 'k':
            switch (other.digit) {
            case '1':
                newDigit = 'k';
                break;
            case 'i':
                newDigit = 'j';
                break;
            case 'j':
                newDigit = 'i';
                isNegative = !isNegative;
                break;
            case 'k':
                newDigit = '1';
                isNegative = !isNegative;
                break;
            }
            break;
        }
        
        return new Dijkstra(isNegative, newDigit);
    }

    public static void main(String[] args) throws IOException {
        Scanner scanner = new Scanner(new File("foo.txt"));
        FileWriter writer = new FileWriter("output.txt");
        int n = scanner.nextInt();
        
        for (int i = 0; i < n; i++) {
            int l = scanner.nextInt();
            int x = scanner.nextInt();
            char[] digitChars = scanner.next().toCharArray();
            Dijkstra[] sequence = new Dijkstra[l * x];
            
            for (int j = 0; j < sequence.length; j++) {
                sequence[j] = new Dijkstra(false, digitChars[j % l]);
            }
            
            // Now, accumulate, checking until we have certain numbers
            Dijkstra accumulator = new Dijkstra(false, '1');
            int index = 0;
            int score = 0;
            
            // find i
            Dijkstra target = new Dijkstra(false, 'i');
            while (index < sequence.length) {
                accumulator = accumulator.multiply(sequence[index]);
                index++;
                if (accumulator.equals(target)) {
                    score++;
                    break;
                }
            }
            // now j
            accumulator = new Dijkstra(false, '1');
            target = new Dijkstra(false, 'j');
            while (index < sequence.length) {
                accumulator = accumulator.multiply(sequence[index]);
                index++;
                if (accumulator.equals(target)) {
                    score++;
                    break;
                }
            }
            // now k
            accumulator = new Dijkstra(false, '1');
            target = new Dijkstra(false, 'k');
            while (index < sequence.length) {
                accumulator = accumulator.multiply(sequence[index]);
                index++;
            }
            if (score == 2 && accumulator.equals(target)) {
                System.out.println(String.format("Case #%d: YES", i+1));
            } else {
                System.out.println(String.format("Case #%d: NO", i+1));
            }
        }
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + digit;
        result = prime * result + (negative ? 1231 : 1237);
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        Dijkstra other = (Dijkstra) obj;
        if (digit != other.digit)
            return false;
        if (negative != other.negative)
            return false;
        return true;
    }
}
