package c;

import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class C {
	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		
		int tests = in.nextInt();
		for ( int test = 1; test <= tests; ++test ) {
			int rows = in.nextInt();
			int cols = in.nextInt();
			int mines = in.nextInt();
			
			Board board = new Board(rows,cols);
			Board solved = board.solve ( mines );
			
			System.out.printf ( "Case #%d:\n", test );
			if ( solved == null ) {
				System.out.println ( "Impossible" );
			} else {
				System.out.print ( solved );
			}
		}
		
		/*
		Board b = new Board(10,10);
		b = b.zero(4,5);
		b = b.zero(4,6);
		b = b.zero(5,4);
		b = b.zero(5,5);
		System.out.println(b.countMines());
		*/
		
		in.close();
	}
}

class Point {
	public final int x, y;
	
	public Point(int x, int y) {
		this.x = x;
		this.y = y;
	}
}

class Board {
	private final int rows, cols;
	
	private final boolean zeroCells[][];

	public Board(int rows, int cols){
		this.rows = rows;
		this.cols = cols;
		this.zeroCells = new boolean[rows][cols];
	}
	
	public Board(int rows, int cols, boolean[][] zeroCells ){
		this(rows,cols);
		for ( int r = 0; r < rows; ++r ) {
			for ( int c = 0; c < cols; ++c ) {
				this.zeroCells[r][c] = zeroCells[r][c]; 
			}
		}
	}
	
	/**
	 * Mark the cell (r,c) as being a "zero"--no neighbouring mines.
	 * @param r
	 * @param c
	 * @return
	 */
	public Board markZeroCell ( int r, int c ) {
		//zeroCells[r][c] = true;
		Board copy = new Board(rows,cols,zeroCells);
		copy.zeroCells[r][c] = true;
		return copy;
	}
	
	public int countMines () {
		boolean notMineCells[][] = new boolean[rows][cols];
		for ( int r = 0; r < rows; ++r ) {
			for ( int c = 0; c < cols; ++c ) {
				if ( zeroCells[r][c] ) {
					for ( int x = r-1; x <= r+1; ++x ) {
						if ( x < 0 || x >= rows ) continue;
						for ( int y = c-1; y <= c+1; ++y ) {
							if ( y < 0 || y >= cols ) continue;
							notMineCells[x][y] = true;
						}
					}
				}
			}
		}
		
		int mines = 0;
		for ( int r = 0; r < rows; ++r ) {
			for ( int c = 0; c < cols; ++c ) {
				if ( ! notMineCells[r][c] ) ++mines;
			}
		}
		return mines;
	}
	
	/** Return true if and only if [r,c] is beside a zero cell--but not zero itself. */
	private boolean besideZeroCell ( int r, int c ) {
		//*
		if ( zeroCells[r][c] ) return false;

		for ( int x = r-1; x <= r+1; ++x ) {
			for ( int y = c-1; y <= c+1; ++y ) {
				if ( isZero(x,y) ) return true;
			}
		}
		
		return false;
		// */
		
		/*
		if ( zeroCells[r][c] ) return false;
		return isZero(r-1,c) || isZero(r+1, c) || isZero(r,c-1) || isZero(r,c+1);
		// */
	}
	
	private boolean isZero ( int r, int c ) {
		if ( r < 0 || r >= rows ) return false;
		if ( c < 0 || c >= cols ) return false;
		return zeroCells[r][c];
	}
	
	private boolean hasZeroes () {
		for ( int r = 0; r < rows; ++r ) {
			for ( int c = 0; c < cols; ++c ) {
				if ( zeroCells[r][c] ) {
					return true;
				}
			}
		}
		return false;
	}
	
	private List<Point> getPerimeter() {
		List<Point> points = new ArrayList<>();
		for ( int r = 0; r < rows; ++r ) {
			for ( int c = 0; c < cols; ++c ) {
				if ( besideZeroCell ( r, c ) ) {
					points.add ( new Point ( r, c ) );
				}
			}
		}
		return points;
	}
	
	public Board solve ( int targetMines ) {
		// Special cases...
		if ( targetMines >= rows * cols ) {
			return null;
		}
		
		// Success or failure that causes a backtrack...
		int currentMines = countMines();
		if ( currentMines < targetMines ) {
			return null;
		} else if ( currentMines == targetMines ) {
			return this;
		}
		
		// Try to add a zero that is contiguous with the existing zeroes
		List<Point> perimeter = getPerimeter();
		if ( perimeter.isEmpty() ) {
			for ( int r = 0; r < rows; ++r ) {
				for ( int c = 0; c < cols; ++c ) {
					perimeter.add ( new Point(r,c) );
				}
			}
		}
		
		// Try recursing into each option (DFS)
		for ( Point pt : perimeter ) {
			Board newBoard = markZeroCell ( pt.x, pt.y );
			Board solved = newBoard.solve ( targetMines );
			if ( solved != null ) return solved;
		}
		
		// Well we failed, that sucks.
		return null;
	}
	
	@Override
	public String toString() {
		StringBuffer buf = new StringBuffer();
		boolean firstZero = true;
		for ( int r = 0; r < rows; ++r ) {
			for ( int c = 0; c < cols; ++c ) {
				if ( zeroCells[r][c] ) {
					if ( firstZero ) {
						buf.append('c');
						firstZero = false;
					} else {
						buf.append('.');
					}
				} else if ( besideZeroCell(r, c) ) {
					buf.append('.');
				} else {
					buf.append('*');
				}
			}
			buf.append('\n');
		}
		return buf.toString();
	}
	
}

