package d;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

public class D {
	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		
		int tests = in.nextInt();
		for ( int test = 1; test <= tests; ++test ) {
			int n = in.nextInt();
			List<Double>	naomiWeights = readWeights(in, n),
							kenWeights = readWeights(in, n);
			
			int dishonest = bestDishonestScore(naomiWeights, kenWeights);
			int honest = bestHonestScore(naomiWeights, kenWeights);
			System.out.printf ( "Case #%d: %d %d\n", test, dishonest, honest );
		}
		
		in.close();
	}
	
	private static List<Double> readWeights ( Scanner in, int count ) {
		List<Double> weights = new ArrayList<>();
		for ( int i = 0; i < count; ++i ) {
			weights.add(in.nextDouble());
		}
		Collections.sort(weights);
		return weights;
	}
	
	private static int bestHonestScore ( List<Double> naomiIn, List<Double> kenIn ) {
		// Operate on copies of the original lists to avoid mangling the originals
		List<Double> naomi = new ArrayList<>(naomiIn);
		List<Double> ken = new ArrayList<>(kenIn);
		
		// Iteratively play the smallest block. Ken will play the smallest block that beats it,
		// or his smallest block (giving up a point to Naomi).
		int points = 0;
		for ( double naomiPlay : naomi ) {
			Double kenWinPlay = minimumAbove ( ken, naomiPlay );
			if ( kenWinPlay == null ) {
				++points;
				ken.remove(0);
			} else {
				ken.remove(kenWinPlay);
			}
		}
		return points;
	}
	
	private static int bestDishonestScore ( List<Double> naomiIn, List<Double> kenIn ) {
		// Operate on copies of the original lists to avoid mangling the originals
		List<Double> naomi = new ArrayList<>(naomiIn);
		List<Double> ken = new ArrayList<>(kenIn);

		// Iteratively draw out Ken's worst block (by lying and saying we have a block that's
		// nearly 1.0) and beat it with the block which is larger, but only very slightly larger.
		// When we can't do that anymore (Ken's smallest block is bigger than our largest), we
		// are done and cannot win more points.
		int points = 0;
		for ( double minKen : ken ) {
			Double bestPlay = minimumAbove ( naomi, minKen );
			if ( bestPlay == null ) break;
			
			naomi.remove(bestPlay);
			++points;
		}
		return points;
	}
	
	/**
	 * Choose the minimum element from (weights) which is above (value), where all elements
	 * are in the range [0.0, 1.0] and (weights) is sorted ascending. If no such value exists,
	 * return null.
	 * 
	 * @param weights
	 * @param value
	 * @return
	 */
	private static Double minimumAbove ( List<Double> weights, double value ) {
		for ( double w : weights ) {
			if ( w > value ) {
				return w;
			}
		}
		return null;
	}
	
	/*
	private static void output ( List<Double> weights ) {
		for ( double w : weights ) System.out.printf("%.3f ", w);
	}
	*/
}
