import java.io.OutputStream;
import java.io.FilenameFilter;
import java.util.Locale;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.FileInputStream;
import java.io.File;
import java.io.InputStream;
import java.io.PrintWriter;
import java.io.StringReader;
import java.io.IOException;
import java.io.Reader;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 *
 * @author Denis Nedelyaev
 */
public class Main {
    public static void main(String[] args) throws Exception {
        Locale.setDefault(Locale.US);
        final String regex = "A-(small|large).*[.]in";
        File directory = new File(".");
        File[] candidates = directory.listFiles(new FilenameFilter() {
            public boolean accept(File dir, String name) {
                return name.matches(regex);
            }
        });
        File toRun = null;
        for (File candidate : candidates) {
            if (toRun == null || candidate.lastModified() > toRun.lastModified())
                toRun = candidate;
        }
        InputStream inputStream = new FileInputStream(toRun);
        OutputStream outputStream = new FileOutputStream("a.out");
        FastScanner in = new FastScanner(inputStream);
        PrintWriter out = new PrintWriter(outputStream);
        TaskA solver = new TaskA(in, out);
        int testCount = Integer.parseInt(in.next());
        for (int i = 1; i <= testCount; i++)
            solver.solve(i);
        out.close();
    }

    static class TaskA {
        private final FastScanner in;
        private final PrintWriter out;

        public TaskA(FastScanner in, PrintWriter out) {
            this.in = in;
            this.out = out;
        }

        public void solve(int testNumber) throws IOException {
            int n = in.nextInt();
            int r = in.nextInt();
            int p = in.nextInt();
            int s = in.nextInt();

            String ans = null;

            if (r > 0) {
                String top = solveR(n);
                if (test(top, r, p, s) && (ans == null || ans.compareTo(top) < 0)) {
                    ans = top;
                }
            }
            if (p > 0) {
                String top = solveP(n);
                if (test(top, r, p, s) && (ans == null || ans.compareTo(top) < 0)) {
                    ans = top;
                }
            }
            if (s > 0) {
                String top = solveS(n);
                if (test(top, r, p, s) && (ans == null || ans.compareTo(top) < 0)) {
                    ans = top;
                }
            }

            out.println("Case #" + testNumber + ": " + (ans == null ? "IMPOSSIBLE" : ans));
        }

        private String solveR(int n) {
            if (n == 0) {
                return "R";
            }
            String r = solveR(n - 1);
            String s = solveS(n - 1);
            return (r + s).compareTo(s + r) < 0 ? r + s : s + r;
        }

        private String solveP(int n) {
            if (n == 0) {
                return "P";
            }
            String p = solveP(n - 1);
            String r = solveR(n - 1);
            return (p + r).compareTo(r + p) < 0 ? p + r : r + p;
        }

        private String solveS(int n) {
            if (n == 0) {
                return "S";
            }
            String s = solveS(n - 1);
            String p = solveP(n - 1);
            return (p + s).compareTo(s + p) < 0 ? p + s : s + p;
        }

        private boolean test(String st, int r, int p, int s) {
            for (char c : st.toCharArray()) {
                if (c == 'R') {
                    r--;
                } else if (c == 'P') {
                    p--;
                } else {
                    s--;
                }
            }
            return r == 0 && p == 0 && s == 0;
        }

    }

    static class FastScanner {
        private final BufferedReader br;
        private String line;
        private int pos;

        public FastScanner(String s) throws IOException {
            this(new StringReader(s));
        }

        public FastScanner(InputStream is) throws IOException {
            this(new InputStreamReader(is, "UTF-8"));
        }

        public FastScanner(Reader reader) throws IOException {
            this(new BufferedReader(reader));
        }

        public FastScanner(BufferedReader reader) throws IOException {
            br = reader;
            line = br.readLine();
            pos = 0;
        }

        public String next() throws IOException {
            if (!skipWhitespace()) {
                return null;
            }

            int start = pos;

            while (pos < line.length()) {
                char c = line.charAt(pos);

                if (c == ' ' || c == '\t') {
                    break;
                }

                pos++;
            }

            return line.substring(start, pos);
        }

        public int nextInt() throws IOException {
            return Integer.parseInt(next());
        }

        private boolean skipWhitespace() throws IOException {
            while (line != null) {
                while (pos < line.length()) {
                    char c = line.charAt(pos);

                    if (c != ' ' && c != '\t') {
                        return true;
                    }

                    pos++;
                }

                line = br.readLine();
                pos = 0;
            }

            return false;
        }

    }
}

