import java.io.Reader;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.io.BufferedReader;
import java.io.FilenameFilter;
import java.util.Map;
import java.util.Locale;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.IOException;
import java.io.FileOutputStream;
import java.io.File;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 * @author Denis Nedelyaev
 */
public class Main {
	public static void main(String[] args) throws Exception {
		Locale.setDefault(Locale.US);
		InputStream inputStream;
		final String regex = "A-(small|large).*[.]in";
		File directory = new File(".");
		File[] candidates = directory.listFiles(new FilenameFilter() {
			public boolean accept(File dir, String name) {
				return name.matches(regex);
			}
		});
		File toRun = null;
		for (File candidate : candidates) {
			if (toRun == null || candidate.lastModified() > toRun.lastModified())
				toRun = candidate;
		}
		inputStream = new FileInputStream(toRun);
		OutputStream outputStream = new FileOutputStream("a.out");
		FastScanner in = new FastScanner(inputStream);
		PrintWriter out = new PrintWriter(outputStream);
		TaskA solver = new TaskA(in, out);
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i);
		out.close();
	}
}

class TaskA {
    private final FastScanner in;
    private final PrintWriter out;
    private int R;
    private int C;
    private String[] map;

    public TaskA(FastScanner in, PrintWriter out) {
        this.in = in;
        this.out = out;
    }

    public void solve(int testNumber) throws IOException {
        R = in.nextInt();
        C = in.nextInt();
        map = new String[R];
        for (int i = 0; i < R; i++) {
            map[i] = in.next();
        }

        Map<Character, Integer> dirIndex = new HashMap<>();
        dirIndex.put('^', 0);
        dirIndex.put('v', 1);
        dirIndex.put('<', 2);
        dirIndex.put('>', 3);
        int[][] dirs = {
            {-1, 0},
            {1, 0},
            {0, -1},
            {0, 1}
        };

        int ans = 0;
        for (int r = 0; r < R; r++) {
            for (int c = 0; c < C; c++) {
                if (map[r].charAt(c) != '.') {
                    int dirIdx = dirIndex.get(map[r].charAt(c));
                    int[] dir = dirs[dirIdx];
                    if (!findArrow(r, c, dir)) {
                        boolean ok = false;
                        for (int i = 0; i < 4 && !ok; i++) {
                            dir = dirs[(dirIdx + i) % 4];
                            ok = findArrow(r, c, dir);
                        }
                        if (!ok) {
                            out.println("Case #" + testNumber + ": IMPOSSIBLE");
                            return;
                        }
                        ans++;
                    }
                }
            }
        }

        out.println("Case #" + testNumber + ": " + ans);
    }

    private boolean findArrow(int r, int c, int[] dir) {
        while (true) {
            r += dir[0];
            c += dir[1];

            if (r < 0 || r >= R || c < 0 || c >= C) {
                return false;
            }
            if (map[r].charAt(c) != '.') {
                return true;
            }
        }
    }
}

class FastScanner {
    private BufferedReader br;
    private String line = "";
    private int pos;

    public FastScanner(InputStream is) {
        this(new BufferedReader(new InputStreamReader(is)));
    }

    public FastScanner(Reader reader) {
        br = new BufferedReader(reader);
    }

    public String next() throws IOException {
        if (!goToNextToken()) {
            return null;
        }
        return readString();
    }

    public int nextInt() throws IOException {
        return Integer.parseInt(next());
    }

    private boolean goToNextToken() throws IOException {
        if (br == null) {
            return false;
        }

        while (pos == line.length()) {
            line = br.readLine();

            if (line == null) {
                br = null;
                return true;
            }

            pos = 0;

            skipWhitespace();
        }

        return true;
    }

    private String readString() {
        int start = pos;

        while (pos < line.length()) {
            char c = line.charAt(pos);

            if (c == ' ' || c == '\t') {
                break;
            }

            pos++;
        }

        String result = line.substring(start, pos);

        skipWhitespace();

        return result;
    }

    private void skipWhitespace() {
        while (pos < line.length()) {
            char c = line.charAt(pos);

            if (c != ' ' && c != '\t') {
                break;
            }

            pos++;
        }
    }
}

