import java.io.OutputStream;
import java.io.FilenameFilter;
import java.util.Locale;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.FileInputStream;
import java.io.File;
import java.io.InputStream;
import java.io.PrintWriter;
import java.io.StringReader;
import java.io.IOException;
import java.io.Reader;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 *
 * @author Denis Nedelyaev
 */
public class Main {
    public static void main(String[] args) throws Exception {
        Locale.setDefault(Locale.US);
        final String regex = "D-(small|large).*[.]in";
        File directory = new File(".");
        File[] candidates = directory.listFiles(new FilenameFilter() {
            public boolean accept(File dir, String name) {
                return name.matches(regex);
            }
        });
        File toRun = null;
        for (File candidate : candidates) {
            if (toRun == null || candidate.lastModified() > toRun.lastModified())
                toRun = candidate;
        }
        InputStream inputStream = new FileInputStream(toRun);
        OutputStream outputStream = new FileOutputStream("d.out");
        FastScanner in = new FastScanner(inputStream);
        PrintWriter out = new PrintWriter(outputStream);
        TaskD solver = new TaskD(in, out);
        int testCount = Integer.parseInt(in.next());
        for (int i = 1; i <= testCount; i++)
            solver.solve(i);
        out.close();
    }

    static class TaskD {
        private final FastScanner in;
        private final PrintWriter out;

        public TaskD(FastScanner in, PrintWriter out) {
            this.in = in;
            this.out = out;
        }

        public void solve(int testNumber) throws IOException {
            int n = in.nextInt();
            boolean[][] can = new boolean[n][n];
            for (int i = 0; i < n; i++) {
                char[] row = in.next().toCharArray();
                for (int j = 0; j < n; j++) {
                    can[i][j] = row[j] == '1';
                }
            }
            out.println("Case #" + testNumber + ": " + realSolve(can));
        }

        private int realSolve(boolean[][] can) {
            int n = can.length;
            int ans = n * n;
            for (int set = 0; set < (1 << (n * n)); set++) {
                boolean[][] curCan = new boolean[n][n];
                int cost = 0;
                for (int i = 0; i < n; i++) {
                    for (int j = 0; j < n; j++) {
                        curCan[i][j] = can[i][j];
                        if (BitUtils.isSet(set, i * n + j)) {
                            curCan[i][j] = true;
                            if (!can[i][j]) {
                                cost++;
                            }
                        }
                    }
                }
                boolean[] used = new boolean[n];
                if (check(0, curCan, used)) {
                    ans = Math.min(ans, cost);
                }
            }
            return ans;
        }

        private boolean check(int workers, boolean[][] curCan, boolean[] used) {
            int n = curCan.length;
            if (workers == (1 << n) - 1) {
                return true;
            }
            for (int i = 0; i < n; i++) {
                if (!BitUtils.isSet(workers, i)) {
                    boolean ans = false;
                    for (int j = 0; j < n; j++) {
                        if (!used[j] && curCan[i][j]) {
                            used[j] = true;
                            if (!check(workers | (1 << i), curCan, used)) {
                                return false;
                            }
                            ans = true;
                            used[j] = false;
                        }
                    }
                    if (!ans) {
                        return false;
                    }
                }
            }
            return true;
        }

    }

    static class BitUtils {
        public static boolean isSet(long number, int index) {
            if (index < 0 || index > 62) {
                throw new IndexOutOfBoundsException();
            }
            return (number & (1L << index)) != 0;
        }

    }

    static class FastScanner {
        private final BufferedReader br;
        private String line;
        private int pos;

        public FastScanner(String s) throws IOException {
            this(new StringReader(s));
        }

        public FastScanner(InputStream is) throws IOException {
            this(new InputStreamReader(is, "UTF-8"));
        }

        public FastScanner(Reader reader) throws IOException {
            this(new BufferedReader(reader));
        }

        public FastScanner(BufferedReader reader) throws IOException {
            br = reader;
            line = br.readLine();
            pos = 0;
        }

        public String next() throws IOException {
            if (!skipWhitespace()) {
                return null;
            }

            int start = pos;

            while (pos < line.length()) {
                char c = line.charAt(pos);

                if (c == ' ' || c == '\t') {
                    break;
                }

                pos++;
            }

            return line.substring(start, pos);
        }

        public int nextInt() throws IOException {
            return Integer.parseInt(next());
        }

        private boolean skipWhitespace() throws IOException {
            while (line != null) {
                while (pos < line.length()) {
                    char c = line.charAt(pos);

                    if (c != ' ' && c != '\t') {
                        return true;
                    }

                    pos++;
                }

                line = br.readLine();
                pos = 0;
            }

            return false;
        }

    }
}

