import java.io.Reader;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.BufferedReader;
import java.io.FilenameFilter;
import java.util.Locale;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.IOException;
import java.io.FileOutputStream;
import java.io.File;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 * @author Denis Nedelyaev
 */
public class Main {
	public static void main(String[] args) throws Exception {
		Locale.setDefault(Locale.US);
		InputStream inputStream;
		final String regex = "C-(small|large).*[.]in";
		File directory = new File(".");
		File[] candidates = directory.listFiles(new FilenameFilter() {
			public boolean accept(File dir, String name) {
				return name.matches(regex);
			}
		});
		File toRun = null;
		for (File candidate : candidates) {
			if (toRun == null || candidate.lastModified() > toRun.lastModified())
				toRun = candidate;
		}
		inputStream = new FileInputStream(toRun);
		OutputStream outputStream = new FileOutputStream("c.out");
		FastScanner in = new FastScanner(inputStream);
		PrintWriter out = new PrintWriter(outputStream);
		TaskC solver = new TaskC(in, out);
		int testCount = Integer.parseInt(in.next());
		for (int i = 1; i <= testCount; i++)
			solver.solve(i);
		out.close();
	}
}

class TaskC {
    private final FastScanner in;
    private final PrintWriter out;
    public static final int I = 2;
    public static final int J = 3;
    public static final int K = 4;
    public static final byte[][] MUL = new byte[K + 1][K + 1];
    static {
        MUL[1][1] =  1; MUL[1][I] =  I; MUL[1][J] =  J; MUL[1][K] =  K;
        MUL[I][1] =  I; MUL[I][I] = -1; MUL[I][J] =  K; MUL[I][K] = -J;
        MUL[J][1] =  J; MUL[J][I] = -K; MUL[J][J] = -1; MUL[J][K] =  I;
        MUL[K][1] =  K; MUL[K][I] =  J; MUL[K][J] = -I; MUL[K][K] = -1;
    }

    public TaskC(FastScanner in, PrintWriter out) {
        this.in = in;
        this.out = out;
    }

    public void solve(int testNumber) throws IOException {
        out.println("Case #" + testNumber + ": " + (solve() ? "YES" : "NO"));
    }

    private boolean solve() throws IOException {
        int L = in.nextInt();
        int X = in.nextInt();
        String s = in.next();
        long n = L * X;

        int segmentP = 1;
        for (int i = 0; i < s.length(); i++) {
            segmentP = mul(segmentP, charVal(s.charAt(i)));
        }
        int totalP = 1;
        for (int i = 0; i < X % 4; i++) {
            totalP = mul(totalP, segmentP);
        }

        s = s + s + s + s;

        long iLen = n;
        int p = 1;
        for (int i = 0; i < s.length(); i++) {
            p = mul(p, charVal(s.charAt(i)));
            if (p == I) {
                iLen = i + 1;
                break;
            }
        }

        long kLen = n;
        p = 1;
        for (int i = s.length() - 1; i >= 0; i--) {
            p = mul(charVal(s.charAt(i)), p);
            if (p == K) {
                kLen = s.length() - i;
                break;
            }
        }

        return iLen + kLen < n && mul(I, mul(J, K)) == totalP;
    }

    private byte charVal(int c) {
        switch (c) {
            case 'i':
                return I;
            case 'j':
                return J;
            case 'k':
                return K;
        }
        throw new AssertionError();
    }

    private byte mul(int x, int y) {
        byte ans = MUL[Math.abs(x)][Math.abs(y)];
        if (x < 0) {
            ans *= -1;
        }
        if (y < 0) {
            ans *= -1;
        }
        return ans;
    }
}

class FastScanner {
    private BufferedReader br;
    private String line = "";
    private int pos;

    public FastScanner(InputStream is) {
        this(new BufferedReader(new InputStreamReader(is)));
    }

    public FastScanner(Reader reader) {
        br = new BufferedReader(reader);
    }

    public String next() throws IOException {
        if (!goToNextToken()) {
            return null;
        }
        return readString();
    }

    public int nextInt() throws IOException {
        if (!goToNextToken()) {
            return 0;
        }
        return readInt();
    }

    private boolean goToNextToken() throws IOException {
        if (br == null) {
            return false;
        }

        while (pos == line.length()) {
            line = br.readLine();

            if (line == null) {
                br = null;
                return true;
            }

            pos = 0;

            skipWhitespace();
        }

        return true;
    }

    private String readString() {
        int start = pos;

        while (pos < line.length()) {
            char c = line.charAt(pos);

            if (c == ' ' || c == '\t') {
                break;
            }

            pos++;
        }

        String result = line.substring(start, pos);

        skipWhitespace();

        return result;
    }

    private int readInt() {
        int result = 0;

        int sign = 1;
        if (line.charAt(pos) == '-') {
            sign = -1;

            pos++;
        }

        while (pos < line.length()) {
            char c = line.charAt(pos);

            if (c == ' ' || c == '\t') {
                break;
            }

            pos++;

            result *= 10;
            result += c - '0';
        }

        skipWhitespace();

        return sign * result;
    }

    private void skipWhitespace() {
        while (pos < line.length()) {
            char c = line.charAt(pos);

            if (c != ' ' && c != '\t') {
                break;
            }

            pos++;
        }
    }
}

