import java.io.FileInputStream;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class Main {

    static final String EXAMPLE_INPUT = "example.txt";
    static final String SMALL_INPUT = "A-small-attempt0.in";
    static final String LARGE_INPUT = "A-large.in";
    static final String OUTPUT = "output.txt";

    static final int X_WON = 1;
    static final int O_WON = 2;
    static final int DRAW = 3;
    static final int NOT_FINISHED = 4;

    static final int SIZE = 4;
    // rows + cols + diags
    static final int NUM_OF_LINES = SIZE * 2 + 2;

    public static void main(String[] args) throws Exception {
        startProcessing();
    }

    static void startProcessing() throws Exception {
        try(FileInputStream stream = new FileInputStream(LARGE_INPUT);
            Scanner scanner = new Scanner(stream);
            PrintWriter writer = new PrintWriter(OUTPUT))
        {
            int T = scanner.nextInt();
            for (int caseNum = 1; caseNum <= T; ++caseNum) {
                int caseRes = solveCase(scanner);
                String caseResult = null;
                switch (caseRes) {
                    case X_WON:
                        caseResult = "X won";
                        break;
                    case O_WON:
                        caseResult = "O won";
                        break;
                    case DRAW:
                        caseResult = "Draw";
                        break;
                    case NOT_FINISHED:
                        caseResult = "Game has not completed";
                        break;
                    default:
                        caseResult = "ERROR - DEFAULT!";
                }
                writer.println("Case #" + caseNum + ": " + caseResult);
            }
        }
    }

    static List<Integer> initLines() {
        List<Integer> lines = new ArrayList<>(NUM_OF_LINES);
        for (int line = 0; line < NUM_OF_LINES; ++line) {
            lines.add(0);
        }
        return lines;
    }

    static void increment(List<Integer> list, int index) {
        list.set(index, list.get(index) + 1);
    }

    static void addInputToLines(List<Integer> lines, int row, int col) {
        increment(lines, row);
        increment(lines, SIZE + col);
        int diagShift = getDiagShift(row, col);
        if (diagShift != -1) {
            increment(lines, SIZE * 2 + diagShift);
        }
    }

    static int solveCase(Scanner scanner) {
        List<Integer> XinLines = initLines();
        List<Integer> OinLines = initLines();
        boolean blanks = false;

        // read
        for (int row = 0; row < SIZE; ++row) {
            String strLine = scanner.nextLine();
            while (strLine.length() == 0) {
                strLine = scanner.nextLine();
            }
            for (int col = 0; col < SIZE; ++col) {
                switch (strLine.charAt(col)) {
                    case 'X':
                        addInputToLines(XinLines, row, col);
                        break;
                    case 'O':
                        addInputToLines(OinLines, row, col);
                        break;
                    case 'T':
                        addInputToLines(XinLines, row, col);
                        addInputToLines(OinLines, row, col);
                        break;
                    case '.':
                        blanks = true;
                        break;
                }
            }
        }

        //check
        for (Integer count : XinLines) {
            if (count == 4) {
                return X_WON;
            }
        }
        for (Integer count: OinLines) {
            if (count == 4) {
                return O_WON;
            }
        }
        if (blanks) {
            return NOT_FINISHED;
        }
        return DRAW;
    }

    static int getDiagShift(int row, int col) {
        if (row == col) {
            return 0;
        }
        if (row + col == 3) {
            return 1;
        }
        return -1;
    }


}
