import java.io.*;
import java.util.ArrayList;
import java.util.StringTokenizer;


public class D
{
	static String FILE_IN = "D-small-attempt2.in";
	static String FILE_OUT = "D.out";

	static int N;

	static ArrayList<Integer> resRows;
	static ArrayList<Integer> resCols;
	static ArrayList<Character> resChars;

	static ArrayList<Integer> curRows;
	static ArrayList<Integer> curCols;
	static ArrayList<Character> curChars;

	static void printGrid(char[][] grid)
	{
		for (char[] row : grid)
		{
			for (char ch : row)
				System.out.print(ch);
			System.out.println();
		}
	}

	static int score(char[][] grid)
	{
		int score = 0;
		for (char[] row : grid)
			for (char ch : row)
				score += ch == 'o' ? 2 :
						(ch == '+' || ch == 'x') ? 1 : 0;
		return score;
	}

	static boolean validGrid(char[][] grid)
	{
		for (int r = 0; r < N; r++)
			for (int c = 0; c < N; c++)
				if (!validate(grid, r, c))
					return false;
		return true;
	}

	static boolean validate(char[][] grid, int r, int c)
	{
		if (r == 0 && (!validCol(grid, c) || !validDiagDown(grid, r, c)))
			return false;
		if (c == 0 && (!validRow(grid, r) || !validDiagUp(grid, r, c) || !validDiagDown(grid, r, c)))
			return false;
		if (r == N - 1 && !validDiagUp(grid, r, c))
			return false;
		return true;
	}

	static boolean validCell(char[][] grid, int r, int c)
	{
		int diagUp = Math.min(N - r - 1, c);
		int diagDown = Math.min(r, c);
		return validRow(grid, r) && validCol(grid, c) &&
				validDiagUp(grid, r + diagUp, c - diagUp) &&
				validDiagDown(grid, r - diagDown, c - diagDown);
	}

	static boolean tryReplace(char[][] grid, int r, int c, char ch)
	{
		char save = grid[r][c];
		grid[r][c] = ch;
		if (validCell(grid, r, c))
		{
			curRows.add(r + 1);
			curCols.add(c + 1);
			curChars.add(ch);
			return true;
		}

		grid[r][c] = save;
		return false;
	}

	@SuppressWarnings("Duplicates")
	static boolean validRow(char[][] grid, int r)
	{
		boolean hasOther = false;
		for (int c = 0; c < N; c++)
			if (grid[r][c] == 'o' || grid[r][c] == 'x')
				if (hasOther)
					return false;
				else
					hasOther = true;
		return true;
	}

	@SuppressWarnings("Duplicates")
	static boolean validCol(char[][] grid, int c)
	{
		boolean hasOther = false;
		for (int r = 0; r < N; r++)
			if (grid[r][c] == 'o' || grid[r][c] == 'x')
				if (hasOther)
					return false;
				else
					hasOther = true;
		return true;
	}

	static boolean validDiagUp(char[][] grid, int r, int c)
	{
		boolean hasOther = false;
		for (; r >= 0 && c < N; r--, c++)
			if (grid[r][c] == 'o' || grid[r][c] == '+')
				if (hasOther)
					return false;
				else
					hasOther = true;
		return true;
	}

	static boolean validDiagDown(char[][] grid, int r, int c)
	{
		boolean hasOther = false;
		for (; r < N && c < N; r++, c++)
			if (grid[r][c] == 'o' || grid[r][c] == '+')
				if (hasOther)
					return false;
				else
					hasOther = true;
		return true;
	}

	static String solve(BufferedReader in) throws IOException
	{
		StringTokenizer st = new StringTokenizer(in.readLine());
		N = Integer.parseInt(st.nextToken());
		int M = Integer.parseInt(st.nextToken());

		char[][] grid = new char[N][N];
		for (int r = 0; r < N; r++)
			for (int c = 0; c < N; c++)
				grid[r][c] = '.';

		int[] rs = new int[M];
		int[] cs = new int[M];
		char ch;
		int r, c;
		for (int m = 0; m < M; m++)
		{
			st = new StringTokenizer(in.readLine());
			ch = st.nextToken().charAt(0);
			r = Integer.parseInt(st.nextToken()) - 1;
			c = Integer.parseInt(st.nextToken()) - 1;

			grid[r][c] = ch;

			rs[m] = r;
			cs[m] = c;
		}

		for (int m = 0; m < M; m++)
			if (grid[rs[m]][cs[m]] != 'o')
				tryReplace(grid, rs[m], cs[m], 'o');

		char[][] perms = {
				{'o', 'x', '+'},
				{'o', '+', 'x'},
				{'+', 'o', 'x'},
				{'+', 'x', 'o'},
				{'x', 'o', '+'},
				{'x', '+', 'o'}
		};

		int max = Integer.MIN_VALUE;
		int cur;
		for (char[] perm : perms)
		{
			curRows = new ArrayList<>();
			curCols = new ArrayList<>();
			curChars = new ArrayList<>();

			char[][] copy = grid.clone();
			for (int i = 0; i < copy.length; i++) {
				copy[i] = copy[i].clone();
			}

			for (char model : perm)
				for (c = 0; c < N; c++)
					for (r = 0; r < N; r++)
						if (copy[r][c] == '.')
							tryReplace(copy, r, c, model);

			if((cur = score(copy)) > max)
			{
				max = cur;
				resRows = new ArrayList<>(curRows);
				resCols = new ArrayList<>(curCols);
				resChars = new ArrayList<>(curChars);
			}
		}

		StringBuilder sb = new StringBuilder(String.format("%d %d", max, resChars.size()));

		for (int i = 0; i < resChars.size(); i++)
			sb.append(String.format("%n%c %d %d", resChars.get(i), resRows.get(i), resCols.get(i)));

		return sb.toString();
	}

	@SuppressWarnings("Duplicates")
	public static void main(String[] args) throws IOException
	{
		BufferedReader in = new BufferedReader
				(new FileReader("files/" + FILE_IN));
		PrintWriter out = new PrintWriter(new BufferedWriter
				(new FileWriter("files/" + FILE_OUT)));

		int T = Integer.parseInt(in.readLine());
		for (int t = 1; t <= T; t++)
		{
			String result = solve(in);
			System.out.printf("Case #%d: %s%n", t, result);
			out.printf("Case #%d: %s%n", t, result);
		}

		System.out.println("Complete");
		in.close();
		out.close();
	}
}
