import java.io.*;
import java.text.SimpleDateFormat;
import java.text.ParseException;
import java.util.*;

public class TrainCounter {
    private static final SimpleDateFormat timeFormat = new SimpleDateFormat("HH:mm");

    private int aTrains;
    private int bTrains;

    private int turnTime;
    private List<Date> aDepartures;
    private List<Date> bReadyTimes;
    private List<Date> bDepartures;
    private List<Date> aReadyTimes;


    public TrainCounter(BufferedReader reader) throws IOException {
        turnTime = Integer.parseInt(reader.readLine());
        String [] numbers = reader.readLine().split("\\s");
        int nA = Integer.parseInt(numbers[0]);
        int nB = Integer.parseInt(numbers[1]);
        aDepartures = new LinkedList();
        bReadyTimes = new LinkedList();
        bDepartures = new LinkedList();
        aReadyTimes = new LinkedList();
        loadTimeTable(nA, reader, aDepartures, bReadyTimes);
        loadTimeTable(nB, reader, bDepartures, aReadyTimes);

    }

    private void loadTimeTable(int n, BufferedReader reader, List depatureTimes, List shiftedTimes) throws IOException {
        for (int i = 0; i < n; i++) {
            String [] times = reader.readLine().split("\\s");
            try {
                Date date1 = timeFormat.parse(times[0]);
                depatureTimes.add(date1);
                Date date2 = timeFormat.parse(times[1]);
                Calendar c = Calendar.getInstance();
                c.setTime(date2);
                c.add(Calendar.MINUTE, turnTime);
                shiftedTimes.add(c.getTime());
            } catch (ParseException e) {
                e.printStackTrace();
            }

        }
    }

    private void calculate() {
        aTrains = countTrains(aDepartures, aReadyTimes);
        bTrains = countTrains(bDepartures, bReadyTimes);
    }

    private int countTrains(List<Date> departures, List<Date> readyTimes) {
        Collections.sort(departures);
        Collections.sort(readyTimes);
        int count = 0;
        for (Date departure : departures) {
            int index = Collections.binarySearch(readyTimes, departure);
            if (index == -1) {
                count++;
            } else {
                int usedTrain = index >= 0 ? index : -index - 2 ;
                readyTimes.remove(usedTrain);
            }

        }
        return count;
    }

    public static void main(String[] args) throws IOException {
        BufferedReader reader = new BufferedReader(new FileReader("data/B-large.in"));
        PrintWriter writer = new PrintWriter("data/B-large.out");
        try {
            int N = Integer.parseInt(reader.readLine());
            for (int i = 0; i < N; i++) {
                TrainCounter trainCounter = new TrainCounter(reader);
                trainCounter.calculate();
                writer.printf("Case #%d: %d %d\n",
                        i + 1, trainCounter.getATrains(), trainCounter.getBTrains());
            }
        } finally {
            try {
                reader.close();
            } catch (IOException e) {

            }
            writer.close();
        }

    }

    public int getATrains() {
        return aTrains;
    }

    public int getBTrains() {
        return bTrains;
    }
}
