package com.devrimtuncer.codejam;

import java.io.File;
import java.math.BigInteger;
import java.util.Calendar;

import com.devrimtuncer.utils.FileUtils;
import com.devrimtuncer.utils.FileUtils.FileReaderCallback;

public abstract class Question3 {
	
	public static void solve() {

		try {
			FileUtils.readFile(getLargeInputFile(), new FileReaderCallback() {
				int lineIndex = 0;
				int caseIndex = 0;
				Case currentCase;
				@Override
				public void onReadLine(String line) {
					if(lineIndex == 0) {
						int caseCount = Integer.parseInt(line.trim());
					} else {
						caseIndex ++;
						currentCase = new Case(caseIndex, line);
						currentCase.solve();
					} 
					lineIndex ++;
				}
			});
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	private static class Case {
		private String caseId;
		
		private int jamcoinCount;
		private int jamcoinLength;
		
		private String status = "";
		
		public Case(int index, String line) {
			this.caseId = "Case #" + index + ": ";
			String[] values = line.split(" ");
			jamcoinLength = Integer.parseInt(values[0]);
			jamcoinCount = Integer.parseInt(values[1]);
		}
		
		public void solve() {
			System.out.println(toString());
			long startTime = Calendar.getInstance().getTimeInMillis();
			int foundJamcoinCount = 0;
			BigInteger binary = new BigInteger("0", 2);
			BigInteger maxBinary = new BigInteger(getMaxBinaryString(jamcoinLength - 2), 2); // between 1 at start and 1 at end.
			
			while(maxBinary.compareTo(binary) >= 0) {
				String result = "";
				String divisorsForBases = "";
				
				String binaryStringValue = binary.toString(2);
				result = "1"+ fillZeros(binaryStringValue, jamcoinLength -2) + "1";

				boolean validJamcoin = true;
				for(int base = 2; base <= 10; base++) {
					BigInteger pow = BigInteger.valueOf(base);
					
					BigInteger initialVal = pow.pow(jamcoinLength - 1);
					initialVal = initialVal.add(BigInteger.ONE);
					
					BigInteger bigIntWithBase = new BigInteger(binary.toString(2), base);
					
					BigInteger additional = bigIntWithBase.multiply(pow);
					BigInteger total = initialVal.add(additional);
					
					BigInteger someDivider = getNontrivialDivisors(total);
					if(someDivider.compareTo(BigInteger.ZERO) == 0) {
						validJamcoin = false;
						
						break;
					}
					
					divisorsForBases += " " + someDivider;
				}
				
				
				
				if(validJamcoin) {
					
					System.out.println(result + divisorsForBases);
					
					foundJamcoinCount ++;
					if(foundJamcoinCount == jamcoinCount) {
						break;
					}
					
				} 
				
				binary = binary.add(BigInteger.ONE);
			}
			
			long endTime = Calendar.getInstance().getTimeInMillis();
			
			System.out.println((endTime - startTime) / 1000);
		}
		
		private String fillZeros(String text, int totalLength) {
			int currentLength = text.trim().length();
			for(int i = 0; i < totalLength - currentLength; i++) {
				text = "0" + text;
			}
			return text;
		}
		private static final BigInteger TWO = BigInteger.valueOf(2);
		
		private static final BigInteger LOOP_LIMIT = BigInteger.valueOf(1000);
		
		private BigInteger getNontrivialDivisors (BigInteger n) {
			if(n.compareTo(TWO) <= 0) {
				return BigInteger.ZERO;
			} else if (n.mod(TWO) == BigInteger.ZERO) {
				return n.divide(TWO);
			} else {
				for(BigInteger i = BigInteger.valueOf(3); i.multiply(i).compareTo(n) <= 0; i = i.add(TWO)) {
					if(i.compareTo(LOOP_LIMIT) > 0) {
						// Loop took too much time, try another assume this is has no divisors
						return BigInteger.ZERO;
					}
					if(n.mod(i).compareTo(BigInteger.ZERO) == 0) {
						return i;
					}
				}
			    
			}
		    return BigInteger.ZERO;
		}
		
		private static String getMaxBinaryString(int length) {
			String binaryString = "";
			for(int i = 0; i < length; i++) {
				binaryString += "1";
			}
			
			return binaryString;
		}
		
		@Override
		public String toString() {
			return this.caseId + status;
		}
	}
	
	private static String getTestInputFile() {
		String file = System.getProperty("user.dir") + File.separator + "src/resources/3/test_input.txt";
		return file;
	}
	
	private static String getSmallInputFile() {
		String file = System.getProperty("user.dir") + File.separator + "src/resources/3/C-small.in";
		return file;
	}
	
	private static String getLargeInputFile() {
		String file = System.getProperty("user.dir") + File.separator + "src/resources/3/C-large.in";
		return file;
	}

}
