package com.devrimtuncer.codejam;

import java.io.File;

import com.devrimtuncer.utils.FileUtils;
import com.devrimtuncer.utils.FileUtils.FileReaderCallback;

public abstract class Question2 {
	
	public static void solve() {

		try {
			FileUtils.readFile(getLargeInputFile(), new FileReaderCallback() {
				int lineIndex = 0;
				int caseIndex = 0;
				Case currentCase;
				@Override
				public void onReadLine(String line) {
					if(lineIndex == 0) {
						int caseCount = Integer.parseInt(line.trim());
					} else {
						caseIndex ++;
						currentCase = new Case(caseIndex, line);
						currentCase.solve();
						System.out.println(currentCase);
					} 
					lineIndex ++;
				}
			});
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	private static class Case {
		private static final boolean PRINT_STACK_ENABLED = false;
		private String caseId;
		
		private boolean hasAtLeastOnBlankPancake;
		private int pancakeCount;
		private boolean[] pancakes;
		
		private String status;
		
		public Case(int index, String line) {
			this.caseId = "Case #" + index + ": ";
			pancakes = getPancackes(line);
			pancakeCount = pancakes.length;
		}
		
		void flipPancakes(int flipIndex) {
			if(flipIndex == 0) {
				pancakes[flipIndex] = !pancakes[flipIndex];
			} else {
				int pancakeCountToBeFlipped = flipIndex + 1;
				
				int middleIndex = pancakeCountToBeFlipped / 2;
				int leap = pancakeCountToBeFlipped % 2;
				
				if (leap != 0) {
					pancakes[middleIndex] = !pancakes[middleIndex];
				}
				for(int i = 0; i < middleIndex; i ++) {
					boolean top = pancakes[i];
					boolean bottom = pancakes[flipIndex - i];
					
					pancakes[i] = !bottom;
					pancakes[flipIndex - i] = !top;
				}
			}
		}
		
		private int findPancakeIndexFromBottom(int bottomIndex, boolean pancakeValue) {
			for(int i = 0; i < bottomIndex; i ++) {
				if(pancakes[bottomIndex - i - 1] == pancakeValue) {
					return bottomIndex - i - 1;
				}
			}
			return -1;
		}
		
		public void solve() {
			int flipCount = 0;
			printStack();
			if(pancakeCount == 0 || !hasAtLeastOnBlankPancake) {
				// Nothing to flip
			} else if (pancakeCount == 1) {
				if(!pancakes[0]) {
					flipCount = 1;
					flipPancakes(0);
					printStack();
				}
			} else {
				while(true) {
					int flipBottomIndex = findPancakeIndexFromBottom(pancakeCount, false);
					if(flipBottomIndex == -1) {
						break;
					}
					if(!pancakes[0]) {
						// flipBottom -, top - : flip all from flipBottomIndex
						flipPancakes(flipBottomIndex);
					} else {
						// flipBottom -, top + : flip from "happy pancake" which is at the end of stack
						int index = findPancakeIndexFromBottom(flipBottomIndex, true);
						flipPancakes(index);
					}
					flipCount ++;
					printStack();
				}
			}
			
			status = String.valueOf(flipCount);
		}
		
		void printStack() {
			if(PRINT_STACK_ENABLED) {
				for (int i = 0; i < pancakes.length; i++) {
					System.out.print(pancakes[i]? "+" : "-");
				}
				System.out.println("");
			}
		}
		
		private boolean[] getPancackes(String line) {
			int lengthOfLine = line.length();
			boolean[] pancakes = new boolean[lengthOfLine];
			for(int i = 0; i < lengthOfLine; i++) {
				String pancakeAsSign = line.substring(i, i + 1);
				pancakes[i] = pancakeAsSign.equals("+");
				if(!pancakes[i]) {
					hasAtLeastOnBlankPancake = true;
				}
			}
			return pancakes;
		}
		
		@Override
		public String toString() {
			return this.caseId + status;
		}
	}
	
	private static String getTestInputFile() {
		String file = System.getProperty("user.dir") + File.separator + "src/resources/2/test_input.txt";
		return file;
	}
	
	private static String getSmallInputFile() {
		String file = System.getProperty("user.dir") + File.separator + "src/resources/2/B-small.in";
		return file;
	}
	
	private static String getLargeInputFile() {
		String file = System.getProperty("user.dir") + File.separator + "src/resources/2/B-large.in";
		return file;
	}

}
