package com.devrimtuncer.codejam;

import java.io.File;
import java.util.HashMap;

import com.devrimtuncer.utils.FileUtils;
import com.devrimtuncer.utils.FileUtils.FileReaderCallback;

public abstract class Question1 {
	
	public static void solve() {

		try {
			FileUtils.readFile(getSmallInputFile(), new FileReaderCallback() {
				int lineIndex = 0;
				int caseIndex = 0;
				Case currentCase;
				@Override
				public void onReadLine(String line) {
					if(lineIndex == 0) {
						int caseCount = Integer.parseInt(line.trim());
					} else {
						caseIndex ++;
						currentCase = new Case(caseIndex, line);
						currentCase.solve();
						System.out.println(currentCase);
					} 
					lineIndex ++;
				}
			});
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	private static class Case {
		private static final String INSOMNIA = "INSOMNIA";
		
		private String caseId;
		
		private int startNumber;
		private int lastNumber;
		
		private HashMap<Integer, Boolean> numberMap;
		
		private String status;
		
		public Case(int index, String line) {
			this.caseId = "Case #" + index + ": ";
			numberMap = new HashMap<Integer, Boolean>();
			startNumber = Integer.parseInt(line);
		}
		
		public void solve() {
			try {
				int prevNumber = -1;
				for(int i = 1; ; i++) {
					lastNumber = startNumber * i;
					
					if(i > 10 && i % 10 == 0) {
						// I have 0 from 123 * 10 so 123 * 2 = 123 * 20 = 123 * 200, or  123 * 3 = 123 * 30 = 123 * 300.
						continue;
					}
					
					if(lastNumber == prevNumber) {
						// Actually only 0 as startNumber can cause INSOMNIA, so this can be a "equals 0" check.
						status = INSOMNIA;
						break;
					}
					
					int[] numbers = getNumbers(lastNumber);
					
					for (int j : numbers) {
						numberMap.put(j, true);
					}
					
					if(numberMap.size() == 10) {
						status = String.valueOf(lastNumber);
						break;
					}
					
					prevNumber = lastNumber;
				}
			} catch(StackOverflowError t) {
				status = INSOMNIA;
			}
		}
		
		private int[] getNumbers(int currentNumber) {
			String str = String.valueOf(currentNumber);
			int lengthOfCurrentNumberStr = str.length();
			int[] numbers = new int[lengthOfCurrentNumberStr];
			for(int i = 0; i < lengthOfCurrentNumberStr; i++) {
				numbers[i] = Integer.parseInt(str.substring(i, i + 1));
			}
			return numbers;
		}
		
		@Override
		public String toString() {
			return this.caseId + status;
		}
	}
	
	private static String getTestInputFile() {
		String file = System.getProperty("user.dir") + File.separator + "src/resources/1/test_input.txt";
		return file;
	}
	
	private static String getSmallInputFile() {
		String file = System.getProperty("user.dir") + File.separator + "src/resources/1/A-small.in";
		return file;
	}
	
	private static String getLargeInputFile() {
		String file = System.getProperty("user.dir") + File.separator + "src/resources/1/A-large.in";
		return file;
	}

}
