package org.devrimtuncer;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class CodeJam2014_4 {

	private static final String SAMPLE_FILE = "sample";
	private static final String SMALL_FILE = "small-practice";
	private static final String LARGE_FILE = "large-practice";

	private static final String PATH = "/Users/devrimtuncer/CodeJam/2014/4/";

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			String caseFileName = SMALL_FILE; // Do not add '.in' type, it'll
												// be auto added

			List<Case> caseList = getCaseList(caseFileName);

			for (Case caseItem : caseList) {
				caseItem.solve();
			}

			writeToFile(caseFileName, caseList);// Do not add '.out' type, it'll
												// be auto added

		} catch (Throwable t) {
			t.printStackTrace();
		}
	}

	private static class Case {
		private int id;
		private String status;

		// TODO: add other fields for case specific
		private int blockCount;
		private Block[] naomiBlocks;
		private Block[] kenBlocks;

		public Case(int id) {
			this.id = id;
		}

		public void setBlocks(int blockCount, String naomi, String ken) {
			this.blockCount = blockCount;
			naomiBlocks = new Block[this.blockCount];
			kenBlocks = new Block[this.blockCount];

			String[] tempNaomiBlocksStr = naomi.split(" ");
			String[] tempKenBlocksStr = ken.split(" ");

			for (int i = 0; i < this.blockCount; i++) {
				naomiBlocks[i] = new Block(
						Double.parseDouble(tempNaomiBlocksStr[i]));
				kenBlocks[i] = new Block(
						Double.parseDouble(tempKenBlocksStr[i]));
			}

			Arrays.sort(naomiBlocks);
			Arrays.sort(kenBlocks);

		}

		private static class Block implements Comparable<Block> {
			private double weight;
			private boolean used = false;

			public Block(double weight) {
				this.weight = weight;
			}

			@Override
			public int compareTo(Block compare) {
				return this.weight > compare.weight ? 1 : -1;
			}

		}
		
		public void solve() {
			int naomiPoint = 0;
			int naomiPointAtDeceitful = 0;

			// Normal starts
			int posKenN = 0; 
			for (int i = 0; i < this.blockCount; i++) {
				boolean kenHasBetterBlock = false;

				// naomi spends her max values first
				double naomisValue = naomiBlocks[this.blockCount - i - 1].weight;
				
				for (int j = 0; j < blockCount; j++) {
					// ken tries to find the smallest value he has which is greater than noami's current value
					if (!kenBlocks[j].used && kenBlocks[j].weight > naomisValue) {
						kenBlocks[j].used = true;
						kenHasBetterBlock = true;

						break;
					}
					
				}

				if (!kenHasBetterBlock) {
					naomiPoint++;
					// if ken doesn't have a value which is greater than noami's current value, then he spends his smallest value he has.
					kenBlocks[posKenN].used = true;
					posKenN ++;
				}
			}
			// Normal ends
			
			// Deceitful starts
			naomiPointAtDeceitful = this.blockCount;
			
			int posKenD = 0; 
			for (int i = 0; i < this.blockCount; i++) {
				if(naomiBlocks[i].weight < kenBlocks[posKenD].weight) {
					// ken spent his max value for naomi's smaller value
					naomiPointAtDeceitful --;
				} else {
					// ken spent his min value for naomi's greater value
					posKenD ++;
				}
			}
	
			// Deceitful ends
			
			this.status = naomiPointAtDeceitful + " " + naomiPoint;
		}

		@Override
		public String toString() {
			return "Case #" + id + ": " + status;
		}
	}

	private static List<Case> getCaseList(String fileName) throws IOException {
		BufferedReader br = null;

		br = new BufferedReader(new FileReader(PATH + fileName + ".in"));

		int caseCount = Integer.parseInt(br.readLine());
		List<Case> caseList = new ArrayList<Case>(caseCount);

		int caseId = 1;

		String sCurrentLine = null;
		while ((sCurrentLine = br.readLine()) != null) {
			Case caseItem = new Case(caseId);

			// TODO: set values for case
			caseItem.setBlocks(Integer.parseInt(sCurrentLine), br.readLine(),
					br.readLine());

			caseId++;
			caseList.add(caseItem);
		}

		try {
			if (br != null)
				br.close();
		} catch (IOException ex) {
			// Ignore
		}

		return caseList;
	}

	public static void writeToFile(String fileName, List<Case> caseList)
			throws IOException {
		File file = new File(PATH + fileName + ".out");

		// if file doesnt exists, then create it
		if (!file.exists()) {
			file.createNewFile();
		}

		FileWriter fw = new FileWriter(file.getAbsoluteFile());
		BufferedWriter bw = new BufferedWriter(fw);

		for (Case caseItem : caseList) {
			bw.write(caseItem + "\n");
			
			//System.out.println(caseItem);
		}

		try {
			if (bw != null)
				bw.close();
		} catch (IOException ex) {
			ex.printStackTrace();
		}
	}
}
