/**
 * 
 */
package round.oneB;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

/**
 * @author Dhiraj Khot
 *
 */
public class CruiseControl {

	public static final String DIR = "/home/Dhiraj/Desktop/CodeJam/Round 1B/Cruise Control/";
	public static final String INPUT_FILE_NAME = "A-small-attempt0.in";
	public static final String OUTPUT_FILE_NAME = "A-small-attempt0.out";
	
	public static void main(String[] args) {

		try {
			PrintWriter writer = new PrintWriter(DIR + OUTPUT_FILE_NAME);
			List<CruiseControlTestCase> testCases = getTestCasesFromFile();
			int testCaseNumber = 1;
			for (CruiseControlTestCase testCase : testCases) {
				writer.println("Case #" + testCaseNumber + ": " + String.format("%.6f", getAnniesSpeed(testCase)));
				testCaseNumber++;
			}
			writer.close();
		} catch (FileNotFoundException e) {
			System.out.println("File writing issue");
		}
	}

	private static Double getAnniesSpeed(CruiseControlTestCase testCase) {
		Double distance = testCase.getDistance();
		List<List<Double>> horseDetails = testCase.getHorseDetails();
		Double maxTime = getMaxTimeForOtherHorses(horseDetails, distance);
		return distance/maxTime;
	}

	private static Double getMaxTimeForOtherHorses(List<List<Double>> horseDetails, Double distance2) {
		Double maxTime = Double.MIN_VALUE;
		for (List<Double> horseDetail : horseDetails) {
			Double distance = horseDetail.get(0);
			Double distanceToTraverse = distance2 - distance;
			Double speed = horseDetail.get(1);
			Double time = distanceToTraverse/speed;
			if (time.compareTo(maxTime) > 0)
				maxTime = time;
		}
		return maxTime;
	}

	private static List<CruiseControlTestCase> getTestCasesFromFile() {
		List<CruiseControlTestCase> testCases = new ArrayList<>();
		Scanner in;
		try {
			in = new Scanner(new File(DIR + INPUT_FILE_NAME));
			Integer numberOfTestCases = in.nextInt();
			for (int i = 0; i < numberOfTestCases; i++) {
				CruiseControlTestCase testCase = new CruiseControlTestCase();
				testCase.setDistance(in.nextDouble());
				testCase.setNumberOfHorses(in.nextInt());
				List<List<Double>> horseDetails = new ArrayList<>();
				for (int j = 0; j < testCase.getNumberOfHorses(); j++) {
					List<Double> horse = new ArrayList<>();
					horse.add(in.nextDouble());
					horse.add(in.nextDouble());
					horseDetails.add(horse);
				}
				testCase.setHorseDetails(horseDetails);
				testCases.add(testCase);
			}
			
		} catch (FileNotFoundException e) {
			System.out.println("File Reading issue.");
		}
		return testCases;
	}
	
}

class CruiseControlTestCase {
	
	private Double distance;
	private Integer numberOfHorses;
	private List<List<Double>> horseDetails;
	public Double getDistance() {
		return distance;
	}
	public void setDistance(Double distance) {
		this.distance = distance;
	}
	public Integer getNumberOfHorses() {
		return numberOfHorses;
	}
	public void setNumberOfHorses(Integer numberOfHorses) {
		this.numberOfHorses = numberOfHorses;
	}
	public List<List<Double>> getHorseDetails() {
		return horseDetails;
	}
	public void setHorseDetails(List<List<Double>> horseDetails) {
		this.horseDetails = horseDetails;
	}
	
	
}
