/**
 * 
 */
package round.qaulification;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

/**
 * @author Dhiraj Khot
 *
 */
public class FashionShow {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		
		Scanner in = new Scanner(new BufferedReader(new InputStreamReader(System.in)));
		int numberOfTestCases = in.nextInt();
		List<TestCase> inputTestCaseList = new ArrayList<>();
		for (int i = 0; i < numberOfTestCases; i++) {
			TestCase testCase = new TestCase();
			testCase.setGridSize(in.nextInt());
			testCase.setNumberOfPrePlacedModels(in.nextInt());
			List<ModelPosition> modelPositions = new ArrayList<>();
			if (testCase.getNumberOfPrePlacedModels() > 0) {
				for (int n = 0; n < testCase.getNumberOfPrePlacedModels(); n++) {
					ModelPosition modelPosition = new ModelPosition();
					modelPosition.setModelType(in.next().charAt(0));
					modelPosition.setRow(in.nextInt());
					modelPosition.setColumn(in.nextInt());
					modelPositions.add(modelPosition);
				}
			}
			testCase.setModelPositions(modelPositions);
			inputTestCaseList.add(testCase);
		}
		Integer testCaseNumber = 1;
		PrintWriter writer = null;
		try {
			writer = new PrintWriter("D-small-output.txt", "UTF-8");
			for (TestCase testCase : inputTestCaseList) {
			    writer.print("Case #" + testCaseNumber + ": ");
				findNewModelPositionsAndStyleScore(testCase, writer);
				testCaseNumber++;
			}
			writer.close();
		} catch(IOException e) {
			System.out.println("File writing issue");
		}
	}

	private static void findNewModelPositionsAndStyleScore(TestCase testCase, PrintWriter writer) {
		
		Integer gridSize = testCase.getGridSize();
		List<ModelPosition> modelPositions = testCase.getModelPositions();
		List<ModelPosition> newModelPositions = new ArrayList<>();
		Character [][] grid = new Character[gridSize][gridSize];
		prepareGrid(grid, gridSize, modelPositions);
		populateGridWithModels(grid, gridSize, newModelPositions);
		Integer score = computeScore(grid, gridSize);
		printOutPut(score, newModelPositions, writer);
		
	}

	private static void printOutPut(Integer score, List<ModelPosition> newModelPositions, PrintWriter writer) {
		
		writer.println(score + " " + newModelPositions.size());
		for (ModelPosition modelPosition : newModelPositions) {
			writer.println(modelPosition.getModelType() + " " + (modelPosition.getRow() + 1) + " " + (modelPosition.getColumn() + 1));
		}
		
	}

	private static Integer computeScore(Character[][] grid, Integer gridSize) {
		Integer score = 0;
		for (int i = 0; i < gridSize; i++) {
			for (int j = 0; j < gridSize; j++) {
				if (grid[i][j] == 'o')
					score = score + 2;
				else if (grid[i][j] == '+' || grid[i][j] == 'x')
					score = score + 1;
			}
		}
		return score;
	}

	private static void populateGridWithModels(Character[][] grid, Integer gridSize, List<ModelPosition> newModelPositions) {
		
		for (int i = 0; i < gridSize; i++) {
			for (int j = 0; j < gridSize; j++) {
				populateCell(grid, gridSize, i, j, newModelPositions);
			}
		}
		
	}

	private static void populateCell(Character[][] grid, Integer gridSize, int i, int j, List<ModelPosition> newModelPositions) {
		
		if (grid[i][j] == '.') {
			
			if (checkConditions(grid, gridSize, i, j, 'o')) {
				grid[i][j] = 'o';
				ModelPosition modelPosition = new ModelPosition();
				modelPosition.setModelType('o');
				modelPosition.setRow(i);
				modelPosition.setColumn(j);
				newModelPositions.add(modelPosition);
			}
			else if (checkConditions(grid, gridSize, i, j, 'x')) {
				grid[i][j] = 'x';
				ModelPosition modelPosition = new ModelPosition();
				modelPosition.setModelType('x');
				modelPosition.setRow(i);
				modelPosition.setColumn(j);
				newModelPositions.add(modelPosition);
			}
			else if (checkConditions(grid, gridSize, i, j, '+')) {
				grid[i][j] = '+';
				ModelPosition modelPosition = new ModelPosition();
				modelPosition.setModelType('+');
				modelPosition.setRow(i);
				modelPosition.setColumn(j);
				newModelPositions.add(modelPosition);
			}
			
		} else if (grid[i][j] == '+' || grid[i][j] == 'x') {
			if (checkConditions(grid, gridSize, i, j, 'o')) {
				grid[i][j] = 'o';
				ModelPosition modelPosition = new ModelPosition();
				modelPosition.setModelType('o');
				modelPosition.setRow(i);
				modelPosition.setColumn(j);
				newModelPositions.add(modelPosition);
			}
		}
		
	}

	private static boolean checkConditions(Character[][] grid, Integer gridSize, int i, int j, Character value) {
		if (rowChecker(grid, gridSize, i, j, value) && columnChecker(grid, gridSize, i, j, value) && diagonalChecker(grid, gridSize, i, j, value))
			return true;
		return false;
	}

	private static void prepareGrid(Character[][] grid, Integer gridSize,
			List<ModelPosition> modelPositions) {
		
		for (int i = 0; i < gridSize; i++) {
			for (int j = 0; j < gridSize; j++) {
				grid[i][j] = '.';
			}
		}
		for (ModelPosition modelPosition : modelPositions) {
			Integer row = modelPosition.getRow() - 1;
			Integer column = modelPosition.getColumn() - 1;
			Character value = modelPosition.getModelType();
			grid[row][column] = value;
		}
		
	}

	private static boolean rowChecker(Character[][] grid, Integer gridSize, int row, int column, Character value) {
		boolean isValid = true;
		if (value.equals(Character.valueOf('+'))) {
			return true;
		}
		int i = 0;
		while (i < gridSize) {
			if (i == row || grid[i][column] == Character.valueOf('.')) {
				i++;
				continue;
			}
			if (grid[i][column] != Character.valueOf('+')) {
				return false;
			}
			i++;
		}
		return isValid;
	}
	
	private static boolean columnChecker(Character[][] grid, Integer gridSize, int row, int column, Character value) {
		boolean isValid = true;
		if (value.equals(Character.valueOf('+'))) {
			return true;
		}
		int i = 0;
		while (i < gridSize) {
			if (i == column || grid[row][i] == Character.valueOf('.')) {
				i++;
				continue;
			}
			if (grid[row][i] != Character.valueOf('+')) {
				return false;
			}
			i++;
		}
		return isValid;
	}
	
	private static boolean diagonalChecker(Character[][] grid, Integer gridSize, int row, int column, Character value) {
		boolean isValid = true;
		if (value.equals(Character.valueOf('x'))) {
			return true;
		}
		int sum = row + column;
		int difference = row - column;
		for (int i = 0; i < gridSize; i++) {
			for (int j = 0; j < gridSize; j++) {
				if ((i == row && j == column) || grid[i][j] == Character.valueOf('.'))
					continue;
				if ((sum == i + j || difference == i - j) && grid[i][j] != Character.valueOf('x')) {
					return false;
				}
			}
		}
		return isValid;
		
	}

}

class TestCase {
	private Integer gridSize;
	private Integer numberOfPrePlacedModels;
	private List<ModelPosition> modelPositions;
	
	public Integer getGridSize() {
		return gridSize;
	}
	public void setGridSize(Integer gridSize) {
		this.gridSize = gridSize;
	}
	public Integer getNumberOfPrePlacedModels() {
		return numberOfPrePlacedModels;
	}
	public void setNumberOfPrePlacedModels(Integer numberOfPrePlacedModels) {
		this.numberOfPrePlacedModels = numberOfPrePlacedModels;
	}
	public List<ModelPosition> getModelPositions() {
		return modelPositions;
	}
	public void setModelPositions(List<ModelPosition> modelPositions) {
		this.modelPositions = modelPositions;
	}
	
	
}

class ModelPosition {
	private Character modelType;
	private Integer row;
	private Integer column;
	
	public Character getModelType() {
		return modelType;
	}
	public void setModelType(Character modelType) {
		this.modelType = modelType;
	}
	public Integer getRow() {
		return row;
	}
	public void setRow(Integer row) {
		this.row = row;
	}
	public Integer getColumn() {
		return column;
	}
	public void setColumn(Integer column) {
		this.column = column;
	}
	
}