package codejam.comp2013.qualification.b;

import codejam.comp2013.Folders;
import common.FileUtil;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Dzmitry Horbach
 */
public class BSolver {

    public static void solve(String fileName) throws IOException {
        List<BCase> cases = extractCases(fileName);
        List<String> results = new ArrayList<>();
        for (BCase caze : cases) {
            String result = caze.solve();
            results.add(result);
        }
        FileUtil.writeFile(Folders.F_2013_QUALI_B_R + "b-output.txt", results);
    }

    public static List<BCase> extractCases(String fileName) throws IOException {
        List<BCase> cases = new ArrayList<>();
        List<String> lines = FileUtil.readFile(fileName);
        int numCases = Integer.valueOf(lines.get(0));
        int pointer = 0;
        for (int c = 0; c < numCases; c++) {
            pointer += 1;

            String[] dims = lines.get(pointer).split(" ");
            int N = Integer.valueOf(dims[0]);
            int M = Integer.valueOf(dims[1]);
            BCase caze = new BCase(N, M);
            cases.add(caze);
            for (int i = 0; i < N; i++) {
                pointer += 1;
                String[] values = lines.get(pointer).split(" ");
                for (int j = 0; j < M; j++) {
                    caze.set(i, j, Integer.valueOf(values[j]));
                }
            }
        }
        return cases;
    }
}

class BCase {
    int N;
    int M;
    int[][] matrix;
    int largest = 1;

    private static int caseGenerator = 0;
    private final int caseNumber;

    public BCase(int N, int M) {
        matrix = new int[N][M];
        this.N = N;
        this.M = M;
        caseNumber = ++caseGenerator;
    }

    public void set(int i, int j, int value) {
        matrix[i][j] = value;
        if (value > largest) {
            largest = value;
        }
    }

    public String solve() {
        for (int c = 1; c < largest; c++) {
            boolean[][] checked = new boolean[N][M];

            for (int i = 0; i < N; i++) {
                if (matrix[i][0] == c) {

                    boolean allSame = true;
                    for (int j = 1; j < M; j++) {
                        if (matrix[i][j] != c) {
                            allSame = false;
                            break;
                        }
                    }
                    if (allSame) {
                        for (int j = 0; j < M; j++) {
                            checked[i][j] = true;
                        }
                    }
                }
            }

            for (int j = 0; j < M; j++) {
                if (matrix[0][j] == c) {

                    boolean allSame = true;
                    for (int i = 1; i < N; i++) {
                        if (matrix[i][j] != c && !checked[i][j]) {
                            allSame = false;
                            break;
                        }
                    }
                    if (allSame) {
                        for (int i = 0; i < N; i++) {
                            checked[i][j] = true;
                        }
                    }
                }
            }

            for (int i = 0; i < N; i++) {
                for (int j = 0; j < M; j++) {
                    if (checked[i][j]) {
                        matrix[i][j] += 1;
                    }
                }
            }


        }

        for (int i = 0; i < N; i++) {
            for (int j = 0; j < M; j++) {
                if (matrix[i][j] != largest) {
                    return "Case #" + caseNumber + ": NO";
                }
            }
        }
        return "Case #" + caseNumber + ": YES";

    }
}

