package common;

import org.apache.commons.lang3.ArrayUtils;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @author Dzmitry Horbach
 */
public class FactorUtil {

    public static final int[] getPrimeFactorsTrialDivision(int number){
        if(number == 1) return new int[]{1};

        int original = number;

        int[] primes = PrimeUtil.getPrimeSieve((number / 2 + 1));
        Set<Integer> primeFactors = new HashSet<>();

        for(int prime : primes){
            if(prime * prime > number) break;
            while(number % prime == 0){
                primeFactors.add(prime);
                number /= prime;
            }
        }

        if(number > 1) primeFactors.add(number);

        return ArrayUtils.toPrimitive(primeFactors.toArray(new Integer[primeFactors.size()]));
    }

    public static final int[] getFactorsBruteForce(int number){
        List<Integer> factors = new ArrayList<>();
        for(int i = 1; i < number; i++){
            if(number % i == 0){
                factors.add(i);
            }
        }
        return ArrayUtils.toPrimitive(factors.toArray(new Integer[factors.size()]));
    }


    public static final int[] getFactorsSqrt(int number){
        Set<Integer> factors = new HashSet<>();
        factors.add(1);
        for(int i = 2; i < (((int) Math.sqrt(number)) + 1); i++){
            if(number % i == 0){
                factors.add(i);
                factors.add(number / i);
            }
        }

        return ArrayUtils.toPrimitive(factors.toArray(new Integer[factors.size()]));
    }


}
