
package stableneighbours;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Arrays;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import javax.swing.JFileChooser;


public class StableNeighbours {
	
	private static final File outputsFolder = new File("output");
	
	public static void main(String[] args) {
		JFileChooser fileChooser = new JFileChooser("inputs/");
		fileChooser.setMultiSelectionEnabled(false);
		
		if (fileChooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION) {
			File inputFile = fileChooser.getSelectedFile();

			if (!outputsFolder.exists()) {
				outputsFolder.mkdir();
			}

			//Rewrite Old Output
			File outFile = new File(outputsFolder, inputFile.getName().replace("in", "out"));
			if (outFile.exists()) {
				outFile.delete();
			}

			try (BufferedReader reader = new BufferedReader(new FileReader(inputFile));
					BufferedWriter writer = new BufferedWriter(new FileWriter(outFile))) {
				int testcases = Integer.parseInt(reader.readLine());

				for (int i = 1; i <= testcases; i++) {
					System.out.println(String.format("@Case #%d of %d", i, testcases));
					String[] split = reader.readLine().split(" ");
					int unicorns = Integer.parseInt(split[0]);
					int red = Integer.parseInt(split[1]);
					int orange = Integer.parseInt(split[2]);
					int yellow = Integer.parseInt(split[3]);
					int green = Integer.parseInt(split[4]);
					int blue = Integer.parseInt(split[5]);
					int violet = Integer.parseInt(split[6]);
					
					writer.write("Case #" + i + ": " + process(unicorns, red, orange, yellow, green, blue, violet) + "\n");
				}
			} catch (FileNotFoundException ex) {
				ex.printStackTrace();
			} catch (IOException ex) {
				ex.printStackTrace();
			}
		} else {
			System.out.println("NO FILE SELECTED!");
		}
		
		System.out.println("DONE!");
	}

	private static String process(int unicorns, int red, int orange, int yellow, int green, int blue, int violet) {
		Unicorn[] stable = new Unicorn[unicorns];
		List<Unicorn> allUnicorns = Stream.of(new Unicorn(red, Color.RED),
				new Unicorn(orange, Color.ORANGE),
				new Unicorn(yellow, Color.YELLOW),
				new Unicorn(green, Color.GREEN),
				new Unicorn(blue, Color.BLUE),
				new Unicorn(violet, Color.VIOLET))
				.sorted((u1, u2) -> u2.getCount() - u1.getCount())
				.filter(Unicorn::exists)
				.collect(Collectors.toList());

		if (red * 2 > unicorns || yellow * 2 > unicorns || blue * 2 > unicorns) {
			return "IMPOSSIBLE";
		}
		
		int i = 0;
		while (!allUnicorns.isEmpty()) {
			Unicorn unicorn = allUnicorns.get(0);

			if (stable[i] == null) {
				if (unicorns == 1) {
					stable[i] = unicorn.place();
					unicorns--;
				} else {
					while (true) {
						i++;
						if (i >= stable.length) {
							i = 0;
						}

						if (stable[i] == null) {
							stable[i] = unicorn.place();
							unicorns--;
							break;
						}

					}
				}

				if (!unicorn.exists()) {
					allUnicorns.remove(unicorn);
				}
			}

			i++;
			if (i >= stable.length) {
				i = 0;
			}
		}
		
		return Arrays.stream(stable).map(Unicorn::getColor).collect(Collectors.joining());
	}

	public static class Unicorn {
		int count;
		Color color;

		public Unicorn(int count, Color color) {
			this.count = count;
			this.color = color;
		}

		public int getCount() {
			return count;
		}

		public Unicorn place() {
			count = count - 1;
			return this;
		}
		
		public boolean exists() {
			return count > 0;
		}

		public String getColor() {
			return String.valueOf(color.name().charAt(0));
		}
	}
	
	public static enum Color {
		RED,
		ORANGE,
		YELLOW,
		GREEN,
		BLUE,
		VIOLET;
	}
}
