
package bathroomstalls;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.swing.JFileChooser;


public class BathroomStalls {

	private static final File outputsFolder = new File("output");
	
	public static void main(String[] args) {
		JFileChooser fileChooser = new JFileChooser("inputs/");
		fileChooser.setMultiSelectionEnabled(false);
		
		if (fileChooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION) {
			File inputFile = fileChooser.getSelectedFile();

			if (!outputsFolder.exists()) {
				outputsFolder.mkdir();
			}

			//Rewrite Old Output
			File outFile = new File(outputsFolder, inputFile.getName().replace("in", "out"));
			if (outFile.exists()) {
				outFile.delete();
			}

			try (BufferedReader reader = new BufferedReader(new FileReader(inputFile));
					BufferedWriter writer = new BufferedWriter(new FileWriter(outFile))) {
				int testcases = Integer.parseInt(reader.readLine());

				for (int i = 1; i <= testcases; i++) {
					System.out.println(String.format("@Case #%d of %d", i, testcases));
					writer.write("Case #" + i + ": " + process(reader.readLine()) + "\n");
				}
			} catch (FileNotFoundException ex) {
				ex.printStackTrace();
			} catch (IOException ex) {
				ex.printStackTrace();
			}
		} else {
			System.out.println("NO FILE SELECTED!");
		}
		
		System.out.println("DONE!");
	}

	private static String process(String line) {
		String[] split = line.split(" ");
		int bathroomSize = Integer.parseInt(split[0]);
		int ppl = Integer.parseInt(split[1]);
		List<Stall[]> substalls = new ArrayList<>();
		
		substalls.add(createBathroom(bathroomSize));
		
		return processStalls(substalls, ppl);
	}
	
	private static String processStalls(List<Stall[]> stalls, int pplLeft) {
		if (pplLeft == 1) {
			
			int maxLen = 0;
			Stall[] choice = new Stall[0];
			for (Stall[] stall : stalls) {
				if (stall.length > maxLen) {
					maxLen = stall.length;
					choice = stall;
				}
			}
			
			Stall optimal = findOptimal(choice);
			return optimal.right + " " + optimal.left;
		}
		
		stalls.sort((s1, s2) -> s2.length - s1.length);
		
		Stall[] biggest = stalls.remove(0);
		Stall optimal = findOptimal(biggest);
		stalls.add(createBathroom(optimal.left));
		stalls.add(createBathroom(optimal.right));
		
		return processStalls(stalls, pplLeft - 1);
	}
	
	private static Stall findOptimal(Stall[] stalls) {
		if (stalls.length == 1) {
			return stalls[0];
		} 
		
		if (stalls.length % 2 == 0) { //even
			return stalls[stalls.length / 2 - 1];
		} else { //odd
			return stalls[stalls.length / 2];
		} 
	}
	
	private static Stall[] createBathroom(int size) {
		Stall[] stalls = new Stall[size];
		
		for (int i = 0; i < size; i++) {
			stalls[i] = new Stall(i, size - 1 - i);
		}
		
		return stalls;
	}
	
	private static class Stall {
		int left;
		int right; 

		public Stall(int left, int right) {
			this.left = left;
			this.right = right;
		}
	}
}
