
package bathroomstalls;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import javax.swing.JFileChooser;


public class BathroomStalls2 {

	private static final File outputsFolder = new File("output");
	
	public static void main(String[] args) {
		JFileChooser fileChooser = new JFileChooser("inputs/");
		fileChooser.setMultiSelectionEnabled(false);
		
		if (fileChooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION) {
			File inputFile = fileChooser.getSelectedFile();

			if (!outputsFolder.exists()) {
				outputsFolder.mkdir();
			}

			//Rewrite Old Output
			File outFile = new File(outputsFolder, inputFile.getName().replace("in", "out"));
			if (outFile.exists()) {
				outFile.delete();
			}

			try (BufferedReader reader = new BufferedReader(new FileReader(inputFile));
					BufferedWriter writer = new BufferedWriter(new FileWriter(outFile))) {
				int testcases = Integer.parseInt(reader.readLine());

				for (int i = 1; i <= testcases; i++) {
					System.out.println(String.format("@Case #%d of %d", i, testcases));
					writer.write("Case #" + i + ": " + process(reader.readLine()) + "\n");
				}
			} catch (FileNotFoundException ex) {
				ex.printStackTrace();
			} catch (IOException ex) {
				ex.printStackTrace();
			}
		} else {
			System.out.println("NO FILE SELECTED!");
		}
		
		System.out.println("DONE!");
	}

	private static String process(String line) {
		String[] split = line.split(" ");
		int bathroomSize = Integer.parseInt(split[0]);
		int ppl = Integer.parseInt(split[1]);
		
		// Size / Count
		Map<Integer, Integer> substalls = new HashMap<>();
		substalls.put(bathroomSize, 1);
		
		while (ppl > 0) {
//			System.out.println("People Left: " + ppl);
			
			int longestSection = substalls.keySet().stream().max(Integer::compare).get();
			Integer count = substalls.get(longestSection);
			
			if (count == 1) {
				substalls.remove(longestSection);
			} else {
				substalls.put(longestSection, count - 1);
			}
		
			if (ppl == 1) {
				if (longestSection == 1) {
					return "0 0"; // a spot between to taken spots was taken
				} else {
					if (longestSection % 2 == 0) { //even
						int left = longestSection / 2 - 1;
						int right = longestSection / 2;
						return right + " " + left;
					} else { //odd
						int halves = longestSection / 2;
						return halves + " " + halves;
					}
				}
			} else {
				if (longestSection > 1) {
					if (longestSection % 2 == 0) { //even
						int left = longestSection / 2 - 1;
						int right = longestSection / 2;
						substalls.put(left, substalls.getOrDefault(left, 0) + 1);
						substalls.put(right, substalls.getOrDefault(right, 0) + 1);		
					} else { //odd
						int halves = longestSection / 2;
						substalls.put(halves, substalls.getOrDefault(halves, 0) + 2);

					}
				}
			}
			
			ppl--;
		}
		
		return "SOMETHING WENT VERY WRONG";
	}
	
	private static int[] optimalSectionSplit(int sectionSize) {
        if (sectionSize == 1) {
			return new int[]{0};
		}

		if (sectionSize % 2 == 0) { //even
			return new int[]{sectionSize / 2 - 1, sectionSize / 2};
		} else { //odd
			return new int[]{sectionSize / 2, sectionSize / 2};
		}
	}
}
