
package rattattoille;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import javax.swing.JFileChooser;


public class Rattattoille {

	private static final File outputsFolder = new File("output");
	
	public static void main(String[] args) {
		JFileChooser fileChooser = new JFileChooser("inputs/");
		fileChooser.setMultiSelectionEnabled(false);
		
		if (fileChooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION) {
			File inputFile = fileChooser.getSelectedFile();

			if (!outputsFolder.exists()) {
				outputsFolder.mkdir();
			}

			//Rewrite Old Output
			File outFile = new File(outputsFolder, inputFile.getName().replace("in", "out"));
			if (outFile.exists()) {
				outFile.delete();
			}

			try (BufferedReader reader = new BufferedReader(new FileReader(inputFile));
					BufferedWriter writer = new BufferedWriter(new FileWriter(outFile))) {
				int testcases = Integer.parseInt(reader.readLine());

				for (int i = 1; i <= testcases; i++) {
					System.out.println(String.format("@Case #%d of %d", i, testcases));
					String line = reader.readLine();
					String[] split = line.split(" ");
					int totalIngredients = Integer.parseInt(split[0]);
					int totalPacks = Integer.parseInt(split[1]);
					
					List<Ingredient> ingredients = Arrays.stream(reader.readLine().split(" "))
							.map(Integer::parseInt)
							.map(Ingredient::new)
							.collect(Collectors.toList());

					for (Ingredient ingredient : ingredients) {
						List<Integer> packs = Arrays.stream(reader.readLine().split(" "))
								.map(Integer::parseInt)
								.filter(pack -> ingredient.accept(pack))
								.collect(Collectors.toList());
						
						ingredient.setPackages(packs);
					}
					
					writer.write("Case #" + i + ": " + process(ingredients, totalIngredients, totalPacks) + "\n");
				}
			} catch (FileNotFoundException ex) {
				ex.printStackTrace();
			} catch (IOException ex) {
				ex.printStackTrace();
			}
		} else {
			System.out.println("NO FILE SELECTED!");
		}
		
		System.out.println("DONE!");
	}

	private static int process(List<Ingredient> ingredients, int totalIngredients, int totalPacks) {
		int max = totalPacks;
		
		for (Ingredient ingredient : ingredients) {
			if (ingredient.packages.size() < max) {
				max = ingredient.packages.size();
			}
		}
		
		return max;
	}

	private static class Ingredient {
		
		private int gRequired;
		private int mingReq;
		private int maxgReq;
		
		List<Integer> packages = new ArrayList<>();

		public Ingredient(int gReq) {
			this.gRequired = gReq;
			this.mingReq = (int) (gReq * 0.9);
			this.maxgReq = (int) (gReq * 1.1);
		}

		public void setPackages(List<Integer> packages) {
			this.packages = packages;
		}
		
		public boolean accept(int weight) {
			if (weight < mingReq) {
				return false;
			} else if (weight > maxgReq && weight % maxgReq == 0) {
				return true;
			} 
			
			double ratio = (double) weight / (double) gRequired;
			return ratio >= 0.9 && ratio <= 1.1;
		}
	}
}
