
package tidynumbers;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import javax.swing.JFileChooser;

public class TidyNumbers {

	private static final File outputsFolder = new File("output");
	
	public static void main(String[] args) {
		JFileChooser fileChooser = new JFileChooser("inputs/");
		fileChooser.setMultiSelectionEnabled(false);
		
		if (fileChooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION) {
			File inputFile = fileChooser.getSelectedFile();

			if (!outputsFolder.exists()) {
				outputsFolder.mkdir();
			}

			//Rewrite Old Output
			File outFile = new File(outputsFolder, inputFile.getName().replace("in", "out"));
			if (outFile.exists()) {
				outFile.delete();
			}

			try (BufferedReader reader = new BufferedReader(new FileReader(inputFile));
					BufferedWriter writer = new BufferedWriter(new FileWriter(outFile))) {
				int testcases = Integer.parseInt(reader.readLine());

				for (int i = 1; i <= testcases; i++) {
					System.out.println(String.format("@Case #%d of %d", i, testcases));
					writer.write("Case #" + i + ": " + process(Integer.parseInt(reader.readLine())) + "\n");
				}
			} catch (FileNotFoundException ex) {
				ex.printStackTrace();
			} catch (IOException ex) {
				ex.printStackTrace();
			}
		} else {
			System.out.println("NO FILE SELECTED!");
		}
		
		System.out.println("DONE!");
	}

	private static int process(int max) {
		if (isTidy(max)) {
			return max;
		}

		int number = (max / 10) * 10 - 1;
		if (isTidy(number)) {
			return number;
		}
		
		return process(number / 10) * 10 + number % 10;
	}

	
	private static boolean isTidy(int number) {
		int n = number / 10;
		int prevDigit = number % 10;

		while (n != 0) {
			int newPrevDigit = n % 10;
			if (prevDigit < newPrevDigit) {
				return false;
			}

			prevDigit = newPrevDigit;
			n /= 10;
		}
		
		return true;
	}
}
