import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;


public class Portal {
    public static void main(String[] args) throws Exception {
        BufferedReader reader = new BufferedReader(new FileReader("input.txt"));
        BufferedWriter writer = new BufferedWriter(new FileWriter("output.txt"));
        
        int numtests = Integer.parseInt(reader.readLine());
        for (int testnum = 1; testnum <= numtests; testnum++) {
            int R,C;
            String[] sp = reader.readLine().split(" ");
            R = Integer.parseInt(sp[0]);
            C = Integer.parseInt(sp[1]);
            
            char[][] map = new char[R+2][C+2];
            for (int i = 0; i < R+2; i++) {
                for (int j = 0; j < C+2; j++) {
                    map[i][j] = '#';
                }
            }
            
            for (int r = 0; r < R; r++) {
                String row = reader.readLine();
                for (int c = 0; c < C; c++) {
                    map[r+1][c+1] = row.charAt(c);
                }
            }
            
            int[][] nearwall = new int[R+2][C+2];
            for (int r = 1; r < R+1; r++) {
                for (int c = 1; c < C+1; c++) {
                    if (map[r][c] != '#' &&
                                (
                                    map[r-1][c]=='#' ||
                                    map[r+1][c]=='#' ||
                                    map[r][c-1]=='#' ||
                                    map[r][c+1]=='#'
                                )) {
                        nearwall[r][c] = 1;
                    }
                }
            }
            
            int[][][][] posout = new int[R+2][C+2][4][2];
            for (int r = 1; r <= R; r++) {
                for (int c = 1; c <= C; c++) {
                    if (map[r][c]=='#') {
                        posout[r][c][0][0] = -1;
                    } else {
                        // up
                        int rr = r;
                        while (map[rr-1][c]!='#') {
                            rr--;
                        }
                        posout[r][c][0][0] = rr;
                        posout[r][c][0][1] = c;
                        
                        // down
                        rr = r;
                        while (map[rr+1][c]!='#') {
                            rr++;
                        }
                        posout[r][c][1][0] = rr;
                        posout[r][c][1][1] = c;
                        
                        // left
                        int cc = c;
                        while (map[r][cc-1]!='#') {
                            cc--;
                        }
                        posout[r][c][2][0] = r;
                        posout[r][c][2][1] = cc;
                        
                        // right
                        cc = c;
                        while (map[r][cc+1]!='#') {
                            cc++;
                        }
                        posout[r][c][3][0] = r;
                        posout[r][c][3][1] = cc;
                    }
                }
            } // end calculating posout
            
            List<int[]> Q = new LinkedList<int[]>();
            int[][][][] solved = new int[R+2][C+2][R+2][C+2];
            for (int i = 0; i < R+2; i++) {
                for (int j = 0; j < C+2; j++) {
                    for (int ii = 0; ii < R+2; ii++) {
                        for (int jj = 0; jj < C+2; jj++) {
                            solved[i][j][ii][jj] = -1;
                        }
                    }
                }
            }
            int[][][][] tried = new int[R+2][C+2][R+2][C+2];
            
            int sx = -1;
            int sy = -1;
            int ex = -1;
            int ey = -1;
            
            for (int i = 1; i <= R; i++) {
                for (int j = 1; j <= C; j++) {
                    if (map[i][j] == 'O') {
                        sx = i;
                        sy = j;
                    }
                    if (map[i][j] == 'X') {
                        ex = i;
                        ey = j;
                    }
                }
            }
            
            //System.out.println(sx + " " + sy + " " + ex + " " + ey + "\n");
            
            // get any portal position
            int px,py;
            px = posout[sx][sy][0][0];
            py = posout[sx][sy][0][1];
            
            solved[sx][sy][px][py] = 0;
            tried[sx][sy][px][py] = 1;
            Q.add(new int[] {sx,sy,px,py,0});
            
            int ans = 1000000;
            while (true) {
                if (Q.size() == 0) {
                    break;
                }
                
                int[] head = Q.get(0);
                Q.remove(0);
                
                int curx = head[0];
                int cury = head[1];
                int curpx = head[2];
                int curpy = head[3];
                int curd = solved[curx][cury][curpx][curpy];
                if (curx == ex && cury == ey) {
                    ans = Math.min(ans, curd);
                }
                
                tried[curx][cury][curpx][curpy] = 0;
                
                int nx,ny,npx,npy,nd;
                
                // move portal in dir 0
                nx = curx;
                ny = cury;
                nd = curd;
                npx = posout[nx][ny][0][0];
                npy = posout[nx][ny][0][1];
                
                if (solved[nx][ny][npx][npy] == -1 || 
                        solved[nx][ny][npx][npy] > nd) {
                    solved[nx][ny][npx][npy] = nd;
                    if (tried[nx][ny][npx][npy] == 0) {
                        tried[nx][ny][npx][npy] = 1;
                        Q.add(new int[] {nx,ny,npx,npy,nd});
                    }
                }

                // move portal in dir 1
                nx = curx;
                ny = cury;
                nd = curd;
                npx = posout[nx][ny][1][0];
                npy = posout[nx][ny][1][1];
                if (solved[nx][ny][npx][npy] == -1 || 
                        solved[nx][ny][npx][npy] > nd) {
                    solved[nx][ny][npx][npy] = nd;
                    if (tried[nx][ny][npx][npy] == 0) {
                        tried[nx][ny][npx][npy] = 1;
                        Q.add(new int[] {nx,ny,npx,npy,nd});
                    }
                }
                
                // move portal in dir 2
                nx = curx;
                ny = cury;
                nd = curd;
                npx = posout[nx][ny][2][0];
                npy = posout[nx][ny][2][1];
                if (solved[nx][ny][npx][npy] == -1 || 
                        solved[nx][ny][npx][npy] > nd) {
                    solved[nx][ny][npx][npy] = nd;
                    if (tried[nx][ny][npx][npy] == 0) {
                        tried[nx][ny][npx][npy] = 1;
                        Q.add(new int[] {nx,ny,npx,npy,nd});
                    }
                }
                
                // move portal in dir 3
                nx = curx;
                ny = cury;
                nd = curd;
                npx = posout[nx][ny][3][0];
                npy = posout[nx][ny][3][1];
                if (solved[nx][ny][npx][npy] == -1 || 
                        solved[nx][ny][npx][npy] > nd) {
                    solved[nx][ny][npx][npy] = nd;
                    if (tried[nx][ny][npx][npy] == 0) {
                        tried[nx][ny][npx][npy] = 1;
                        Q.add(new int[] {nx,ny,npx,npy,nd});
                    }
                }
                
                // walk left
                nx = curx;
                ny = cury-1;
                npx = curpx;
                npy = curpy;
                nd = curd+1;
                if (map[nx][ny] != '#') {
                    if (solved[nx][ny][npx][npy] == -1 || 
                            solved[nx][ny][npx][npy] > nd) {
                        solved[nx][ny][npx][npy] = nd;
                        if (tried[nx][ny][npx][npy] == 0) {
                            tried[nx][ny][npx][npy] = 1;
                            Q.add(new int[] {nx,ny,npx,npy,nd});
                        }
                    }
                }


                // walk right
                nx = curx;
                ny = cury+1;
                npx = curpx;
                npy = curpy;
                nd = curd+1;
                if (map[nx][ny] != '#') {
                    if (solved[nx][ny][npx][npy] == -1 || 
                            solved[nx][ny][npx][npy] > nd) {
                        solved[nx][ny][npx][npy] = nd;
                        if (tried[nx][ny][npx][npy] == 0) {
                            tried[nx][ny][npx][npy] = 1;
                            Q.add(new int[] {nx,ny,npx,npy,nd});
                        }
                    }
                }

                // walk top
                nx = curx-1;
                ny = cury;
                npx = curpx;
                npy = curpy;
                nd = curd+1;
                if (map[nx][ny] != '#') {
                    if (solved[nx][ny][npx][npy] == -1 || 
                            solved[nx][ny][npx][npy] > nd) {
                        solved[nx][ny][npx][npy] = nd;
                        if (tried[nx][ny][npx][npy] == 0) {
                            tried[nx][ny][npx][npy] = 1;
                            Q.add(new int[] {nx,ny,npx,npy,nd});
                        }
                    }
                }

                // walk bottom
                nx = curx;
                ny = cury+1;
                npx = curpx;
                npy = curpy;
                nd = curd+1;
                if (map[nx][ny] != '#') {
                    if (solved[nx][ny][npx][npy] == -1 || 
                            solved[nx][ny][npx][npy] > nd) {
                        solved[nx][ny][npx][npy] = nd;
                        if (tried[nx][ny][npx][npy] == 0) {
                            tried[nx][ny][npx][npy] = 1;
                            Q.add(new int[] {nx,ny,npx,npy,nd});
                        }
                    }
                }

                // walk into the portal
                if (nearwall[curx][cury] == 1) {
                    nx = curpx;
                    ny = curpy;
                    nd = curd+1;
                    npx = curx;
                    npy = cury;
                    if (solved[nx][ny][npx][npy] == -1 || 
                            solved[nx][ny][npx][npy] > nd) {
                        solved[nx][ny][npx][npy] = nd;
                        if (tried[nx][ny][npx][npy] == 0) {
                            tried[nx][ny][npx][npy] = 1;
                            Q.add(new int[] {nx,ny,npx,npy,nd});
                        }
                    }
                }
                
            } // while Q not empty
            
            if (ans == 1000000)
                writer.write("Case #" + testnum + ": THE CAKE IS A LIE\n");
            else
                writer.write("Case #" + testnum + ": " + ans + "\n");
            
        } // end test
        
        writer.close();
        System.out.println(new File("output.txt").getAbsolutePath());
    }// end main
    
    static void updsolved(int[][][][] solved, int x,int y,int px,int py,int d) {
        if (solved[x][y][px][py] == -1 || solved[x][y][px][py] > d) {
            solved[x][y][px][py] = d;
        }
    }
} // end class
