import java.io.*;
import java.util.*;

public class Main {
    
    private static double integral(double R, double x){
        return (R * R * Math.asin(x / R) + x * Math.sqrt(R * R - x * x)) / 2;
    }
    
    private static double integrate(double R, double xLeft, double xRight){
        double integral = integral(R, xRight) - integral(R, xLeft);
        return integral;
    }

    private static double getHolesSquare(double R, double r, double g) {
        if(g <= 0)
            return 0;
        
        double square = 0;
        
        double lim = Math.sqrt(R * R - r * r);
		assert lim <= R;
		
        double step = g + r * 2;
        
        for(double x = r; x < lim; x += step){
            double lBnd = x;
            double rBnd = x + g;
            
            double yLeftInter = Math.sqrt(R * R - lBnd * lBnd);
            double yRightInter = Math.sqrt(R * R - rBnd * rBnd);
			assert !Double.isNaN(yLeftInter);
			assert Double.isNaN(yRightInter) || yLeftInter > yRightInter;
            
            double yLim = Math.ceil((yLeftInter - r) / step) * step;
            for(double y = r; y < yLim; y += step){
                double bBnd = y;
                double tBnd = y + g;
                
                double xBottomInter = Math.sqrt(R * R - bBnd * bBnd);
                double xTopInter = Math.sqrt(R * R - tBnd * tBnd);
				assert !Double.isNaN(xBottomInter);
				assert Double.isNaN(xTopInter) || xBottomInter > xTopInter;
                
                if(!Double.isNaN(xTopInter) && lBnd < xTopInter && xTopInter <= rBnd){//cases A and C
                    double xRight = 0;
                    if(!Double.isNaN(yRightInter) && bBnd < yRightInter && yRightInter <= tBnd)//case A
                        xRight = rBnd;
                    else //case C
                        xRight = xBottomInter;
					
                    assert lBnd < xRight;
					double S = integrate(R, xTopInter, xRight);
					assert S > 0;
					S -= y * (xRight - xTopInter);
					assert S > 0;
                    square += S;
                    square += g * (xTopInter - lBnd);
                    
                } else if(bBnd < yLeftInter && yLeftInter <= tBnd){//cases B and D
                    double xRight = 0;
					if(!Double.isNaN(yRightInter) && bBnd < yRightInter && yRightInter <= tBnd)//case B
                        xRight = rBnd;
					else //case C
                        xRight = xBottomInter;
					
                    assert lBnd < xRight;
					double S = integrate(R, lBnd, xRight);
					assert S > 0;
					S -= y * (xRight - lBnd);
					assert S > 0;
                    square += S;
                } else {//'normal' case
                    square += g * g;
                }
            }
            
        }
        
        return square * 4;
    }
	
	public static void main(String[] args) throws Exception{
		Locale.setDefault(Locale.US);
		Scanner in = new Scanner(new FileInputStream("input.txt"));
		PrintWriter out = new PrintWriter("output.txt");
		
		int n = in.nextInt();
		for(int i = 0; i < n; ++i){
			double f = in.nextDouble();
			double R = in.nextDouble();
			double t = in.nextDouble();
			double r = in.nextDouble();
			double g = in.nextDouble();
            
            double S = Math.PI * R * R;
            
            double RCor = R - t - f;
            double rCor = r + f;
            double gCor = g - f * 2;
            
            double hS = getHolesSquare(RCor, rCor, gCor);
            double prob = 1 - hS / S;

			out.println(String.format("Case #%d: %f", i + 1, prob));			
			out.flush();
			
		}
		
	}
	
}