package task02;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintStream;
import java.util.HashSet;
import java.util.Scanner;
import java.util.Set;

public class Main {

    public static void main(String[] args) throws FileNotFoundException, IOException {
		Scanner s = new Scanner(new File("input.txt"));
		PrintStream out = new PrintStream("output.txt");

		final int T = s.nextInt();
		for(int i = 0; i < T; ++i){
			s.nextLine();
			final int H = s.nextInt();
			final int W = s.nextInt();

			int alt[][] = new int[H][W];
			for(int h = 0; h < H; ++h){
				s.nextLine();
				for(int w = 0; w < W; ++w){
					alt[h][w] = s.nextInt();
				}
			}
			
			solve(out, i + 1, alt, H, W);
			if(i + 1 < T)
				out.println();
		}

    }

	private static void solve(PrintStream out, int caseNo, final int alt[][], final int H, final int W){
		out.print(String.format("Case #%d:", caseNo));

		int basins[][] = new int[H][W];

		Coord pos = new Coord();

		int basinId = 1;
		while((pos = findFree(basins, H, W, pos)) != null){
			Coord basinPos = pos.clone();
			if(findPath(basinPos, basins, alt, H, W, basinId, new HashSet<Coord>()) == basinId)
				++basinId;
		}

		for(int h = 0; h < H; ++h){
			out.println();
			for(int w = 0; w < W; ++w){
				out.print((char)(basins[h][w] + (int)'a' - 1));
				if(w + 1 < W)
					out.print(' ');
			}
		}
	}
	
	private static int findPath(Coord basinPos, int basins[][], final int alt[][], final int H, final int W, int nextBasinId, Set<Coord> used){
		used.add(basinPos);

		Direction d = findDirection(basinPos, alt, H, W, used);
		if(d == null){
			basins[basinPos.getY()][basinPos.getX()] = nextBasinId;
			return nextBasinId;
		}

		Coord newBasinsPos = basinPos.clone();
		newBasinsPos.scroll(d);
		int basinId = basins[newBasinsPos.getY()][newBasinsPos.getX()];
		if(basinId > 0){
			basins[basinPos.getY()][basinPos.getX()] = basinId;
			return basinId;
		}
		
		basinId = findPath(newBasinsPos, basins, alt, H, W, nextBasinId, used);
		basins[basinPos.getY()][basinPos.getX()] = basinId;
		return basinId;
	}
	
	private static Direction findDirection(Coord pos, final int alt[][], final int H, final int W, Set<Coord> used){

		int base = alt[pos.getY()][pos.getX()];
		Direction maxD = null;
		int maxDiff = -1;
		for(Direction d: Direction.values()){
			int y = pos.getY() + d.dy;
			int x = pos.getX() + d.dx;
			if(y < 0 || y >= H || x < 0 || x >= W)
				continue;
			
			int diff = base - alt[pos.getY() + d.dy][pos.getX() + d.dx];
			if(diff <= 0 || (maxDiff != -1 && diff <= maxDiff))
				continue;

			if(used.contains(new Coord(pos.getX() + d.dx, pos.getY() + d.dy)))
				continue;
			
			maxD = d;
			maxDiff = diff;
		}
		
		return maxD;
	}
	
	private static Coord findFree(int alt[][], final int H, final int W, Coord pos){
		do{
			pos.scrollRight(H, W);
			if(pos.isAfterEnd())
				return null;

			if(alt[pos.getY()][pos.getX()] == 0)
				return pos;

		}while(true);
	}

	private enum Direction{
		N(0, -1)
			, W(-1, 0)
			, S(0, 1)
			, E(1, 0)
		;

		int dx;
		int dy;

		private Direction(int dx, int dy) {
			this.dx = dx;
			this.dy = dy;
		}

	}

	private static class Coord implements Cloneable{
		private int x = -1;
		private int y = 0;

		public Coord() {
		}

		public Coord(int x, int y) {
			this.x = x;
			this.y = y;
		}

		@Override
		public Coord clone() {
			return new Coord(x, y);
		}

		@Override
		public int hashCode() {
			int hash = 5;
			hash = 79 * hash + this.x;
			hash = 79 * hash + this.y;
			return hash;
		}

		@Override
		public boolean equals(Object obj) {
			if (obj == null) {
				return false;
			}
			if (getClass() != obj.getClass()) {
				return false;
			}
			final Coord other = (Coord) obj;
			if (this.x != other.x) {
				return false;
			}
			if (this.y != other.y) {
				return false;
			}
			return true;
		}


		
		public int getX() { return x; }
		public int getY() { return y; }

		public void scrollRight(final int H, final int W){
			++x;
			if(x < W)
				return;

			x = 0;
			++y;
			if(y < H)
				return;

			x = -1;
			y = -1;
		}
		
		public void scroll(Direction d){
			x += d.dx;
			y += d.dy;
		}

		public boolean isBeforeBegin(){
			return x == -1 && y == 0;
		}

		public boolean isAfterEnd(){
			return x == -1 && y == -1;
		}
	}

}
