import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * 
 */

/**
 * @author b117
 * 
 */
public class AlienLanguage {
	
	/**
	 * length of an alien word
	 */
	private int lengthWord;
	/**
	 * count of known words
	 */
	private int countKnownWords;
	/**
	 * count of unknown words
	 */
	private int countUnknownWords;

	/**
	 * holds all known words
	 */
	private List<String> listKnownWords = Collections.EMPTY_LIST;
	/**
	 * holds all unknown words
	 */
	private List<String> listUnknownWords = Collections.EMPTY_LIST;

	
	/**
	 * @return the lengthWord
	 */
	public int getLengthWord() {
		return lengthWord;
	}

	/**
	 * @param lengthWord
	 *            the lengthWord to set
	 */
	public void setLengthWord(int lengthWord) {
		this.lengthWord = lengthWord;
	}

	/**
	 * @return the countKnownWords
	 */
	public int getCountKnownWords() {
		return countKnownWords;
	}

	/**
	 * @param countKnownWords
	 *            the countKnownWords to set
	 */
	public void setCountKnownWords(int countKnownWords) {
		this.countKnownWords = countKnownWords;
	}

	/**
	 * @return the countUnknownWords
	 */
	public int getCountUnknownWords() {
		return countUnknownWords;
	}

	/**
	 * @param countUnknownWords
	 *            the countUnknownWords to set
	 */
	public void setCountUnknownWords(int countUnknownWords) {
		this.countUnknownWords = countUnknownWords;
	}

	/**
	 * @return the listKnownWords
	 */
	public List<String> getListKnownWords() {
		return listKnownWords;
	}

	/**
	 * @param listKnownWords
	 *            the listKnownWords to set
	 */
	public void setListKnownWords(List<String> listKnownWords) {
		this.listKnownWords = listKnownWords;
	}

	/**
	 * @return the listUnknownWords
	 */
	public List<String> getListUnknownWords() {
		return listUnknownWords;
	}

	/**
	 * @param listUnknownWords
	 *            the listUnknownWords to set
	 */
	public void setListUnknownWords(List<String> listUnknownWords) {
		this.listUnknownWords = listUnknownWords;
	}

	/**
	 * initializes all private variables
	 */
	public AlienLanguage() {
		listKnownWords = new ArrayList<String>();
		listUnknownWords = new ArrayList<String>();
		lengthWord = 0;
		countKnownWords = 0;
		countUnknownWords = 0;
	}

	/**
	 * 
	 * delivers a regular expression for an unknown word
	 * 
	 * @param unknown unknown word
	 * 
	 * @return regular expression
	 */
	private String getAsregExp(String unknown) {
		StringBuffer buffer = new StringBuffer(unknown);

		for (int i = 0; i < buffer.length(); i++) {
			//starting brackets
			if (buffer.charAt(i) == '(') {
				//replace
				buffer.replace(i, i + 1, "[");
			} else if (buffer.charAt(i) == ')') {
				//replace and add a quantifier
				buffer.replace(i, i + 1, "]");
				buffer.insert(i + 1, "{1}");
			}
		}

		//return regular expression
		return buffer.toString();
	}

	/**
	 * reads an input file 
	 * 
	 * @param file name of the file delivered by the arguments as parameter 0
	 */
	private void readFile(String file) {
		File f = new File(file);
		BufferedReader reader = null;
		try {
			reader = new BufferedReader(new FileReader(f));
		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		if (reader != null) {
			try {
				String line = null;
				line = reader.readLine();

				String[] splitter = line.split(" ");
				if (splitter.length != 3) {
					System.out.println("What happend?");
				} else {
					//set static parameters
					setLengthWord(Integer.parseInt(splitter[0]));
					setCountKnownWords(Integer.parseInt(splitter[1]));
					setCountUnknownWords(Integer.parseInt(splitter[2]));
				}

				for (int i = 0; i < getCountKnownWords(); i++) {
					line = reader.readLine();
					if (line != null) {
						//add known words
						listKnownWords.add(line);
					}
				}

				for (int i = 0; i < getCountUnknownWords(); i++) {
					line = reader.readLine();
					if (line != null) {
						//add unknown words
						listUnknownWords.add(line);
					}
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
			finally {
				try {
					reader.close();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}
	}

	/**
	 * 
	 * writes outputfile to disk
	 * 
	 * @param file name and path of the file given as parameter 1 in args-array
	 * @param text Text which ist written to the file system
	 */
	private void writeFile(String file, String text) {
		File f = new File(file);
		BufferedWriter writer = null;

		try {
			writer = new BufferedWriter(new FileWriter(f));
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}

		if(writer != null) {
			try {
				writer.write(text);
			} catch (IOException e) {
				e.printStackTrace();
			}
			finally {
				try {
					writer.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		
		
	}
	
	/**
	 * starts this application
	 * 
	 * both parameters input and output files are given with program arguments
	 * 
	 * @param args 
	 * 			absolute name and place of the input file on the filesystem at position 0
	 * 			absolute name and place of the output file on the filesystem at position 1
	 */
	public static void main(String[] args) {
		AlienLanguage a = new AlienLanguage();
		StringBuffer output = new StringBuffer();
		a.readFile(args[0]);

		int numbers = 0;
		int i = 1;
		for (String s : a.getListUnknownWords()) {
			Pattern p = Pattern.compile(a.getAsregExp(s));

			for (String s1 : a.getListKnownWords()) {
				Matcher m = p.matcher(s1);

				if (m.matches()) {
					numbers++;
				}
			}

			output.append("Case #" + i + ": " + numbers + "\n");
			i++;
			numbers = 0;
		}
		
		a.writeFile(args[1], output.toString());
	}

}
