import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Andreas Denninger
 * 
 */
public class Waterheds {

	/**
	 * holds the areas
	 */
	private List areas = null;
	/**
	 * holds the actual cahr to print
	 */
	private static char actual = 'a';
	/**
	 * holds an actual list of neighbors
	 */
	private List<Node> neighbours = null;
	/**
	 * holds a result area
	 */
	private char[][] result = null;

	/**
	 * inner data structure to represent a neighbour
	 * @author Dingel
	 *
	 */
	private class Node {
		int h = 0;
		int w = 0;
		
		/**
		 * @return the h
		 */
		public int getH() {
			return h;
		}

		/**
		 * @param h
		 *            the h to set
		 */
		public void setH(int h) {
			this.h = h;
		}

		/**
		 * @return the w
		 */
		public int getW() {
			return w;
		}

		/**
		 * @param w
		 *            the w to set
		 */
		public void setW(int w) {
			this.w = w;
		}

		public Node(int h, int w) {
			this.h = h;
			this.w = w;
		}
	}

	/**
	 * @return the areas
	 */
	public List getAreas() {
		return areas;
	}

	/**
	 * @param areas
	 *            the areas to set
	 */
	public void setAreas(List areas) {
		this.areas = areas;
	}

	private int numberOfAreas;
	private boolean change = false;

	/**
	 * @return the numberOfAreas
	 */
	public int getNumberOfAreas() {
		return numberOfAreas;
	}

	/**
	 * @param numberOfAreas
	 *            the numberOfAreas to set
	 */
	public void setNumberOfAreas(int numberOfAreas) {
		this.numberOfAreas = numberOfAreas;
	}

	public Waterheds() {
		areas = new ArrayList();
		numberOfAreas = 0;
		neighbours = new ArrayList<Node>();

	}

	/**
	 * reads an input file
	 * 
	 * @param file
	 *            input file given as first parameter of args (args[0])
	 */
	private void readFile(String file) {
		File f = new File(file);
		BufferedReader reader = null;
		try {
			reader = new BufferedReader(new FileReader(f));
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}

		if (reader != null) {
			try {
				String line = null;
				line = reader.readLine();

				try {
					numberOfAreas = Integer.parseInt(line);
				} catch (NumberFormatException e) {
					e.printStackTrace();
				}

				//get all areas
				for (int i = 0; i < numberOfAreas; i++) {
					line = reader.readLine();
					String[] splitter = line.split(" ");
					int h = Integer.parseInt(splitter[0]);
					int w = Integer.parseInt(splitter[1]);
					int[][] area = new int[h][w];

					//height
					for (int j = 0; j < h; j++) {
						line = reader.readLine();
						String[] areaSplitter = line.split(" ");

						//width
						for (int k = 0; k < w; k++) {
							area[j][k] = Integer.parseInt(areaSplitter[k]);
						}
					}

					areas.add(area);
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
	}

	/**
	 * 
	 * searches some neighbors for the actual cell which is a source
	 * sources and sinks are always connected 
	 * 
	 * @param area the actual area
	 * @param h the actual height of an area
	 * @param w the actual width of an area
	 */
	private void hasSource(int[][] area, int h, int w) {
		int max = area[h][w];
		int newH = -1;
		int newW = -1;

		// check north
		if (h > 0) {
			//value greater
			max = Math.max(max, area[h - 1][w]);
			if (max > area[h][w]) {
				newH = h - 1;
				newW = w;

				//check, if this cell is a sink for the neighbur
				Node n = isSink(area, newH, newW, false);

				if (n.getH() == h && n.getW() == w) {
					//this cell is a sink, connect
					neighbours.add(new Node(newH, newW));
				}

			}
		}

		// check west
		if (w > 0) {
			max = Math.max(max, area[h][w - 1]);
			if (max > area[h][w]) {
				newH = h;
				newW = w - 1;
				Node n = isSink(area, newH, newW, false);

				if (n.getH() == h && n.getW() == w) {
					neighbours.add(new Node(newH, newW));
				}

			}

		}

		// check east
		if (w < area[0].length - 1) {
			max = Math.max(max, area[h][w + 1]);
			if (max > area[h][w]) {
				newH = h;
				newW = w + 1;
				Node n = isSink(area, newH, newW, false);

				if (n.getH() == h && n.getW() == w) {
					neighbours.add(new Node(newH, newW));
				}
			}
		}

		// check south
		if (h < area.length - 1) {
			max = Math.max(max, area[h + 1][w]);
			if (max > area[h][w]) {
				newH = h + 1;
				newW = w;
				Node n = isSink(area, newH, newW, false);

				if (n.getH() == h && n.getW() == w) {
					neighbours.add(new Node(newH, newW));
				}
			}

		}
	}

	/**
	 * 
	 * searches a sink for the actual cell
	 * 
	 * this method can operate stand alone and connect cells with save == true
	 * 
	 * also it works for hasSource(int[][] area, int h, int w) to 
	 * decide if a source is really a source (save == false)
	 * 
	 * @param area actual area
	 * @param h height of an area
	 * @param w width of an area
	 * @param save should connect?
	 * @return new connection if cells should get connected
	 */
	private Node isSink(int[][] area, int h, int w, boolean save) {
		int min = area[h][w];
		int min2 = area[h][w];
		int newH = -1;
		int newW = -1;

		// check north
		if (h > 0) {
			// calculate value
			min = Math.min(min, area[h - 1][w]);
			// minimal value -> best sink
			if (min < min2) {
				newH = h - 1;
				newW = w;
				min2 = min;
			}
		}

		// check west
		if (w > 0) {
			min = Math.min(min, area[h][w - 1]);
			if (min < min2) {
				newH = h;
				newW = w - 1;
				min2 = min;
			}

		}

		// check east
		if (w < area[0].length - 1) {
			min = Math.min(min, area[h][w + 1]);
			if (min < min2) {
				newH = h;
				newW = w + 1;
				min2 = min;
			}
		}

		// check south
		if (h < area.length - 1) {
			min = Math.min(min, area[h + 1][w]);
			if (min < min2) {
				newH = h + 1;
				newW = w;
				min2 = min;
			}

		}
		
		//a cell can only have one sink
		Node n = new Node(newH, newW);
		if (newH > -1 && newW > -1 && save) {
			neighbours.add(n);
		}

		return n;

	}

	/**
	 * 
	 * visit neighbors of a cell
	 * 
	 * @param area actual area
	 * @param h height of an area
	 * @param w width of an area
	 */
	private void update(int[][] area, int h, int w) {
		neighbours.remove(0);
		if (result[h][w] == '#') {
			//next character is allowed
			change = true;
			//mark as visited
			result[h][w] = Waterheds.actual;
			//search neighbors
			isSink(area, h, w, true);
			hasSource(area, h, w);
		}
	}

	/**
	 * 
	 * calculate result area 
	 * 
	 * @param area actual area
	 * 
	 */
	private void calcArray(int[][] area) {
		for (int h = 0; h < area.length; h++) {

			for (int w = 0; w < area[0].length; w++) {

				//if cell was not visited before
				if (result[h][w] == '#') {
					//mark as visited
					result[h][w] = Waterheds.actual;
					//allow change for character
					change = true;
					//search neighbors
					isSink(area, h, w, true);
					hasSource(area, h, w);

					//visit neighbors
					while (neighbours.size() > 0) {
						update(area, neighbours.get(0).getH(), neighbours.get(0).getW());
					}

				}

				//if actual character is in use
				if (change) {
					//get next character
					actual++;
					change = false;
				}
			}
		}
	}

	/**
	 * init result area with default values
	 * 
	 * @param h height of an area
	 * @param w width of an area
	 */
	public void init(int h, int w) {
		result = new char[h][w];

		for (int i = 0; i < h; i++) {
			for (int j = 0; j < w; j++) {
				result[i][j] = '#';
			}
		}

	}

	/**
	 * 
	 * writes output file to disk
	 * 
	 * @param file
	 *            name and path of the file given as parameter 1 in args-array
	 * @param text
	 *            text which is written to the file system
	 */
	private void writeFile(String file, String text) {
		File f = new File(file);
		BufferedWriter writer = null;

		try {
			writer = new BufferedWriter(new FileWriter(f));
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}

		if (writer != null) {
			try {
				writer.write(text);
			} catch (IOException e) {
				e.printStackTrace();
			} finally {
				try {
					writer.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}

	}
	
	/**
	 * runs the application
	 * @param args
	 * 			args[0] input file with full path
	 * 			args[1] output file with full path
	 */
	public static void main(String[] args) {
		Waterheds waterheds = new Waterheds();

		//read values
		waterheds.readFile(args[0]);
		StringBuffer buffer = new StringBuffer();
		
		//get all results
		for(int i = 0; i < waterheds.getAreas().size(); i++) {
			int[][] area = (int[][]) waterheds.getAreas().get(i);
			waterheds.init(area.length, area[0].length);
			//calculate result
			waterheds.calcArray(area);
			//delete working variables
			waterheds.neighbours = new ArrayList<Node>();
			Waterheds.actual = 'a';
			waterheds.change = false;
			
			//build output
			buffer.append("Case #" + (i+1) + ": \n");
			for(int j = 0; j < waterheds.result.length; j++) {
				for(int k = 0; k < waterheds.result[j].length; k++) {
					buffer.append(waterheds.result[j][k] + " ");
				}
				buffer.replace(buffer.length() - 1, buffer.length(), "\n");
			}
		}
		
		//write output
		waterheds.writeFile(args[1], buffer.toString());
	}

}
