import java.io.*;
import java.math.BigInteger;
import java.text.DecimalFormat;
import java.util.*;

public class ProbC {
    public static void main(String[] args) throws FileNotFoundException, IOException {
        ProbC p = new ProbC();
        p.solveAll();
    }
    int tests = 0;
    Scanner in;
    PrintWriter out;
    
    
    public ProbC() throws FileNotFoundException, IOException {
        out = new PrintWriter(new FileWriter("c.out"));
        in = new Scanner(new File("c.in"));
        tests = in.nextInt();
    }

    public void solveAll() throws IOException {
        for(int i = 0; i < tests; i++) {
            solve(i+1);
        }
        out.close();
        in.close();
    }
    
    public void solve(int casenr) throws IOException {
        out.print("Case #"+casenr+": ");
        int L = in.nextInt();
        int X = in.nextInt();
        String word = in.next();
        Unit[] init = new Unit[L];
        for(int i = 0; i < L; i++) {
            init[i] = new Unit(word.charAt(i), true);
        }
        Unit[] startseq = new Unit[L];
        Unit[] endseq = new Unit[L];
        
        startseq[0] = init[0].doClone();
        for(int i = 1; i < L; i++) {
            startseq[i] = startseq[i-1].multiply(init[i]);
        }
        
        endseq[init.length-1] = init[init.length-1].doClone();
        for(int i = init.length-2; i >= 0; i--) {
            endseq[i] = init[i].multiply(endseq[i+1]);
        }
        
        Unit seq1 = startseq[init.length-1].doClone();
        Unit seq2 = seq1.multiply(seq1);
        Unit seq3 = seq2.multiply(seq1);
        Unit seq4 = seq3.multiply(seq1);
        Unit iunit = new Unit('i', true);
        
        try {
            //match starting seq to i
            boolean found = false;
            for(int i = 0; i < startseq.length && !found; i++) {
                if(startseq[i].isEqualTo(iunit)) {
                    found = makeStartingSeq(init, startseq, endseq, X, i, 0);
                }
                if(seq1.multiply(startseq[i]).isEqualTo(iunit) && !found) {
                    for(int j = 1; j < X && !found; j+=4) {
                        found = makeStartingSeq(init, startseq, endseq, X, i, j);
                    }
                }
                if(seq2.multiply(startseq[i]).isEqualTo(iunit) && !found) {
                    for(int j = 2; j < X && !found; j+=4) {
                        found = makeStartingSeq(init, startseq, endseq, X, i, j);
                    }
                }
                if(seq3.multiply(startseq[i]).isEqualTo(iunit) && !found) {
                    for(int j = 3; j < X && !found; j+=4) {
                        found = makeStartingSeq(init, startseq, endseq, X, i, j);
                    }
                }
                if(seq4.multiply(startseq[i]).isEqualTo(iunit) && !found) {
                    for(int j = 4; j < X && !found; j+=4) {
                        found = makeStartingSeq(init, startseq, endseq, X, i, j);
                    }
                }
            }
            
            if(found)
                out.println("YES");
            else 
                out.println("NO");
        } catch (Exception e) {
            System.out.println("Exception case "+casenr);
            System.out.println(e.toString());
        }
    }
    
    public boolean makeStartingSeq(Unit[] init, Unit[] startseq, Unit[] endseq, int X, int startpos, int startdelta) {
        Unit seq1 = startseq[init.length-1].doClone();
        Unit seq2 = seq1.multiply(seq1);
        Unit seq3 = seq2.multiply(seq1);
        Unit seq4 = seq3.multiply(seq1);
        Unit kunit = new Unit('k', true);
        boolean found = false;
        for(int i = 0; i < endseq.length && !found; i++) {
            if(endseq[i].isEqualTo(kunit)) {
                found = makeEndSeq(init, startseq, endseq, X, startpos, startdelta, i, 0);
            }
            if(endseq[i].multiply(seq1).isEqualTo(kunit)) {
                for(int j = 1; j < X-startdelta && !found; j+=4) {
                    found = makeEndSeq(init, startseq, endseq, X, startpos, startdelta, i, j);
                }
            }
            if(endseq[i].multiply(seq2).isEqualTo(kunit)) {
                for(int j = 2; j < X-startdelta && !found; j+=4) {
                    found = makeEndSeq(init, startseq, endseq, X, startpos, startdelta, i, j);
                }
            }
            if(endseq[i].multiply(seq3).isEqualTo(kunit)) {
                for(int j = 3; j < X-startdelta && !found; j+=4) {
                    found = makeEndSeq(init, startseq, endseq, X, startpos, startdelta, i, j);
                }
            }
            if(endseq[i].multiply(seq4).isEqualTo(kunit)) {
                for(int j = 4; j < X-startdelta && !found; j+=4) {
                    found = makeEndSeq(init, startseq, endseq, X, startpos, startdelta, i, j);
                }
            }
        }
        return found;
    }
    
    public boolean makeEndSeq(Unit[] init, Unit[] startseq, Unit[] endseq, int X, int startpos, int startdelta, int endpos, int enddelta) {
        Unit seq1 = startseq[init.length-1].doClone();
        Unit seq2 = seq1.multiply(seq1);
        Unit seq3 = seq2.multiply(seq1);
        Unit seq4 = seq3.multiply(seq1);
        Unit junit = new Unit('j', true);
        Unit result;
        if(startpos < init.length-1)
            result = endseq[startpos+1];
        else
            result = new Unit('1', true);
        
        int no_seq = X - startdelta - enddelta - 2;
        if(X  == 0)
            return midSeq(init, startpos+1, endpos-1).isEqualTo(junit);
        if(no_seq > 0) {
            if(no_seq%4 == 1)
                result = result.multiply(seq1);
            else if(no_seq%4 == 2)
                result = result.multiply(seq2);
            else if(no_seq%4 == 3)
                result = result.multiply(seq3);
            else
                result = result.multiply(seq4);
        } else if(no_seq < 0) {
            return false;
        }
        if(endpos > 0)
            result = result.multiply(startseq[endpos-1]);
        return result.isEqualTo(junit);
    }
    
    public Unit midSeq(Unit[] init, int start, int end) {
//        if(start >= init.length || end < 0)
//            return new Unit('1', true);
        if(start >= end)
            return new Unit('1', true);
        Unit result = init[start].doClone();
        for(int i = start+1; i <= end; i++) {
            result = result.multiply(init[i]);
        }
        return result;
    }
    
    public class Unit {
        char ch;
        boolean sign;

        public Unit(char ch, boolean sign) {
            this.ch = ch;
            this.sign = sign;
        }

        public char getCh() {
            return ch;
        }

        public void setCh(char ch) {
            this.ch = ch;
        }

        public boolean getSign() {
            return sign;
        }

        public void setSign(boolean sign) {
            this.sign = sign;
        }
        
        public boolean isEqualTo(Unit other) {
            return this.getCh() == other.getCh() && this.getSign() == other.getSign();
        }
        
        public Unit doClone() {
            return new Unit(getCh(), getSign());
        }
        
        public Unit multiply(Unit other) {
            char result_ch = '1';
            boolean result_sign = other.getSign() == this.getSign();
            if(this.getCh() == '1') {
                result_ch = other.getCh();
            } else if(other.getCh() == '1') {
                result_ch = this.getCh();
            } else if(this.getCh() == other.getCh()) {
                result_ch = '1';
                result_sign = !result_sign;
            } else if(this.getCh() == 'i') {
                if(other.getCh() == 'j') {
                    result_ch = 'k';
                } else if(other.getCh() == 'k') {
                    result_ch = 'j';
                    result_sign = !result_sign;
                } else {
                    System.out.println("ERROR!");
                }
            } else if(this.getCh() == 'j') {
                if(other.getCh() == 'i') {
                    result_ch = 'k';
                    result_sign = !result_sign;
                } else if(other.getCh() == 'k') {
                    result_ch = 'i';
                } else {
                    System.out.println("ERROR!");
                }
            } else if(this.getCh() == 'k') {
                if(other.getCh() == 'i') {
                    result_ch = 'j';
                } else if(other.getCh() == 'j') {
                    result_ch = 'i';
                    result_sign = !result_sign;
                } else {
                    System.out.println("ERROR!");
                }
            } else {
                System.out.println("ERROR!");
            }
            return new Unit(result_ch, result_sign);
        }
    }
}