package fr.sfr.perso.broca.didier.gcj2010;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Scanner;

public class CalifC {
	
	private Scanner fileScanner;
	private Scanner lineScanner;
	private int numberOfCase;
	
	public CalifC(String fileName) {
		try {
			fileScanner = new Scanner(new BufferedReader(new FileReader(fileName)));
			numberOfCase = fileScanner.nextInt();
			nextLine();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
	}
	
	public int getNumberOfCase() {
		return numberOfCase;
	}
	
	public boolean hasNextLine() {
		return fileScanner.hasNextLine();
	}
	
	public void nextLine() {
		lineScanner = new Scanner(fileScanner.nextLine());
	}
	
	public boolean hasNext() {
		return lineScanner.hasNext();
	}
	
	public String next() {
		return lineScanner.next();
	}
	
	public void close() {
		if (lineScanner != null) {
			lineScanner.close();
		}
		fileScanner.close();
	}
	
	private void computeCase(String outPutFileName) throws IOException {
		BufferedWriter file = new BufferedWriter(new FileWriter(outPutFileName));

		for (int i = 0; i < numberOfCase; i++) {
			long r = Long.valueOf(fileScanner.next());
			long k = Long.valueOf(fileScanner.next());
			int n = Integer.valueOf(fileScanner.next());
			
			long g[] = new long[n];
			for (int j = 0; j < g.length; j++) {
				g[j] = Long.valueOf(fileScanner.next());
			}
			
			String result = computeNextCase(r, k, n, g);
			file.append("Case #" + (i + 1) + ": " + result);
			System.out.println("Case #" + (i + 1) + " " + result);
			file.newLine();
		}
		file.close();
	}

	long sumBoucle;
	
	private String computeNextCase(long r, long k, int n, long[] g) {
		long sum[] = new long[n];
		int nextGroup[] = new int[n];
		
		Arrays.fill(sum, 0);
		Arrays.fill(nextGroup, -1);
		
		int beginBoucle = fillArray(k, n, g, sum, nextGroup);
		int sizeBoucle = sizeSumBoucle(sum, nextGroup, beginBoucle);
		
		long remainingR = r;
		int currentGroup = 0;
		BigInteger recette = BigInteger.ZERO;
		
		while (currentGroup != beginBoucle && remainingR > 0) {
			recette = recette.add(BigInteger.valueOf(sum[currentGroup]));
			
			currentGroup = nextGroup[currentGroup];
			remainingR --;
		}
		
		long boucleCount = remainingR / sizeBoucle;
		recette = recette.add(BigInteger.valueOf(sumBoucle).multiply(BigInteger.valueOf(boucleCount)));
		
		remainingR = remainingR % sizeBoucle;
		
		while (remainingR > 0) {
			recette = recette.add(BigInteger.valueOf(sum[currentGroup]));
			
			currentGroup = nextGroup[currentGroup];
			remainingR --;
		}
		
		return recette.toString();
	}

	private int sizeSumBoucle(long[] sum, int[] nextGroup, int beginBoucle) {
		int currentIdx = nextGroup[beginBoucle];
		int size = 1;
		sumBoucle = sum[beginBoucle];
		
		while(currentIdx != beginBoucle) {
			size++;
			sumBoucle += sum[currentIdx];
			currentIdx = nextGroup[currentIdx];
		}
		
		return size;
	}

	private int fillArray(long k, int n, long[] g, long[] sum, int[] nextGroup) {
		int currentGroup = 0;
		
		while(sum[currentGroup] == 0) {
			sum[currentGroup] = g[currentGroup];
			int idxNextGroup = (currentGroup+1) % n;
			
			while (sum[currentGroup] + g[idxNextGroup] <= k && currentGroup != idxNextGroup) {
				sum[currentGroup] = sum[currentGroup] + g[idxNextGroup];
				idxNextGroup = (idxNextGroup+1) % n;
			}
			
			nextGroup[currentGroup] = idxNextGroup;
			
			currentGroup = idxNextGroup;
		}
		
		return currentGroup;
	}

	public static void main(String[] args) throws IOException {
		CalifC s = null;
        try {
            String file = "C-small-attempt0";
			s = new CalifC("/home/didier/codejam/" + file  + ".in");
            s.computeCase("/home/didier/codejam/" + file + ".out");
         } finally {
            if (s != null) {
                s.close();
            }
        }
    }
}
