package fr.diodfr.y2011.qual;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Scanner;

public class Exo2 {
	static class Pair {
		Character first;
		Character second;
		
		public Pair(Character first, Character second) {
			this.first = first;
			this.second = second;
		}
		
		@Override
		public boolean equals(Object obj) {
			if (obj instanceof Pair) {
				return (first.equals(((Pair) obj).first)
						&& second.equals(((Pair) obj).second))
				|| (first.equals(((Pair) obj).second)
						&& second.equals(((Pair) obj).first)) ;
			} 
			
			return false;
		}
		
		@Override
		public int hashCode() {
			return first.hashCode() * second.hashCode();
		}
	}
	
	private Scanner fileScanner;
	private Scanner lineScanner;
	private int numberOfCase;

	public Exo2(String fileName) {
		try {
			fileScanner = new Scanner(new BufferedReader(new FileReader(fileName)));
			numberOfCase = fileScanner.nextInt();
			nextLine();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
	}

	public int getNumberOfCase() {
		return numberOfCase;
	}

	public boolean hasNextLine() {
		return fileScanner.hasNextLine();
	}

	public void nextLine() {
		String nextLine = fileScanner.nextLine();
//		System.out.println("Exo2.nextLine():" + nextLine);
		lineScanner = new Scanner(nextLine);
	}

	public boolean hasNext() {
		return lineScanner.hasNext();
	}

	public String next() {
		return lineScanner.next();
	}

	public void close() {
		if (lineScanner != null) {
			lineScanner.close();
		}
		fileScanner.close();
	}
	
	
	private void computeCase(String outPutFileName) throws IOException {
		BufferedWriter file = new BufferedWriter(new FileWriter(outPutFileName));

		for (int i = 0; i < numberOfCase; i++) {
			nextLine();
			List<Character> resultList = getResult();

			StringBuilder result = new StringBuilder("[");
			
			for (Character element : resultList) {
				result.append(element);
				result.append(", ");
			}
			
			if (result.length() > 1) {
				result.delete(result.length()-2, result.length()); // suppression de la virgule
			}
			result.append("]");
			
			file.append("Case #" + (i + 1) + ": " + result);
			System.out.println("Case #" + (i + 1) + " : " + result);
			file.newLine();
		}
		file.close();
	}
	
	private List<Character> getResult() {
		Map<Pair, Character> composition = constructMap();
		Map<Character, List<Character>> opposite = constructOpposite();
		
		List<Character> result = new ArrayList<Character>();
		
		int size = lineScanner.nextInt();
		String elements = lineScanner.next();
		for (int i = 0; i < size; i++) {
			Character element = elements.charAt(i);
			
			if (result.size() == 0) {
				result.add(element);
			} else {
				Pair currentPair = new Pair(result.get(result.size()-1), element);
				
				if (composition.containsKey(currentPair)) {
					result.remove(result.size() - 1);
					result.add(composition.get(currentPair));
				} else if (opposite.containsKey(element) && containsElement(result, opposite.get(element))) {
					result.clear();
				} else {
					result.add(element);
				}
			}
		}
		
		return result;
	}

	private boolean containsElement(List<Character> result, List<Character> character) {
		return !Collections.disjoint(result, character);
	}

	private Map<Character, List<Character>> constructOpposite() {
		int size = lineScanner.nextInt();
		Map<Character, List<Character>> result = new HashMap<Character, List<Character>>();
		
		for (int i = 0; i < size; i++) {
			String elements = lineScanner.next();
			
			addMap(result, elements.charAt(0), elements.charAt(1));
			addMap(result, elements.charAt(1), elements.charAt(0));
		}

		return result;
	}
	
	private void addMap(Map<Character, List<Character>> oppositeMap, Character opposite, Character opposite1) {
		if (!oppositeMap.containsKey(opposite)) {
			oppositeMap.put(opposite, new ArrayList<Character>());
		}
		
		oppositeMap.get(opposite).add(opposite1);
	}

	private Map<Pair, Character> constructMap() {
		int size = lineScanner.nextInt();
		Map<Pair, Character> result = new HashMap<Exo2.Pair, Character>();
		
		for (int i = 0; i < size; i++) {
			String elements = lineScanner.next();
			
			Pair current = new Pair(elements.charAt(0), elements.charAt(1));
			result.put(current, elements.charAt(2));
		}

		return result;
	}

	public static void main(String[] args) {
		
		Exo2 exo = new Exo2("/home/didier/Téléchargements/B-small-attempt1.in");
	
		try {
			exo.computeCase("/home/didier/Téléchargements/B-small-attempt1.out");
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
