package fr.sfr.perso.broca.didier.tools;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.Set;
import java.util.AbstractMap.SimpleEntry;
import java.util.Map.Entry;

public class Watersheds {
	
	private Scanner fileScanner;
	private Scanner lineScanner;
	
	private int numberOfCase;
	
	public Watersheds(String fileName) {
		try {
			fileScanner = new Scanner(new BufferedReader(new FileReader(fileName)));
			numberOfCase = fileScanner.nextInt();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
	}
		
	public boolean hasNextLine() {
		return fileScanner.hasNextLine();
	}
	
	public void nextLine() {
		lineScanner = new Scanner(fileScanner.nextLine());
	}
	
	public boolean hasNext() {
		return lineScanner.hasNext();
	}
	
	public String next() {
		return lineScanner.next();
	}
	
	private void computeCase(String fileName) throws IOException {
		BufferedWriter file = new BufferedWriter(new FileWriter(fileName));
		
		for (int i = 0; i < numberOfCase; i++) {
			file.append("Case #" + (i+1) + ":");
			file.newLine();
			String[][] result = computeNextCase();
			
			int nbLine = result.length;
			for (int j = 0; j < nbLine; j++) {
				int nbCol = result[j].length;
				
				for (int k = 0; k < nbCol; k++) {
					file.append(result[j][k]);
					if (k != nbCol - 1) {
						file.append(" ");
					}
				}
				file.newLine();
			}

		}
		file.close();
	}
	
	private String[][] computeNextCase() {
		int lineCount = fileScanner.nextInt();
		int colCount = fileScanner.nextInt();
		nextLine();
		int[][] map = getMap(lineCount, colCount);
		
		List<Set<Map.Entry<Integer,Integer>>> list= new ArrayList<Set<Map.Entry<Integer,Integer>>>();
		
		for (int i = 0; i < lineCount; i++) {
			for (int j = 0; j < colCount; j++) {
				SimpleEntry<Integer, Integer> currentCell = new SimpleEntry<Integer,Integer>(i,j);
				
				SimpleEntry<Integer, Integer> fallCell = getFallCell(i, j, map, lineCount, colCount);
				
				Set<Map.Entry<Integer,Integer>> currentSet = containsEntry(list, currentCell);
				
				if (!currentCell.equals(fallCell)) {
					Set<Map.Entry<Integer,Integer>> fallSet = containsEntry(list, fallCell);
					
					if (fallSet == null) {
						fallSet = new HashSet<Entry<Integer,Integer>>();
						fallSet.add(fallCell);
						list.add(fallSet);
					}
					
					if (currentSet == null) {
						fallSet.add(currentCell);
					} else {
						fallSet.addAll(currentSet);
						list.remove(currentSet);
					}
				} else if (currentSet == null) { 
					currentSet = new HashSet<Entry<Integer,Integer>>();
					currentSet.add(currentCell);
					list.add(currentSet);
				}
			}
		}
		
		Map<Set<Map.Entry<Integer,Integer>>, Character> reservoirMap = new HashMap<Set<Entry<Integer,Integer>>, Character>();
		String[][] result = new String[lineCount][colCount];
		char reservoir = 'a';
		
		for (int i = 0; i < lineCount; i++) {
			for (int j = 0; j < colCount; j++) {
				Set<Entry<Integer, Integer>> set = containsEntry(list, new SimpleEntry<Integer, Integer>(i,j));
				Character currentReservoir;
				if (reservoirMap.containsKey(set)) {
					currentReservoir = reservoirMap.get(set);
				} else {
					currentReservoir = reservoir;
					reservoir += 1;
					reservoirMap.put(set, currentReservoir);
				}
				result[i][j] = currentReservoir.toString(); 
			}
		}
		return result;
	}

	private Set<Entry<Integer, Integer>> containsEntry(List<Set<Entry<Integer, Integer>>> list,	SimpleEntry<Integer, Integer> cell) {
		
		for (Set<Entry<Integer, Integer>> set : list) {
			if (set.contains(cell)) {
				return set;
			}
		}
		
		return null;
	}

	private SimpleEntry<Integer, Integer> getFallCell(int i, int j, int[][] map, int lineCount, int colCount) {
		int x = i;
		int y = j;
		
		if (i != 0) {
			if (map[i-1][j] < map[x][y]) {
				x = i-1;
				y = j;
			}
		}
		
		if (j != 0) {
			if (map[i][j-1] < map[x][y]) {
				x = i;
				y = j-1;
			}
		}
		
		if (j+1 != colCount) {
			if (map[i][j+1] < map[x][y]) {
				x = i;
				y = j+1;
			}
		}
		
		if (i+1 != lineCount) {
			if (map[i+1][j] < map[x][y]) {
				x = i+1;
				y = j;
			}
		}
		
		
		return new SimpleEntry<Integer, Integer>(x, y);
	}

	private int[][] getMap(int lineCount, int colCount) {
		int [][] map = new int[lineCount][colCount];
		
		for (int i = 0; i < lineCount; i++) {
			nextLine();
			
			for (int j = 0; j < colCount; j++) {
				map[i][j] = lineScanner.nextInt();
			}
		}
		
		return map;
	}

	public void close() {
		if (lineScanner != null) {
			lineScanner.close();
		}
		fileScanner.close();
	}
	
	public static void main(String[] args) throws IOException {
        Watersheds s = null;
        try {
            String file = "B-small-attempt1";
			s = new Watersheds("D:\\" + file  + ".in");
            s.computeCase("D:\\" + file + ".out");
         } finally {
            if (s != null) {
                s.close();
            }
        }
    }
}
