package fr.diod.gcj2013.qualif.exo3;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Scanner;

public class Exo3 {
	private Scanner fileScanner;
	private Scanner lineScanner;
	private int numberOfCase;

	public Exo3(String fileName) {
		try {
			fileScanner = new Scanner(new BufferedReader(new FileReader(fileName)));
			numberOfCase = fileScanner.nextInt();
			nextLine();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
	}

	public int getNumberOfCase() {
		return numberOfCase;
	}

	public boolean hasNextLine() {
		return fileScanner.hasNextLine();
	}

	public String nextLine() {
		String nextLine = fileScanner.nextLine();
		//		System.out.println("Exo2.nextLine():" + nextLine);
		lineScanner = new Scanner(nextLine);
		return nextLine;
	}

	public boolean hasNext() {
		return lineScanner.hasNext();
	}

	public String next() {
		return lineScanner.next();
	}

	public int nextInt() {
		return lineScanner.nextInt();
	}

	public void close() {
		if (lineScanner != null) {
			lineScanner.close();
		}
		fileScanner.close();
	}


	private void computeCase(String outPutFileName) throws IOException {
		BufferedWriter file = new BufferedWriter(new FileWriter(outPutFileName));

		for (int i = 0; i < numberOfCase; i++) {
			nextLine();

			BigInteger min = new BigInteger(next());
			BigInteger max = new BigInteger(next());
			String result = getResult(min , max);

			file.append("Case #" + (i + 1) + ": " + result);
			System.out.println("Case #" + (i + 1) + " : " + result);
			file.newLine();
		}
		file.close();
	}


	private String getResult(BigInteger min, BigInteger max) {
		int count = 0;
		BigInteger current = min.subtract(BigInteger.ONE);

		while(true) {
			current = nextPalindrome(current);

			if(current.compareTo(max) > 0) {
				break;
			}

			BigInteger squareRoot = squareRoot(current);

			if (isPalindrome(squareRoot)) {
				count++;
			}
		}

		return String.valueOf(count);
	}

	private BigInteger squareRoot(BigInteger current) {
		
		double doubleValue = current.doubleValue();
		
		if (Double.isInfinite(doubleValue)) {
			BigInteger nrsqrt = nrsqrt(current);
			if (current.compareTo(nrsqrt.multiply(nrsqrt)) != 0) {
				return null;
			}
			
			return nrsqrt;
		}
		double sqrt = Math.sqrt(doubleValue);
		if (Double.compare(Math.abs(sqrt - Math.ceil(sqrt)), 0.001)>0) {
			return null;
		}

		return BigInteger.valueOf((long) sqrt);
	}

	private static BigInteger nrsqrt(BigInteger n) {
		// Uses the fact that the square root, any base, usually has 1/2
		// the digits of the number to take root of to get a close first
		// guess. NR converges fast when close to the actual value.
		//
		// If I used the number itself instead of the TWO I started with
		// it would of probably been better since I saw somewhere that
		// initial values close to a minimum can cause it to not converge.
		//
		// All of this was from various mail forum posts I googled.
		// It seems correct and despite not eliminating the one divide it
		// seems fast enough for a BigInteger squareroot.
		//
		// At least for now.
		//
		BigInteger t = n.shiftRight(BigInteger.valueOf(n.bitLength()).shiftRight(1).intValue()),
				result = null; 
		for (;;) {
			result = t.add(n.divide(t)).shiftRight(1);
			if (t.compareTo(result) == 0) break;
			t = result;
		}
		return result;
	}

	private boolean isPalindrome(BigInteger squareRoot) {
		if (squareRoot == null) {
			return false;
		}

		String stringSquareRoot = squareRoot.toString();

		int length = stringSquareRoot.length()/2 + stringSquareRoot.length()%2;
		for (int i = 0; i < length; i++) {
			if (stringSquareRoot.charAt(i) != stringSquareRoot.charAt(stringSquareRoot.length() - 1 - i)) {
				return false;
			}
		}

		return true;
	}

	private BigInteger nextPalindrome(BigInteger value) {
		String stringValue = value.toString();
		char[] stringResult = new char[stringValue.length()];
		int size = stringValue.length()/2 + stringValue.length()%2 - 1;

		for (int i = 0; i <= size; i++) {
			stringResult[i] = stringValue.charAt(i);
			stringResult[stringResult.length-1 - i] = stringResult[i];
		}

		BigInteger resultValue = new BigInteger(String.copyValueOf(stringResult));
		int lastElement = stringResult.length-1;

		while (value.compareTo(resultValue) >= 0) {
			for (int i = size; i >= 0; i--) {
				char current = stringResult[i];


				if (current == '9') {
					if (i == 0) {
						stringResult = new char[stringResult.length + 1];
						Arrays.fill(stringResult, '0');
						stringResult[0] = '1';
						stringResult[stringResult.length - 1] = '1';
						break;
					}

					for (int j = i; j >= size; j--) {
						stringResult[j] = '0';
						stringResult[lastElement - j] = stringResult[j];
					}


					if (stringResult[i-1] != '9') {
						stringResult[i-1] = (char) (stringResult[i-1] + 1);
						stringResult[lastElement - i + 1] = stringResult[i-1]; // FIXME
						break;
					}
				} else {
					stringResult[i] = (char) (current + 1);
					stringResult[lastElement - i] = stringResult[i];
					break;
				}
			}

			resultValue = new BigInteger(String.copyValueOf(stringResult));
		}

		return resultValue;
	}



	public static void main(String[] args) {

		//		String inputFileName = "test";
		//		String inputFileName = "C-small-attempt0";
		String inputFileName = "C-large-2";

		Exo3 exo = new Exo3("/home/didier/Téléchargements/" + inputFileName + ".in");

		try {
			exo.computeCase("/home/didier/Téléchargements/" + inputFileName + ".out");
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
