import java.io.*;
import java.util.Locale;
import java.util.StringTokenizer;
import java.util.concurrent.Callable;
import java.util.concurrent.Future;
import java.util.concurrent.ScheduledThreadPoolExecutor;

public class SolutionA implements Runnable {

    private PrintWriter out;

    final String file = "A-large";

    static class InputData {
        int r;
        int c;
        int w;

        InputData(FastReader in) throws IOException {
            r = in.nextInt();
            c = in.nextInt();
            w = in.nextInt();
        }

        void solve(PrintWriter out) {
            int result = 0;
            result += (r - 1) * (c / w);

            int cur = c;
            while (cur > 2*w) {
                cur -= w;
                result++;
            }
            if (cur == w) {
                result += w;
            } else {
                result += w + 1;
            }

            out.println(result);
        }
    }

    static class Solver implements Callable<String> {

        InputData data;

        Solver(InputData data) {
            this.data = data;
        }

        @Override
        public String call() throws Exception {
            StringWriter out = new StringWriter();
            data.solve(new PrintWriter(out));
            return out.toString();
        }

    }

    public void run() {
        try {
            FastReader in = new FastReader(new BufferedReader(new FileReader(file + ".in")));
            out = new PrintWriter(file + ".out");

            ScheduledThreadPoolExecutor service = new ScheduledThreadPoolExecutor(8);

            int tests = in.nextInt();
            Future<String>[] ts = new Future[tests];
            for (int test = 0; test < tests; ++test) {
                ts[test] = service.submit(new Solver(new InputData(in)));
            }
            for (int test = 0; test < tests; ++test) {
                while (!ts[test].isDone()) {
                    Thread.sleep(500);
                }
                System.err.println("Test " + test);
                out.print("Case #" + (test + 1) + ": ");
                out.print(ts[test].get());
            }
            service.shutdown();

            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    static class FastReader {
        public FastReader(BufferedReader in) {
            this.in = in;
            eat("");
        }

        private StringTokenizer st;
        private BufferedReader in;

        void eat(String s) {
            st = new StringTokenizer(s);
        }

        String next() throws IOException {
            while (!st.hasMoreTokens()) {
                String line = in.readLine();
                if (line == null) {
                    return null;
                }
                eat(line);
            }
            return st.nextToken();
        }

        int nextInt() throws IOException {
            return Integer.parseInt(next());
        }

        long nextLong() throws IOException {
            return Long.parseLong(next());
        }

        double nextDouble() throws IOException {
            return Double.parseDouble(next());
        }
    }

    public static void main(String[] args) {
        Locale.setDefault(Locale.US);
        new SolutionA().run();
    }

}
