import java.io.*;
import java.util.*;

public class SavingTheUniverse {

    private static class Queries {
        Map<String, Integer> index = new HashMap<String, Integer>();
        List<Integer> queries = new ArrayList<Integer>();
        int numberSwitches;

        public Map<String, Integer> getIndex() {
            return index;
        }

        public void setIndex(Map<String, Integer> index) {
            this.index = index;
        }

        public List<Integer> getQueries() {
            return queries;
        }

        public void setQueries(List<Integer> queries) {
            this.queries = queries;
        }

        public int getNumberSwitches() {
            return numberSwitches;
        }

        public void setNumberSwitches(int numberSwitches) {
            this.numberSwitches = numberSwitches;
        }
    }

    private static byte[] readContent(String fileName) {
        File input = new File(fileName);
        FileInputStream is = null;
        byte[] content = null;
        try {
            is = new FileInputStream(input);
            content = new byte[(int) input.length()];
            is.read(content);
        } catch (FileNotFoundException e) {
            throw new RuntimeException("File Not Found");
        } catch (IOException e) {
            throw new RuntimeException("Exception while reading file");
        } finally {
            try {
                if (is != null) {
                    is.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return content;
    }

     public static void main(String[] args){
        String inputPath = args[0];
        byte[] content =  readContent(inputPath);
        List<Queries> queries = parseContent(content);
        processContent(queries);
        saveResult(queries, inputPath.substring(0, inputPath.lastIndexOf(File.separator)));
         
     }

    private static List<Queries> parseContent(byte[] content){
        List<Queries> queries = new ArrayList<Queries>();
        if (content!=null && content.length > 0) {
            StringTokenizer rowTokenizer = new StringTokenizer(new String(content), "\r\n");
            boolean fullSizeFound = false;
            boolean engineSizeFound = false;
            boolean querySizeFound = false;

            int fullSize = 0;
            int curEngineSize = 0;
            int curQuerySize = 0;


            int curEngineCount = 0;
            int curQueryCount = 0;


            Queries curQueries = null;
            while (rowTokenizer.hasMoreTokens()) {

                String row = rowTokenizer.nextToken();
                if(!fullSizeFound && !engineSizeFound && !querySizeFound) {
                    fullSize = Integer.parseInt(row);
                    fullSizeFound = true;
                    continue;
                }

                if(fullSizeFound && !engineSizeFound && !querySizeFound) {
                    curQueries = new Queries();
                    curEngineSize = Integer.parseInt(row);
                    engineSizeFound = true;
                    continue;
                }

                if(fullSizeFound && engineSizeFound && !querySizeFound) {

                   if (curEngineCount < curEngineSize) {
                    curQueries.index.put(row, new Integer(curEngineCount));
                   } else {
                    querySizeFound = true;
                    curQuerySize = Integer.parseInt(row);
                    curEngineCount = 0;
                    continue;
                   }

                   curEngineCount++;
                }

                if(fullSizeFound && engineSizeFound && querySizeFound) {
                    if(curQueryCount < curQuerySize) {
                        curQueries.queries.add(curQueries.index.get(row));
                    } else {
                        curEngineSize = Integer.parseInt(row);
                        engineSizeFound = true;
                        querySizeFound = false;
                        curQueryCount = 0;
                        curQuerySize = 0;

                        curEngineCount = 0;

                        queries.add(copyQueries(curQueries));
                        curQueries = new Queries(); 
                        continue;
                    }
                    curQueryCount++;
                }
            }
            queries.add(copyQueries(curQueries));


        }
        return queries;
    }

    private static Queries copyQueries(Queries q){
        Queries newQ = new Queries();
        newQ.index.putAll(q.index);
        newQ.queries.addAll(q.queries);
        return newQ;
    }

    private static void processContent(List<Queries> queries){
        for (Queries curQueries: queries) {
            int switchesCount = 0;
            int curEngineSize = curQueries.index.size();
            Set<Integer> curSequence = new HashSet<Integer>();
            for (Integer curQuery: curQueries.queries) {
                curSequence.add(curQuery);
                if (curSequence.size() >= curEngineSize) {
                    switchesCount++;
                    curSequence = new HashSet<Integer>();
                    curSequence.add(curQuery);
                }
            }
            curQueries.setNumberSwitches(switchesCount);    
        }
    }

    private static void saveResult(List<Queries> queries, String dir) {
        StringBuilder builder = new StringBuilder();
        int curIndex = 1;
        for (Queries cur: queries) {
            builder.append("Case #").append(curIndex).append(": ").append(cur.numberSwitches).append("\r\n");
            curIndex++;
        }
        String result = builder.toString();


        FileWriter writer = null;
        try {
            writer = new FileWriter(new File(dir + File.separator + "output.txt"));
            writer.write(builder.toString());
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                if (writer != null) {
                    writer.flush();
                    writer.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

}

