import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.util.Set;
import java.util.HashSet;
import java.io.*;


public class CropTriangles {

        private static class Inputs {
            long n;
            long x0;
            long y0;
            long A;
            long B;
            long C;
            long D;
            long M;

            List<Point> points = new ArrayList<Point>();
            long count = 0;
        }

        private static class Point {
            long x;
            long y;

            public boolean equals(Object obj) {
                Point point1 = (Point) obj;
                return point1.x ==this.x && point1.y ==this.y ;
            }
        }


        public static void main(String[] args) throws FileNotFoundException {
            String inputPath = args[0];
            List<Inputs> inputs = new ArrayList<Inputs>();
            FileReader reader = new FileReader(inputPath);
            parseContent(reader, inputs);
            calculateXY(inputs);


            processContent(inputs);
            saveResult(inputs, inputPath.substring(0, inputPath.lastIndexOf(File.separator)));
        }


        private static void calculateXY(List<Inputs> inputs) {

            List<Point> pointList = new ArrayList<Point>();
            /*
            X = x0, Y = y0
            print X, Y
            for i = 1 to n-1
            X = (A * X + B) mod M
            Y = (C * Y + D) mod M
            print X, Y

             */

            for(Inputs input: inputs) {

                long x =input.x0;
                long y =input.y0;
                Point point = new Point();
                point.x = x;
                point.y = y;
                input.points.add(point);

                for (int i=1; i <= (input.n-1); i++) {
                    Point curPoint = new Point();
                    x = (input.A * x + input.B) % input.M;
                    y = (input.C * y + input.D) % input.M;
                    curPoint.x = x;
                    curPoint.y = y;
                    input.points.add(curPoint);
                }
            }
        }

        private static void parseContent(FileReader reader, List<Inputs> inputs){
            BufferedReader bufReader = new BufferedReader(reader);
             try{
                String curRow = "";
                 boolean sizeFound = false;
                 while ((curRow = bufReader.readLine())!=null) {

                     if (!sizeFound) {
                         sizeFound = true;
                        continue;
                     } else {
                         //n, A, B, C, D, x0, y0
                         String[] splittedRow = curRow.split(" ");
                         Inputs input = new Inputs();
                         input.n = Integer.parseInt(splittedRow[0]);
                         input.A = Integer.parseInt(splittedRow[1]);
                         input.B = Integer.parseInt(splittedRow[2]);
                         input.C = Integer.parseInt(splittedRow[3]);
                         input.D = Integer.parseInt(splittedRow[4]);
                         input.x0 = Integer.parseInt(splittedRow[5]);
                         input.y0 = Integer.parseInt(splittedRow[6]);
                         input.M = Integer.parseInt(splittedRow[7]);
                         inputs.add(input);
                     }
                 }
             } catch(Exception ex) {

             } finally {
                 try {
                     bufReader.close();
                 } catch (IOException e) {
                     e.printStackTrace();
                 }
             }
        }


        private static void processContent(List<Inputs> inputs){

            for (Inputs input: inputs) {
                int count = 0;

                for(int i=0;i<input.points.size();i++) {
                    Point point1 =input.points.get(i);
                    for(int j=(i+1); j<input.points.size();j++) {
                        Point point2 =input.points.get(j);
                        for(int k=(j+1); k<input.points.size();k++) {
                            Point point3 =input.points.get(k);    
                            if (!((point1.x==point2.x && point1.y==point2.y) ||
                                (point1.x==point3.x && point1.y==point3.y) ||
                                (point2.x==point3.x && point2.y==point3.y))
                                    && ((point1.x + point2.x + point3.x)%(long)3==0) &&
                                        ((point1.y+point2.y+point3.y)%(long)3==0) ) {
                                count++;
                            }
                        }
                 }
                }
                input.count = count;
            }

        }

       private static void saveResult(List<Inputs> inputs, String dir) {

        StringBuilder builder = new StringBuilder();
        int curIndex = 1;
        for (Inputs cur: inputs) {
            builder.append("Case #").append(curIndex).append(": ").
                    append(cur.count).append("\r\n");
            curIndex++;
        }
        String result = builder.toString();


        FileWriter writer = null;
        try {
            writer = new FileWriter(new File(dir + File.separator + "output.txt"));
            writer.write(builder.toString());
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                if (writer != null) {
                    writer.flush();
                    writer.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }
}
