import java.io.*;
import java.util.*;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.text.ParseException;

public class TrainTimetable {

    private static class TrainTrip implements Comparable<TrainTrip>{
        //time in minutes from begining of the day
        int beginTime;
        int endTime;
        //true if from A to B, false in other case
        boolean fromAtoB;

        public int compareTo(TrainTrip o) {
            if(this.beginTime < o.beginTime){
                return -1;
            } else if(this.beginTime > o.beginTime){
                return 1;
            } else {
                return 0;
            }
        }
    }

    private static class Timetable {
        List<TrainTrip> tripsFromA = new ArrayList<TrainTrip>();
        List<TrainTrip> tripsFromB = new ArrayList<TrainTrip>();
        int turnArroundTime = 0;
        int totalTrainsRequiredInA = 0;
        int totalTrainsRequiredInB = 0;
    }

    public static void main(String[] args) {

        String inputPath = args[0];
        byte[] content =  readContent(inputPath);
        List<Timetable> timetables = new ArrayList<Timetable>();
        parseContent(content, timetables);
        processContent(timetables);
        saveResult(timetables, inputPath.substring(0, inputPath.lastIndexOf(File.separator)));
    }

    private static byte[] readContent(String fileName) {
        File input = new File(fileName);
        FileInputStream is = null;
        byte[] content = null;
        try {
            is = new FileInputStream(input);
            content = new byte[(int) input.length()];
            is.read(content);
        } catch (FileNotFoundException e) {
            throw new RuntimeException("File Not Found");
        } catch (IOException e) {
            throw new RuntimeException("Exception while reading file");
        } finally {
            try {
                if (is != null) {
                    is.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return content;
    }

    private static void parseContent(byte[] content, List<Timetable> timetables){

        if (content!=null && content.length > 0) {
            StringTokenizer rowTokenizer = new StringTokenizer(new String(content), "\r\n");
            boolean fullSizeFound = false;
            boolean turnArroundFound = false;
            boolean timeTableSizeFound = false;

            int fullSize = 0;
            int timetableASize = 0;
            int timetableBSize = 0;
            int timetableCount = 0;

            String row = "";
            Timetable curTimetable = new Timetable();
            while (rowTokenizer.hasMoreTokens()) {
                row = rowTokenizer.nextToken();
                if(!fullSizeFound && !turnArroundFound && !timeTableSizeFound) {
                    fullSize = Integer.parseInt(row);
                    fullSizeFound = true;
                    continue;
                }

                if (fullSizeFound && !turnArroundFound && !timeTableSizeFound) {
                    curTimetable.turnArroundTime = Integer.parseInt(row);
                    turnArroundFound = true;
                    continue;
                }

                if (fullSizeFound && turnArroundFound && !timeTableSizeFound) {
                    StringTokenizer sizeTokenizer = new StringTokenizer(row, " ");
                    timetableASize = Integer.parseInt(sizeTokenizer.nextToken());
                    timetableBSize = Integer.parseInt(sizeTokenizer.nextToken());
                    timeTableSizeFound = true;
                    continue;
                }

                if (fullSizeFound && turnArroundFound && timeTableSizeFound) {
                   if (timetableCount < (timetableASize + timetableBSize)) {
                       if (timetableCount < timetableASize) {
                           StringTokenizer dateTokenizer = new StringTokenizer(row, " :");
                           TrainTrip trip = new TrainTrip();
                           trip.beginTime = Integer.parseInt(dateTokenizer.nextToken()) * 60 + Integer.parseInt(dateTokenizer.nextToken());
                           trip.endTime = Integer.parseInt(dateTokenizer.nextToken()) * 60 + Integer.parseInt(dateTokenizer.nextToken());
                           trip.fromAtoB = true;

                           curTimetable.tripsFromA.add(trip);
                       } else {
                           StringTokenizer dateTokenizer = new StringTokenizer(row, " :");
                           TrainTrip trip = new TrainTrip();
                           trip.beginTime = Integer.parseInt(dateTokenizer.nextToken()) * 60 + Integer.parseInt(dateTokenizer.nextToken());
                           trip.endTime = Integer.parseInt(dateTokenizer.nextToken()) * 60 + Integer.parseInt(dateTokenizer.nextToken());
                           trip.fromAtoB = false;

                           curTimetable.tripsFromB.add(trip);
                       }
                       timetableCount++;
                   } else {
                        timetables.add(copyTimeTable(curTimetable));
                        curTimetable = new Timetable();
                        curTimetable.turnArroundTime = Integer.parseInt(row);
                        turnArroundFound = true;
                        timeTableSizeFound = false;
                        timetableASize = 0;
                        timetableBSize = 0;
                        timetableCount = 0;
                   }
                }
            }
            timetables.add(copyTimeTable(curTimetable));
        }
    }

    private static Timetable copyTimeTable(Timetable forCopy){
        Timetable timeTable = new Timetable();
        timeTable.turnArroundTime = forCopy.turnArroundTime;
        timeTable.tripsFromA.addAll(forCopy.tripsFromA);
        timeTable.tripsFromB.addAll(forCopy.tripsFromB);
        return timeTable;
    }

    private static void processContent(List<Timetable> timetables){
        int numberOfUsedTrains = 0;
        for (Timetable curTimetable: timetables) {
            Collections.sort(curTimetable.tripsFromA);
            Collections.sort(curTimetable.tripsFromB);
            numberOfUsedTrains = 0;
            //process station A
            int curTime = -1;
            for (TrainTrip curTrip: curTimetable.tripsFromA) {
                if (curTime == curTrip.beginTime) {
                    continue;
                }
                curTime = curTrip.beginTime;
                int numberOfStartTrainFromA = numberOfStartTrain(curTimetable.tripsFromA, curTime);
                int numberOfReadyTrains = numberOfArriveTrain(curTimetable.tripsFromB, (curTime - curTimetable.turnArroundTime));

                int numberOfNeedTrain = numberOfStartTrainFromA - (numberOfReadyTrains - numberOfUsedTrains);

                if (numberOfNeedTrain > 0) {
                   curTimetable.totalTrainsRequiredInA += numberOfNeedTrain;
                }
                if (numberOfNeedTrain < 0) {
                    numberOfUsedTrains += (numberOfReadyTrains - numberOfUsedTrains) + numberOfNeedTrain;
                } else {
                    numberOfUsedTrains += (numberOfReadyTrains - numberOfUsedTrains);
                }
            }

            //process station B
            curTime = -1;
            numberOfUsedTrains = 0;
            for (TrainTrip curTrip: curTimetable.tripsFromB) {
                if (curTime == curTrip.beginTime) {
                    continue;
                }
                curTime = curTrip.beginTime;
                int numberOfStartTrainFromB = numberOfStartTrain(curTimetable.tripsFromB, curTime);
                int numberOfReadyTrains = numberOfArriveTrain(curTimetable.tripsFromA, (curTime - curTimetable.turnArroundTime));

                int numberOfNeedTrain = numberOfStartTrainFromB - (numberOfReadyTrains - numberOfUsedTrains);

                if (numberOfNeedTrain > 0) {
                   curTimetable.totalTrainsRequiredInB += numberOfNeedTrain;
                }
                if (numberOfNeedTrain < 0) {
                    numberOfUsedTrains += (numberOfReadyTrains - numberOfUsedTrains) + numberOfNeedTrain;
                } else {
                    numberOfUsedTrains += (numberOfReadyTrains - numberOfUsedTrains);
                }
            }
       }
    }

    private static int findMinBeginTime(List<TrainTrip> trips, int startAt) {
        int min = startAt;
        for (TrainTrip trip: trips) {
            if (trip.beginTime < min) {
                min = trip.beginTime;
            }
        }
        return min;
    }

    private static int numberOfStartTrain(List<TrainTrip> trips, int startAt) {
        int count = 0;
        for (TrainTrip trip: trips) {
            if (trip.beginTime == startAt) {
                count++;
            }
        }
        return count;
    }

    private static int numberOfArriveTrain(List<TrainTrip> trips, int arriveTime) {
        int count = 0;
        for (TrainTrip trip: trips) {
            if (trip.endTime <= arriveTime) {
                count++;
            }
        }
        return count;
    }

    private static int findMinEndTime(List<TrainTrip> trips, int startAt) {
        int min = startAt;
        for (TrainTrip trip: trips) {
            if (trip.endTime < min) {
                min = trip.endTime;
            }
        }
        return min;
    }



    private static void saveResult(List<Timetable> timeTables, String dir) {
        StringBuilder builder = new StringBuilder();
        int curIndex = 1;
        for (Timetable cur: timeTables) {
            builder.append("Case #").append(curIndex).append(": ").
                    append(cur.totalTrainsRequiredInA).append(" ").append(cur.totalTrainsRequiredInB).append("\r\n");
            curIndex++;
        }
        String result = builder.toString();


        FileWriter writer = null;
        try {
            writer = new FileWriter(new File(dir + File.separator + "output.txt"));
            writer.write(builder.toString());
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                if (writer != null) {
                    writer.flush();
                    writer.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }
}
