import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.math.MathContext;
import java.math.RoundingMode;
import java.util.ArrayList;

public class Numbers {
	BufferedReader r;
	BufferedWriter w;
	int C = 0;
	
	public static BigDecimal bigSqrt(BigDecimal squarD, MathContext rootMC) {
	    BigDecimal TWO = new BigDecimal(2);
	    double SQRT_10 = 3.162277660168379332;
	    

	    // General number and precision checking
	    int sign = squarD.signum();
	    if(sign == -1)
	      throw new ArithmeticException("\nSquare root of a negative number: " + squarD);
	    else if(sign == 0)
	      return squarD.round(rootMC);
	    
	    int prec = rootMC.getPrecision();           // the requested precision
	    if(prec == 0)
	      throw new IllegalArgumentException("\nMost roots won't have infinite precision = 0");
	    
	    // Initial precision is that of double numbers 2^63/2 ~ 4E18
	    int BITS = 62;                              // 63-1 an even number of number bits
	    int nInit = 16;                             // precision seems 16 to 18 digits
	    MathContext nMC = new MathContext(18, RoundingMode.HALF_DOWN);
	    
	    
	    // Iteration variables, for the square root x and the reciprocal v
	    BigDecimal x = null, e = null;              // initial x:  x0 ~ sqrt()
	    BigDecimal v = null, g = null;              // initial v:  v0 = 1/(2*x)
	    
	    // Estimate the square root with the foremost 62 bits of squarD
	    BigInteger bi = squarD.unscaledValue();     // bi and scale are a tandem
	    int biLen = bi.bitLength();
	    int shift = Math.max(0, biLen - BITS + (biLen%2 == 0 ? 0 : 1));   // even shift..
	    bi = bi.shiftRight(shift);                  // ..floors to 62 or 63 bit BigInteger
	    
	    double root = Math.sqrt(bi.doubleValue());
	    BigDecimal halfBack = new BigDecimal(BigInteger.ONE.shiftLeft(shift/2));
	    
	    int scale = squarD.scale();
	    if(scale % 2 == 1)                          // add half scales of the root to odds..
	      root *= SQRT_10;                          // 5 -> 2, -5 -> -3 need half a scale more..
	    scale = (int)Math.floor(scale/2.);          // ..where 100 -> 10 shifts the scale
	    
	    // Initial x - use double root - multiply by halfBack to unshift - set new scale
	    x = new BigDecimal(root, nMC);
	    x = x.multiply(halfBack, nMC);                          // x0 ~ sqrt()
	    if(scale != 0)
	      x = x.movePointLeft(scale);

	    if(prec < nInit)                 // for prec 15 root x0 must surely be OK
	      return x.round(rootMC);        // return small prec roots without iterations

	    // Initial v - the reciprocal
	    v = BigDecimal.ONE.divide(TWO.multiply(x), nMC);        // v0 = 1/(2*x)
	    
	    
	    // Collect iteration precisions beforehand
	    ArrayList nPrecs = new ArrayList();
	    
	    assert nInit > 3 : "Never ending loop!";                // assume nInit = 16 <= prec
	    
	    // Let m be the exact digits precision in an earlier! loop
	    for(int m = prec+1; m > nInit; m = m/2 + (m > 100 ? 1 : 2))                      
	      nPrecs.add(m);
	    

	    // The loop of "Square Root by Coupled Newton Iteration" for simpletons
	    for(int i = nPrecs.size()-1; i > -1; i--)
	    {
	      // Increase precision - next iteration supplies n exact digits
	      nMC = new MathContext((Integer) nPrecs.get(i), (i%2 == 1) ? RoundingMode.HALF_UP : 
	                                                        RoundingMode.HALF_DOWN);
	      
	      // Next x                                                 // e = d - x^2
	      e = squarD.subtract(x.multiply(x, nMC), nMC);
	      if(i != 0)
	        x = x.add(e.multiply(v, nMC));                          // x += e*v     ~ sqrt()
	      else
	      {
	        x = x.add(e.multiply(v, rootMC), rootMC);               // root x is ready!
	        break;
	      }

	      // Next v                                                 // g = 1 - 2*x*v
	      g = BigDecimal.ONE.subtract(TWO.multiply(x).multiply(v, nMC));
	      
	      v = v.add(g.multiply(v, nMC));                            // v += g*v     ~ 1/2/sqrt()
	    }

	    return x;                        // return sqrt(squarD) with precision of rootMC
	  }
	
	void solveInput() throws IOException {
		String s = r.readLine();
		int N = Integer.parseInt(s);

		BigDecimal a = new BigDecimal(3);
		BigDecimal b = new BigDecimal(5);
		b = bigSqrt(b, new MathContext(100));
		a = a.add(b);
		a = a.pow(N);
		
		s = a.toString();
		int pos = s.indexOf('.') - 1;
		String res = "";
		for (int i = pos; i >= 0; --i) {
			res = s.charAt(i) + res;
			if (3 == res.length()) {break;}
		}
		while (res.length() < 3) {
			res = '0' + res;
		}
		
		w.write(res + '\n');
	}
	
	void solve() throws IOException {
		r = new BufferedReader(new FileReader("c.in"));
		w = new BufferedWriter(new FileWriter("c.out"));
		
		String s = r.readLine();
		C = Integer.parseInt(s);
		for (int i = 0; i < C; ++i) {
			w.write("Case #" + (i + 1) + ": ");
			solveInput();
		}
		
		r.close();
		w.close();
	}
	public static void main(String[] args) throws IOException {
		(new Numbers()).solve();
	}

}
