package name.dlazerka.codejam.y2017.c;

import java.io.IOException;
import java.math.BigInteger;
import java.nio.file.*;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.stream.Collectors;

import static java.nio.charset.StandardCharsets.US_ASCII;
import static java.nio.file.StandardOpenOption.CREATE;
import static java.nio.file.StandardOpenOption.TRUNCATE_EXISTING;

public class C_Qualification_2017 {
	static String IN_FILE
			//= "test.in";
			//= "C-small-1-attempt0.in";
			//= "C-small-1-attempt1.in";
			//= "C-small-2-attempt0.in";
			= "C-large.in";

	static Path inPath;
	static Path outPath;

	static {
		FileSystem fs = FileSystems.getDefault();
		// Not class.getResource() because we keep those in 'src', not 'resources'.
		String className = C_Qualification_2017.class.getPackage().getName();

		inPath = fs.getPath("src/main/java", className.replace('.', '/'), IN_FILE);
		if (!Files.exists(inPath)) {
			throw new RuntimeException(new NoSuchFileException(inPath.toAbsolutePath().toString()));
		}
		outPath = inPath.resolveSibling(inPath.getFileName().toString().replace(".in", ".out"));
	}

	static class Test {
		final int num;
		final BigInteger N;
		final BigInteger K;

		Test(int num, Iterator<String> lines) {
			this.num = num;
			BigInteger[] ints = IO.readBigIntegers(lines.next());
			N = ints[0];
			K = ints[1];
		}

		static class Pool {
			final BigInteger size;
			final BigInteger count;

			Pool(BigInteger size, BigInteger count) {
				this.size = size;
				this.count = count;
			}

			@Override
			public String toString() {
				return size + " x " + count;
			}
		}

		ArrayDeque<Pool> pools = new ArrayDeque<>();

		String solve() {
			BigInteger k = K;

			pools.add(new Pool(N, BigInteger.ONE));

			BigInteger min = null;
			BigInteger max = null;

			while (k.compareTo(BigInteger.ZERO) > 0) {
				Pool bestPool = pools.pollFirst();

				if (bestPool.size.testBit(0)) { // odd
					min = max = bestPool.size.shiftRight(1);
					BigInteger count = bestPool.count.shiftLeft(1);
					addPool(new Pool(max, count));
				} else { // even
					max = bestPool.size.shiftRight(1);
					addPool(new Pool(max, bestPool.count));

					min = max.subtract(BigInteger.ONE);
					addPool(new Pool(min, bestPool.count));
				}

				k = k.subtract(bestPool.count);
			}

			return "" + max + " " + min;
		}

		void addPool(Pool pool) {
			Pool lastPool = pools.peekLast();
			if (lastPool != null && lastPool.size.equals(pool.size)) {
				pools.pollLast();
				pools.add(new Pool(pool.size, pool.count.add(lastPool.count)));
			} else {
				pools.addLast(pool);
			}
		}
	}

	public static void main(String[] args) throws Exception {
		List<Test> cases = read();

		List<String> outs = cases
				.stream()
				.map(c -> "Case #" + c.num + ": " + c.solve())
				.collect(Collectors.toList());

		// Also write to STDOUT
		outs.forEach(System.out::println);

		Files.write(outPath, outs, US_ASCII, CREATE, TRUNCATE_EXISTING);

	}

	static List<Test> read() throws IOException {
		Iterator<String> lines = Files.lines(inPath, US_ASCII).iterator();

		int T = Integer.parseInt(lines.next());
		List<Test> tests = new ArrayList<>(T);
		for (int ci = 1; ci <= T; ci++) {
			tests.add(new Test(ci, lines));
		}
		return tests;
	}

	@SuppressWarnings("unused")
	static class IO {
		/**
		 * Use Arrays.asList() if you want a List.
		 */
		public static int[] readInts(String line) {
			String[] split = line.trim().split(" ");
			int[] result = new int[split.length];
			for (int i = 0; i < result.length; i++) {
				result[i] = Integer.parseInt(split[i]);
			}

			return result;
		}

		/**
		 * Use Arrays.asList() if you want a List.
		 */
		public static long[] readLongs(String line) {
			String[] split = line.trim().split(" ");
			long[] result = new long[split.length];
			for (int i = 0; i < result.length; i++) {
				result[i] = Long.parseLong(split[i]);
			}

			return result;
		}

		public static BigInteger[] readBigIntegers(String line) {
			String[] split = line.split(" ");
			BigInteger[] result = new BigInteger[split.length];
			for (int i = 0; i < split.length; i++) {
				result[i] = new BigInteger(split[i]);
			}
			return result;
		}

		public static void printMap(char[][] map) {
			for (char[] charMap : map) {
				System.out.println(charMap);
			}
		}
	}
}
