package name.dlazerka.codejam.y2016.c;

import com.google.common.base.Stopwatch;
import com.google.common.base.Throwables;
import com.google.common.math.BigIntegerMath;

import javax.annotation.Nullable;
import java.io.BufferedWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.math.RoundingMode;
import java.nio.file.FileSystem;
import java.nio.file.FileSystems;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import static java.nio.file.StandardOpenOption.CREATE;
import static java.nio.file.StandardOpenOption.TRUNCATE_EXISTING;
import static java.util.concurrent.TimeUnit.MILLISECONDS;

public class Main {
	static FileSystem fs = FileSystems.getDefault();

	//static String TEST = "test";
	//static String TEST = "small";
	static String TEST = "large";

	public static void main(String[] args) throws Exception {
		Stopwatch startedAt = Stopwatch.createStarted();
		List<Main> cases = read();

		List<String> res = cases
				.stream()
				.map(c -> "Case #" + c.num + ": " + c.solve() + "\n")
				.collect(Collectors.toList());

		res.forEach(System.out::print);

		Path out = fs.getPath("out." + TEST);
		try (BufferedWriter writer = Files.newBufferedWriter(out, CREATE, TRUNCATE_EXISTING)) {
			res.forEach(r -> {
				try {
					writer.write(r);
				} catch (IOException e) {
					Throwables.propagate(e);
				}
			});
		}


		System.out.println(startedAt.elapsed(MILLISECONDS) + "ms");
	}

	static List<Main> read() throws IOException {
		Main main = new Main(1);

		if (TEST.equals("test")) {
			main.N = 6;
			main.J = 3;
		}

		if (TEST.equals("small")) {
			main.N = 16;
			main.J = 50;
		}

		if (TEST.equals("large")) {
			main.N = 32;
			main.J = 500;
		}

		return Collections.singletonList(main);
	}


	final int num;
	public Main(int num) {
        this.num = num;
    }

	////////////////////////////

	int N;
	int J;

   	String solve() {
	    StringBuilder result = new StringBuilder();
	    result.append('\n');
	    char[] cc = new char[N];
	    cc[0] = '1';
	    cc[N-1] = '1';
	    for (int i = 1; i < N-1; i++) {
		    cc[i] = '0';
	    }

	    long test = Long.parseUnsignedLong(new String(cc), 2);

	    for (int j = 0; j < J;) {
		    System.out.print("\nTesting " + test);

		    BigInteger[] factors = getFactors(test);
		    if (factors != null) {
			    System.out.print("Success, j=" + j);
			    j++;
			    result.append(Long.toBinaryString(test));
			    for (int r = 2; r <= 10; r++) {
				    result.append(' ').append(factors[r - 2].toString());
			    }
			    result.append("\n");
		    }

		    test++;
		    test++;
	    }

	    return result.toString();
    }

	@Nullable
	BigInteger[] getFactors(long test) {
		String s = Long.toBinaryString(test);

		BigInteger[] result = new BigInteger[9];

		for (int r = 2; r <= 10; r++) {
			System.out.print(" " + r + " ");
			BigInteger num = new BigInteger(s, r);

			BigInteger f = getFirstFactor(num);
			if (f == null) {
				return null;
			}
			result[r - 2] = f;
		}
		return result;
	}

	private BigInteger getFirstFactor(BigInteger num) {
		if (num.isProbablePrime(10)) {
			System.out.print("Probably prime");
			return null;
		}

		//BigInteger sq = BigIntegerMath.sqrt(num, RoundingMode.FLOOR);
		BigInteger sq = BigInteger.valueOf(10000);

		for (BigInteger i = BigInteger.valueOf(2); i.compareTo(sq) <= 0; i = i.add(BigInteger.ONE)) {
			if (num.remainder(i).equals(BigInteger.ZERO)) {
				return i;
			}
		}
		return null;
	}
}
