package name.dlazerka.codejam.y2016.d;

import com.google.common.base.Joiner;
import com.google.common.base.Splitter;
import com.google.common.base.Stopwatch;
import com.google.common.base.Throwables;

import java.io.BufferedWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.nio.file.*;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import static java.math.BigInteger.ONE;
import static java.nio.charset.StandardCharsets.US_ASCII;
import static java.nio.file.StandardOpenOption.CREATE;
import static java.nio.file.StandardOpenOption.TRUNCATE_EXISTING;
import static java.util.concurrent.TimeUnit.MILLISECONDS;

class Main {
	static FileSystem fs = FileSystems.getDefault();

	//static String TEST = "test";
	static String TEST = "small";
	//static String TEST = "large";

	public static void main(String[] args) throws Exception {
		Stopwatch startedAt = Stopwatch.createStarted();
		List<Main> cases = read();

		List<String> res = cases
				.stream()
				.map(c -> "Case #" + c.num + ": " + c.solve() + "\n")
				.collect(Collectors.toList());

		res.forEach(System.out::print);

		Path out = fs.getPath("out." + TEST);
		try (BufferedWriter writer = Files.newBufferedWriter(out, CREATE, TRUNCATE_EXISTING)) {
			res.forEach(r -> {
				try {
					writer.write(r);
				} catch (IOException e) {
					Throwables.propagate(e);
				}
			});
		}


		System.out.println(startedAt.elapsed(MILLISECONDS) + "ms");
	}

	static List<Main> read() throws IOException {
		String packageName = Main.class.getPackage().getName();
		Path path = fs.getPath("src/main/java", packageName.replace('.', '/'), "in." + TEST);
		if (!Files.exists(path)) {
			throw new NoSuchFileException(path.toAbsolutePath().toString());
		}

		List<String> lines = Files.readAllLines(path, US_ASCII);

		//List<String> lines = Files.readAllLines(path);
		int T = Integer.parseInt(lines.get(0));
		List<Main> cases = new ArrayList<>(T);

		for(int lineNum = 1; lineNum <= T; lineNum++) {
			Main main = new Main(lineNum);

			List<String> strings = Splitter.on(' ').splitToList(lines.get(lineNum));

			main.K = Integer.parseInt(strings.get(0));
			main.C = Integer.parseInt(strings.get(1));
			main.S = Integer.parseInt(strings.get(2));

			cases.add(main);
		}
		return cases;
	}


	final int num;
	public Main(int num) {
        this.num = num;
    }

	////////////////////////////

	int K;
	int C;
	int S;

   	String solve() {
		BigInteger k = BigInteger.valueOf(K);
	    BigInteger kc = k.pow(C);

	    if (K == 1) {
		    return "1";
	    }

	    BigInteger step = kc
			    .subtract(ONE)
			    .divide(k.subtract(ONE));

	    ArrayList<String> res = new ArrayList<>(K);
	    BigInteger cur = BigInteger.valueOf(1);
	    for(int i = 0; i < K; i++) {
		    res.add(cur.toString());
		    cur = cur.add(step);
	    }

	    return Joiner.on(' ').join(res);
    }

}
