package name.dlazerka.codejam.y2017.a;

import com.google.common.base.Splitter;
import com.google.common.base.Stopwatch;
import com.google.common.base.Throwables;

import java.io.BufferedWriter;
import java.io.IOException;
import java.nio.file.*;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import static java.nio.charset.StandardCharsets.US_ASCII;
import static java.nio.file.StandardOpenOption.CREATE;
import static java.nio.file.StandardOpenOption.TRUNCATE_EXISTING;
import static java.util.concurrent.TimeUnit.MILLISECONDS;

public class Main {
	static FileSystem fs = FileSystems.getDefault();

	//static String TEST = "test";
	//static String TEST = "small";
	static String TEST = "large";

	public static void main(String[] args) throws Exception {
		Stopwatch startedAt = Stopwatch.createStarted();
		List<Case> cases = read();

		List<String> res = cases
				.stream()
				.map(c -> "Case #" + c.num + ": " + c.solve() + "\n")
				.collect(Collectors.toList());

		res.forEach(System.out::print);

		Path out = fs.getPath("out." + TEST);
		try (BufferedWriter writer = Files.newBufferedWriter(out, CREATE, TRUNCATE_EXISTING)) {
			res.forEach(r -> {
				try {
					writer.write(r);
				} catch (IOException e) {
					Throwables.propagate(e);
				}
			});
		}


		System.out.println(startedAt.elapsed(MILLISECONDS) + "ms");
	}

	static List<Case> read() throws IOException {
		String packageName = Main.class.getPackage().getName();
		Path path = fs.getPath("src/main/java", packageName.replace('.', '/'), "in." + TEST);
		if (!Files.exists(path)) {
			throw new NoSuchFileException(path.toAbsolutePath().toString());
		}

		List<String> lines = Files.readAllLines(path, US_ASCII);

		//List<String> lines = Files.readAllLines(path);
		int T = Integer.parseInt(lines.get(0));
		List<Case> cases = new ArrayList<>(T);

		for(int ci = 1; ci <= T; ci++) {
			String line = lines.get(ci);


			Case c = new Case(ci);
			readCase(line, c);
			cases.add(c);
		}
		return cases;
	}

	private static void readCase(String line, Case c) {
		List<String> list = Splitter.on(' ').splitToList(line);
		c.K = Integer.parseInt(list.get(1));
		c.S = list.get(0);
	}
}
