import java.io.BufferedReader;
import java.io.DataInputStream;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;


public class CandySplitting {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		CandySplitting cs = new CandySplitting();
		cs.run(args);
	}

	public void run(String []args) {
	    try{
	    	FileInputStream fstream = new FileInputStream(args[0]);
	    	
	    	DataInputStream in = new DataInputStream(fstream);
	    	BufferedReader br = new BufferedReader(new InputStreamReader(in));
	    	    
	    	String line = br.readLine();
	    	int testCase = 1;
	    	while ((line = br.readLine()) != null)   {
	    		line = br.readLine();
	    		String[] candies = line.split(" ");
	    		
	    	    runTestCase(testCase, candies);
	    	    testCase++;
	    	}
	    	
	    	in.close();
	    }
	    catch (Exception e){
	    	System.err.println("Error: " + e.getMessage());
	    }
	}
	
	private void runTestCase(int testCaseNumber, String[] candies) {
		
		Pile pile1 = new Pile();
		Pile pile2 = new Pile();
		splitInTwo(candies, pile1, pile2);

		if(pile1.isEqualTo(pile2)) {
			int result = pile1.seanValue > pile2.seanValue ? pile1.seanValue : pile2.seanValue;
			printResult(testCaseNumber, String.valueOf(result));
			return;
		}

		for(int i = 0; i < pile2.candies.size(); i++) {
			
			int pile2Val = pile2.candies.get(i);
			
			int patrick2Value = pile2.patrickValue;
			int sean2Value = pile2.seanValue;
			
			patrick2Value = ~(patrick2Value ^ pile2Val);
			sean2Value -= pile2Val;
			
			
			for(int j = pile1.candies.size() - 1; j >= 0; j--) {
				
				int pile1Val = pile1.candies.get(j);
				
				int patrick1Value = pile1.patrickValue;
				int sean1Value = pile1.patrickValue;
				
				patrick1Value = ~(patrick1Value ^ pile1Val);
				sean1Value -= pile1Val;
				
				
				patrick2Value ^= pile1Val;
				sean2Value += pile1Val;
				
				patrick1Value ^= pile2Val;
				sean1Value += pile2Val;

				if(patrick1Value == patrick2Value) {
					int result = sean1Value > sean2Value ? sean1Value : sean2Value;
					printResult(testCaseNumber, String.valueOf(result));
					return;
				}
			}
			
		}

		printResult(testCaseNumber, "NO");
		
	}
	
	private void printResult(int testCaseNumber, String result) { 
		System.out.println("Case #" + testCaseNumber + ": " + result);
	}
	
	private void splitInTwo(String[] candies, Pile pile1, Pile pile2) {
		int i = 0;
		for(i = 0; i < candies.length/2; i++) {
			Integer value = Integer.valueOf(candies[i]);
			pile1.candies.add(value);
			pile1.incValues(value);
		}
		for(; i < candies.length; i++) {
			Integer value = Integer.valueOf(candies[i]);
			pile2.candies.add(value);
			pile2.incValues(value);
		}
	}
	
	
	private class Pile {
		public List<Integer> candies;
		public int seanValue = 0;
		public int patrickValue = 0;
		
		public Pile() {
			this.candies = new ArrayList<Integer>();
		}
		
		public void incValues(Integer value) {
			this.seanValue += value;
			this.patrickValue ^= value;
		}
		
		
		public boolean isEqualTo(Pile p) {
			return p.patrickValue == this.patrickValue;
		}
		
		public String toString() {
			return "Patrick Value = " + this.patrickValue + ", " +
				"Sean Value = " + this.seanValue + ", " + 
				"Candies = " + this.candies.toString();
		}
	}
}
