import java.io.BufferedReader;
import java.io.DataInputStream;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;


public class BotTrust {
	public static void main(String []args) {
		BotTrust bt = new BotTrust();
		bt.run(args);
	}
	
	public void run(String []args) {
	    try{
	    	FileInputStream fstream = new FileInputStream(args[0]);
	    	
	    	DataInputStream in = new DataInputStream(fstream);
	    	BufferedReader br = new BufferedReader(new InputStreamReader(in));
	    	    
	    	String line = br.readLine();
	    	int testCase = 1;
	    	while ((line = br.readLine()) != null)   {
	    	    runTest(testCase, line);
	    	    testCase++;
	    	}
	    	
	    	in.close();
	    }
	    catch (Exception e){
	    	System.err.println("Error: " + e.getMessage());
	    }
	}
	
	private void runTest(int testCase, String s) {
		String[] tokens = s.split(" ");
		
		List<Integer> oTargets = new ArrayList<Integer>();
		List<Integer> bTargets = new ArrayList<Integer>();
		
		// store targets for each robot
		for(int i = 1; i < tokens.length; i++) {
			if(tokens[i].equals("O")) {
				oTargets.add(Integer.valueOf(tokens[i + 1]));
			}
			else {
				bTargets.add(Integer.valueOf(tokens[i + 1]));
			}
			i++;
		}
		
		int oPosition = 1;
		int bPosition = 1;

		int bTargetIndex = 0;
		int oTargetIndex = 0;

		int steps = 0;
		
		for(int i = 1; i < tokens.length; i+=2) {
			boolean reachedTarget = false;
				
			if(tokens[i].equals("O")) {
				while(!reachedTarget) {
					steps++;

					if(canMove(bPosition, bTargetIndex, bTargets)) {
						bPosition = move(bTargets, bPosition, bTargetIndex);
					}
			
					if(reachedButton(oPosition, oTargets.get(oTargetIndex))) {
						oTargetIndex++;
						reachedTarget = true;
					}
					else {
						oPosition = move(oTargets, oPosition, oTargetIndex);
					}
				}
			}
			else {
				while(!reachedTarget) {
					steps++;
	
					if(canMove(oPosition, oTargetIndex, oTargets)) {
						oPosition = move(oTargets, oPosition, oTargetIndex);
					}
					
					if(reachedButton(bPosition, bTargets.get(bTargetIndex))) {
						bTargetIndex++;
						reachedTarget = true;
					} else {
						bPosition = move(bTargets, bPosition, bTargetIndex);
					}
				}
			}
		}
		printResult(testCase, steps);
	}
	
	private void printResult(int caseNumber, int steps) {
		System.out.println("Case #" + caseNumber + ": " + steps);
	}

	
	private int move(List<Integer> targets, int position, int targetIndex) {
		if(targetIndex >= targets.size()) {
			return position;
		}
		
		if(position < targets.get(targetIndex)) {
			position++;
		}
		else {
			position--;
		}
		return position;
	}

	private boolean canMove(int pos, int targetPointer, List<Integer> targets) {
		if(targetPointer < targets.size()) {
			if(pos != targets.get(targetPointer)) {
				return true;
			}
		}
		return false;
	}
	
	private boolean reachedButton(int pos, int target) {
		return pos == target;
	}

}
