import java.io.BufferedReader;
import java.io.DataInputStream;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;


public class Magicks {
	public static void main(String []args) {
		Magicks bt = new Magicks();
		bt.run(args);
	}
	
	public void run(String []args) {
	    try{
	    	FileInputStream fstream = new FileInputStream(args[0]);
	    	
	    	DataInputStream in = new DataInputStream(fstream);
	    	BufferedReader br = new BufferedReader(new InputStreamReader(in));
	    	    
	    	String line = br.readLine();
	    	int testCase = 1;
	    	while ((line = br.readLine()) != null)   {
	    		TestCase tc = new TestCase(line);
	    		tc.run();
	    		
	    	    printResult(testCase, tc.getResults());
	    	    testCase++;
	    	}
	    	
	    	in.close();
	    }
	    catch (Exception e){
	    	System.err.println("Error: " + e.getMessage());
	    	e.printStackTrace();
	    }
	}

	
	private void printResult(int caseNumber, String results) {
		System.out.println("Case #" + caseNumber + ": " + results);
	}

	private class TestCase {
		private Map<String, Integer> invokedElementsMap = new HashMap<String, Integer>();
		private List<String> invokedElementsList = new ArrayList<String>();
		private String previousElement = null;
		private String elementsToInvoke = null;
		
		
		// <element, set<opposed elements>>
		private Map<String, Set<String>> opposedElements = new HashMap<String, Set<String>>();
		
		// <element, <element, combined element>>
		private Map<String, Map<String, String>> combinableElements = new HashMap<String, Map<String, String>>();
		
		// base to non-base elements
		// opposed base elements
		// elements to invoke
		public TestCase(String testData) {
			String[] tokens = testData.split(" ");
			
			int index = 0;			
			int C = Integer.valueOf(tokens[index]);
			index++;

			for(int i = 0 ; i < C; i++) {
				String elementCombo = tokens[index];
				parseElementCombo(elementCombo);
				index++;
			}

			int D = Integer.valueOf(tokens[index]);
			index++;

			for(int i = 0; i < D; i++) {
				String opposites = tokens[index];
				parseOpposites(opposites);
				index++;
			}
			
			// Skip one, we don't need to know the length of elements to invoke
			index++;
			this.elementsToInvoke = tokens[index];
			
		}
		
		public String toString() {
			return "Elements to invoke: " + this.elementsToInvoke + 
				", Combos: " + this.combinableElements + 
				", Opposites: " + this.opposedElements;
		}
		
		public void run() {
			char[] elements = this.elementsToInvoke.toCharArray();
			for(char c : elements) {
				invoke(String.valueOf(c));
			}
			// invoke element
			// check if can combine
			// check if opposed
		}
		
		public String getResults() {
			return this.invokedElementsList.toString();
		}
		
		private void invoke(String element) {
			if(combineElements(element)) {
				return;
			}
			else if(isOpposed(element)) {
				clearInvokedElements();
				return;
			} 
			else {
				Integer elementCount = this.invokedElementsMap.get(element);
				if(elementCount == null) {
					this.invokedElementsMap.put(element, 1);
				}
				else {
					elementCount++;
					this.invokedElementsMap.put(element,elementCount);
				}
				
				this.invokedElementsList.add(element);
				this.previousElement = element;
			}
		}


		
		private void parseOpposites(String opposites) {
			char[] chars = opposites.toCharArray();
			String element1 = String.valueOf(chars[0]);
			String element2 = String.valueOf(chars[1]);
			
			Set<String> element1Opposites = this.opposedElements.get(element1);
			if(element1Opposites == null) {
				element1Opposites = new HashSet<String>();
			}
			element1Opposites.add(element2);
			this.opposedElements.put(element1, element1Opposites);
			
			Set<String> element2Opposites = this.opposedElements.get(element2);
			if(element2Opposites == null) {
				element2Opposites = new HashSet<String>();
			}
			element2Opposites.add(element1);
			this.opposedElements.put(element2, element2Opposites);
			
		}
		
		private void parseElementCombo(String combo) {
			char[] chars = combo.toCharArray();
			String element1 = String.valueOf(chars[0]);
			String element2 = String.valueOf(chars[1]);
			String comboValue = String.valueOf(chars[2]);
			Map<String, String> element1Combo = this.combinableElements.get(element1);
			if(element1Combo == null) {
				element1Combo = new HashMap<String, String>();
			}
			element1Combo.put(element2, comboValue);
			this.combinableElements.put(element1, element1Combo);
			
			Map<String, String> element2Combo = this.combinableElements.get(element2);
			if(element2Combo == null) {
				element2Combo = new HashMap<String, String>();
			}
			element2Combo.put(element1, comboValue);
			this.combinableElements.put(element2, element2Combo);
		}
		
		
		private boolean combineElements(String element) {
			if(this.previousElement == null) {
				return false;
			}
			
			Map<String, String> combinableElementsForCurrentElement = this.combinableElements.get(element);
			if(combinableElementsForCurrentElement == null || combinableElementsForCurrentElement.isEmpty()) {
				return false;
			}
			
			String combinedElementResult = combinableElementsForCurrentElement.get(this.previousElement);
			if(combinedElementResult == null) {
				return false;
			}

			// Store the combined element in the list (replace the previous element)
			this.invokedElementsList.remove(this.invokedElementsList.size() - 1);
			this.invokedElementsList.add(combinedElementResult);
			
			// Remove previous element from invoked elements
			// No need to do this for current elemnt since it hasn't been stored yet
			Integer invokedCount = this.invokedElementsMap.get(this.previousElement);
			if(invokedCount == 1) {
				this.invokedElementsMap.remove(this.previousElement);
			} else {
				invokedCount--;
				this.invokedElementsMap.put(this.previousElement, invokedCount);
			}
			
			this.previousElement = combinedElementResult;
			
			return true;
		}

		
		private boolean isOpposed(String element) {
			Set<String> opposedElementsSet = this.opposedElements.get(element);
			if(opposedElementsSet == null) {
				return false;
			}
			
			for(String opposedElement : opposedElementsSet) {
				if(hasBeenInvoked(opposedElement)) {
					return true;
				}
			}
			return false;
		}
		
		private boolean hasBeenInvoked(String element) {
			Integer count = this.invokedElementsMap.get(element);
			if(count != null && count > 0) {
				return true;
			}
			return false;
		}

		private void clearInvokedElements() {
			this.invokedElementsList.clear();
			this.invokedElementsMap.clear();
		}
		
	}

}
