package dmitrib.gcj.basins;

import java.io.FileInputStream;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.FileWriter;
import java.util.List;
import java.util.ArrayList;

/**
 * WaterBasins
 * <p/>
 *
 * @author Dmitri Bogdel
 */
public class WaterBasins {

  static class Cell {
    final int h;
    final int i;
    final int j;

    Cell nextCell;

    List<Cell> directedCells = new ArrayList<Cell>();

    Cell(int h, int i, int j) {
      this.h = h;
      this.i = i;
      this.j = j;
    }

    @Override
    public String toString() {
      return "Cell{" +
             "h=" + h +
             ", i=" + i +
             ", j=" + j +
             '}';
    }

  }



  public static void main(String[] args) throws IOException {

    long start = System.currentTimeMillis();

    Cell[][] cells;

    String[][] items = GcjInputReader.readItems("input-basins.txt");

    int count = Integer.parseInt(items[0][0]);

    int index = 1;

    //char startAlpha = 'a';

    FileWriter wr = new FileWriter("out-basins.txt");

    for (int i=0; i<count; i++) {

      int h = Integer.parseInt(items[index][0]);
      int w = Integer.parseInt(items[index][1]);

      index++;

      cells = new Cell[h][];

      int alphaIndex = 0;

      for (int j=0; j<h; j++) {
        cells[j] = new Cell[w];
        for (int k=0; k<w; k++) {
          int hh = Integer.parseInt(items[index][k]);
          cells[j][k] = new Cell(hh, j, k);
          alphaIndex++;
        }
        index++;
      }

      attachNextCells(cells, h, w);

      Character[][] basins = attachBasins(cells, h, w);

      wr.write("Case #" + (i+1) + ":\n" + print(basins));

      wr.flush();

      System.out.println("p = \n" + print(basins));
      //System.out.println("cells = " + Arrays.asList(cells));

    }


    wr.close();


    System.out.println("System.currentTimeMillis() - start = " + (System.currentTimeMillis() - start)/1000);
  }

  private static List<Cell> allNeigbourCells(Cell cell, Cell[][] cells, int h, int w) {

    List<Cell> neighbourCells = new ArrayList<Cell>();

    if (cell.i > 0) {
      neighbourCells.add(cells[cell.i-1][cell.j]);
    }

    if (cell.j > 0) {
      neighbourCells.add(cells[cell.i][cell.j-1]);
    }

    if (cell.j < w-1) {
      neighbourCells.add(cells[cell.i][cell.j+1]);
    }

    if (cell.i < h-1) {
      neighbourCells.add(cells[cell.i+1][cell.j]);
    }

    return neighbourCells;
  }

  private static Cell selectNextCell(Cell cell, List<Cell> neighbours) {

    Cell next = null;

    for (Cell c : neighbours) {

      if (next == null) {
        if (c.h < cell.h) {
          next = c;
        }
      }
      else {
        if (c.h < next.h) {
          next = c;
        }
      }
    }

    return next;

  }

  private static void attachNextCells(Cell[][] cells, int h, int w) {
    for (int i=0; i<h; i++) {
      for (int j=0; j<w; j++) {
        List<Cell> neighbours = allNeigbourCells(cells[i][j], cells, h, w);
        Cell next = selectNextCell(cells[i][j], neighbours);
        cells[i][j].nextCell = next;
        if (next != null) {
          next.directedCells.add(cells[i][j]);
        }
      }
    }
  }

  private static void labelStart(Character[][] labels, Cell cell, char label) {
    Cell sink = cell;
    while (sink.nextCell != null) {
      sink = sink.nextCell;
    }
    label(labels, sink, label);
  }

  private static void label(Character[][] labels, Cell cell, char label) {
    //System.out.println("label = " + label + " " + cell.i + " " + cell.j);
    labels[cell.i][cell.j] = label;
    for (Cell next : cell.directedCells) {
      label(labels, next, label);
    }
  }

  private static String print(Character[][] labels) {
    String s = "";
    for (Character[] cc : labels) {
      for (Character c : cc) {
        s += (" " + c);
      }
      s += "\n";
    }
    return s;
  }

  private static Character[][] attachBasins(Cell[][] cells, int h, int w) {

    Character[][] labels = new Character[h][];

    for (int i=0; i<h; i++) {
      labels[i] = new Character[w];
      for (int j=0; j<w; j++) {
        labels[i][j] = null;
      }
    }


    char ch = 'a';

    //int labelIndex = 0;

    for (int i=0; i<h; i++) {
      for (int j=0; j<w; j++) {
        if (labels[i][j] == null /*&& cells[i][j].nextCell == null*/) {
          //System.out.println("ch = " + ch + " for " + i + " " + j);
          labelStart(labels, cells[i][j], ch);
          ch = (char)(ch + 1);
        }

      }
    }

    return labels;
  }

  


}


class GcjInputReader {

  //private static String items[][];

  public static String[][] readItems(String file) {

    String items[][];

    FileInputStream stream = null;

    try {

      stream = new FileInputStream(file);
      BufferedReader input = new BufferedReader(new InputStreamReader(stream));

      List<String> lines = new ArrayList<String>();

      String line;

      while((line = input.readLine()) != null) {
        lines.add(line);
      }


      items = new String[lines.size()][];

      int i=0;
      for (String l : lines) {
        items[i++] = l.split("\\s");
      }

      return items;

    }
    catch (FileNotFoundException e) {
      throw new RuntimeException(e);
    }
    catch (IOException e) {
      throw new RuntimeException(e);
    }
    finally {
      if (stream != null) {
        try {
          stream.close();
        }
        catch (IOException e) {
          e.printStackTrace();
        }
      }
    }

  }

}
