package dmitrib.gcj.alien;

import java.io.FileInputStream;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.FileWriter;
import java.util.List;
import java.util.ArrayList;

/**
 * AlienWords
 * <p/>
 *
 * @author Dmitri Bogdel
 */
public class AlienWords {

  public static void main(String[] args) throws IOException {

    long start = System.currentTimeMillis();

    String[][] items = GcjInputReader.readItems("input-alien.txt");

    FileWriter wr = new FileWriter("out-alien.txt");

    int L = Integer.parseInt(items[0][0]);
    int D = Integer.parseInt(items[0][1]);
    int N = Integer.parseInt(items[0][2]);

    List<String> words = new ArrayList<String>();
    List<String> patterns = new ArrayList<String>();

    int index = 1;

    for (int i=0; i<D; i++) {
      words.add(items[index++][0]);
    }

    for (int i=0; i<N; i++) {
      String pattern = items[index++][0];
      patterns.add(pattern);
      long count = calc(words, pattern);
      System.out.println(i + " count = " + count);
      wr.write("Case #" + (i+1) + ": " + count);
      wr.write("\n");
    }

    //System.out.println("words = " + words);
    //System.out.println("patterns = " + patterns);

    wr.close();


    System.out.println("System.currentTimeMillis() - start = " + (System.currentTimeMillis() - start)/1000);
  }



  private static int calc(List<String> words, String pattern) {

    List<String> tokens = splitIntoTokens(pattern);

    System.out.println("tokens = " + tokens);

    int count = 0;

    int[] ct = new int[] {0};

    matches(tokens, words, ct);

    count += ct[0];

    return count;
  }

  static void matches(List<String> tokens, List<String> words, int[] count) {

    if (tokens.size() == 0) {
      return;
    }

    if (words.size() == 0) {
      return;
    }

    List<String> tokensCopy = new ArrayList<String>(tokens);

    String token = tokensCopy.remove(0);

    for (int i=0; i<token.length(); i++) {
      char tokenChar = token.charAt(i);
      List<String> words2 = new ArrayList<String>();
      for (String word : words) {
        char w = word.charAt(0);
        if (w == tokenChar) {
          if (word.length() == 1) {
            count[0]++;
          }
          words2.add(word.substring(1));
        }
      }
      matches(tokensCopy, words2, count);
    }


  }

  private static List<String> splitIntoTokens(String pattern) {

    List<String> tokens = new ArrayList<String>();


    String tt = "";

    boolean insideGroup = false;

    for (int i=0; i<pattern.length(); i++) {

      char t = pattern.charAt(i);

      if (t == '(') {
        insideGroup = true;
      }
      else if (t == ')') {
        tokens.add(tt);
        tt = "";
        insideGroup = false;
      }
      else {
        if (insideGroup) {
          tt = tt + String.valueOf(t);
        }
        else {
          tokens.add(String.valueOf(t));
        }
      }

    }

    return tokens;
  }

}

class GcjInputReader {

  //private static String items[][];

  static String[][] readItems(String file) {

    String items[][];

    FileInputStream stream = null;

    try {

      stream = new FileInputStream(file);
      BufferedReader input = new BufferedReader(new InputStreamReader(stream));

      List<String> lines = new ArrayList<String>();

      String line;

      while((line = input.readLine()) != null) {
        lines.add(line);
      }


      items = new String[lines.size()][];

      int i=0;
      for (String l : lines) {
        items[i++] = l.split("\\s");
      }

      return items;

    }
    catch (FileNotFoundException e) {
      throw new RuntimeException(e);
    }
    catch (IOException e) {
      throw new RuntimeException(e);
    }
    finally {
      if (stream != null) {
        try {
          stream.close();
        }
        catch (IOException e) {
          e.printStackTrace();
        }
      }
    }

  }

}


