import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.*;

public class Solution implements Runnable {
    private final BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
    private final PrintWriter writer = new PrintWriter(System.out);
    private StringTokenizer tokenizer;

    private String next() throws Exception {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            tokenizer = new StringTokenizer(reader.readLine());
        }
        return tokenizer.nextToken();
    }

    private int nextInt() throws Exception {
        return Integer.parseInt(next());
    }

    private long nextLong() throws Exception {
        return Long.parseLong(next());
    }

    public static void main(String[] args) {
        new Solution().run();
    }

    @Override
    public void run() {
        try {
            Locale.setDefault(Locale.US);
            solve();
            reader.close();
            writer.close();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(9875);
        }
    }

    private static final char[] COLOR_NAMES = new char[]{'R', 'O', 'Y', 'G', 'B', 'V'};

    private void solve() throws Exception {
        int tests = nextInt();

        for (int test = 1; test <= tests; test++) {
            int n = nextInt();
            Color[] colors = new Color[COLOR_NAMES.length];
            for (int i = 0; i < COLOR_NAMES.length; i++) {
                colors[i] = new Color(COLOR_NAMES[i], nextInt());
            }

            Arrays.sort(colors);

            List<Character> ans = new ArrayList<>(n);
            int pos = 0;
            for (int it = 0; it < n; it++) {
                while (colors[pos].count == 0) {
                    pos++;
                    pos %= COLOR_NAMES.length;
                }

                ans.add(colors[pos].name);
                colors[pos].count--;
                pos++;
                pos %= COLOR_NAMES.length;
            }

            writer.printf("Case #%d: ", test);
            if (!check(ans)) {
                writer.println("IMPOSSIBLE");
            } else {
                for (char c : ans) {
                    writer.print(c);
                }
                writer.println();
            }
        }
    }

    private boolean check(List<Character> c) {
        for (int i = 1; i < c.size(); i++) {
            if (c.get(i) == c.get(i - 1)) {
                return false;
            }
        }
        return c.get(0) != c.get(c.size() - 1);
    }

    private static class Color implements Comparable<Color> {
        final char name;
        int count;

        public Color(char name, int count) {
            this.name = name;
            this.count = count;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Color color = (Color) o;

            if (name != color.name) return false;
            return count == color.count;
        }

        @Override
        public int hashCode() {
            int result = (int) name;
            result = 31 * result + count;
            return result;
        }

        @Override
        public int compareTo(Color o) {
            if (count != o.count) {
                return Integer.compare(o.count, count);
            }
            return Character.compare(name, o.name);
        }
    }
}

