import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.StringTokenizer;

public class Solution implements Runnable {
    private final BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
    private final PrintWriter writer = new PrintWriter(System.out);
    private StringTokenizer tokenizer;

    private String next() throws Exception {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            tokenizer = new StringTokenizer(reader.readLine());
        }
        return tokenizer.nextToken();
    }

    private int nextInt() throws Exception {
        return Integer.parseInt(next());
    }

    private long nextLong() throws Exception {
        return Long.parseLong(next());
    }

    public static void main(String[] args) {
        new Solution().run();
    }

    @Override
    public void run() {
        try {
            solve();
            reader.close();
            writer.close();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(9875);
        }
    }

    private void solve() throws Exception {
        int tests = nextInt();
        for (int test = 1; test <= tests; test++) {
            Turn result = get(nextLong(), nextLong());
            writer.printf("Case #%d: %d %d", test, result.max, result.min);
            writer.println();
        }
    }


    private Turn get(long N, long K) {
        int n = (int) N;
        int k = (int) K;

        boolean[] used = new boolean[n];
        Turn result = null;
        for (int i = 0; i < k; i++) {
            result = makeTurn(used);
        }

        return result;
    }

    private Turn makeTurn(boolean[] used) {
        int n = used.length;
        Turn result = null;
        for (int i = 0; i < n; i++) {
            if (!used[i]) {
                Turn cur = calc(used, i);
                if (result == null || cur.compareTo(result) < 0) {
                    result = cur;
                }
            }
        }

        used[(int) result.position] = true;
        return result;
    }

    private Turn calc(boolean[] used, int pos) {
        int l = 0;
        int r = 0;

        for (int i = pos - 1; i >= 0; i--) {
            if (!used[i]) {
                l++;
            } else {
                break;
            }
        }
        for (int i = pos + 1; i < used.length; i++) {
            if (!used[i]) {
                r++;
            } else {
                break;
            }
        }

        return new Turn(Math.min(l, r), Math.max(l, r), pos);
    }

    private static class Turn implements Comparable<Turn> {
        final long min;
        final long max;
        final long position;

        Turn(long min, long max, long position) {
            this.min = min;
            this.max = max;
            this.position = position;
        }

        @Override
        public int compareTo(Turn o) {
            if (min != o.min) {
                return Long.compare(o.min, min);
            } else if (max != o.max) {
                return Long.compare(o.max, max);
            } else {
                return Long.compare(position, o.position);
            }
        }
    }
}

