import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.text.DecimalFormat;
import java.util.Locale;
import java.util.StringTokenizer;

public class Solution implements Runnable {
    private final BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
    private final PrintWriter writer = new PrintWriter(System.out);
    private StringTokenizer tokenizer;

    private String next() throws Exception {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            tokenizer = new StringTokenizer(reader.readLine());
        }
        return tokenizer.nextToken();
    }

    private int nextInt() throws Exception {
        return Integer.parseInt(next());
    }

    private long nextLong() throws Exception {
        return Long.parseLong(next());
    }

    public static void main(String[] args) {
        new Solution().run();
    }

    @Override
    public void run() {
        try {
            Locale.setDefault(Locale.US);
            solve();
            reader.close();
            writer.close();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(9875);
        }
    }

    private static final long INF = 1_000_000_000_000_000_000L;

    private void solve() throws Exception {
        int tests = nextInt();

        DecimalFormat format = new DecimalFormat("0.000000000");

        for (int test = 1; test <= tests; test++) {
            int n = nextInt();
            int q = nextInt();
            int[] e = new int[n];
            int[] s = new int[n];
            for (int i = 0; i < n; i++) {
                e[i] = nextInt();
                s[i] = nextInt();
            }
            long[][] d = new long[n][n];
            for (int i = 0; i < n; i++) {
                for (int j = 0; j < n; j++) {
                    d[i][j] = nextInt();
                    if (d[i][j] == -1) {
                        d[i][j] = INF;
                    }
                    if (i == j) {
                        d[i][j] = 0;
                    }
                }
            }
            int[] u = new int[q];
            int[] v = new int[q];
            for (int i = 0; i < q; i++) {
                u[i] = nextInt() - 1;
                v[i] = nextInt() - 1;
            }

            for (int k = 0; k < n; k++) {
                for (int i = 0; i < n; i++) {
                    for (int j = 0; j < n; j++) {
                        d[i][j] = Math.min(d[i][j], d[i][k] + d[k][j]);
                    }
                }
            }

            double[][] time = new double[n][n];
            for (int v1 = 0; v1 < n; v1++) {
                for (int v2 = 0; v2 < n; v2++) {
                    double t = INF;
                    if (v1 != v2) {
                        for (int i = 0; i < n; i++) {
                            if (d[i][v1] + d[v1][v2] <= e[i]) {
                                t = Math.min(t, ((double) (d[i][v1] + d[v1][v2])) / (double) s[i]);
                            }
                        }
                    } else {
                        t = 0.0;
                    }
                    time[v1][v2] = t;
                }
            }

            for (int k = 0; k < n; k++) {
                for (int i = 0; i < n; i++) {
                    for (int j = 0; j < n; j++) {
                        time[i][j] = Math.min(time[i][j], time[i][k] + time[k][j]);
                    }
                }
            }

            writer.printf("Case #%d:", test);
            for (int c = 0; c < q; c++) {
                writer.print(" " + format.format(time[u[c]][v[c]]));
            }
            writer.println();
        }
    }
}

