import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.*;

public class Solution implements Runnable {
    private final BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
    private final PrintWriter writer = new PrintWriter(System.out);
    private StringTokenizer tokenizer;

    private String next() throws Exception {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            tokenizer = new StringTokenizer(reader.readLine());
        }
        return tokenizer.nextToken();
    }

    private int nextInt() throws Exception {
        return Integer.parseInt(next());
    }

    private long nextLong() throws Exception {
        return Long.parseLong(next());
    }

    public static void main(String[] args) {
        new Solution().run();
    }

    @Override
    public void run() {
        try {
            solve();
            reader.close();
            writer.close();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(9875);
        }
    }

    private int hd, ad, hk, ak, b, d;
    private Queue<State> q;
    private Set<State> used;
    private Queue<Integer> dist;

    private void solve() throws Exception {
        int tests = nextInt();
        for (int test = 1; test <= tests; test++) {
            hd = nextInt();
            ad = nextInt();
            hk = nextInt();
            ak = nextInt();
            b = nextInt();
            d = nextInt();

            State cur = new State(hd, ad, hk, ak);
            int result = -1;
            used = new HashSet<>();
            used.add(cur);
            q = new LinkedList<>();
            q.add(cur);
            dist = new LinkedList<>();
            dist.add(0);

            while (!q.isEmpty()) {
                cur = q.remove();
                int curDist = dist.remove();

                if (cur.isLoose()) {
                    continue;
                }
                if (cur.isWin()) {
                    result = curDist;
                    break;
                }

                add(cur.attack(), curDist);
                add(cur.buff(), curDist);
                add(cur.cure(), curDist);
                add(cur.debuff(), curDist);
            }

            writer.printf("Case #%d: ", test);
            writer.println(result != -1 ? result : "IMPOSSIBLE");
        }
    }

    private void add(State next, int curDist) {
        if (!used.contains(next)) {
            q.add(next);
            used.add(next);
            dist.add(curDist + 1);
        }
    }

    private class State {
        private final int hd, ad, hk, ak;

        State(int hd, int ad, int hk, int ak) {
            this.hd = Math.max(0, hd);
            this.ad = Math.max(0, ad);
            this.hk = Math.max(0, hk);
            this.ak = Math.max(0, ak);
        }

        boolean isWin() {
            return !isLoose() && hk <= 0;
        }

        boolean isLoose() {
            return hd <= 0;
        }

        State attack() {
            int nhk = hk - ad;
            int nhd = nhk > 0 ? hd - ak : hd;
            return new State(nhd, ad, nhk, ak);
        }

        State buff() {
            return new State(hd - ak, ad + b, hk, ak);
        }

        State cure() {
            return new State(Solution.this.hd - ak, ad, hk, ak);
        }

        State debuff() {
            return new State(hd - Math.max(0, ak - d), ad, hk, ak - d);
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            State state = (State) o;

            if (hd != state.hd) return false;
            if (ad != state.ad) return false;
            if (hk != state.hk) return false;
            return ak == state.ak;
        }

        @Override
        public int hashCode() {
            int result = hd;
            result = 31 * result + ad;
            result = 31 * result + hk;
            result = 31 * result + ak;
            return result;
        }
    }
}

