import java.util.Scanner;

public class Solution {
    private static final int[] dx = {-1, -1, -1, 0, 1, 1, 1, 0};
    private static final int[] dy = {-1, 0, 1, 1, 1, 0, -1, -1};

    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);

        int tests = scanner.nextInt();
        for (int test = 1; test <= tests; test++) {
            int r = scanner.nextInt();
            int c = scanner.nextInt();
            int m = scanner.nextInt();

            System.out.printf("Case #%d:", test);
            System.out.println();

            String[] solution = solve(r, c, m);
            for (String line : solution) {
                System.out.println(line);
            }
        }

        scanner.close();
    }

    private static String[] solve(int r, int c, int m) {
        for (int mask = 0; mask < (1 << (r * c)); mask++) {
            int position = findPosition(r, c, m, mask);
            if (position != -1) {
                return prepareAnswer(r, c, mask, position);
            }
        }

        return new String[]{"Impossible"};
    }

    private static String[] prepareAnswer(int r, int c, int mask, int position) {
        String[] result = new String[r];

        for (int i = 0; i < r; i++) {
            StringBuilder row = new StringBuilder();

            for (int j = 0; j < c; j++) {
                if (i * c + j == position) {
                    row.append('c');
                } else {
                    row.append(getBit(mask, c, i, j) ? '*' : '.');
                }
            }

            result[i] = row.toString();
        }

        return result;
    }

    private static boolean getBit(int mask, int c, int i, int j) {
        return (mask & (1 << (i * c + j))) != 0;
    }

    private static int setBit(int mask, int c, int i, int j) {
        return mask | (1 << (i * c + j));
    }

    private static int findPosition(int r, int c, int m, int mask) {
        if (Integer.bitCount(mask) != m) {
            return -1;
        }

        for (int i = 0; i < r; i++) {
            for (int j = 0; j < c; j++) {
                if (check(r, c, i, j, mask)) {
                    return i * c + j;
                }
            }
        }

        return -1;
    }

    private static boolean check(int r, int c, int x, int y, int bombMask) {
        if (getBit(bombMask, c, x, y)) {
            return false;
        }

        int openedMask = openCell(r, c, x, y, bombMask, 0);

        return (openedMask | bombMask) == (1 << (r * c)) - 1;
    }

    private static int openCell(int r, int c, int x, int y, int bombMask, int openedMask) {
        openedMask = setBit(openedMask, c, x, y);

        int cnt = countNeighborBombs(r, c, x, y, bombMask);

        if (cnt == 0) {
            for (int i = 0; i < dx.length; i++) {
            int nx = x + dx[i];
            if (nx >= 0 && nx < r) {
                for (int j = 0; j < dy.length; j++) {
                        int ny = y + dy[i];
                        if (ny >= 0 && ny < c && !getBit(bombMask | openedMask, c, nx, ny)) {
                            openedMask = openCell(r, c, nx, ny, bombMask, openedMask);
                        }
                    }
                }   
            }
        }

        return openedMask;
    }

    private static int countNeighborBombs(int r, int c, int x, int y, int bombMask) {
        int result = 0;

        for (int i = 0; i < dx.length; i++) {
            int nx = x + dx[i];
            if (nx >= 0 && nx < r) {
                for (int j = 0; j < dy.length; j++) {
                    int ny = y + dy[i];
                    if (ny >= 0 && ny < c && getBit(bombMask, c, nx, ny)) {
                        result++;
                    }
                }
            }   
        }

        return result;
    }
}
