package Qualification;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.Scanner;
import java.util.TreeMap;

public class Task3 {
	
	private static class Result
	{
		public long minValue;
		public long maxValue;
		
		public Result(long iMinValue, long iMaxValue)
		{
			minValue = iMinValue;
			maxValue = iMaxValue;
		}
	}
	
	private static TreeMap<Long, Long> ranges;
	private static long largestRange;
	private static long largestRangeAmount;
	private static long optimalBound;
	
	private static void incrementMapValue(long key, long value)
	{
		if (ranges.containsKey(key))
			ranges.put(key, ranges.get(key) + value);
		else
			ranges.put(key, value);
	}
	
	private static void splitLargestRange()
	{
		ranges.remove(largestRange);
		long splitRange = largestRange / 2;
		if ((largestRange % 2) == 0)
		{
			incrementMapValue(splitRange - 1, largestRangeAmount);
			incrementMapValue(splitRange, largestRangeAmount);
		}
		else
			incrementMapValue(splitRange, 2 * largestRangeAmount);
		
		largestRange = ranges.lastKey();
		largestRangeAmount = ranges.lastEntry().getValue();
	}
	
	// Just some small empiric rule I found when tried to determine all the stall occupying queues for all stall numbers under 1000.
	// This number determines when the leftmost stall is occupied, and that means... actually that does not mean a thing.
	// I wanted to find a moment when all stalls will have neighbors immediately to the left and to the right, but this is not when the leftmost stall is filled (for example N=5).
	// Scratch that, will develop after the contest.
	private static void determineOptimalBound(long N)
	{
		optimalBound = 5;
		long power = 2;
		while (N > optimalBound + power * 3 - 1)
		{
			optimalBound += power *3 - 1;
			power *= 2;
		}
		
		long difference = N - optimalBound;
		optimalBound = power + difference;
	}
	
	private static Result resultForCase(long N, long K)
	{
		//To be optimized later
		// determineOptimalBound();
		//if (K > optimalBound)
		//	return new Result(0, 0);
		
		ranges = new TreeMap<Long, Long>();
		ranges.put(N, 1L);
		largestRange = N;
		largestRangeAmount = 1;
		
		while (K > largestRangeAmount)
		{
			K -= largestRangeAmount;
			splitLargestRange();
		}
		
		if ((largestRange % 2) == 0)
			return new Result(largestRange/2-1, largestRange/2);
		else
			return new Result(largestRange/2, largestRange/2); 
	}
	
	public static void main(String[] args) throws FileNotFoundException {
		File file = new File("D:/Development/Competitions/GoogleCodeJam/GoogleCodeJam2017/data/Qualification/C-large.in");
		PrintStream out = new PrintStream(new FileOutputStream("D:/Development/Competitions/GoogleCodeJam/GoogleCodeJam2017/data/Qualification/C-large.out"));
		System.setOut(out);
		
		Scanner sc = new Scanner(file);
		int T = sc.nextInt();
		Result[] result = new Result[T];
		
		for (int i = 0; i < T; ++i)
		{
			long N = sc.nextLong();
			long K = sc.nextLong();
			result[i] = resultForCase(N, K);
		}
		sc.close();
		
		for (int i = 0; i < T; ++i)
		{
			System.out.println(String.format("Case #%d: %d %d", i + 1, result[i].maxValue, result[i].minValue));
		}
	}
}

/*
Problem

A certain bathroom has N + 2 stalls in a single row; the stalls on the left and right ends are permanently occupied by the bathroom guards. The other N stalls are for users.

Whenever someone enters the bathroom, they try to choose a stall that is as far from other people as possible. To avoid confusion, they follow deterministic rules: For each empty stall S, they compute two values LS and RS, each of which is the number of empty stalls between S and the closest occupied stall to the left or right, respectively. Then they consider the set of stalls with the farthest closest neighbor, that is, those S for which min(LS, RS) is maximal. If there is only one such stall, they choose it; otherwise, they choose the one among those where max(LS, RS) is maximal. If there are still multiple tied stalls, they choose the leftmost stall among those.

K people are about to enter the bathroom; each one will choose their stall before the next arrives. Nobody will ever leave.

When the last person chooses their stall S, what will the values of max(LS, RS) and min(LS, RS) be?

Solving this problem

This problem has 2 Small datasets and 1 Large dataset. You must solve the first Small dataset before you can attempt the second Small dataset. You will be able to retry either of the Small datasets (with a time penalty). You will be able to make a single attempt at the Large, as usual, only after solving both Small datasets.

Input

The first line of the input gives the number of test cases, T. T lines follow. Each line describes a test case with two integers N and K, as described above.

Output

For each test case, output one line containing Case #x: y z, where x is the test case number (starting from 1), y is max(LS, RS), and z is min(LS, RS) as calculated by the last person to enter the bathroom for their chosen stall S.

Limits

1 <= T <= 100.
1 <= K <= N.
Small dataset 1

1 <= N <= 1000.
Small dataset 2

1 <= N <= 10^6.
Large dataset

1 <= N <= 10^18.
Sample


Input 
 
5
4 2
5 2
6 2
1000 1000
1000 1

Output

Case #1: 1 0
Case #2: 1 0
Case #3: 1 1
Case #4: 0 0
Case #5: 500 499

In Case #1, the first person occupies the leftmost of the middle two stalls, leaving the following configuration (O stands for an occupied stall and . for an empty one): O.O..O. Then, the second and last person occupies the stall immediately to the right, leaving 1 empty stall on one side and none on the other.

In Case #2, the first person occupies the middle stall, getting to O..O..O. Then, the second and last person occupies the leftmost stall.

In Case #3, the first person occupies the leftmost of the two middle stalls, leaving O..O...O. The second person then occupies the middle of the three consecutive empty stalls.

In Case #4, every stall is occupied at the end, no matter what the stall choices are.

In Case #5, the first and only person chooses the leftmost middle stall.
*/