package Qualification;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.Iterator;
import java.util.Scanner;
import java.util.Vector;

public class Task4 {
	private static class Model
	{
		public int row;
		public int col;
		public int value;
		
		public Model(char iValue, int iRow, int iCol)
		{
			row = iRow;
			col = iCol;
			if (iValue == '+')
				value = 1;
			else if (iValue == 'x')
				value = 2;
			else
				value = 3;
		}
	}
	
	private static int[][] actualBoard;
	private static int[][] valuesBoard;
	private static int N;
	
	private static void recalculateValuesBoard(Model newModel)
	{
		if ((newModel.value & 2) == 2) // This is an X or an O. You can't put X on same vertical and horizontal lines with it.
		{
			for (int i = 0; i < N; ++i)
			{
				valuesBoard[i][newModel.col] &= ~2;
				valuesBoard[newModel.row][i] &= ~2;
			}
		}
		
		if ((newModel.value & 1) == 1) // This is a + or an O. You can't put + on same diagonals with it.
		{
			int newRow;
			int newCol;
			for (int i = 0; i < N; ++i)
			{
				if (i <= newModel.row)
				{
					newRow = newModel.row - i;
					if (i <= newModel.col)
					{
						newCol = newModel.col - i;
						valuesBoard[newRow][newCol] &= ~1;
					}
					
					if (newModel.col + i < N)
					{
						newCol = newModel.col + i;
						valuesBoard[newRow][newCol] &= ~1;
					}
				}
				if (newModel.row + i < N)
				{
					newRow = newModel.row + i;
					if (i <= newModel.col)
					{
						newCol = newModel.col - i;
						valuesBoard[newRow][newCol] &= ~1;
					}
					
					if (newModel.col + i < N)
					{
						newCol = newModel.col + i;
						valuesBoard[newRow][newCol] &= ~1;
					}
				}
			}
		} 
	}
	
	private static int calculateValueLoss(Model newModel)
	{
		int totalValueLoss = 0;
		if ((newModel.value & 2) == 2)
		{
			for (int i = 0; i < N; ++i)
			{
				if ((valuesBoard[i][newModel.col] & 2) == 2)
					totalValueLoss++;
				if ((valuesBoard[newModel.row][i] & 2) == 2)
					totalValueLoss++;
			}
		}
		
		if ((newModel.value & 1) == 1)
		{
			int newRow;
			int newCol;
			for (int i = 0; i < N; ++i)
			{
				if (i <= newModel.row)
				{
					newRow = newModel.row - i;
					if (i <= newModel.col)
					{
						newCol = newModel.col - i;
						if ((valuesBoard[newRow][newCol] & 1) == 1) 
							++totalValueLoss;
					}
					
					if (newModel.col + i < N)
					{
						newCol = newModel.col + i;
						if ((valuesBoard[newRow][newCol] & 1) == 1) 
							++totalValueLoss;
					}
				}
				if (newModel.row + i < N)
				{
					newRow = newModel.row + i;
					if (i <= newModel.col)
					{
						newCol = newModel.col - i;
						if ((valuesBoard[newRow][newCol] & 1) == 1) 
							++totalValueLoss;
					}
					
					if (newModel.col + i < N)
					{
						newCol = newModel.col + i;
						if ((valuesBoard[newRow][newCol] & 1) == 1) 
							++totalValueLoss;
					}
				}
			}
		}
		
		return totalValueLoss;
	}
	
	private static Model determineNextModel()
	{
		int minimumLoss = 3*N*N;
		Model result = null;
		for (int row = 0; row < N; ++row)
			for (int col = 0; col < N; ++col)
			{
				int possibleLoss;
				if ((valuesBoard[row][col] & 1) == 1)
				{
					possibleLoss = calculateValueLoss(new Model('+', row, col));
					if (possibleLoss < minimumLoss)
					{
						possibleLoss = minimumLoss;
						result = new Model('+', row, col);
					}
				}
				
				if ((valuesBoard[row][col] & 2) == 2)
				{
					possibleLoss = calculateValueLoss(new Model('x', row, col));
					if (possibleLoss < minimumLoss)
					{
						possibleLoss = minimumLoss;
						result = new Model('x', row, col);
					}
				}
			}
			
		return result;
	}
	
	public static void addModelToBoard(Model newModel)
	{
		actualBoard[newModel.row][newModel.col] = newModel.value;
		recalculateValuesBoard(newModel);
	}

	public static void main(String[] args) throws FileNotFoundException {
		File file = new File("D:/Development/Competitions/GoogleCodeJam/GoogleCodeJam2017/data/Qualification/D-small-attempt0.in");
		PrintStream out = new PrintStream(new FileOutputStream("D:/Development/Competitions/GoogleCodeJam/GoogleCodeJam2017/data/Qualification/D-small-attempt0.out"));
		System.setOut(out);
		
		Scanner sc = new Scanner(file);
		
		int T = sc.nextInt();
		
		for (int i = 0; i < T; ++i)
		{
			N = sc.nextInt();
			actualBoard = new int[N][N];
			valuesBoard = new int[N][N];
			for (int row = 0; row < N; ++row)
				for (int col = 0; col < N; ++col)
					valuesBoard[row][col] = 3;
			int M = sc.nextInt();
			Vector<Model> presentModels = new Vector<Model>();
			Vector<Model> addedModels = new Vector<Model>();
			for (int j = 0; j < M; ++j)
			{
				Model newModel = new Model(sc.next().toCharArray()[0], sc.nextInt()-1, sc.nextInt()-1);
				presentModels.add(newModel);
				addModelToBoard(newModel);
			}
			
			Model newModel = determineNextModel(); 
			while (newModel != null) 
			{
				//Check if we have to substitute existing model with this one.
				Iterator<Model> modelIterator = presentModels.iterator();
				while (modelIterator.hasNext())
				{
					Model model = modelIterator.next();
					if ((model.col == newModel.col) && (model.row == newModel.row))
					{
						//We are upgrading an existing model. Removing old one from the container and update the new one with it.
						newModel.value = 3;
						modelIterator.remove();
						break;
					}
				}
				
				//Check if we have to substitute added model with this one.
				modelIterator = addedModels.iterator();
				while (modelIterator.hasNext())
				{
					Model model = modelIterator.next();
					if ((model.col == newModel.col) && (model.row == newModel.row))
					{
						//We are upgrading an existing model. Removing old one from the container and update the new one with it.
						newModel.value = 3;
						modelIterator.remove();
						break;
					}
				}
				
				addedModels.add(newModel);
				addModelToBoard(newModel);
				
				newModel = determineNextModel();
			}
			
			int totalValue = 0;
			for (int row = 0; row < N; ++row)
				for (int col = 0; col < N; ++col)
					if (actualBoard[row][col] == 3)
						totalValue += 2;
					else if (actualBoard[row][col] > 0)
						totalValue ++;
			
			System.out.println(String.format("Case #%d: %d %d", i + 1, totalValue, addedModels.size()));
			Iterator<Model> modelIterator = addedModels.iterator();
			while (modelIterator.hasNext())
			{
				Model model = modelIterator.next();
				if (model.value == 1)
					System.out.print("+ ");
				else if (model.value == 2)
					System.out.print("x ");
				else 
					System.out.print("o ");
				
				System.out.println(String.format("%d %d", model.row+1, model.col+1));
			}
		}
		
		sc.close();
	}
}