import java.util.*;
import java.io.*;

public class Solution implements Runnable {
	
	final int INF = Integer.MAX_VALUE >> 2;
	
	public static void main(String[] args) {
		new Thread(new Solution()).start();
	}
	
	class State {
		int x, l, r;

		public State(int x, int l, int r) {
			this.x = x;
			this.l = l;
			this.r = r;
		}
		
		public String toString() {
			return x + " [" + l + "," + r + "]";
		}
	}

	public void run() {
		try {
			solve();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	String next() throws Exception {
		while (tok == null || !tok.hasMoreTokens())
			tok = new StringTokenizer(cin.readLine());
		return tok.nextToken();
	}
	
	int nextInt() throws Exception {
		return Integer.parseInt(next());
	}
	
	BufferedReader cin;
	PrintWriter cout;
	StringTokenizer tok;
	
	char[][] a;
	int n, m, f;
	int[][][] d;
	Queue<State> q = new LinkedList<State>();
	
	boolean isFree(int x, int y, int l, int r) {
		if (x >= n) return false;
		if (y < 0 || y >= m) return false;
		return a[x][y] == '.' || l <= y && y <= r;
	}

	State findBreach(int x, int y, int l, int r) {
		int al = y;
		while (isFree(x, al - 1, l, r) && !isFree(x + 1, al - 1, INF, -INF)) --al;
		int ar = y;
		while (isFree(x, ar + 1, l, r) && !isFree(x + 1, ar + 1, INF, -INF)) ++ar;
		return new State(x, al, ar);
	}
	
	int getDepth(int x, int y, int l, int r) {
		int fall = 0;
		while (fall < 1 && isFree(x + fall + 1, y, l, r) || isFree(x + fall + 1, y, INF, -INF)) {
			++fall;
			if (fall > f) return -1;
		}
		return x + fall;
	}

	private void solve() throws Exception {
		cin = new BufferedReader(new FileReader("input.txt"));
		cout = new PrintWriter(new File("output.txt"));
		
		int tk = nextInt();
		for(int tc = 1; tc <= tk; ++tc) {
			n = nextInt();
			m = nextInt();
			f = nextInt();
			
			a = new char[n][];
			for(int i = 0; i < n; ++i)
				a[i] = next().toCharArray();
			
			d = new int[n][m][m];
			for(int i = 0; i < n; ++i)
				for(int j =0; j < m; ++j)
					Arrays.fill(d[i][j], INF);
			
			q.clear();
			State first = findBreach(0, 0, 0, 0);
			d[0][first.l][first.r] = 0;
			q.add(first);
			
			while (!q.isEmpty()) {
				
				State s = q.poll();
				
				tryStep(s.x, s.l - 1, d[s.x][s.l][s.r]);
				tryStep(s.x, s.r + 1, d[s.x][s.l][s.r]);
				
				for(int l = s.l; l <= s.r; ++l)
					for(int r = l; r <= s.r; ++r) {
						if (l != s.l)
							tryDig(s.x, l, r, l, d[s.x][s.l][s.r] + r - l + 1);
						if (r != s.r)
							tryDig(s.x, l, r, r, d[s.x][s.l][s.r] + r - l + 1);
					}
			}
			int ans = INF;
			for(int l = 0; l < m; ++l)
				for(int r = l; r < m; ++r)
					ans = Math.min(ans, d[n - 1][l][r]);
					
			if (ans == INF) cout.println("Case #" + tc + ": No");
			else cout.println("Case #" + tc + ": Yes " + ans);
			System.out.println("Solved case " + tc + "/" + tk);
			System.out.flush();
		}
		
		cin.close();
		cout.close();
	}

	private void tryDig(int x, int l, int r, int y, int dst) {
		if (x == n - 1) return;
		int tx = getDepth(x, y, l, r);
		if (tx == -1) return;
		
		State nw = null;
		if (tx == x + 1) nw = findBreach(tx, y, l, r);
		else nw = findBreach(tx, y);
		
		if (d[nw.x][nw.l][nw.r] > dst) {
			q.add(nw);
			d[nw.x][nw.l][nw.r] = dst;
		}
	}

	private void tryStep(int x, int y, int dst) {
		if (x == n - 1) return;
		if (y < 0 || y >= m) return;
		if (a[x][y] == '#') return;
		int tx = getDepth(x, y, INF, -INF);
		if (tx == -1) return;
		State nw = findBreach(tx, y);
		if (d[nw.x][nw.l][nw.r] > dst) {
			q.add(nw);
			d[nw.x][nw.l][nw.r] = dst;
		}
	}

	private State findBreach(int x, int y) {
		return findBreach(x, y, INF, -INF);
	}
}
