import java.util.*;
import java.io.*;
import java.math.*;
import static java.lang.Math.*;

public class Solution implements Runnable {
	public static void main(String[] args) {
		new Thread(new Solution()).start();
	}

	public void run() {
		try {
			solve();
		} catch (Exception e) {
			e.printStackTrace();
			throw new RuntimeException("Bug in solution");
		}
	}
	
	private String next() throws Exception {
		while (tok == null || !tok.hasMoreTokens()) {
			tok = new StringTokenizer(cin.readLine());
		}
		
		return tok.nextToken();
	}
	
	private int nextInt() throws Exception {
		return Integer.parseInt(next());
	}
	
	private double nextDouble() throws Exception {
		return Double.parseDouble(next());
	}
	
	private long nextLong() throws Exception {
		return Long.parseLong(next());
	}
	
	class Trip implements Comparable<Trip> {
		int startTime;
		int endTime;
		int startStation;
		
		public Trip(int startTime, int endTime, int startStation) {
			this.startTime = startTime;
			this.endTime = endTime;
			this.startStation = startStation;
		}

		public int compareTo(Trip o) {
			if (startTime < o.startTime) return -1;
			if (startTime > o.startTime) return 1;
			
			return 0;
		}
	}
	
	BufferedReader cin;
	StringTokenizer tok;
	PrintWriter cout;
	
	Trip[] trips;
	PriorityQueue<Integer>[] trains;
	int[] ans;
	int delay;
	int n;
	
	private void solve() throws Exception {
		//cin = new BufferedReader(new FileReader("input.txt"));
		//cin = new BufferedReader(new FileReader("b-small.in"));
		cin = new BufferedReader(new FileReader("b-large.in"));
		cout = new PrintWriter(new File("output.txt"));
		//cout = new PrintWriter(System.out);
		
		int cases = nextInt();
		
		for (int testcase = 1; testcase <= cases; ++testcase) {
			delay = nextInt();
			int na = nextInt();
			int nb = nextInt();
			trips = new Trip[na + nb];
			n = 0;
			
			for (int i = 0; i < na; ++i) {
				trips[n] = new Trip(toTime(next()), toTime(next()), 0);
				++n;
			}
			for (int i = 0; i < nb; ++i) {
				trips[n] = new Trip(toTime(next()), toTime(next()), 1);
				++n;
			}
			
			Arrays.sort(trips);
			
			trains = new PriorityQueue[2];
			trains[0] = new PriorityQueue<Integer>();
			trains[1] = new PriorityQueue<Integer>();
			ans = new int[2];

			for (int i = 0; i < n; ++i) {
				int start = trips[i].startStation;
				if (!trains[start].isEmpty() && trains[start].peek() <= trips[i].startTime) {
					trains[start].poll();
				} else {
					++ans[start];
				}
				
				trains[1 - start].add(trips[i].endTime + delay);
			}
			
			cout.println("Case #" + testcase + ": " + ans[0] + " " + ans[1]);
		}
		
		
		
		cout.close();
	}

	private int toTime(String s) {
		return Integer.parseInt(s.substring(0, 2)) * 60 + Integer.parseInt(s.substring(3, 5));
	}
}