import java.util.*;
import java.io.*;
import java.math.*;
import static java.lang.Math.*;

public class Solution implements Runnable {

	private static final double EPS = 1e-8;

	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new Thread(new Solution()).start();
	}
	
	@Override
	public void run() {
		try {
			solve();
		} catch (Exception e) {
			e.printStackTrace();
			throw new RuntimeException("Laja in solution");
		}
	}

	private String next() throws IOException {
		while (tok == null || !tok.hasMoreTokens()) {
			tok = new StringTokenizer(cin.readLine());
		}
		
		return tok.nextToken();
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(next());
	}
	
	BufferedReader cin;
	StringTokenizer tok;
	PrintWriter cout;
	
	private void solve() throws Exception {
		//cin = new BufferedReader(new FileReader("input.txt"));
		cin = new BufferedReader(new FileReader("A-small-attempt0.in"));
		cout = new PrintWriter(new File("output.txt"));
		
		int testcases = nextInt();
		
		for (int testcase = 0; testcase < testcases; ++testcase) {
			double length = nextInt();
			double walking = nextInt();
			double runningDifference = nextInt() - walking;
			double stamina = nextInt();
			int n = nextInt();
			
			ArrayList<Edge> a = new ArrayList<Solution.Edge>();
			
			double prevRight = 0;
			
			for (int i = 0; i < n; ++i) {
				double left = nextInt();
				double right = nextInt();
				double waySpeed = nextInt();
				
				if (prevRight < left - EPS) {
					a.add(new Edge(left - prevRight, walking));
				}
				
				a.add(new Edge(right - left, walking + waySpeed));

				prevRight = right;
			}
			
			if (prevRight < length - EPS) {
				a.add(new Edge(length - prevRight, walking));
			}
			
			Collections.sort(a);
			
			double answer = 0;
			for(Edge e: a) {
				if (stamina < EPS) {
					answer += e.length / e.speed;
				} else {
					double t = e.length / (e.speed + runningDifference);
					
					if (t < stamina + EPS) {
						answer += t;
						stamina -= t;
					} else {
						double walkDist = e.length - stamina * (e.speed + runningDifference);
						
						answer += stamina + walkDist / e.speed;
						
						stamina = 0;
					}
				}
			}
			
			cout.printf("Case #%d: %.10f\n", (testcase + 1), answer);
		}
		
		cout.close();
	}
	
	private class Edge implements Comparable<Edge> {
		double length;
		double speed;
		
		public Edge(double length, double speed) {
			this.length = length;
			this.speed = speed;
		}

		public double getLength() {
			return length;
		}

		public double getSpeed() {
			return speed;
		}

		@Override
		public int compareTo(Edge other) {
			return (int)(speed - other.speed);
		}
	}
}
