package codeJam;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map.Entry;
import java.util.Stack;

public class Treasure
{
    public static int getKeyCount(ArrayList<Key> myKeys)
    {
        int ret = 0;
        for (Key k : myKeys)
            if (!k.keyUsed)
                ret++;
        return ret;
    }
    public static Key getUnlockKey(Chest c, ArrayList<Key> myKeys)
    {
        Key goodKey = null;
        for (Key k : myKeys)
        {
            if (!k.keyUsed && c.canUnlock(k))
            {
                goodKey = k;
                break;
            }
        }
        return goodKey;
    }
    public static void main(String args[]) throws IOException
    {
        String in = "/home/sam/google/2013/qual/4/D-small-attempt1.in";
        String out = "/home/sam/google/2013/qual/4/smallOut";
        FileUtils fUtils = new FileUtils(in, out);
        int caseNums = fUtils.readNumOfCases();
        for (int c = 0; c < caseNums; c++)
        {
            System.out.println(c);
            int[] sets = fUtils.explodeNextLineAsInt();
            int numOfKeys = sets[0];
            int numOfChests = sets[1];
            int[] keyTypes = fUtils.explodeNextLineAsInt();
            ArrayList<Key> myKeys = new ArrayList<Key>();
            ArrayList<Key> allKeys = new ArrayList<Key>();
            ArrayList<Chest> chests = new ArrayList<Chest>();
            HashMap<Integer, ArrayList<Chest>> chestsByVal = new HashMap<Integer, ArrayList<Chest>>();
            for (int i = 0; i < numOfKeys; i++)
            {
                Key k = new Key(keyTypes[i], null);
                myKeys.add(k);
                allKeys.add(k);
            }
            for (int i = 0; i < numOfChests; i++)
            {
                int[] chestSet = fUtils.explodeNextLineAsInt();
                int numOfKeysInChest = chestSet[1];
                int[] keys = new int[numOfKeysInChest];
                if (numOfKeysInChest > 0)
                {
                    for (int j = 0; j < numOfKeysInChest; j++)
                    {
                        keys[j] = chestSet[j + 2];
                    }
                }
                Chest chest = new Chest(i + 1, chestSet[0], keys);
                chests.add(chest);
                if (chestsByVal.containsKey(chest.unlockedBy))
                    chestsByVal.get(chest.unlockedBy).add(chest);
                else
                {
                    ArrayList<Chest> temp = new ArrayList<Chest>();
                    temp.add(chest);
                    chestsByVal.put(chest.unlockedBy, temp);
                }
                allKeys.addAll(chest.contains);
            }
            // now do the work
            Stack<Chest> myChests = new Stack<Chest>();
            boolean impossible = myChests.size() != numOfChests;
            for (int j = 0; j < numOfChests && impossible; j++)
            {
                Chest check = chests.get(j);
                if (!check.locked)
                    continue;
                Key checkKey = getUnlockKey(check, myKeys);
                if (checkKey != null)
                    impossible = unlockChest(check, checkKey, myChests, myKeys,
                            chests, allKeys, numOfChests, chestsByVal);
            }
            if (impossible)
            {
                fUtils.writeCase("IMPOSSIBLE");
            } else
            {
                String str = "";
                for (int i = 0; i < myChests.size(); i++)
                {
                    str += Integer.toString(myChests.get(i).index);
                    if (myChests.size() - 1 != i)
                    {
                        str += " ";
                    }
                }
                fUtils.writeCase(str);
            }
        }
        fUtils.closeFile();
        fUtils.closeWriteFile();
    }
    public static boolean unlockChest(Chest c, Key k, Stack<Chest> myChests,
            ArrayList<Key> myKeys, ArrayList<Chest> allChests,
            ArrayList<Key> allKey, int numOfChests,
            HashMap<Integer, ArrayList<Chest>> chestsByVal)
    {
        c.useKey(k);
        myKeys.addAll(c.contains);
        myChests.push(c);
        chestsByVal.get(c.unlockedBy).remove(c);
        boolean impossible = myChests.size() != numOfChests;
        System.out.println("Chests to go " + (numOfChests - myChests.size()));
        boolean reallyImpossible = false;
        if (impossible)
        {
            HashMap<Integer, Integer> counts = new HashMap<Integer, Integer>();
            for (Key k1 : allKey)
            {
                if (!k1.keyUsed)
                {
                    int count = 0;
                    if (counts.containsKey(k1.type))
                        count = counts.get(k1.type);
                    count++;
                    counts.put(k1.type, count);
                }
            }
            for (Entry<Integer, ArrayList<Chest>> temp : chestsByVal.entrySet())
            {
                try
                {
                    if (counts.get(temp.getKey()) <= temp.getValue().size())
                    {
                        reallyImpossible = true;
                        break;
                    }
                } catch (NullPointerException e)
                {
                    reallyImpossible = true;
                }
            }
        }
        for (int i = 0; i < numOfChests && impossible && !reallyImpossible; i++)
        {
            Chest check = allChests.get(i);
            if (!check.locked)
                continue;
            Key checkKey = getUnlockKey(check, myKeys);
            if (checkKey != null)
            {
                impossible = unlockChest(check, checkKey, myChests, myKeys,
                        allChests, allKey, numOfChests, chestsByVal);
            }
        }
        if (impossible)
        {
            Chest l = myChests.pop();
            l.reLock();
            myKeys.removeAll(l.contains);
            chestsByVal.get(c.unlockedBy).add(c);
        }
        return impossible;
    }
}

class Chest
{
    public ArrayList<Key> contains;
    public int index;
    public Key keyUsed;
    public boolean locked;
    public int unlockedBy;

    Chest(int index, int unlockedBy, int[] contains)
    {
        this.index = index;
        this.unlockedBy = unlockedBy;
        this.contains = new ArrayList<Key>();
        this.locked = true;
        for (int k : contains)
        {
            Key key = new Key(k, this);
            this.contains.add(key);
        }
    }
    public boolean canUnlock(Key k)
    {
        return k.type == unlockedBy;
    }
    public void reLock()
    {
        keyUsed.keyUsed = false;
        locked = true;
        keyUsed = null;
    }
    public void useKey(Key k)
    {
        keyUsed = k;
        keyUsed.keyUsed = true;
        locked = false;
    }
}

class Key
{
    public boolean keyUsed = false;
    public Chest parent;
    public int type;

    Key(int type, Chest parent)
    {
        this.type = type;
        this.parent = parent;
    }
}