package codejam2017.qualif;

import java.io.BufferedWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Stream;

public class CodeJam03Stalls {
	
	private static String solve(TestCase testCase) {
		while(testCase.k.compareTo(BigInteger.ONE) != 0) {
			chooseStall(testCase);
		}
		
		BigInteger size= getSizeAndPos(testCase).sizeOfGreatestSection.subtract(BigInteger.ONE);
		BigInteger[] div = size.divideAndRemainder(TWO);
		BigInteger half = div[0];
		BigInteger remainder = div[1];
		
		if (remainder.compareTo(BigInteger.ONE) == 0) {
			return half.add(BigInteger.ONE) + " " + half;
		} else {
			return half + " " + half;
		}
	}
	
	static class SizeAndPos {
		BigInteger sizeOfGreatestSection;
		int positionOfGreatestSection;
	}
	
	static SizeAndPos getSizeAndPos(TestCase testCase) {
		BigInteger sizeOfGreatestSection = BigInteger.ZERO;
		int positionOfGreatestSection = -1;
		for (int i = 0; i < testCase.stallSections.size(); i++) {
			BigInteger stallSection = testCase.stallSections.get(i);
			if (stallSection.compareTo(sizeOfGreatestSection) > 0) {
				sizeOfGreatestSection = stallSection;
				positionOfGreatestSection = i;
			}
		}
		SizeAndPos sizeAndPos = new SizeAndPos();
		sizeAndPos.positionOfGreatestSection = positionOfGreatestSection;
		sizeAndPos.sizeOfGreatestSection = sizeOfGreatestSection;
		return sizeAndPos;
	}
	
	final static BigInteger TWO = new BigInteger("2");
	private static void chooseStall(TestCase testCase) {
		testCase.k = testCase.k.subtract(BigInteger.ONE);
		
		SizeAndPos sizeAndPos = getSizeAndPos(testCase);
		
		if (sizeAndPos.sizeOfGreatestSection.compareTo(BigInteger.ONE) == 0) {
			testCase.stallSections.remove(sizeAndPos.positionOfGreatestSection);
		} else if (sizeAndPos.sizeOfGreatestSection.compareTo(TWO) == 0) {
			testCase.stallSections.set(sizeAndPos.positionOfGreatestSection, BigInteger.ONE);
		} else {
			BigInteger[] div = sizeAndPos.sizeOfGreatestSection.subtract(BigInteger.ONE).divideAndRemainder(TWO);
			BigInteger newSectionSizes = div[0];
			BigInteger remainder = div[1];
			
			testCase.stallSections.add(sizeAndPos.positionOfGreatestSection, newSectionSizes.add(remainder));
			testCase.stallSections.add(sizeAndPos.positionOfGreatestSection, newSectionSizes);
			testCase.stallSections.remove(sizeAndPos.positionOfGreatestSection + 2);
		}
	}

	static class ChooseResult {
		BigInteger min;
		BigInteger max;
	}
	
	static class TestCase {
		List<BigInteger> stallSections;
		BigInteger k;
		
		@Override
		public String toString() {
			return "TestCase [n=" + stallSections + ", k=" + k + "]";
		}
	}
	
	
	/*
	 *  ------------------------------------------
	 *   Boilerplate to run test and handle files
	 *  ------------------------------------------
	 */

	public static void main(String[] args) {
		TestInput testInput = getInput();
		TestOutput testOutput = solve(testInput);
		writeOutput(testOutput);
	}
	
	private static TestOutput solve(TestInput testInput) {
		TestOutput testOutput = new TestOutput();
		
		for (TestCase testCase : testInput.cases) {
			String result = solve(testCase);
			testOutput.result.add(result);
		}
		
		return testOutput;
	}

	private static void writeOutput(TestOutput testOutput) {
		Path path = Paths.get("/home/dodi/temp/output.txt");
		try (BufferedWriter writer = Files.newBufferedWriter(path)) {
			int caseNumber = 1;
			for (String line : testOutput.result) {
				writer.write("Case #" + caseNumber + ": " + line + "\n");
				caseNumber++;
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		
	}


	private static TestInput getInput() {
		String fileName = "/home/dodi/temp/input.txt";
		
		TestInput testInput = new TestInput();
		try (Stream<String> stream = Files.lines(Paths.get(fileName))) {
			stream.forEach((line) -> {
				if (testInput.numberOfCases == -1) {
					testInput.numberOfCases = Integer.parseInt(line);
				} else {
					TestCase testCase = new TestCase();
					testCase.stallSections = new ArrayList<>();
					testCase.stallSections.add(new BigInteger(line.split(" ")[0]));
					testCase.k = new BigInteger(line.split(" ")[1]);
					testInput.cases.add(testCase);
				}
			});
		} catch (IOException e) {
			e.printStackTrace();
		}
		return testInput;
	}
	
	static class TestInput {
		int numberOfCases = -1;
		List<TestCase> cases = new ArrayList<>();
		
		@Override
		public String toString() {
			return "TestInput [numberOfCases=" + numberOfCases + ", cases=" + cases + "]";
		}
	}
	
	static class TestOutput {
		List<String> result = new ArrayList<>();
	}
}
