package hu.awm.codejam;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.List;
import java.util.function.Function;
import java.util.stream.Collectors;

public class HouseOfPencaces {
	
	static final String INPUT_FILE_PATH = "/home/dodi/temp/input.txt";
	static final String OUTPUT_FILE_PATH = "/home/dodi/temp/output.txt";
	static int numberOfCases = 1;
	
	public static void main(String[] args) throws IOException {
		process(
				inputString -> {
					return new Input(inputString);
				},
				input -> {
					String prev = input.pencaces;
					String current = next(input.pencaces);
					int steps = 1;
					
					while (!prev.equalsIgnoreCase(current)) {
						prev = current;
						current = next(current);
						steps++;
					}
					
					return new Result(steps - 1);
				},
				result -> {
					return "Case #" + result.caseNumber + ": " + result.numberOfSteps;
				},
				INPUT_FILE_PATH
//				,OUTPUT_FILE_PATH
				);
	}
	
	private static String flip(String pencaces, int pos) {
		String flippinPencaces = pencaces.substring(0, pos);
		String stayingPencaces = pencaces.substring(pos);
		
		flippinPencaces = new StringBuilder(flippinPencaces).reverse().toString().replace("-", "*").replace("+", "-").replace("*", "+");
		
		return flippinPencaces + stayingPencaces;
	}
	
	private static String next(String pencaces) {
		if (pencaces.indexOf("-") == -1) {
			return pencaces;
		} else {
			if (pencaces.indexOf("-") != 0) {
				// flip starting + signs.
				return flip(pencaces, pencaces.indexOf("-"));
			} else {
				// flip everything until the last + or the end.
				if (pencaces.indexOf("+") != -1) {
					return flip(pencaces, pencaces.lastIndexOf("-") + 1);
				} else {
					return flip(pencaces, pencaces.length());
				}
			}
		}
	}
	
	static class Input {
		String pencaces;
		Input(String pencaces) {
			this.pencaces = pencaces;
		}
	}
	
	private static class Result {
		int numberOfSteps;
		int caseNumber;
		Result(int numberOfSteps) {
			this.caseNumber = numberOfCases++;
			this.numberOfSteps = numberOfSteps;
		}
	}

	private static void process(Function<? super String, ? extends Input> parser, 
			Function<? super Input, ? extends Result> solver,
			Function<? super Result, ? extends String> formatter,
			String inputFilePath) throws IOException {
		process(parser, solver, formatter, inputFilePath, null);
	}
	
	private static void process(Function<? super String, ? extends Input> parser, 
			Function<? super Input, ? extends Result> solver,
			Function<? super Result, ? extends String> formatter,
			String inputFilePath, String outputFilePath) throws IOException {

		List<String> output = Files.lines(Paths.get(inputFilePath))
			.skip(1)
			.map(parser)
			.map(solver)
			.map(formatter)
			.collect(Collectors.toList());
		
		if (outputFilePath == null) {
			for (String string : output) {
				System.out.println(string);
			}
		} else {
			Files.write(Paths.get(outputFilePath), output);
		}
		
	}
	
}
