package hu.awm.codejam;

import java.io.IOException;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Function;
import java.util.stream.Collectors;

public class CoinJam {

	static final String INPUT_FILE_PATH = "/home/dodi/temp/input.txt";
	static final String OUTPUT_FILE_PATH = "/home/dodi/temp/output.txt";
	static int numberOfCases = 1;

	public static void main(String[] args) throws IOException {
		process(inputString -> {
			int n = Integer.parseInt(inputString.split(" ")[0].trim());
			int j = Integer.parseInt(inputString.split(" ")[1].trim());
			return new Input(n, j);
		}, input -> {
			List<Coin> coins = new ArrayList<>();

			long lowerBound = Math.round(Math.pow(2, input.n - 1));
			long upperBound = Math.round(Math.pow(2, input.n));

			for (long i = lowerBound + 1; i < upperBound
					&& coins.size() < input.j; i++) {
				String coinString = Long.toString(i, 2);
				List<BigInteger> proofs = getProofs(coinString);
				if (proofs.size() == 9) {
					coins.add(new Coin(coinString, proofs));
				}
			}

			return new Result(coins);
		}, result -> {
			String r = "Case #1:\n";
			for (Coin coin : result.coins) {
				r += coin.coin;

				for (BigInteger proof : coin.proofs) {
					r += " " + proof.toString();
				}

				r += "\n";
			}
			return r;
		}, INPUT_FILE_PATH
		 ,OUTPUT_FILE_PATH
		);
	}

	private static List<BigInteger> getProofs(String coinString) {
		System.out.println("Cheking: " + coinString);
		List<BigInteger> proofs = new ArrayList<>();

		for (int base = 2; base <= 10; base++) {
			BigInteger value = new BigInteger(coinString, base);

			System.out.println(" is " + value.toString() + " in base " + base);

			BigInteger proof = getProof(value, base);
			if (proof == null) {
				return new ArrayList<>();
			} else {
				proofs.add(proof);
			}
		}

		return proofs;
	}

	private static BigInteger getProof(BigInteger value, int base) {
		for (BigInteger i = new BigInteger("2"); i.longValue() <= sqrt(value).longValue(); i = i.add(BigInteger.ONE)) {
			if (value.remainder(i).equals(BigInteger.ZERO)) {
				System.out.println("Proof for base " + base + " is " + value);
				return i;
			}
		}
		System.out.println("Has no proof for base " + base);
		return null;
	}

	static BigInteger sqrt(BigInteger n) {
		return BigInteger.valueOf((long) Math.ceil(Math.sqrt(n.longValue())));
	}

	private static class Input {
		int n;
		int j;

		Input(int n, int j) {
			this.n = n;
			this.j = j;
		}
	}

	private static class Coin {
		String coin;
		List<BigInteger> proofs;

		Coin(String coin, List<BigInteger> proofs) {
			this.proofs = proofs;
			this.coin = coin;
		}
	}

	private static class Result {
		List<Coin> coins;
		int caseNumber;

		Result(List<Coin> coins) {
			this.caseNumber = numberOfCases++;
			this.coins = coins;
		}
	}

	private static void process(
			Function<? super String, ? extends Input> parser,
			Function<? super Input, ? extends Result> solver,
			Function<? super Result, ? extends String> formatter,
			String inputFilePath) throws IOException {
		process(parser, solver, formatter, inputFilePath, null);
	}

	private static void process(
			Function<? super String, ? extends Input> parser,
			Function<? super Input, ? extends Result> solver,
			Function<? super Result, ? extends String> formatter,
			String inputFilePath, String outputFilePath) throws IOException {

		List<String> output = Files.lines(Paths.get(inputFilePath)).skip(1)
				.map(parser).map(solver).map(formatter)
				.collect(Collectors.toList());

		if (outputFilePath == null) {
			for (String string : output) {
				System.out.println(string);
			}
		} else {
			Files.write(Paths.get(outputFilePath), output);
		}

	}

}
