package hu.awm.codejam;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.function.Function;
import java.util.stream.Collectors;

public class CountingSheep {
	
	static final String INPUT_FILE_PATH = "/home/dodi/temp/input.txt";
	static final String OUTPUT_FILE_PATH = "/home/dodi/temp/output.txt";
	static int numberOfCases = 1;
	
	public static void main(String[] args) throws IOException {
		
		process(
				inputString -> {
					return new Input(Integer.parseInt(inputString));
				},
				input -> {
					if (input.startingNumber == 0) {
						return new Result(0, true);
					} else {
						int steps = 0;
						int last = 0;
						int current = input.startingNumber;
						Set<Character> numbers = new HashSet<>();
						while (numbers.size() != 10) {
							String chars = (current + "");
							chars.chars()
						        .mapToObj(c -> Character.valueOf((char) c))
						        .forEach(c -> numbers.add(c));
							steps++;
							last = current;
							current = (steps + 1) * input.startingNumber;
						}
						return new Result(last, false);
					}
				},
				result -> {
					if (result.insomnia) {
						return "Case #" + result.caseNumber + ": INSOMNIA";
					} else {
						return "Case #" + result.caseNumber + ": " + result.numberOfSteps;
					}
				},
				INPUT_FILE_PATH
				,OUTPUT_FILE_PATH
				);
	}
	
	private static class Input {
		int startingNumber;
		Input(int i) {
			this.startingNumber = i;
		}
	}
	
	private static class Result {
		int numberOfSteps;
		boolean insomnia;
		int caseNumber;
		Result(int numberOfSteps, boolean insomnia) {
			this.caseNumber = numberOfCases++;
			this.numberOfSteps = numberOfSteps;
			this.insomnia = insomnia;
		}
	}

	private static void process(Function<? super String, ? extends Input> parser, 
			Function<? super Input, ? extends Result> solver,
			Function<? super Result, ? extends String> formatter,
			String inputFilePath) throws IOException {
		process(parser, solver, formatter, inputFilePath, null);
	}
	
	private static void process(Function<? super String, ? extends Input> parser, 
			Function<? super Input, ? extends Result> solver,
			Function<? super Result, ? extends String> formatter,
			String inputFilePath, String outputFilePath) throws IOException {

		List<String> output = Files.lines(Paths.get(inputFilePath))
			.skip(1)
			.map(parser)
			.map(solver)
			.map(formatter)
			.collect(Collectors.toList());
		
		if (outputFilePath == null) {
			for (String string : output) {
				System.out.println(string);
			}
		} else {
			Files.write(Paths.get(outputFilePath), output);
		}
		
	}
	
}
