import java.util.ArrayList;
import java.util.List;

import commons.read.ProblemReader;
import commons.read.model.Case;
import commons.read.model.Cases;
import commons.write.SolutionWriter;


public class MinesweeperMaster {
	private static final String PATH = "/home/dodie/workspace_codejam/codejam201404/MinesweeperMaster/src/main/resources";
	private static final String INPUT_FILE = "C-small-attempt1.in";
	private static final String OUT_FILE = "C-small-attempt1.out";
	
	public static void main(String[] args) {
		Cases cases = new ProblemReader(PATH, INPUT_FILE).read().split().toProblem();
		List<String> solution = new ArrayList<String>();
		
		for (Case problem : cases) {
			System.out.println("Case #" + problem.getCaseNumber() + ":");
			solution.add("Case #" + problem.getCaseNumber() + ":");
			
			int rows = Integer.parseInt(problem.getLines().get(0).get(0));
			int columns = Integer.parseInt(problem.getLines().get(0).get(1));
			int mines = Integer.parseInt(problem.getLines().get(0).get(2));
			
			Model model = new Model(rows, columns, mines);
			
			if (model.clickCol != null) {
				StringBuilder sb = new StringBuilder();
				for (int i = 0; i < rows; i++) {
					for (int j = 0; j < columns; j++) {
						if (model.mines.get(i).get(j)) {
							sb.append("*");
						} else {
							if (i == model.clickRow && j == model.clickCol) {
								sb.append("C");
							} else {
								sb.append(".");
							}
						}
					}
					
					if (i != rows -1)
					sb.append("\n");
				}
				
				solution.add(sb.toString());
			} else {
				solution.add("Impossible");
			}
		}
		
		for (String string : solution) {
			System.out.println(string);
		}
		
		new SolutionWriter(PATH, OUT_FILE ).write(solution);
	}
	
	private static class Model {
		final Integer clickRow;
		final Integer clickCol;
		final List<List<Boolean>> mines;
		
		public Model(int rows, int columns, int numOfMines) {
			mines = new ArrayList<List<Boolean>>();
			
			for (int i = 1; i <= rows; i++) {
				List<Boolean> emptyFieldsForRow = new ArrayList<Boolean>();
				for (int j = 1; j <= columns; j++) {
					emptyFieldsForRow.add(false);
				}
				mines.add(emptyFieldsForRow);
			}
			
			int currentRowToFill = 0;
			int currentColToFill = 0;
			int remaningMines = numOfMines;
			
			int currentWidth = columns - currentColToFill;
			int currentHeight = rows - currentRowToFill;
			while (remaningMines > 0 && (remaningMines >= currentWidth ||remaningMines >= currentHeight )) {
				if (currentHeight > currentWidth) {
					for (int i = currentColToFill; i < columns; i++) {
						mines.get(currentRowToFill).set(i, true);
						remaningMines--;
					}
					currentRowToFill ++;
				} else {
					for (int i = currentRowToFill; i < rows; i++) {
						mines.get(i).set(currentColToFill, true);
						remaningMines--;
					}
					currentColToFill ++;
				}
				
				currentWidth = columns - currentColToFill;
				currentHeight = rows - currentRowToFill;
			}
			
			if (remaningMines == 0) {
				// TODO
				if (currentWidth == 1 && currentHeight == 1) {
					clickRow = rows - 1;
					clickCol = columns - 1;
				} else if (columns == 1 || rows == 1) {
					clickRow = rows - 1;
					clickCol = columns - 1;
				} else if ( currentWidth == 1 || currentHeight == 1 ) {
					clickRow = null;
					clickCol = null;
				} else {
					clickRow = rows - 1;
					clickCol = columns - 1;
				}
			} else {
				mines.get(currentRowToFill).set(currentColToFill, true);
				remaningMines--;
				
				if (remaningMines == 0) {
					if (currentHeight > 2 && currentWidth > 2) {
						clickRow = rows - 1;
						clickCol = columns - 1;
					} else {
						clickRow = null;
						clickCol = null;
					}
				} else {
					if (currentHeight > currentWidth) {
						for (int i = currentColToFill; i < columns - 2 && remaningMines > 0; i++) {
							if (!mines.get(currentRowToFill).get(i)) {
								mines.get(currentRowToFill).set(i, true);
								remaningMines--;
							}
						}
						
						if (remaningMines == 0) {
							clickRow = rows - 1;
							clickCol = columns - 1;
						} else {
							mines.get(currentRowToFill + 1).set(currentColToFill, true);
							
							if (currentHeight > 3) {
								clickRow = rows - 1;
								clickCol = columns - 1;
							} else {
								clickRow = null;
								clickCol = null;
							}
						}
					} else {
						for (int i = currentRowToFill; i < rows - 2 && remaningMines > 0; i++) {
							if (!mines.get(i).get(currentColToFill)) {
								mines.get(i).set(currentColToFill, true);
								remaningMines--;
							}
						}
						
						if (remaningMines == 0) {
							clickRow = rows - 1;
							clickCol = columns - 1;
						} else {
							mines.get(currentRowToFill).set(currentColToFill + 1, true);
							
							if (currentWidth > 3) {
								clickRow = rows - 1;
								clickCol = columns - 1;
							} else {
								clickRow = null;
								clickCol = null;
							}
						}
					}
				}
			}
			
		}
		
	}
}
