import java.util.ArrayList;
import java.util.List;

import commons.read.ProblemReader;
import commons.read.model.Case;
import commons.read.model.Cases;
import commons.write.SolutionWriter;


public class CookieClickerAlpha {
	private static final String PATH = "/home/dodie/workspace_codejam/codejam201404/CookieClickerAlpha/src/main/resources";
	private static final String INPUT_FILE = "B-small-attempt0.in";
	private static final String OUT_FILE = "B-small-attempt0.out";
	
	public static void main(String[] args) {
		Cases cases = new ProblemReader(PATH, INPUT_FILE).read().split().toProblem();
		
		List<String> solutions = new ArrayList<String>();
		for (Case problem : cases) {
			double farmCost = Double.parseDouble(problem.getLines().get(0).get(0));
			double farmRate = Double.parseDouble(problem.getLines().get(0).get(1));
			double goal = Double.parseDouble(problem.getLines().get(0).get(2));
			
			int desiredNumberOfFarms = 0;
			
			double shortestSolutionTime = Double.MAX_VALUE;
			while (true) {
				double solutionTime = time(desiredNumberOfFarms, farmCost, farmRate, goal);
				desiredNumberOfFarms ++;
				if (shortestSolutionTime > solutionTime) {
					shortestSolutionTime = solutionTime;
					
					if (farmCost >= goal) {
						break;
					}
				} else {
					break;
				}
			}
			
			solutions.add("Case #" + problem.getCaseNumber() + ": " + shortestSolutionTime);
		}
		
		new SolutionWriter(PATH, OUT_FILE).write(solutions);
	}

	private static double time(int desiredNumberOfFarms, double farmCost, double farmRate, double goal) {
		Model model = new Model(0, 0, desiredNumberOfFarms, farmCost, farmRate, goal);
		
		while (model.desiredNumberOfFarms > model.numberOfFarms) {
			model = model.buyFarm();
		}
		
		return model.waitForGoal();
	}
	
	private static class Model {
		public static final double INITIAL_RATE = 2;
		
		final double elapsedTime;
		final int numberOfFarms;
		final int desiredNumberOfFarms;
		final double farmCost;
		final double farmRate;
		final double goal;
		
		Model(double elapsedTime, int numberOfFarms, int desiredNumberOfFarms, double farmCost, double farmRate, double goal) {
			this.elapsedTime = elapsedTime;
			this.numberOfFarms = numberOfFarms;
			this.desiredNumberOfFarms = desiredNumberOfFarms;
			this.farmCost = farmCost;
			this.farmRate = farmRate;
			this.goal = goal;
		}
		
		Model buyFarm() {
			double rate = INITIAL_RATE + farmRate * numberOfFarms;
			double timeForBuy = farmCost / rate;
			return new Model(elapsedTime + timeForBuy, numberOfFarms + 1, desiredNumberOfFarms, farmCost, farmRate, goal);
		}
		
		double waitForGoal() {
			double rate = INITIAL_RATE + farmRate * numberOfFarms;
			double timeToFinish = goal / rate;
			return elapsedTime + timeToFinish;
		}
	}
}
