import java.io.BufferedReader;
import java.io.IOException;
import java.io.PrintStream;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.*;
import java.util.logging.Logger;

public class B {

    private static final String PROBLEM_SET = "B-small-attempt3";

    private static class Case {

        private int caseId;
        private String solution = "unsolved";
        private int n;
        private int numLists;
        private List<List<Integer>> lists;

        public void read(BufferedReader in) throws IOException {
            n = Integer.parseInt(in.readLine());
            numLists = 2 * n - 1;
            lists = new ArrayList<>(numLists);
            for (int i = 0; i < numLists; ++i) {
                List<Integer> list = new ArrayList<>(n);
                log("created list of size %d", list.size());
                String[] strings = in.readLine().split(" ");
                log("read list: %s", Arrays.asList(strings));
                for (int j = 0; j < n; ++j) {
                    list.add(Integer.parseInt(strings[j]));
                }
                lists.add(list);
            }
        }

        public void solve() {
            log("starting: %d", 123);
            lists.sort(new Comparator<List<Integer>>() {
                public int compare(List<Integer> a, List<Integer> b) {
                    for (int i = 0; i < a.size(); ++i) {
                        if (a.get(i) < b.get(i)) {
                            return -1;
                        } else if (a.get(i) > b.get(i)) {
                            return 1;
                        }
                    }
                    return 0;
                }
            });
            for (List<Integer> list : lists) {
                log(list.toString());
            }
            int[][] grid = new int[n][n];
            boolean doRow = false;
            int missing = 0;
            boolean missingIsRow = false;
            // do first row
            String assignments[] = new String[numLists];
            int assignmentNums[] = new int[numLists];
            boolean rowAssigned[] = new boolean[n];
            boolean colAssigned[] = new boolean[n];
            boolean gridAssigned[][] = new boolean[n][n];
            for (int i = 0; i < n; ++i) {
                rowAssigned[i] = false;
                colAssigned[i] = false;
            }
            int numCols = 0, numRows = 0;
            for (int i = 0; i < lists.size(); ++i) {
                boolean bestMatchIsRow = true;
                int bestMatchNum = 0;
                int bestMatches = -1;
                for (int r = 0; r < n; ++r) {
                    if (!rowAssigned[r]) {
                        int matches = 0;
                        for (int c = 0; c < n; ++c) {
                            if (gridAssigned[r][c]) {
                                if (lists.get(i).get(c) != grid[r][c]) {
                                    break;
                                } else {
                                    ++matches;
                                }
                            }
                        }
                        if (matches > bestMatches) {
                            bestMatches = matches;
                            bestMatchNum = r;
                            bestMatchIsRow = true;
                        }
                    }
                }
                for (int c = 0; c < n; ++c) {
                    if (!colAssigned[c]) {
                        int matches = 0;
                        for (int r = 0; r < n; ++r) {
                            if (gridAssigned[r][c]) {
                                if (lists.get(i).get(r) != grid[r][c]) {
                                    break;
                                } else {
                                    ++matches;
                                }

                            }
                        }
                        if (matches > bestMatches) {
                            bestMatches = matches;
                            bestMatchNum = c;
                            bestMatchIsRow = false;
                        }
                    }
                }
                if (bestMatchIsRow) {
                    assignments[i] = "r";
                    assignmentNums[i] = numRows;
                    for (int j = 0; j < n; ++j) {
                        grid[bestMatchNum][j] = lists.get(i).get(j);
                        gridAssigned[bestMatchNum][j] = true;
                    }
                    rowAssigned[bestMatchNum] = true;
                    ++numRows;
                } else {
                    assignments[i] = "c";
                    assignmentNums[i] = bestMatchNum;
                    colAssigned[bestMatchNum] = true;
                    for (int j = 0; j < n; ++j) {
                        grid[j][bestMatchNum] = lists.get(i).get(j);
                        gridAssigned[j][bestMatchNum] = true;
                    }
                    ++numCols;
                }
            }
            StringBuilder b = new StringBuilder();
            if (numCols < numRows) {
                log("was missing column");
                for (int i = 0; i < n; ++i) {
                    if (colAssigned[i] == false) {
                        for (int r = 0; r < n; ++r) {
                            if (r > 0) {
                                b.append(" ");
                            }
                            b.append(grid[r][i]);
                        }
                        break;
                    }
                }
            } else {
                log("was missing row");
                for (int i = 0; i < n; ++i) {
                    if (rowAssigned[i] == false) {
                        for (int c = 0; c < n; ++c) {
                            if (c > 0) {
                                b.append(" ");
                            }
                            b.append(grid[i][c]);
                        }
                        break;
                    }
                }
            }
            solution = b.toString();
            for (int i = 0; i < n; ++i) {
                for (int j = 0; j < n; ++j) {
                    System.out.print(grid[i][j]);
                    System.out.print(" ");
                }
                System.out.println();
            }
            log("finished: %s", solution);
        }

        public Case(int caseId, BufferedReader in) throws IOException {
            this.caseId = caseId;
            read(in);
        }

        public void write(PrintStream out) {
            out.printf("Case #%d: %s\n", caseId, solution);
        }

        private void log(String format, Object... args) {
            String message = String.format(format, args);
            logger.info(String.format("Case #%d: %s", caseId, message));
        }

    }

    private static class Problem {

        private List<Case> cases;

        public Problem() {
        }

        public void read(String filename) throws IOException {
            try (BufferedReader in = Files.newBufferedReader(Paths.get(filename))) {
                String line = in.readLine();
                int numCases = Integer.parseInt(line);
                cases = new ArrayList<>(numCases);
                for (int t = 1; t <= numCases; ++t)
                    cases.add(new Case(t, in));
            }
        }

        public void solve() throws InterruptedException {
            cases.forEach(c -> c.solve()); // can parallelStream if needed
        }

        public void write(String filename) throws IOException {
            try (PrintStream out = new PrintStream(Files.newOutputStream(Paths.get(filename)))) {
                cases.forEach(c -> c.write(out));
            }
        }

    }

    private static Logger logger = Logger.getLogger(PROBLEM_SET);

    public static void main(String args[]) throws IOException, InterruptedException {
        Problem problem = new Problem();
        problem.read(PROBLEM_SET + ".in");
        problem.solve();
        problem.write(PROBLEM_SET + ".out");
    }

}
