import java.io.BufferedReader;
import java.io.IOException;
import java.io.PrintStream;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

public class A {

    private static final String PROBLEM_SET = "A-large";

    private static class Case {

        private int caseId;
        private String solution = "unsolved";
        private String firstWord;

        public void read(BufferedReader in) throws IOException {
            firstWord = in.readLine();
        }

        public void solve() {
            log("starting: %d", 123);
            StringBuilder builder = new StringBuilder();
            for (int i = 0; i < firstWord.length(); ++i) {
                char nextLetter = firstWord.charAt(i);
                if (builder.length() == 0) {
                    builder.append(nextLetter);
                } else if (nextLetter >= builder.charAt(0)) {
                    builder.insert(0, nextLetter);
                } else {
                    builder.append(nextLetter);
                }
            }
            solution = builder.toString();
            log("finished: %s", solution);
        }

        public Case(int caseId, BufferedReader in) throws IOException {
            this.caseId = caseId;
            read(in);
        }

        public void write(PrintStream out) {
            out.printf("Case #%d: %s\n", caseId, solution);
        }

        private void log(String format, Object... args) {
            String message = String.format(format, args);
            logger.info(String.format("Case #%d: %s", caseId, message));
        }

    }

    private static class Problem {

        private List<Case> cases;

        public Problem() {
        }

        public void read(String filename) throws IOException {
            try (BufferedReader in = Files.newBufferedReader(Paths.get(filename))) {
                String line = in.readLine();
                int numCases = Integer.parseInt(line);
                cases = new ArrayList<>(numCases);
                for (int t = 1; t <= numCases; ++t)
                    cases.add(new Case(t, in));
            }
        }

        public void solve() throws InterruptedException {
            cases.forEach(c -> c.solve()); // can parallelStream if needed
        }

        public void write(String filename) throws IOException {
            try (PrintStream out = new PrintStream(Files.newOutputStream(Paths.get(filename)))) {
                cases.forEach(c -> c.write(out));
            }
        }

    }

    private static Logger logger = Logger.getLogger(PROBLEM_SET);

    public static void main(String args[]) throws IOException, InterruptedException {
        Problem problem = new Problem();
        problem.read(PROBLEM_SET + ".in");
        problem.solve();
        problem.write(PROBLEM_SET + ".out");
    }

}
