package codejam.rpi;

import java.io.File;
import java.util.Scanner;
import static java.lang.Integer.parseInt;

import codejam.Base;

public class RPI extends Base {

	RPI() {
		setDebugEnabled(false);
	}

	public static void main(String[] args) throws Exception {
		Scanner s = new Scanner(new File(args[0]));
		int maxCase = parseInt(s.nextLine());
		for (int caseId = 1; caseId <= maxCase; caseId++) {
			int maxTeam = parseInt(s.nextLine());
			char metrix[][] = new char[maxTeam][maxTeam];

			for (int i = 0; i < maxTeam; i++) {
				metrix[i] = s.nextLine().toCharArray();
			}

			double[] rpi = new RPI().solve(maxTeam, metrix);
			System.out.printf("Case #%d:\n", caseId);
			for (int i = 0; i < maxTeam; i++) {
				System.out.println(rpi[i]);
			}
		}
	}

	private double[] solve(int maxTeam, char[][] metrix) {
		double[] result = new double[maxTeam];

		double[] wp = calWp(maxTeam, metrix, -1);
		double[] owp = calOwp(maxTeam, wp, metrix);
		double[] oowp = calOowp(maxTeam, owp, metrix);

		for (int i = 0; i < maxTeam; i++) {
			result[i] = 0.25 * wp[i] + 0.50 * owp[i] + 0.25 * oowp[i];
		}

		return result;
	}

	private double[] calOowp(int maxTeam, double[] owp, char[][] metrix) {
		double[] result = new double[maxTeam];

		for (int i = 0; i < maxTeam; i++) {
			int games = 0;
			double oowp = 0;
			for (int j = 0; j < maxTeam; j++) {
				if (i == j || metrix[i][j] == '.') continue;
				oowp += owp[j];
				games++;
			}
			result[i] = oowp / games;
		}

		if (isDebugEnabled()) {
			for (int i = 0; i < maxTeam; i++) {
				debug("oowp[%d]: %s", i, result[i]);
			}
		}

		return result;
	}

	private double[] calOwp(int maxTeam, double[] wp, char[][] metrix) {
		double[] result = new double[maxTeam];
		for (int i = 0; i < maxTeam; i++) {
			int games = 0;
			double owp = 0;
			debug("finding OWP for %d", i);
			double[] _result = calWp(maxTeam, metrix, i);
			for (int k = 0; k < _result.length; k++) {
				if (k == i || metrix[i][k] == '.') continue;
				owp += _result[k];
				games++;
			}
			result[i] = owp / games;
		}

		if (isDebugEnabled()) {
			for (int i = 0; i < maxTeam; i++) {
				debug("owp[%d]: %s", i, result[i]);
			}
		}

		return result;
	}

	private double[] calWp(int maxTeam, char[][] metrix, int ignoreTeam) {
		double[] result = new double[maxTeam];

		for (int i = 0; i < maxTeam; i++) {
			if (ignoreTeam == i)
				continue;
			int games = 0;
			double wp = 0;
			for (int j = 0; j < maxTeam; j++) {
				if (ignoreTeam == j)
					continue;
				if (i == j)
					continue;
				switch (metrix[i][j]) {
				case '.':
					break;
				case '1':
					games++;
					wp++;
					break;
				case '0':
					games++;
					break;
				}
			}
			result[i] = wp / games;
		}

		if (isDebugEnabled()) {
			for (int i = 0; i < maxTeam; i++) {
				debug("wp[%d]: %s", i, result[i]);
			}
		}

		return result;
	}
}
