package comejam.megicka;

import static java.lang.Integer.parseInt;

import java.io.File;
import java.util.Arrays;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Scanner;
import java.util.Set;
import java.util.StringTokenizer;
import java.util.TreeMap;
import java.util.TreeSet;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class Megicka {
	
	String[] SPELL_LIST = {"Q", "W", "E", "R", "A", "S", "D", "F"};
	static final boolean logEnabled = false;
	public Megicka() {
		
	}
	
	static String join(String[] ss, String delimiter) {
		StringBuilder result = new StringBuilder(ss.length * 2);
		for (String s : ss) {
			result.append(delimiter);
			result.append(s);
		}
		if (result.length() > 0) {
			result.deleteCharAt(result.length() - 1);
		}
		return result.toString();
	 }
	
	public Character[] solve(String[] combos, String[] opposes, String elements) {
//		System.out.println(join(combos, " "));
		
		StringBuilder result = new StringBuilder();
		Arrays.sort(combos);
		Arrays.sort(opposes);
		
		Map<String, Character> comboMap = new TreeMap<String, Character>();
		for (String combo : combos) {
			comboMap.put(combo.substring(0, 2), combo.charAt(2));
		}
		for (String combo : combos) {
			String l = "" + combo.charAt(1) + combo.charAt(0);
			if (comboMap.get(l) == null) {
				comboMap.put(l, combo.charAt(2));
			}
		}
//		System.out.println(comboMap);
		Map<Character, Set<Character>> opposedMap = new LinkedHashMap<Character, Set<Character>>();
		for (String opposed : opposes) {
			char c1 = opposed.charAt(0);
			char c2 = opposed.charAt(1);
			Set<Character> opposedSet = opposedMap.get(c1);
			if (opposedSet == null) {
				opposedSet = new TreeSet<Character>();
				opposedMap.put(c1, opposedSet);
			}
			opposedSet.add(c2);
			
			opposedSet = opposedMap.get(c2);
			if (opposedSet == null) {
				opposedSet = new TreeSet<Character>();
				opposedMap.put(c2, opposedSet);
			}
			opposedSet.add(c1);
		}
		
		// invoke form the first
		for (char c : elements.toCharArray()) {
			result.append(c);
			if (logEnabled)
				log("loop : %s\n", result.toString());
			if (result.length() > 1) {
				if (comboMap.size() > 0) transform(result, comboMap);
				if (opposedMap.size() > 0) {
					Set<Character> opposedSet = opposedMap.get(getPeak(result));
					if (opposedSet != null) discard(result, opposedSet);
				}
			}
		}
		
		// transform the collect to string[]
		Character[] sresult = new Character[result.length()];
		for (int i = 0; i < result.length(); i++) {
			sresult[i] = result.charAt(i);
		}
		if (logEnabled) 
			log(Arrays.asList(sresult).toString() + "\n");
		return sresult;
	}

	private Object getPeak(StringBuilder result) {
		return result.charAt(result.length() - 1);
	}

	private void discard(StringBuilder result, Set<Character> opposedSet) {
		for (int i = result.length() - 1; i >= 0; i--) {
			for (char c : opposedSet) {
				char rc = result.charAt(i);
				if (rc == c) {
					if (logEnabled)
						log("check on %s at %d ## %s == %s\n", result.toString(), i, rc, c);
//					result.delete(i, result.length());
					result.delete(0, result.length());
					return;
				}
			}
		}
	}

	private void transform(StringBuilder result, Map<String, Character> comboMap) {
		String s = "" + getPeak(result);
		s += result.charAt(result.length() - 2);
		
		Character cmb = comboMap.get(s);
		if (cmb != null) {
			result.deleteCharAt(result.length() - 1);
			result.deleteCharAt(result.length() - 1);
			result.append(cmb);
			if (logEnabled)
				log("transform: %s\n", result.toString());
		}
	}
	
	public void log(String s, Object... args) {
		System.out.printf(s, args);
	}

	public static void main(String[] args) throws Exception {
		final boolean concurrent = false;
		ExecutorService executor = Executors.newFixedThreadPool(2);
		
		Scanner s = new Scanner(new File(args[0]));
		int maxCase =  parseInt(s.nextLine());
		
		Map<Integer, Character[]> outputs = new LinkedHashMap<Integer, Character[]>(maxCase);
		for (int caseNo = 0; caseNo < maxCase; caseNo++)  {
			String line = s.nextLine();
			if (line.startsWith("#")) {
				continue;
			}
			StringTokenizer st = new StringTokenizer(line);
			int comboNo = parseInt(st.nextToken());
			// read combo set
			final String[] combos = new String[comboNo];
			for (int i = 0; i < comboNo; i++) {
				combos[i] = st.nextToken();
			}
			// read opposed set
			final int opposedNo = parseInt(st.nextToken());
			final String[] opposes = new String[opposedNo];
			for (int i = 0; i < opposes.length; i++) {
				opposes[i] = st.nextToken();
			}
			
			st.nextToken(); // discard input length
			
			final String elements = st.nextToken();
			final int tCaseNo = caseNo;
			if (concurrent)
				executor.execute(new CaseWorker(tCaseNo, combos, opposes, elements, outputs));
			else 
				new CaseWorker(tCaseNo, combos, opposes, elements, outputs).run();
		}
		if (concurrent)
			while (true) {
				synchronized (outputs) {
	//				System.out.printf("outputs(%d) >= maxCase(%d)\n", outputs.size() ,maxCase);
					if (outputs.size() >= maxCase)
						break;
				}
				Thread.sleep(1000);
			}
		
		for (int i = 0 ; i < outputs.size(); i++) {
			Character[] spells = outputs.get(i);
			System.out.printf("Case #%d: %s\n", i + 1, Arrays.asList(spells));
		}
		executor.shutdown();
	}
}

class CaseWorker implements Runnable {
	
	int caseId;
	String[] combos;
	String[] opposes;
	String elements;
	Map<Integer, Character[]> outputs;
	
	CaseWorker(int caseId, String[] combos, String[] opposes, String elements, Map<Integer, Character[]> outputs) {
		this.outputs = outputs;
		this.caseId = caseId;
		this.combos = combos;
		this.opposes = opposes;
		this.elements = elements;
	}
	
	public void run() {
		Megicka m = new Megicka();
		Character[] spells = m.solve(combos, opposes, elements);
		synchronized (outputs) {
			outputs.put(caseId, spells);
//			System.out.println(spells);
		}
	}
}
