package com.dongmyo.codejam;

import java.io.BufferedReader;
import java.io.FileReader;
import java.math.BigInteger;

import java.util.StringTokenizer;

public class CandySplitting {
	//public static String INPUT_FILE = "input.txt";
	public static String INPUT_FILE = "C-small-attempt0.in";
	
	public static final String DELIM = " ";
	
	private int caseNo;
	
	private int N;
	private int[] arr;
	
	private int[] indices;
	
	private int sumOfPile1ByPatrick;
	private int sumOfPile2ByPatrick;
	
	private int sumOfPile1BySean;
	private int sumOfPile2BySean;
	
	public CandySplitting(int caseNo, int N, int[] arr) {
		this.caseNo = caseNo;
		this.N = N;
		this.arr = arr;
	}
	
	public void solve() {
		boolean isFound = false;
		int maxSum = Integer.MIN_VALUE;
		
		CombinationGenerator com;
		
		for(int i = 1; i <= (N / 2); i++) {
			com = new CombinationGenerator(N, i);
			
			while(com.hasMore()) {
				indices = com.getNext();
				
				sumOfPile1ByPatrick = sumOfPile2ByPatrick = 0;
				sumOfPile1BySean = sumOfPile2BySean = 0;
				
				sumOfPile1();
				sumOfPile2();
				
				if(sumOfPile1ByPatrick == sumOfPile2ByPatrick) {
					isFound = true;
					maxSum = Math.max(maxSum, Math.max(sumOfPile1BySean, sumOfPile2BySean));
				}
			}
		}
		
		System.out.print("Case #" + caseNo + ": ");
		
		if(isFound) {
			System.out.println(maxSum);
		}
		else {
			System.out.println("NO");
		}
		
		return;
	}
	
	protected void sumOfPile1() {
		for(int i = 0; i < indices.length; i++) {
			sumOfPile1ByPatrick = sumByPatrick(sumOfPile1ByPatrick, arr[indices[i]]);
			sumOfPile1BySean += arr[i];
		}
		
		return;
	}
	
	protected void sumOfPile2() {
		for(int i = 0; i < arr.length; i++) {
			if(!indicesContains(i)) {
				sumOfPile2ByPatrick = sumByPatrick(sumOfPile2ByPatrick, arr[i]);
				sumOfPile2BySean += arr[i];
			}
		}
		
		return;
	}
	
	protected boolean indicesContains(int idx) {
		for(int i = 0; i < indices.length; i++) {
			if(indices[i] == idx) {
				return true;
			}
		}
		
		return false;
	}
	
	protected int sumByPatrick(int a, int b) {
		int sum = 0;
		
		String s1 = Integer.toBinaryString(a);
		String s2 = Integer.toBinaryString(b);
		
		StringBuffer tmp;
		
		if(s1.length() > s2.length()) {
			tmp = new StringBuffer(s2);
			
			for(int i = 0; i < (s1.length() - s2.length()); i++) {
				tmp = new StringBuffer("0").append(tmp);
			}
			
			s2 = tmp.toString();
		}
		else if(s1.length() < s2.length()) {
			tmp = new StringBuffer(s1);
			
			for(int i = 0; i < (s2.length() - s1.length()); i++) {
				tmp = new StringBuffer("0").append(tmp);
			}
			
			s1 = tmp.toString();
		}

		StringBuffer strSum = new StringBuffer();
		
		for(int i = 0; i < s1.length(); i++) {
			if(s1.charAt(i) == s2.charAt(i)) {
				strSum.append("0");
			}
			else {
				strSum.append("1");
			}
		}
		
		sum = Integer.parseInt(strSum.toString(), 2);
		
		return sum;
	}
	
	public static void main(String[] args) {
		try {
			BufferedReader in = new BufferedReader(new FileReader(INPUT_FILE));
			
			int T = Integer.parseInt(in.readLine());
			
			for(int i = 0; i < T; i++) {
				int N = Integer.parseInt(in.readLine());
				String C = in.readLine();
				
				StringTokenizer st = new StringTokenizer(C, CandySplitting.DELIM);
				
				int[] arr = new int[N];
				
				for(int j = 0; j < N; j++) {
					arr[j] = Integer.parseInt(st.nextToken());
				}
				
				new CandySplitting(i + 1, N, arr).solve();
			}
			
			in.close();
		}
		catch(Exception e) {}
	}
}

class CombinationGenerator {
	private int n;
	private int r;
	
	private int[] a;
	
	private BigInteger numLeft;
	private BigInteger total;	
	
	public CombinationGenerator(int n, int r) {
		this.n = n;
		this.r = r;
		
		init();
	}
	
	public boolean hasMore() {
		return (numLeft.compareTo(BigInteger.ZERO) == 1);
	}
	
	public int[] getNext() {
	    if(numLeft.equals(total)) {
	        numLeft = numLeft.subtract(BigInteger.ONE);
	    }
	    else {
		    int i = r - 1;
		    
		    while(a[i] == n - r + i) {
		        i--;
		    }
		    
		    a[i] = a[i] + 1;
		    
		    for(int j = i + 1; j < r; j++) {
		    	a[j] = a[i] + j - i;
		    }
	
		    numLeft = numLeft.subtract(BigInteger.ONE);
	    }
	    
	    return a;
	}
	
	protected void init() {
		a = new int[r];

	    for(int i = 0; i < a.length; i++) {
	        a[i] = i;
	    }
		
		BigInteger nFact = getFactorial(n);
		BigInteger rFact = getFactorial(r);
		BigInteger nMinusRFact = getFactorial(n - r);
		
		total = nFact.divide(rFact.multiply(nMinusRFact));
	    
	    numLeft = new BigInteger(total.toString());
	}
	
	protected static BigInteger getFactorial(int num) {
		BigInteger fact = BigInteger.ONE;
		
		for(int i = num; i > 1; i--) {
			fact = fact.multiply(new BigInteger(Integer.toString(i)));
		}
		
		return fact;
	}	
}
