package com.test;


import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Queue;
import java.util.concurrent.LinkedBlockingQueue;


public class BotTrust
{
	final static String			COLOR_BLUE				= "B";
	final static String			COLOR_ORANGE			= "O";

	final static Queue<String>	colorQueue				= new LinkedBlockingQueue<String>();
	final static Queue<Integer>	blueDestinationQueue	= new LinkedBlockingQueue<Integer>();
	final static Queue<Integer>	orangeDestinationQueue	= new LinkedBlockingQueue<Integer>();

	public static void main( String[] args ) throws Exception
	{
		final List<String> testCaseList = loadFile();

		final BufferedWriter writer = new BufferedWriter(new FileWriter(new File("C:\\Users\\brandon.salzberg\\Workspace_Eclipse\\CodeJam\\res\\testOutput.txt")));

		int caseNumber = 1;
		for (String testCase : testCaseList)
		{
			loadTestCase(testCase);
			final int timer = executeTestCase();

			writer.write("Case #" + caseNumber++ + ": " + timer + "\n");
		}

		writer.flush();
		writer.close();
	}

	private static int executeTestCase()
	{
		final Robot blue = new Robot();

		if (blueDestinationQueue.peek() != null)
		{
			blue.destination = blueDestinationQueue.poll();
		}
		final Robot orange = new Robot();
		if (orangeDestinationQueue.peek() != null)
		{
			orange.destination = orangeDestinationQueue.poll();
		}

		String currentColor = colorQueue.poll();

		int timer = 0;

		while (null != currentColor)
		{
			timer++;

			System.out.println("CurrentColor: " + currentColor);
			System.out.println(blue.current);
			System.out.println(blue.destination);
			System.out.println(orange.current);
			System.out.println(orange.destination);

			boolean dirty = false;

			if (blue.destination > blue.current)
			{
				blue.current++;
			}
			else if (blue.destination < blue.current)
			{
				blue.current--;
			}
			else if (COLOR_BLUE.equals(currentColor))
			{
				if (blueDestinationQueue.peek() != null)
				{
					blue.destination = blueDestinationQueue.poll();
				}

				currentColor = colorQueue.poll();
				dirty = true;
			}

			if (orange.destination > orange.current)
			{
				orange.current++;
			}
			else if (orange.destination < orange.current)
			{
				orange.current--;
			}
			else if (COLOR_ORANGE.equals(currentColor) && !dirty)
			{
				if (orangeDestinationQueue.peek() != null)
				{
					orange.destination = orangeDestinationQueue.poll();
				}
				currentColor = colorQueue.poll();
			}
		}

		return timer;
	}

	private static void loadTestCase( String testCaseStr ) throws Exception
	{
		colorQueue.clear();
		blueDestinationQueue.clear();
		orangeDestinationQueue.clear();

		final String[] operationStrArray = testCaseStr.split(" ");

		int numOperations = Integer.parseInt(operationStrArray[0]);

		int i = 1;
		while (i < operationStrArray.length)
		{
			int colorIndex = i++;
			int destinationIndex = i++;

			colorQueue.offer(operationStrArray[colorIndex]);

			if (operationStrArray[colorIndex].equals(COLOR_ORANGE))
			{
				orangeDestinationQueue.offer(Integer.parseInt(operationStrArray[destinationIndex]));
			}
			else
			{
				blueDestinationQueue.offer(Integer.parseInt(operationStrArray[destinationIndex]));
			}
		}
	}

	private static List<String> loadFile() throws Exception
	{
		BufferedReader reader = new BufferedReader(new FileReader(new File("C:\\Users\\brandon.salzberg\\Workspace_Eclipse\\CodeJam\\res\\testInput.txt")));
		final int numCases = Integer.parseInt(reader.readLine());

		final List<String> retVal = new ArrayList<String>(numCases);
		for (int i = 0; i < numCases; i++)
		{
			retVal.add(reader.readLine());
		}

		return retVal;
	}

	private static class Robot
	{
		public int	destination	= 0;
		public int	current		= 1;
	}
}
