import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;
import java.util.HashSet;
import java.nio.charset.Charset;
import java.io.PrintWriter;
import java.lang.Character;


public class Jamcoin{
	
	private static HashSet<Integer> primes = new HashSet<Integer>();

	private static int isPrime(int n) {
	    if(n%2 == 0)
	    	return 2;
	    if(n%3 == 0)
	    	return 3;
	    if(primes.contains(n))
	    	return 1;
	    int sqrtN = (int)Math.sqrt(n)+1;
	    for(int i = 5; i <= sqrtN; i ++)
        	if (n % i == 0) 
        		return i;
        	
	    //it's prime - let's add it to our hashset
	    if(!primes.contains(n))
	    	primes.add(n);
	    return 1;
	}
	
	private static int transform(String n, int base){
		int result = 0;
		int length = n.length();
		for (int i = length-1, b = 0; i >= 0; i--, b++){
			result += Character.getNumericValue(n.charAt(i))*Math.pow(base, b);
		}
		return result;
	}
	
	//returns a set of 9 divisors
	private static int[] isJam(String n){
		int [] proof = new int[9];
		for(int b = 2; b <= 10; b++){
			int coin = transform(n, b);
			proof[b-2]  = isPrime(coin);
			if(proof[b-2] == 1)
				return null;
		}
		return proof;
		
	}
	
	// builds the candidate string to be a jamcoin
	private static String buildCoin(int n, int len){
		String result = "1";
		String biN = Integer.toBinaryString(n);
		for (int i = 0; i < len - biN.length() - 2; i++)
			result += "0";
		return result + biN + "1";
		
	}
	
	private static String proofToString(int[] proof){
		String result = "";
		for(int p: proof)
			result += " " + p;
		return result;
	}
	
	private static void solve(String fileName, String fileOut){
		Charset charset = Charset.forName("ISO-8859-1");
		Path path = Paths.get("", fileName);
		try {
			List<String> lines = Files.readAllLines(path, charset);
			String words = "";
			int tests = Integer.parseInt(lines.get(0));
			for (int i = 0; i < tests; i++){
				String[] line = lines.get(i+1).split(" ");
				int N = Integer.parseInt(line[0]);
				int J = Integer.parseInt(line[1]);
				
				int coinIndex = 0;
				int middle = 0;//(int)Math.pow(2, N-2)-1;
				while(coinIndex < J){
					String coin = buildCoin(middle, N);
					//check if it's jam and collect proofs
					int [] proof = isJam(coin);
					while(proof == null){// || middle == 0 ){
						coin = buildCoin(middle++, N);
						proof = isJam(coin);
					}
					String proofStr = proofToString(proof);
					words += coin +	proofStr + "\n";
					coinIndex++;
					middle++;					
				}

			}
			
			PrintWriter out = new PrintWriter(fileOut);
		    	out.print("Case #1:\n" + words);	
		    	out.close();	
		}
		catch (IOException e){
			e.printStackTrace();
		}
	}

	public static void main(String[] args){
		solve("C-small-attempt0.in", "test.out");
	}
}
