import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;


public class Q2 {
	private static Problem[] probs;
	
	public static final int NORTH = 0;
	public static final int WEST = 1;
	public static final int EAST = 2;
	public static final int SOUTH = 3;
	public static final int SINK = 4;
	
	private static class Problem {
		public int H;
		public int W;
		public int map[][];
		public int drainage[][];
		public ArrayList<int[]> sinkList = new ArrayList<int[]>();
	}
	
	public static void main(String[] args) {
		readData(args[0]);
		process();
	}

	private static void process() {
		try {
			BufferedWriter bw = new BufferedWriter(new FileWriter("Q2/Q2.out"));
			for (int i=0; i<probs.length; i++) {
				Problem currProb = probs[i];
				for (int j=0; j<currProb.H; j++) {
					for (int k=0; k<currProb.W; k++) {
						//find min of 4 neighbors
						//if tie, use N/W/E/S
						int[][] neighbors = new int[4][2];
						//north
						neighbors[NORTH][0] = j-1;
						neighbors[NORTH][1] = k;
						//west
						neighbors[WEST][0] = j;
						neighbors[WEST][1] = k-1;
						//east
						neighbors[EAST][0] = j;
						neighbors[EAST][1] = k+1;
						//south
						neighbors[SOUTH][0] = j+1;
						neighbors[SOUTH][1] = k;
						int smallest = currProb.map[j][k];
						int smallestIndex = -1;
						for (int n=0; n<4; n++) {
							int y = neighbors[n][0];
							int x = neighbors[n][1];
							if (y>=0 && x>=0) {
								if (y<currProb.H && x<currProb.W) {
									if (currProb.map[y][x]<smallest) {
										smallest = currProb.map[y][x];
										smallestIndex = n;
									}
								}
							}
						}
						switch (smallestIndex) {
						case NORTH:
							currProb.drainage[j][k] = NORTH;
							break;
						case WEST:
							currProb.drainage[j][k] = WEST;
							break;
						case SOUTH:
							currProb.drainage[j][k] = SOUTH;
							break;
						case EAST:
							currProb.drainage[j][k] = EAST;
							break;
						case -1:
							currProb.drainage[j][k] = SINK;
							currProb.sinkList.add(new int[]{j,k});
							break;
						}
					}
				}
				//now, process recursively back from the sinks
				int sinkLabel = -1;
				for (int[] sink: currProb.sinkList) {
					currProb.drainage[sink[0]][sink[1]] = sinkLabel;
					processPoint(currProb, sink, sinkLabel);
					sinkLabel--;
				}
				bw.write("Case #" + (i+1) + ":\n");
				//now, change labels
				char label = 'a';
				HashMap<Integer, Character> map = new HashMap<Integer, Character>();
				for (int j=0; j<currProb.H; j++) {
					for (int k=0; k<currProb.W; k++) {
						if (map.containsKey(currProb.drainage[j][k])) {
							bw.write(map.get(currProb.drainage[j][k]) + " ");
						} else {
							map.put(currProb.drainage[j][k], label);
							bw.write(label + " ");
							label++;
						}
					}
					bw.write("\n");
				}
			}
			bw.flush();
			bw.close();
		} catch (Exception ex) {
			ex.printStackTrace();
		}
		
	}
	
	private static void processPoint(Problem currProb, int[] point, int sinkLabel) {
		int y = point[0];
		int x = point[1];
		if (y>0) {
			//north
			if (currProb.drainage[y-1][x]==SOUTH) {
				currProb.drainage[y-1][x]=sinkLabel;
				processPoint(currProb, new int[]{y-1, x}, sinkLabel);
			}
		}
		if (x>0) {
			//west
			if (currProb.drainage[y][x-1]==EAST) {
				currProb.drainage[y][x-1]=sinkLabel;
				processPoint(currProb, new int[]{y, x-1}, sinkLabel);
			}
		}			
		if (x<currProb.W-1) {
			//east
			if (currProb.drainage[y][x+1]==WEST) {
				currProb.drainage[y][x+1]=sinkLabel;
				processPoint(currProb, new int[]{y, x+1}, sinkLabel);
			}
		}
		if (y<currProb.H-1) {
			//south
			if (currProb.drainage[y+1][x]==NORTH) {
				currProb.drainage[y+1][x]=sinkLabel;
				processPoint(currProb, new int[]{y+1, x}, sinkLabel);
			}
		}
	}
	
	
	private static void readData(String inFile) {
		try {
			BufferedReader br = new BufferedReader(new FileReader(inFile));
			String line = br.readLine();
			probs = new Problem[Integer.parseInt(line)];
			for (int i=0; i<probs.length; i++) {
				probs[i] = new Problem();
				line = br.readLine();
				String[] pieces = line.split(" ");
				probs[i].H = Integer.parseInt(pieces[0]);
				probs[i].W = Integer.parseInt(pieces[1]);
				probs[i].map = new int[probs[i].H][probs[i].W];
				probs[i].drainage = new int[probs[i].H][probs[i].W];
				for (int j=0; j<probs[i].H; j++) {
					line = br.readLine();
					pieces = line.split(" ");
					for (int k=0; k<probs[i].W; k++) {
						probs[i].map[j][k] = Integer.parseInt(pieces[k]);
					}
				}
			}
			br.close();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
