import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;


public class R1Q1 {
	private static Problem[] probs;
	
	private static class Problem {
		public Node root;
		public Animal[] animals;
	}
	
	private static class Animal {
		public String name;
		public int numFeatures;
		public String[] features;
	}
	
	private static class Node {
		public double weight;
		public String feature;
		public Node yesChild;
		public Node noChild;
	}
	
	public static void main(String[] args) {
		readData(args[0]);
		process();
	}

	private static void process() {
		try {
			BufferedWriter bw = new BufferedWriter(new FileWriter("R1Q1/R1Q1.out"));
			for (int i=0; i<probs.length; i++) {
				Problem currProb = probs[i];
				bw.write("Case #" + (i+1) + ":\n");
				for (int j=0; j<currProb.animals.length; j++) {
					Animal currAnimal = currProb.animals[j];
					double probability = 1;
					Node currNode = currProb.root;
					probability *= currNode.weight;
					while (currNode.yesChild!=null && currNode.noChild!=null) {
						String currFeature = currNode.feature;
						boolean hasFeature = false;
						for (int k=0; k<currAnimal.numFeatures; k++) {
							if (currFeature.equals(currAnimal.features[k])) {
								hasFeature = true;
								break;
							}
						}
						if (hasFeature) {
							currNode = currNode.yesChild;
						} else {
							currNode = currNode.noChild;
						}
						probability *= currNode.weight;
					}
					
					bw.write(String.format("%9.7f", probability) + "\n");
				}
				

			}
			bw.flush();
			bw.close();
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}
	
	private static int recParse(Node currNode, BufferedReader br) {
		try {
			
		String line = br.readLine();
		int closeParens = 0;
		//yes child
		Node n = new Node();
		currNode.yesChild = n;
		//see if line has a end parenths
		if (line.indexOf(')')!=-1) {
			n.yesChild = null;
			n.noChild = null;
			String[] pieces = line.split("\\(")[1].split("\\)");
			n.weight = Double.parseDouble(pieces[0]);
		} else { //recurse
			String[] pieces = line.split("\\(")[1].split(" ");
			n.weight = Double.parseDouble(pieces[0]);
			n.feature = pieces[1];
			closeParens += recParse(n, br);
		}
		
		line = br.readLine();
		//no child
		n = new Node();
		currNode.noChild = n;
		//see if line has a end parenths
		if (line.indexOf(')')!=-1) {
			n.yesChild = null;
			n.noChild = null;
			String[] pieces = line.split("\\(")[1].split("\\)");
			n.weight = Double.parseDouble(pieces[0]);
			//do we have multiple close parens?  count them
			int i=0;
			while (line.indexOf(')', i)!=-1) {
				closeParens++;
				i = line.indexOf(')', i) + 1;
			}
			//need one here
			closeParens--;
		} else { //recurse
			String[] pieces = line.split("\\(")[1].split(" ");
			n.weight = Double.parseDouble(pieces[0]);
			n.feature = pieces[1];
			closeParens += recParse(n, br);
		}
		
		//close
		if (closeParens==0) {
			line = br.readLine();
			if (line.indexOf(")")==-1) {
				System.err.println("Error in parsing.");
				System.exit(1);
			}
		} else {
			closeParens--;
		}
		
		return closeParens;
		} catch (Exception ex) {
			ex.printStackTrace();
		}

		return 0;
	}
	
	
	private static void readData(String inFile) {
		try {
			BufferedReader br = new BufferedReader(new FileReader(inFile));
			String line = br.readLine();
			probs = new Problem[Integer.parseInt(line)];
			for (int i=0; i<probs.length; i++) {
				probs[i] = new Problem();
				line = br.readLine();
				int treeLines = Integer.parseInt(line);
				line = br.readLine();
				String[] pieces = line.substring(1).split(" ");
				if (pieces[0].indexOf(")")==-1) {
				probs[i].root = new Node();
				probs[i].root.weight = Double.parseDouble(pieces[0]);
				probs[i].root.feature = pieces[1];
				recParse(probs[i].root, br);
				} else {
					probs[i].root = new Node();
					pieces = pieces[0].split("\\)");
					probs[i].root.weight = Double.parseDouble(pieces[0]);
					if (pieces.length>1) {
						probs[i].root.feature = pieces[1];
					}
				}
				//parse animals
				line = br.readLine();
				int numAnimals = Integer.parseInt(line);
				probs[i].animals = new Animal[numAnimals];
				for (int j=0; j<numAnimals; j++) {
					probs[i].animals[j] = new Animal();
					line = br.readLine();
					pieces = line.split(" ");
					probs[i].animals[j].name = pieces[0];
					probs[i].animals[j].numFeatures = Integer.parseInt(pieces[1]);
					probs[i].animals[j].features = new String[probs[i].animals[j].numFeatures];
					for (int k=0; k<probs[i].animals[j].numFeatures; k++) {
						probs[i].animals[j].features[k] = pieces[k+2];
					}
				}
			}
			br.close();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
