import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;


public class Q2 {
	public static Problem[] probs;

	static class Problem {
		public int C;
		public int D;
		public ArrayList<Integer> vendors = new ArrayList<Integer>();
	}
		
	public static void main(String[] args) {
		String inputFile = args[0];
		parseFile(inputFile);
		try {
			BufferedWriter bw = new BufferedWriter(new FileWriter(inputFile + ".out"));
			for (int i=0; i<probs.length; i++) {
				String output = solveProblem(probs[i]);
				bw.write("Case #" + (i+1) + ": " + output + "\n");
			}
			bw.flush();
			bw.close();
		} catch (IOException ex) {
			ex.printStackTrace();
		}
	}
		
	private static String solveProblem(Problem p) {
		//remove vendors that don't matter
		boolean removed = false;
		do {
			removed = false;
			if (p.vendors.size()>1) {
				if (p.vendors.get(1)-p.vendors.get(0)>p.D) {
					p.vendors.remove(0);
					removed = true;
				} else if (p.vendors.get(p.vendors.size()-1)-p.vendors.get(p.vendors.size()-2)>p.D) {
					p.vendors.remove(p.vendors.size()-1);
					removed = true;
				}
			}
		} while (removed);
		//look for partitions
		ArrayList<ArrayList<Integer>> partitions = new ArrayList<ArrayList<Integer>>();
		ArrayList<Integer> firstpart = new ArrayList<Integer>();
		for (int i=0; i<p.vendors.size(); i++) {
			firstpart.add(p.vendors.get(i));
		}
		partitions.add(firstpart);
		int i=0;
		boolean newpart = false;
		while (i<partitions.size()) {
			newpart = false;
			ArrayList<Integer> currpart = partitions.get(i);
			for (int j=0; j<currpart.size()-1; j++) {
				double bottom_reach = currpart.get(j)+(j)*p.D/2.0;
				double top_reach = currpart.get(j+1)-(currpart.size()-j-1)*p.D/2.0;
				if (bottom_reach<top_reach) {
					//make new partition
					ArrayList<Integer> part1 = new ArrayList<Integer>();
					for (int k=0; k<=j; k++) {
						part1.add(currpart.remove(0));
					}
					partitions.add(part1);
					newpart = true;
				}
			}
			if (!newpart) {
				i++;
			} else {
				i = 0;
			}
		}
		
		
		double global_max_delta = 0.0;
		for(ArrayList<Integer> currlist: partitions) {
		
		int span = (currlist.size()-1)*p.D;
		int diff = currlist.get(currlist.size()-1) - currlist.get(0);
		
		double offset, up_offset, down_offset;
		offset = up_offset = down_offset = 0.0;
		double max_delta, up_max_delta, down_max_delta;
		max_delta = up_max_delta = down_max_delta = 0.0;
		
		do {
		
			if (up_max_delta<max_delta) {
				offset = up_offset;
			} else if (down_max_delta<max_delta) {
				offset = down_offset;
			}
			
			
		//set up test
		ArrayList<Double> test = new ArrayList<Double>();
		for (i=0; i<currlist.size(); i++) {
			test.add(currlist.get(0) - (span-diff)/2.0 + i*p.D + offset);
		}
	
		//calc delta
		max_delta = 0.0;
		for (i=0; i<currlist.size(); i++) {
			if (Math.abs(currlist.get(i)-test.get(i))>max_delta) {
				max_delta = Math.abs(currlist.get(i)-test.get(i));
			}
		}
	
		//see if we can improve it
		test.clear();
		up_offset = offset + .5;
		for (i=0; i<currlist.size(); i++) {
			test.add(currlist.get(0) - (span-diff)/2.0 + i*p.D + up_offset);
		}
	
		//calc delta
		up_max_delta = 0.0;
		for (i=0; i<currlist.size(); i++) {
			if (Math.abs(currlist.get(i)-test.get(i))>up_max_delta) {
				up_max_delta = Math.abs(currlist.get(i)-test.get(i));
			}
		}
	
		test.clear();
		down_offset = offset - .5;
		for (i=0; i<currlist.size(); i++) {
			test.add(currlist.get(0) - (span-diff)/2.0 + i*p.D + down_offset);
		}
	
		//calc delta
		down_max_delta = 0.0;
		for (i=0; i<currlist.size(); i++) {
			if (Math.abs(currlist.get(i)-test.get(i))>down_max_delta) {
				down_max_delta = Math.abs(currlist.get(i)-test.get(i));
			}
		}
		
		} while (up_max_delta<max_delta || down_max_delta<max_delta);
		
		if (max_delta>global_max_delta) {
			global_max_delta = max_delta;
		}
		
		}
		
		return "" + global_max_delta;
	}

	public static void parseFile(String inputFile) {
		BufferedReader br;
		try {
			br = new BufferedReader(new FileReader(inputFile));
			String line = br.readLine();
			probs = new Problem[Integer.parseInt(line)];
			line = br.readLine();
			for (int i=0; i<probs.length; i++) {
				probs[i] = new Problem();
				String[] pieces = line.split(" ");
				probs[i].C = Integer.parseInt(pieces[0]);
				probs[i].D = Integer.parseInt(pieces[1]);
				for (int j=0; j<probs[i].C; j++) {
					line = br.readLine();
					pieces = line.split(" ");
					for (int k=0; k<Integer.parseInt(pieces[1]); k++) {
						probs[i].vendors.add(Integer.parseInt(pieces[0]));
					}
				}
				line = br.readLine();
			}
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
