import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;


public class Q1 {
	public static Problem[] probs;

	static class Problem {
		public int N;
		public char results[][];
	}
		
	public static void main(String[] args) {
		String inputFile = args[0];
		parseFile(inputFile);
		try {
			BufferedWriter bw = new BufferedWriter(new FileWriter(inputFile + ".out"));
			for (int i=0; i<probs.length; i++) {
				String output = solveProblem(probs[i]);
				bw.write("Case #" + (i+1) + ": " + output + "\n");
			}
			bw.flush();
			bw.close();
		} catch (IOException ex) {
			ex.printStackTrace();
		}
	}
		
	private static String solveProblem(Problem p) {
		double wp[] = new double[p.N];
		double owp[] = new double[p.N];
		double oowp[] = new double[p.N];
		int games_played[] = new int[p.N];
		int games_won[] = new int[p.N];
		
		//wp
		for (int i=0; i<p.N; i++) {
			int num_games = 0;
			int num_wins = 0;
			for (int j=0; j<p.N; j++) {
				if (p.results[i][j]=='0') {
					num_games++;
				} else if (p.results[i][j]=='1') {
					num_games++;
					num_wins++;
				}
			}
			wp[i] = ((double)num_wins)/((double)num_games);
			games_played[i] = num_games;
			games_won[i] = num_wins;
		}
		
		//owp
		for (int i=0; i<p.N; i++) {
			int num_opp = 0;
			double tot_owp = 0.0;
			for (int j=0; j<p.N; j++) {
				if (p.results[i][j]=='0') {
					//i lost, so they won
					//remove a gp and a win from them
					double mod_owp = ((double)(games_won[j]-1))/((double)(games_played[j]-1));
					tot_owp += mod_owp;
					num_opp++;
				} else if (p.results[i][j]=='1') {
					//i won, they lost
					//remove a gp and a loss
					double mod_owp = ((double)(games_won[j]))/((double)(games_played[j]-1));
					tot_owp += mod_owp;
					num_opp++;
				}
			}
			owp[i] = tot_owp/num_opp;
		}
		
		//oowp
		for (int i=0; i<p.N; i++) {
			int num_opp = 0;
			double tot_oowp = 0.0;
			for(int j=0; j<p.N; j++) {
				if (p.results[i][j]!='.') {
					tot_oowp += owp[j];
					num_opp++;
				}
			}
			oowp[i] = tot_oowp/num_opp;
		}
		
		StringBuffer sb = new StringBuffer();
		for (int i=0; i<p.N; i++) {
			sb.append("\n" + (.25*wp[i]+.5*owp[i]+.25*oowp[i]));
		}
		return sb.toString();
	}

	public static void parseFile(String inputFile) {
		BufferedReader br;
		try {
			br = new BufferedReader(new FileReader(inputFile));
			String line = br.readLine();
			probs = new Problem[Integer.parseInt(line)];
			line = br.readLine();
			for (int i=0; i<probs.length; i++) {
				probs[i] = new Problem();
				String[] pieces = line.split(" ");
				probs[i].N = Integer.parseInt(pieces[0]);
				probs[i].results = new char[probs[i].N][probs[i].N];
				for (int j=0; j<probs[i].N; j++) {
					line = br.readLine();
					for (int k=0; k<line.trim().length(); k++) {
						probs[i].results[j][k] = line.charAt(k);
					}
				}
				line = br.readLine();
			}
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
