import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;

public class Q1 {
	public static Problem[] probs;

	static class Problem {
		public int R;
		public int C;
		public char[][] cake;
	}
				
	
	public static void main(String[] args) {
		String inputFile = args[0];
		parseFile(inputFile);
		try {
			BufferedWriter bw = new BufferedWriter(new FileWriter(inputFile + ".out"));
			for (int i=0; i<probs.length; i++) {
				String output = solveProblem(probs[i]);
				System.out.println(output);
				bw.write("Case #" + (i+1) + ": " + output + "\n");
			}
			bw.flush();
			bw.close();
		} catch (IOException ex) {
			ex.printStackTrace();
		}
	}
		
	private static void printCake(char[][] cake) {
		for (int i=0; i<cake.length; i++) {
			for (int j=0; j<cake[0].length; j++) {
				System.out.print(cake[i][j]);
			}
			System.out.println();
		}
	}
	
	
	private static String solveProblem(Problem p) {
		ArrayList<int[]> letterCoords = new ArrayList<>();
		for (int i=0; i<p.R; i++) {
			for (int j=0; j<p.C; j++) {
				if (p.cake[i][j]!='?') {
					letterCoords.add(new int[]{i, j});
				}
			}
		}
		
		for (int[] coords: letterCoords) {
			int i = coords[0];
			int j = coords[1];
				if (p.cake[i][j]!='?') {
					//Try expanding horizontally
					int k = j-1;
					int minCol = j;
					int maxCol = j;
					while (k>=0 && p.cake[i][k]=='?') {
						p.cake[i][k] = p.cake[i][j];
						minCol = k;
						k--;
					}
					k = j+1;
					while (k<p.C && p.cake[i][k]=='?') {
						p.cake[i][k] = p.cake[i][j];
						maxCol = k;
						k++;
					}
					//Try expanding vertically
					k = i-1;
					int minRow = i;
					int maxRow = i;
					while (k>=0) {
						boolean breakFlag = false;
						for (int l=minCol; l<=maxCol; l++) {
							if (p.cake[k][l]!='?') {
								breakFlag = true;
								break;
							}
						}
						if (breakFlag) {
							break;
						}
						for (int l=minCol; l<=maxCol; l++) {
							p.cake[k][l] = p.cake[i][j];
							minRow = k;
						}
						k--;
					}
					k = i+1;
					while (k<p.R) {
						boolean breakFlag = false;
						for (int l=minCol; l<=maxCol; l++) {
							if (p.cake[k][l]!='?') {
								breakFlag = true;
								break;
							}
						}
						if (breakFlag) {
							break;
						}
						for (int l=minCol; l<=maxCol; l++) {
							p.cake[k][l] = p.cake[i][j];
							maxRow = k;
						}
						k++;
					}
				}
				printCake(p.cake);
			}
		
		StringBuffer returnBuf = new StringBuffer();
		for (int i=0; i<p.R; i++) {
			returnBuf.append("\n");
			for (int j=0; j<p.C; j++) {
				returnBuf.append(p.cake[i][j]);
			}
		}
		
		return returnBuf.toString();
	}

	public static void parseFile(String inputFile) {
		BufferedReader br;
		try {
			br = new BufferedReader(new FileReader(inputFile));
			String line = br.readLine();
			probs = new Problem[Integer.parseInt(line)];
			line = br.readLine();
			for (int i=0; i<probs.length; i++) {
				probs[i] = new Problem();
				String[] pieces = line.split("\\s+");
				probs[i].R = Integer.parseInt(pieces[0]);
				probs[i].C = Integer.parseInt(pieces[1]);
				probs[i].cake = new char[probs[i].R][probs[i].C];
				for (int j=0; j<probs[i].R; j++) {
					line = br.readLine();
					probs[i].cake[j] = line.toCharArray();
				}
				line = br.readLine();
			}
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
