package dmitry.shohov;

import java.io.*;
import java.util.*;
import java.util.concurrent.*;

public class MainThreaded {
    private static List<List<String>> input = new ArrayList<>();
    private static PrintWriter writer;
    private SortedMap<Integer, String> outputLines = Collections.synchronizedSortedMap(new TreeMap<Integer, String>());

    private ThreadPoolExecutor executor = new ThreadPoolExecutor(1, 1, 5, TimeUnit.DAYS, new LinkedBlockingQueue<Runnable>(), new ThreadFactory() {
        @Override
        public Thread newThread(Runnable r) {
            Thread thread = new Thread(r);
            thread.setDaemon(true);
            return thread;
        }
    });

    public MainThreaded() {

    }

    public void run() throws Exception {
        assert input.size() > 0;
        int numberOfCases = Integer.parseInt(input.get(0).get(0));
        List<Future<?>> tasks = new ArrayList<>(numberOfCases);
        int rowsFrom = 1;
        for (int i = 0; i < numberOfCases; i++) {
            final int fi = i;
            int numberOfStrings = Integer.parseInt(input.get(rowsFrom).get(0));
            final int from = rowsFrom;
            final int to = rowsFrom + 1 + numberOfStrings;
            tasks.add(executor.submit(new Runnable() {
                @Override
                public void run() {
                    try {
                        runCase(fi + 1, input.subList(from, to));
                    } catch (Throwable t) {
                        t.printStackTrace();
                    }
                }
            }));
            rowsFrom = to;
        }
        for (Future<?> task : tasks) {
            task.get();
        }
        for (String outputLine : outputLines.values()) {
            writer.println(outputLine);
        }
    }

    public void runCase(int caseNumber, List<List<String>> caseData) {
        int numberOfStrings = Integer.parseInt(caseData.get(0).get(0));
        List<List<CharNum>> words = new ArrayList<>();
        for (int i = 0; i < numberOfStrings; i++) {
            String word = caseData.get(1 + i).get(0);
            Character previousC = null;
            CharNum previousCN = null;
            List<CharNum> wordList = new ArrayList<>();
            words.add(wordList);
            for (int j = 0; j < word.length(); j++) {
                Character c = word.charAt(j);
                if (previousC == c) {
                    ++previousCN.number;
                } else {
                    previousC = c;
                    previousCN = new CharNum();
                    previousCN.character = c;
                    ++previousCN.number;
                    wordList.add(previousCN);
                }
            }
        }

        List<CharNum> firstWord = words.get(0);
        for (List<CharNum> word : words) {
            if (word.size() != firstWord.size()) {
                feglaWon(caseNumber);
                return;
            }
        }
        for (int i = 0; i < firstWord.size(); i++) {
            CharNum charNum = firstWord.get(i);
            for (List<CharNum> word : words) {
                CharNum charNum1 = word.get(i);
                if (charNum.character != charNum1.character) {
                    feglaWon(caseNumber);
                    return;
                }
            }
        }

        int steps = 0;
        for (int i = 0; i < firstWord.size(); i++) {
            int sum = 0;
            for (List<CharNum> word : words) {
                CharNum charNum = word.get(i);
                sum += charNum.number;
            }
            int avg = sum / words.size();
            for (List<CharNum> word : words) {
                CharNum charNum = word.get(i);
                if (charNum.number < avg) {
                    steps += avg - charNum.number;
                } else if (charNum.number > avg) {
                    steps += charNum.number - avg;
                }
            }
        }
        outputLines.put(caseNumber, "Case #" + caseNumber + ": " + steps);
    }

    private void feglaWon(int caseNumber) {
        outputLines.put(caseNumber, "Case #" + caseNumber + ": Fegla Won");
    }

    private static class CharNum {
        Character character;
        int number;
    }

    public static void main(String[] args) throws Exception {
        Locale.setDefault(Locale.US);
        TimeZone.setDefault(TimeZone.getTimeZone("GMT"));

        if (args.length < 2) {
            System.err.println("Requires two arguments - input and output files");
            return;
        }
        File inputFile = new File(args[0]);
        if (!inputFile.exists()) {
            System.err.println("Input file (first argument) does not exist");
            return;
        }

        BufferedReader inputReader = new BufferedReader(new FileReader(inputFile));
        String line;
        while ((line = inputReader.readLine()) != null) {
            List<String> lineInput = new ArrayList<>();
            StringTokenizer tokenizer = new StringTokenizer(line, " ");
            while (tokenizer.hasMoreTokens()) {
                lineInput.add(tokenizer.nextToken());
            }
            input.add(lineInput);
        }
        inputReader.close();

        writer = new PrintWriter(new BufferedWriter(new FileWriter(args[1])));

        MainThreaded main = new MainThreaded();
        main.run();

        writer.flush();
        writer.close();

        inputReader = new BufferedReader(new FileReader(args[1]));
        while ((line = inputReader.readLine()) != null) {
            System.out.println(line);
        }
        inputReader.close();
    }
}
