package codejam.qualification;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;

/*
 * Problem C. Coin Jam
 */
public class QualificationC {

	private static BufferedReader br;

	private static void init(String filePath) {
		try {
			br = new BufferedReader(new FileReader(filePath));
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
	}

	private static String readNextline() {
		String line = null;
		if (br != null) {
			try {
				line = br.readLine();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return line;
	}

	public static void main(String args[]) {
		init("C-small-attempt01.in");
		execute();
	}

	private static void execute() {

		int testCases = 0;
		testCases = Integer.parseInt(readNextline());

		for (int currentTestCase = 1; currentTestCase <= testCases; currentTestCase++) {
			String secondLine = readNextline();
			String[] s = secondLine.split(" ");
			int N = Integer.parseInt(s[0]);
			int J = Integer.parseInt(s[1]);
			boolean largeinput = N > 16;

			System.out.println("Case #" + currentTestCase + ": ");

			String num = generateCandidateNumber(N);
			for (int i = 0; i < J; i++) {
				boolean repeat = true;
				while (repeat) {
					List<String> list = new ArrayList<String>();
					if (isJamCoin(num, list, largeinput)) {
						System.out.print(list.get(0));
						for (int j = 1; j <= 9; j++) {
							System.out.print(" " + list.get(j));
						}
						repeat = false;
					} else {
						num = getNextNumber(num);
					}
				}
				num = getNextNumber(num);
				System.out.println();
			}

		}

	}

	private static boolean isJamCoin(String number, List<String> resultList,
			boolean largeInput) {
		resultList.add(number);
		if (largeInput) {
			for (int radix = 2; radix <= 10; radix++) {
				long value = getValueByRadix(number, radix);
				if (!isPrime(value, resultList)) {
					continue;
				} else {
					return false;
				}
			}
		} else {
			for (int radix = 2; radix <= 10; radix++) {
				BigInteger value = getValueByRadixBig(number, radix);
				if (!isPrimeBig(value, resultList)) {
					continue;
				} else {
					return false;
				}
			}
		}

		return true;
	}

	private static String generateCandidateNumber(int digits) {
		char[] raw = new char[digits];
		raw[0] = '1';
		raw[digits - 1] = '1';
		for (int i = 1; i < digits - 1; i++) {
			raw[i] = '0';
		}
		String number = String.valueOf(raw);
		return number;
	}

	private static String getNextNumber(String number) {
		// remove last 1's
		String subNum = number.substring(0, number.length() - 1);
		long num = Long.parseLong(subNum, 2);
		String newNum = Long.toBinaryString(num + 1);
		return newNum + "1";
	}

	private static long getValueByRadix(String number, int radix) {
		long sum = 0;
		char[] num = number.toCharArray();
		for (int i = (num.length - 1), pow = 0; i >= 0; i--, pow++) {
			int x = Integer.parseInt(String.valueOf(num[i]));
			sum = sum + ((long) Math.pow(radix, pow) * x);
		}
		return sum;
	}

	private static boolean isPrime(long num, List<String> divisors) {
		long numBy2 = num / 2;
		for (long i = 2; i < numBy2; i++) {
			if (num % i == 0) {
				divisors.add(String.valueOf(i));
				return false;
			}
		}
		return true;
	}

	private static boolean isPrimeBig(BigInteger num, List<String> divisors) {
		boolean prime = num.isProbablePrime(1);
		if (!prime) {
			BigInteger numBy2 = num.divide(new BigInteger("2"));

			for (BigInteger i = new BigInteger("2"); !i.equals(numBy2); i = i
					.add(BigInteger.ONE)) {
				if (num.mod(i).equals(BigInteger.ZERO)) {
					divisors.add(i.toString());
					return false;
				}
			}
		}
		return prime;
	}

	private static BigInteger getValueByRadixBig(String number, int radix) {
		BigInteger sum = new BigInteger("0");
		BigInteger rad = new BigInteger(String.valueOf(radix));
		char[] num = number.toCharArray();
		for (int i = (num.length - 1), pow = 0; i >= 0; i--, pow++) {
			int x = Integer.parseInt(String.valueOf(num[i]));
			sum = sum.add(rad.pow(pow).multiply(BigInteger.valueOf(x)));
		}
		return sum;
	}

}
