import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.StringTokenizer;

public class Magicka {
   private static final char[] baseElements =
   {'Q', 'W', 'E', 'R', 'A', 'S', 'D', 'F'};
   private char[][] comboGrid;
   private boolean[][] opposeGrid;

   private void createGrids(String[] comboList, String[] opposeList) {
      comboGrid = new char[baseElements.length][baseElements.length];
      opposeGrid = new boolean[baseElements.length][baseElements.length];
      
      for (String combo : comboList) {
         int a = getElementId(combo.charAt(0));
         int b = getElementId(combo.charAt(1));
         comboGrid[a][b] = combo.charAt(2);
         comboGrid[b][a] = combo.charAt(2);
      }

      for (String oppose : opposeList) {
         int a = getElementId(oppose.charAt(0));
         int b = getElementId(oppose.charAt(1));
         opposeGrid[a][b] = true;
         opposeGrid[b][a] = true;
      }
   }

   private int getElementId(char c) {
      for (int i = 0; i < baseElements.length; i++) {
         if (c == baseElements[i])
            return i;
      }
      // not a base element
      return -1;
   }

   private int getElementChar(int i) {
      return baseElements[i];
   }
   
   private void solve() {
      // T
      int numCases = nextInt();
      for (int cases = 0; cases < numCases; cases++) {
         // C
         int numCombos = nextInt();
         String[] comboList = new String[numCombos];
         for (int i = 0; i < numCombos; i++) {
            comboList[i] = nextToken();
         }
         
         // D
         int numOppose = nextInt();
         String[] opposeList = new String[numOppose];
         for (int i = 0; i < numOppose; i++) {
            opposeList[i] = nextToken();
         }

         // N
         int numChars = nextInt();
         String invoke = nextToken();
         createGrids(comboList, opposeList);

         // out will have numChars at max
         char[] out = new char[numChars];
         
         // index to place next char
         int index = 0;

         // element id of last char in out
         // -1 if not a base element
         int prevId = -1;
         
         for (int i = 0; i < invoke.length(); i++) {
            // FIXME
//            printCharArray(out, index);
            
            char c = invoke.charAt(i);
            int id = getElementId(c);

            // check for combos
            if (prevId != -1) {
               char combo = comboGrid[prevId][id];
               if (combo != 0) {
                  out[index-1] = combo;
                  prevId = -1;
                  continue;
               }
            }
            
            // check for opposers
            boolean cleared = false;
            for (int j = 0; j < index; j++) {
               int otherId = getElementId(out[j]);
               if (otherId != -1 && opposeGrid[otherId][id]) {
                  out = new char[numChars];
                  index = 0;
                  prevId = -1;
                  cleared = true;
               }
            }
            
            if (!cleared) {
               // add char to out
               out[index++] = c;
               prevId = id;
            }
         }
         // FIXME
//         System.out.println();

         writer.print("Case #" + (cases + 1) + ": ");
         if (index == 0) {
            writer.println("[]");
         } else {
            writer.print("[");
            for (int i = 0; i < index-1; i++) {
               writer.print(out[i] + ", ");
            }
            writer.println(out[index-1] + "]");
         }
      }
   }

   private void printCharArray(char[] arr, int numChars) {
      if (numChars == 0) {
         System.out.println("[]");
         return;
      }
      System.out.print("[");
      for (int i = 0; i < numChars-1; i++) {
         System.out.print(arr[i] + ", ");
      }
      System.out.println(arr[numChars-1] + "]");
   }
   
   private static String TASK_ID;

   public static void main(String[] args) {
      TASK_ID = args[0];
      new Magicka().run();
   }

   BufferedReader reader;
   StringTokenizer tokenizer = null;
   PrintWriter writer;

   public void run() {
      try {
         long now = System.currentTimeMillis();
         reader = new BufferedReader(new FileReader(TASK_ID + ".in"));
         writer = new PrintWriter(TASK_ID + ".out");
         solve();
         reader.close();
         writer.close();
         System.out.println(System.currentTimeMillis() - now + "ms");
      } catch (Exception e) {
         throw new RuntimeException(e);
      }
   }

   int nextInt() {
      return Integer.parseInt(nextToken());
   }

   double nextDouble() {
      return Double.parseDouble(nextToken());
   }

   long nextLong() {
      return Long.parseLong(nextToken());
   }

   String nextToken() {
      while (tokenizer == null || !tokenizer.hasMoreTokens()) {
         try {
            tokenizer = new StringTokenizer(reader.readLine());
         } catch (IOException e) {
            throw new RuntimeException(e);
         }
      }
      return tokenizer.nextToken();
   }
}
