package ru.orangesoftware.dragon;

import java.io.*;
import java.util.*;

public class Play {

    private static final StringBuilder sb = new StringBuilder();

    public static void main(String[] args) throws IOException {
        String inFileName = args[0];
        solve(inFileName);
        writeResult(inFileName);
    }

    private static void solve(String inFileName) throws FileNotFoundException {
        try (Scanner in = new Scanner(new BufferedReader(new InputStreamReader(new FileInputStream(inFileName))))) {
            int t = in.nextInt();
            for (int i = 1; i <= t; ++i) {
                int hd = in.nextInt();
                int ad = in.nextInt();
                int hk = in.nextInt();
                int ak = in.nextInt();
                int b = in.nextInt();
                int d = in.nextInt();
                Node start = new Node(hd, hd, ad, hk, ak, b, d, 0);
                int turn = solve(start);
                System.out.println("Case #" + i + ": " + turn);
                sb.append("Case #").append(i).append(": ").append(turn == -1 ? "IMPOSSIBLE" : turn).append("\n");
            }
        }
    }

    private static int solve(Node start) {
        Queue<Node> queue = new LinkedList<>();
        queue.add(start);
        Set<Node> seen = new HashSet<>();
        while (!queue.isEmpty()) {
            Node next = queue.poll();
            if (next.hk <= 0) return next.turn;
            queue.addAll(mutate(next, seen));
            //System.out.println(queue.size());
        }
        return -1;
    }

    private static List<Node> mutate(Node node, Set<Node> seen) {
        if (node.health <= 0) return Collections.emptyList();
        List<Node> nodes = new ArrayList<>();
        addNode(nodes, seen, node.attack());
        addNode(nodes, seen, node.buff());
        addNode(nodes, seen, node.cure());
        addNode(nodes, seen, node.debuff());
        return nodes;
    }

    private static void addNode(List<Node> nodes, Set<Node> seen, Node newNode) {
        if (seen.add(newNode)) nodes.add(newNode);
    }

    private static void writeResult(String inFileName) throws IOException {
        try (BufferedOutputStream out = new BufferedOutputStream(new FileOutputStream(new File(inFileName + ".out")))) {
            out.write(sb.toString().getBytes());
            out.flush();
        }
    }

    static class Node {
        int health;
        int hd;
        int ad;
        int hk;
        int ak;
        int b;
        int d;
        int turn;

        Node(int health, int hd, int ad, int hk, int ak, int b, int d, int turn) {
            this.health = health;
            this.hd = hd;
            this.ad = ad;
            this.hk = hk;
            this.ak = ak;
            this.b = b;
            this.d = d;
            this.turn = turn;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Node node = (Node) o;

            if (health != node.health) return false;
            if (hd != node.hd) return false;
            if (ad != node.ad) return false;
            if (hk != node.hk) return false;
            if (ak != node.ak) return false;
            if (b != node.b) return false;
            return d == node.d;
        }

        @Override
        public int hashCode() {
            int result = health;
            result = 31 * result + hd;
            result = 31 * result + ad;
            result = 31 * result + hk;
            result = 31 * result + ak;
            result = 31 * result + b;
            result = 31 * result + d;
            return result;
        }

        Node attack() {
            return new Node(health - ak, hd, ad, hk - ad, ak, b, d, turn + 1);
        }

        Node buff() {
            return new Node(health - ak, hd, ad + b, hk, ak, b, d, turn + 1);
        }

        Node cure() {
            return new Node(hd - ak, hd, ad, hk, ak, b, d, turn + 1);
        }

        Node debuff() {
            return new Node(health - ak, hd, ad, hk, Math.max(0, ak - d), b, d, turn + 1);
        }
    }

}
