package ru.orangesoftware.cake;

import java.io.*;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Scanner;
import java.util.Set;

public class Cake {

    private static final StringBuilder sb = new StringBuilder();

    public static void main(String[] args) throws IOException {
        String inFileName = args[0];
        solve(inFileName);
        writeResult(inFileName);
    }

    private static void solve(String inFileName) throws FileNotFoundException {
        try (Scanner in = new Scanner(new BufferedReader(new InputStreamReader(new FileInputStream(inFileName))))) {
            int t = in.nextInt();
            for (int i = 1; i <= t; ++i) {
                int r = in.nextInt();
                int c = in.nextInt();
                char[][] cake = new char[r][];
                for (int j = 0; j < r; j++) {
                    cake[j] = in.next().trim().toCharArray();
                }
                fillCake(cake, r, c);
                System.out.println("Case #" + i + ": " + r + " -> " + c + " =>\n" + printCake(cake));
                if (i > 1) sb.append("\n");
                sb.append("Case #").append(i).append(":");
                printCake(sb, cake);
            }
        }
    }

    private static void fillCake(char[][] cake, int r, int c) {
        fillColumns(cake, r, c);
        fillRows(cake, r, c);
    }

    private static void fillColumns(char[][] cake, int r, int c) {
        Set<Character> seen = new HashSet<>();
        for (int i = 0; i < r; i++) {
            for (int j = 0; j < c; j++) {
                if (seen.add(cake[i][j]) && nextIsNotSame(cake, r, c, i, j)) {
                    fillColumn(cake, r, c, i, j);
                }
            }
        }
    }

    private static boolean nextIsNotSame(char[][] cake, int r, int c, int i, int j) {
        if (j == c - 1) return true;
        return cake[i][j] != cake[i][j + 1];
    }

    private static void fillColumn(char[][] cake, int r, int c, int i, int j) {
        for (int k = i - 1; k >= 0; k--) {
            if (cake[k][j] == '?') cake[k][j] = cake[i][j];
            else break;
        }
        for (int k = i + 1; k < r; k++) {
            if (cake[k][j] == '?') cake[k][j] = cake[i][j];
            else break;
        }
    }

    private static void fillRows(char[][] cake, int r, int c) {
        for (int i = 0; i < r; i++) {
            for (int j = 0; j < c; j++) {
                fillRow(cake, r, c, i, j);
            }
        }

    }

    private static void fillRow(char[][] cake, int r, int c, int i, int j) {
        for (int k = j - 1; k >= 0; k--) {
            if (cake[i][k] == '?') cake[i][k] = cake[i][j];
            else break;
        }
        for (int k = j + 1; k < c; k++) {
            if (cake[i][k] == '?') cake[i][k] = cake[i][j];
            else break;
        }
    }

    private static void printCake(StringBuilder sb, char[][] cake) {
        for (char[] aCake : cake) {
            sb.append("\n").append(new String(aCake));
        }
    }

    private static String printCake(char[][] cake) {
        StringBuilder sb = new StringBuilder();
        printCake(sb, cake);
        return sb.toString();
    }

    private static void writeResult(String inFileName) throws IOException {
        try (BufferedOutputStream out = new BufferedOutputStream(new FileOutputStream(new File(inFileName + ".out")))) {
            out.write(sb.toString().getBytes());
            out.flush();
        }
    }

}
