package ru.orangesoftware.stalls;

import java.io.*;
import java.util.Comparator;
import java.util.PriorityQueue;
import java.util.Scanner;

public class Stalls {

    private static final StringBuilder sb = new StringBuilder();

    public static void main(String[] args) throws IOException {
        String inFileName = args[0];
        solve(inFileName);
        writeResult(inFileName);
    }

    private static void solve(String inFileName) throws FileNotFoundException {
        try (Scanner in = new Scanner(new BufferedReader(new InputStreamReader(new FileInputStream(inFileName))))) {
            int t = in.nextInt();
            for (int i = 1; i <= t; ++i) {
                long n = in.nextLong();
                long k = in.nextLong();
                MinMax p = occupyStalls(n, k);
                System.out.println("Case #" + i + ": " + n + "/" + k + " -> " + p.max + " " + p.min);
                sb.append("Case #").append(i).append(": ").append(p.max).append(" ").append(p.min).append("\n");
            }
        }
    }

    private static MinMax occupyStalls(long n, long k) {
        if (n == k) return new MinMax(0, 0);
        MinMax minMax = null;
        PriorityQueue<Long> queue = new PriorityQueue<>(Comparator.<Long>naturalOrder().reversed());
        queue.add(n);
        for (int i = 0; i < k; i++) {
            long longest = queue.poll();
            long mid = longest / 2;
            if (isOdd(longest)) {
                minMax = new MinMax(mid, mid);
            } else {
                minMax = new MinMax(mid - 1, mid);
            }
            queue.add(minMax.min);
            queue.add(minMax.max);
        }
        return minMax;
    }

    private static boolean isOdd(long n) {
        return n % 2 == 1;
    }

    private static void writeResult(String inFileName) throws IOException {
        try (BufferedOutputStream out = new BufferedOutputStream(new FileOutputStream(new File(inFileName + ".out")))) {
            out.write(sb.toString().getBytes());
            out.flush();
        }
    }

    static class MinMax {
        final long min;
        final long max;

        MinMax(long min, long max) {
            this.min = min;
            this.max = max;
        }
    }

}
