package ru.orangesoftware.ample;

import java.io.*;
import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

public class Syrup {

    private static final BigDecimal BPI = BigDecimal.valueOf(Math.PI);

    private static final StringBuilder sb = new StringBuilder();

    public static void main(String[] args) throws IOException {
        String inFileName = args[0];
        solve(inFileName);
        writeResult(inFileName);
    }

    private static void solve(String inFileName) throws FileNotFoundException {
        try (Scanner in = new Scanner(new BufferedReader(new InputStreamReader(new FileInputStream(inFileName))))) {
            int t = in.nextInt();
            for (int i = 1; i <= t; ++i) {
                int n = in.nextInt();
                int k = in.nextInt();
                List<Pancake> pancakes = new ArrayList<>(n);
                for (int j = 0; j < n; j++) {
                    pancakes.add(new Pancake(in.nextInt(), in.nextInt()));
                }
                BigDecimal r = arrangePancakes(pancakes, k);
                System.out.println("Case #" + i + ": " + n + " -> " + r);
                sb.append("Case #").append(i).append(": ").append(r).append("\n");
            }
        }
    }

    private static Comparator<Pancake> hComparator = (o1, o2) -> o2.ha.compareTo(o1.ha);
    private static Comparator<Pancake> rComparator = (o1, o2) -> o2.r - o1.r;

    private static BigDecimal arrangePancakes(List<Pancake> pancakes, int k) {
        pancakes.sort(rComparator);
        BigDecimal max = BigDecimal.ZERO;
        for (Pancake pancake : pancakes) {
            List<Pancake> rest = pancakes.stream().filter(p -> p != pancake && p.r <= pancake.r).collect(Collectors.toList());
            if (rest.size() < k - 1) continue;
            rest.sort(hComparator);
            List<Pancake> selected = rest.subList(0, k - 1);
            selected.add(pancake);
            BigDecimal area = calculateArea(selected);
            if (area.compareTo(max) > 0) {
                max = area;
            }
        }
        return max;
    }

    private static BigDecimal calculateArea(List<Pancake> selected) {
        selected.sort(Comparator.comparingInt(o -> o.r));
        BigDecimal r = BigDecimal.ZERO;
        for (Pancake p : selected) {
            r = r.add(p.ha);
        }
        r = r.add(selected.get(selected.size() - 1).sa);
        return r.multiply(BPI);
    }

    private static void writeResult(String inFileName) throws IOException {
        try (BufferedOutputStream out = new BufferedOutputStream(new FileOutputStream(new File(inFileName + ".out")))) {
            out.write(sb.toString().getBytes());
            out.flush();
        }
    }

    static class Pancake {
        int r;
        int h;
        BigDecimal sa;
        BigDecimal ha;
        BigDecimal a;

        Pancake(int r, int h) {
            this.r = r;
            this.h = h;
            this.sa = BigDecimal.valueOf(r).multiply(BigDecimal.valueOf(r));
            this.ha = BigDecimal.valueOf(2).multiply(BigDecimal.valueOf(r)).multiply(BigDecimal.valueOf(h));
            this.a = sa.add(ha);
        }
    }

}
