package ru.orangesoftware.tidy;

import java.io.*;
import java.util.Scanner;

public class TidyLarge {

    private static long[] POW10_CACHE = new long[]{
            1,
            10,
            100,
            1000,
            10000,
            100000,
            1000000,
            10000000,
            100000000,
            1000000000,
            10000000000L,
            100000000000L,
            1000000000000L,
            10000000000000L,
            100000000000000L,
            1000000000000000L,
            10000000000000000L,
            100000000000000000L,
            1000000000000000000L
    };

    private static long pow10(int k) {
        if (k < 18) return POW10_CACHE[k];
        return (long) Math.pow(10, k);
    }

    private static final StringBuilder sb = new StringBuilder();

    public static void main(String[] args) throws IOException {
        String inFileName = args[0];
        solve(inFileName);
        writeResult(inFileName);
    }

    private static void solve(String inFileName) throws FileNotFoundException {
        try (Scanner in = new Scanner(new BufferedReader(new InputStreamReader(new FileInputStream(inFileName))))) {
            int t = in.nextInt();
            for (int i = 1; i <= t; ++i) {
                long n = in.nextLong();
                long r = lastTidy(n);
                System.out.println("Case #" + i + ": " + n + " -> " + r);
                sb.append("Case #").append(i).append(": ").append(r).append("\n");
            }
        }
    }

    private static long lastTidy(long n) {
        if (n < 10) return n;
        int lastUntidy = 0;
        long m = 1;
        while (m < n) {
            lastUntidy = isTidy(n, lastUntidy);
            if (lastUntidy == -1) return n;
            m = pow10(lastUntidy);
            n = (n / m - 1) * m + (m - 1);
        }
        return n;
    }

    private static int isTidy(long num, int startFrom) {
        // could have been cleaner
        long prevDigit = -1;
        int i = startFrom;
        num = num / pow10(startFrom);
        while (num > 0) {
            long digit = num % 10;
            if (prevDigit != -1) {
                if (prevDigit < digit) return i;
            }
            prevDigit = digit;
            num = num / 10;
            ++i;
        }
        return -1;
    }

    private static void writeResult(String inFileName) throws IOException {
        try (BufferedOutputStream out = new BufferedOutputStream(new FileOutputStream(new File(inFileName + ".out")))) {
            out.write(sb.toString().getBytes());
            out.flush();
        }
    }

}
