package ru.orangesoftware.stalls;

import java.io.*;
import java.math.BigInteger;
import java.util.Comparator;
import java.util.PriorityQueue;
import java.util.Scanner;

public class StallsLarge {


    private static final BigInteger TWO = BigInteger.valueOf(2);

    private static int log2(long n) {
        return (int) (Math.log(n) / Math.log(2));
    }

    private static long pow2(int n) {
        return TWO.pow(n).longValue();
    }

    private static final StringBuilder sb = new StringBuilder();

    public static void main(String[] args) throws IOException {
        String inFileName = args[0];
        solve(inFileName);
        writeResult(inFileName);
    }

    private static void solve(String inFileName) throws FileNotFoundException {
        try (Scanner in = new Scanner(new BufferedReader(new InputStreamReader(new FileInputStream(inFileName))))) {
            int t = in.nextInt();
            for (int i = 1; i <= t; ++i) {
                long n = in.nextLong();
                long k = in.nextLong();
                MinMax p = occupyStalls(n, k);
                System.out.println("Case #" + i + ": " + n + "/" + k + " -> " + p.max + " " + p.min);
                sb.append("Case #").append(i).append(": ").append(p.max).append(" ").append(p.min).append("\n");
            }
        }
    }

    private static MinMax occupyStalls(long n, long k) {
        if (n == k) return MinMax.ZERO;

        int m = log2(k + 1) - 1;
        long symmetricUsers = pow2(m + 1) - 1;

        if (symmetricUsers == k) {
            symmetricUsers -= pow2(m);
        }

        long numSpaces = n - symmetricUsers;
        long numIntervals = symmetricUsers + 1;
        k = k - symmetricUsers;

        long intervalSize = numSpaces / numIntervals;
        long residualSize = numSpaces - numIntervals * intervalSize;

        long interval;
        if (residualSize >= k) {
            interval = intervalSize + 1;
        } else {
            interval = intervalSize;
        }

        if (interval == 1) return MinMax.ZERO;

        long mid = interval / 2;
        if (isOdd(interval)) {
            return new MinMax(mid, mid);
        } else {
            return new MinMax(mid - 1, mid);
        }
    }

    private static boolean isOdd(long n) {
        return n % 2 == 1;
    }

    private static void writeResult(String inFileName) throws IOException {
        try (BufferedOutputStream out = new BufferedOutputStream(new FileOutputStream(new File(inFileName + ".out")))) {
            out.write(sb.toString().getBytes());
            out.flush();
        }
    }

    static class MinMax {
        static final MinMax ZERO = new MinMax(0, 0);

        final long min;
        final long max;

        MinMax(long min, long max) {
            this.min = min;
            this.max = max;
        }
    }

}
