package ru.orangesoftware.pancakes;

import java.io.*;
import java.util.*;

public class Pancakes {

    private static final StringBuilder sb = new StringBuilder();

    public static void main(String[] args) throws IOException {
        String inFileName = args[0];
        solve(inFileName);
        writeResult(inFileName);
    }

    private static void solve(String inFileName) throws FileNotFoundException {
        try (Scanner in = new Scanner(new BufferedReader(new InputStreamReader(new FileInputStream(inFileName))))) {
            int t = in.nextInt();
            in.nextLine();
            for (int i = 1; i <= t; ++i) {
                String[] split = in.nextLine().split(" ");
                String s = split[0].trim();
                int k = Integer.valueOf(split[1]);
                int r = flipPancakes(s, k);
                System.out.println("Case #" + i + ": " + s + ", " + k + " -> " + r);
                if (r == -1) {
                    sb.append("Case #").append(i).append(": IMPOSSIBLE\n");
                } else {
                    sb.append("Case #").append(i).append(": ").append(r).append("\n");
                }
            }
        }
    }


    private static int flipPancakes(String s, int k) {
        Queue<Node> queue = new LinkedList<>();
        Set<String> seen = new HashSet<>();
        seen.add(s);
        queue.add(new Node(s, 0));
        while (!queue.isEmpty()) {
            Node next = queue.poll();
            if (allHappy(next.s)) return next.level;
            for (String flip : generateFlips(next.s, k)) {
                if (seen.add(flip)) {
                    queue.add(new Node(flip, next.level + 1));
                }
            }
        }
        return -1;
    }

    private static List<String> generateFlips(String s, int k) {
        List<String> list = new ArrayList<>();
        for (int i = 0; i < s.length() - k + 1; i++) {
            String flipped = flipAt(s, i, k);
            list.add(flipped);
        }
        return list;
    }

    private static String flipAt(String s, int pos, int k) {
        StringBuilder sb = new StringBuilder();
        sb.append(s.substring(0, pos));
        for (int i = pos; i < pos + k; i++) {
            if (s.charAt(i) == '+') sb.append('-');
            else sb.append('+');
        }
        sb.append(s.substring(pos + k));
        return sb.toString();
    }

    private static boolean allHappy(String s) {
        for (int i = 0; i < s.length(); i++) {
            if (s.charAt(i) != '+') return false;
        }
        return true;
    }

    private static void writeResult(String inFileName) throws IOException {
        try (BufferedOutputStream out = new BufferedOutputStream(new FileOutputStream(new File(inFileName + ".out")))) {
            out.write(sb.toString().getBytes());
            out.flush();
        }
    }

    static class Node {
        final String s;
        final int level;

        Node(String s, int level) {
            this.s = s;
            this.level = level;
        }
    }

}
