import java.util.ArrayDeque;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Scanner;

public class A {
	private static final long PRIME = 1000002013;

	public static void main(String[] args) {
		Scanner scan = new Scanner(System.in);
		int numCases = scan.nextInt();
		for (int caseNum = 1; caseNum <= numCases; caseNum++) {
			System.out.println("Case #" + caseNum + ": " + solveProblem(scan));
		}
	}

	private static final class Ticket {
		long startStop, endStop, numPassOn, numPassOff;

		public Ticket(long o, long e, long p) {
			startStop = o;
			endStop = e;
			numPassOn = p;
			numPassOff = p;
		}

		public long getCost() {
			return A.getCost(startStop, endStop, numPassOn);
		}
	}

	static long n;

	private static final Comparator<Ticket> starts = new Comparator<Ticket>() {

		@Override
		public int compare(Ticket o1, Ticket o2) {
			return sign(o1.startStop - o2.startStop);
		}

	};

	private static final Comparator<Ticket> ends = new Comparator<Ticket>() {

		@Override
		public int compare(Ticket o1, Ticket o2) {
			return sign(o1.endStop - o2.endStop);
		}

	};

	private static int sign(long l) {
		return l < 0 ? -1 : (l > 0 ? 1 : 0);
	}

	private static long solveProblem(Scanner scan) {
		n = scan.nextLong() % PRIME;
		int m = scan.nextInt();
		long totCost = 0L;
		Ticket[] endTickets = new Ticket[m];
		for (int i = 0; i < m; i++) {
			endTickets[i] = new Ticket(scan.nextLong(), scan.nextLong(),
					scan.nextLong());
			totCost += endTickets[i].getCost();
			totCost %= PRIME;
		}
		Ticket[] startTickets = Arrays.copyOf(endTickets, m);
		Arrays.sort(endTickets, ends);
		Arrays.sort(startTickets, starts);
		ArrayDeque<Ticket> stack = new ArrayDeque<Ticket>(m);
		long bestCost = 0;
		int i = 0, j = 0;
		for (;;) {
			if (i < m && startTickets[i].startStop <= endTickets[j].endStop) {
				stack.push(startTickets[i++]);
			} else {
				Ticket end = endTickets[j];
				Ticket from = stack.peek();
				long numPass = Math.min(end.numPassOff, from.numPassOn);
				bestCost += getCost(from.startStop, end.endStop, numPass);
				bestCost %= PRIME;
				from.numPassOn -= numPass;
				end.numPassOff -= numPass;
				if (from.numPassOn == 0)
					stack.pop();
				if (end.numPassOff == 0) {
					j++;
					if (j >= m)
						break;
				}
			}
		}
		long res = (totCost - bestCost) % PRIME;
		if (res < 0)
			res += PRIME;
		return res;
	}

	public static long getCost(long start, long end, long numPass) {
		long numStops = end - start;
		return ((numStops * n - (numStops - 1) * numStops / 2) % PRIME)
				* numPass % PRIME;
	}
}
