package main;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/*
 * Solving problems from www.projecteuler.net
 */
public class EntryPoint {

   public static void main(String[] args) {
      EntryPoint ep = new EntryPoint();
      ep.run();
   }


   private void run() {
      List<String> input = getFileAsListOfStrings("input.txt");
      int cases = Integer.parseInt(input.remove(0));
      int caseNum = 1;

      while (input.size() > 0) {
         String customerPlates = input.remove(0);
         String row = input.remove(0);
         System.out.println("Case #" + caseNum + ": " + process(row));
         caseNum++;
      }
   }

   // 9 9 9
   // 9 9 5 4 - 10
   // 9 5 5 4 4 -- 11
   // 5 5 5 4 4 4 -- 8

   // 9 9 9
   // 9 9 6 3 -- 10
   // 9 6 6 3 3 -- 11
   // 6 6 6 3 3 3 -- 9
   // 6 6 3 3 3 3 3 -- 10
   // 6 3 3 3 3 ... 11
   // 3 3 3 3... 9

   private int process(String row) {
      String[] split = row.split(" ");
      int[] pancakeCount = new int[1001];
      for (String s : split) {
         int index = Integer.parseInt(s);
         pancakeCount[index]++;
      }
      int[] c1 = Arrays.copyOf(pancakeCount, pancakeCount.length);
      int[] c2 = Arrays.copyOf(pancakeCount, pancakeCount.length);
      return Math.min(simple(c1), includeThree(c2));

   }

   private int simple(int[] count) {
      int minutes = 0;
      int min = Integer.MAX_VALUE;
      while (true) {
         int index = getHighest(count);
         min = Math.min(min, minutes + index);
         if (index > count[index] * 2) {
            count[index]--;
            count[index / 2]++;
            count[index - index / 2]++;
            minutes++;
         } else {
            return Math.min(min, minutes + index);
         }
      }
   }

   private int includeThree(int[] count) {
      int minutes = 0;
      int min = Integer.MAX_VALUE;
      while (true) {
         int index = getHighest(count);
         min = Math.min(min, minutes + index);
         if (index > count[index] * 2) {
            count[index]--;
            int first = 0;
            int second = 0;
            if (index % 2 == 0 || index % 3 > 0) {
               first = index / 2;
               second = index - first;
            } else {
               first = index / 3;
               second = index - first;
            }
            count[first]++;
            count[second]++;
            minutes++;
         } else {
            return Math.min(min, minutes + index);
         }
      }
   }

   private int getHighest(int[] count) {
      for (int i = count.length - 1; i >= 0; --i) {
         if (count[i] > 0) {
            return i;
         }
      }
      return 0;
   }

   private List<String> getFileAsListOfStrings(String fileName) {
      final String fileBase = "C:\\Users\\drandall\\workspace\\Practice\\src\\files\\";
      List<String> result = new ArrayList<String>();
      BufferedReader in = null;
      try {
         in = new BufferedReader(new FileReader(fileBase + fileName));
         while (in.ready()) {
            result.add(in.readLine());
         }
      } catch (Exception e) {
         System.out.println("Error reading file: " + e);
      } finally {
         if (in != null) {
            try {
               in.close();
            } catch (IOException e) {
            }
         }
      }
      return result;
   }
}
