package main;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/*
 * Solving problems from www.projecteuler.net
 */
public class EntryPoint {

   public static void main(String[] args) {
      EntryPoint ep = new EntryPoint();
      ep.run();
   }


   private void run() {
      List<String> input = getFileAsListOfStrings("input.txt");
      int cases = Integer.parseInt(input.remove(0));
      int caseNum = 1;

      while (input.size() > 0) {
         String[] split = input.remove(0).split(" ");
         int repeats = Integer.parseInt(split[1]);
         String row = input.remove(0);
         System.out.println("Case #" + caseNum + ": " + process(row, repeats));
         caseNum++;
      }
   }


   private static final String YES = "YES";
   private static final String NO = "NO";

   private String process(String row, int repeats) {
      String working = "";
      for (int i = 0; i < repeats; ++i) {
         working += row;
      }
      if (working.length() < 3) {
         return NO;
      }
      if (!totalProduct(working).equals("-1")) {
         return NO;
      }
      boolean result = recurse(working, 'i');
      return result ? YES : NO;
   }

   private boolean recurse(String input, char target) {
      String working = Character.toString(input.charAt(0));
      int index = 1;
      while (index < input.length()) {
         if (working.charAt(0) == target) {
            String product = totalProduct(input.substring(index));
            if (target == 'i' && product.equals("i")) {
               if (recurse(input.substring(index), 'j')) {
                  return true;
               }
            } else if (target == 'j' && product.equals("k")) {
               return true;
            }
         }
         working = multiply(working, input.charAt(index));
         index++;
      }
      return false;
   }

   private String totalProduct(String input) {
      String working = Character.toString(input.charAt(0));
      for (int i = 1; i < input.length(); ++i) {
         working = multiply(working, input.charAt(i));
      }
      return working;
   }

   private String multiply(String lhs, Character rhs) {
      boolean negate = false;
      if (lhs.contains("-")) {
         negate = true;
         lhs = lhs.substring(1);
      }

      String result = "";
      switch (lhs) {
         case "1":
            result = rhs.toString();
            break;
         case "i":
            switch (rhs) {
               case '1':
                  result = lhs;
                  break;
               case 'i':
                  result = "-1";
                  break;
               case 'j':
                  result = "k";
                  break;
               case 'k':
                  result = "-j";
                  break;
            }
            break;
         case "j":
            switch (rhs) {
               case '1':
                  result = lhs;
                  break;
               case 'i':
                  result = "-k";
                  break;
               case 'j':
                  result = "-1";
                  break;
               case 'k':
                  result = "i";
                  break;
            }
            break;
         case "k":
            switch (rhs) {
               case '1':
                  result = lhs;
                  break;
               case 'i':
                  result = "j";
                  break;
               case 'j':
                  result = "-i";
                  break;
               case 'k':
                  result = "-1";
                  break;
            }
            break;
      }

      if (negate) {
         if (result.contains("-")) {
            result = result.substring(1);
         } else {
            result = "-" + result;
         }
      }

      return result;
   }

   private List<String> getFileAsListOfStrings(String fileName) {
      final String fileBase = "C:\\Users\\drandall\\workspace\\Practice\\src\\files\\";
      List<String> result = new ArrayList<String>();
      BufferedReader in = null;
      try {
         in = new BufferedReader(new FileReader(fileBase + fileName));
         while (in.ready()) {
            result.add(in.readLine());
         }
      } catch (Exception e) {
         System.out.println("Error reading file: " + e);
      } finally {
         if (in != null) {
            try {
               in.close();
            } catch (IOException e) {
            }
         }
      }
      return result;
   }
}
