package duarte;

import java.io.FileNotFoundException;
import java.io.IOException;

//1940
public class TicTacToeTomek extends ProblemWithTextFileInput {

	enum Simbolo {
		X('X') {
			@Override
			public Simbolo e(Simbolo outro) {
				if (outro.equals(O) || outro.equals(P))
					return F;
				return X;
			}
			@Override
			public boolean isPlayer() {
				return true;
			}
		},
		O('O') {
			@Override
			public Simbolo e(Simbolo outro) {
				if (outro.equals(X) || outro.equals(P))
					return F;
				return O;
			}
			@Override
			public boolean isPlayer() {
				return true;
			}
		},
		T('T') {
			@Override
			public Simbolo e(Simbolo outro) {
				return outro;
			}
		},
		P('.') {
			@Override
			public Simbolo e(Simbolo outro) {
				return P;
			}
		},
		F('F') {
			@Override
			public Simbolo e(Simbolo outro) {
				return F;
			}

			@Override
			public boolean continua() {
				return false;
			}
		};
		char letra;
		static boolean hasP = false;
		static Simbolo fromChar(char c){
			switch(c){
				case 'X': return Simbolo.X;
				case 'O': return Simbolo.O;
				case '.': hasP = true;return Simbolo.P;
			}
			return Simbolo.F;
		}
		private Simbolo(char letra) {
			this.letra = letra;
		}

		public abstract Simbolo e(Simbolo outro);
		public boolean isPlayer(){
			return false;
		}

		public boolean continua() {
			return true;
		}
		public static boolean hasP() {
			return hasP;
		}
	}

	public TicTacToeTomek(String filename, int linesPerCase)
			throws Exception {
		super(filename, linesPerCase);
	}

	public TicTacToeTomek(char[] filename, int linesPerCase) {
		super(filename, linesPerCase);
	}

	@Override
	public String solveCase(String[] current) throws IOException {
		Simbolo.hasP = false;
		
		Simbolo victor;
		if((victor = checkRows(current)) != Simbolo.F)
			return assembleMessageVictoryFor(victor);
		if((victor = checkColumns(current)) != Simbolo.F)
			return assembleMessageVictoryFor(victor);
		if((victor = checkDiagonals(current)) != Simbolo.F)
			return assembleMessageVictoryFor(victor);
		return assembleMessageVictoryFor(null);
	}

	private Simbolo checkDiagonals(String[] current) {
		Simbolo probing04 = Simbolo.fromChar(current[0].charAt(0));
		Simbolo probing40 = Simbolo.fromChar(current[0].charAt(3));
		for(int i = 1; i < 4; i++){
			probing04 = probing04.e(Simbolo.fromChar(current[i].charAt(i)));
			probing40 = probing40.e(Simbolo.fromChar(current[i].charAt(3-i)));
		}
		if(probing04.isPlayer())
			return probing04;
		else
			return probing40;
	}

	private Simbolo checkColumns(String[] current) {
		for(int i = 0; i < 4; i++){
			Simbolo probing = Simbolo.T; 
			for(String linha : current){
				probing = probing.e(Simbolo.fromChar(linha.charAt(i)));
			}
			if(probing.isPlayer())
				return probing;
		}

		return Simbolo.F;
	}

	private Simbolo checkRows(String[] current) {
		for(String linha : current){
			Simbolo probing = Simbolo.T; 
			for(char c : linha.toCharArray()){
				probing = probing.e(Simbolo.fromChar(c));
			}
			if(probing.isPlayer())
				return probing;
		}
		return Simbolo.F;
	}

	private String assembleMessageVictoryFor(Simbolo victor) {
		String cass = "Case #" + getCurrentCaseNumber() + ": ";
		if(victor == null || !victor.isPlayer()){
			if(!Simbolo.hasP())
				return cass + "Draw";
			else
				return cass + "Game has not completed";
		}
		return cass + victor.toString() + " won";
	}
	
	public static void main(String[] args) throws Exception {
		TicTacToeTomek solver = new TicTacToeTomek("C:\\A-Large.in", 4);
		System.out.println(solver.solveAll());
	}

}
