package duarte;

import java.io.BufferedReader;
import java.io.CharArrayReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

public abstract class ProblemWithTextFileInput {

	int linesPerCase;
	BufferedReader reader;
	int currentCaseNumber = 0;
	
	public ProblemWithTextFileInput(String filename, int linesPerCase)
			throws Exception {
		this.linesPerCase = linesPerCase;
		openFile(filename);
		reader.readLine();
	}

	public ProblemWithTextFileInput(char[] inputValues, int linesPerCase) {
		this.linesPerCase = linesPerCase;
		loadReader(inputValues);
	}

	private void loadReader(char[] inputValues) {
		reader = new BufferedReader(new CharArrayReader(inputValues));
	}

	private void openFile(String filename) throws FileNotFoundException {
		reader = new BufferedReader(new FileReader(filename));
	}

	protected String[] getNextCase() throws IOException {
		String[] aCase = new String[linesPerCase];
//		if (reader.readLine() == null)
//			return null;
		currentCaseNumber++;
		for (int i = 0; i < linesPerCase; i++) {
			aCase[i] = reader.readLine();
		}
		reader.readLine();
		if(aCase[0] == null)
			return null;
		return aCase;
	}

	public abstract String solveCase(String[] aCase) throws IOException;
	
	protected int getCurrentCaseNumber(){
		return currentCaseNumber;
	}
	
	public String solveAll() throws IOException{
		StringBuilder sb = new StringBuilder();
		String[] curCase = getNextCase();
		while(curCase != null){
			sb.append(solveCase(curCase) + "\n");
			curCase = getNextCase();
		}
		return sb.toString();
	}
}
