
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PushbackReader;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;

/**
 * Google code jam.
 * Qualification Round 2012.
 * Round 1C 2012
 * C. Box Factory
 * 
 * Usage: app &lt;input &gt;output
 * 
 * @author sombrabr@gmail.com
 *
 */
public class Round1CC implements Runnable {	

	static class TokenizerInput {
		
		static class Token {
		}
		
		static class NewLine extends Token {
		}
		
		static class EndOfFile extends Token {
		}
		
		static class Atom extends Token {
			String token = null;

			Atom(String token) {
				this.token = token;
			}
			
			public String toString() {
				return this.token;
			}
			
			public int toInteger() {
				return Integer.parseInt(this.token);
			}
			
			public float toFloat() {
				return Float.parseFloat(this.token);
			}

			public long toLong() {
				return Long.parseLong(this.token);
			}
		}
		
		static PushbackReader in = new PushbackReader(new InputStreamReader(System.in));
		
		static Token readToken() throws IOException {
			StringBuffer sb = new StringBuffer();
			
			boolean gotDelimiter = false;
			boolean gotNewLine = false;
			
			int iCh;
			for (iCh = in.read() ; iCh != -1; iCh = in.read()) {
				char ch = (char)iCh;
				
				if('\n' == ch || '\r' == ch) {
						
					if(sb.length()!=0 || gotDelimiter) {
						in.unread(iCh);
						break;
					}
					
					gotNewLine = true;
					if(!in.ready())
						break;
					
					continue;
				}
				
				if(gotNewLine) {
					in.unread(iCh);
					break;
				}
				
				if(' ' == ch && sb.length()==0) continue;
				
				if(' ' == ch) {
					gotDelimiter = true;
					continue;
				}
				
				if(gotDelimiter) {
					in.unread(iCh);
					break;
				}
				
				sb.append(ch);
			}
			
			if(gotNewLine)
				return new NewLine();
			
			if(-1==iCh)
				return new EndOfFile();
			
			return new Atom(sb.toString());
		}
		
		static NewLine readNewLine() throws IOException {
			return (NewLine)readToken();
		}
	}
	
	public static void main(String[] args) throws NumberFormatException, IOException {
		
		int cases = ((TokenizerInput.Atom) TokenizerInput.readToken()).toInteger();
		TokenizerInput.readNewLine();
		
		for(int i=0; i<cases; ++i) {
			System.out.print("Case #" + (i+1) + ": ");
			new Round1CC().run();
			System.out.println();
		}
	}
	
	class Type {
		long quantity;
		int type;
		
		Type(long quantity, int type) {
			this.quantity = quantity;
			this.type = type;
		}
		
		protected Type clone() {
			return new Type(this.quantity, this.type);
		}
	}
	
	
	@Override
	public void run() {
		try {
			int N = ((TokenizerInput.Atom)TokenizerInput.readToken()).toInteger();
			int M = ((TokenizerInput.Atom)TokenizerInput.readToken()).toInteger();
			TokenizerInput.readNewLine();
			
			ArrayList<Type> boxes = new ArrayList<Type>();
			ArrayList<Type> toys = new ArrayList<Type>();
			
			for(int i=0; i<N; i++) {
				boxes.add(new Type(((TokenizerInput.Atom)TokenizerInput.readToken()).toLong(), ((TokenizerInput.Atom)TokenizerInput.readToken()).toInteger())); 
			}
			TokenizerInput.readNewLine();
			
			for(int i=0; i<M; i++) {
				toys.add(new Type(((TokenizerInput.Atom)TokenizerInput.readToken()).toLong(), ((TokenizerInput.Atom)TokenizerInput.readToken()).toInteger())); 
			}
			TokenizerInput.readNewLine();
			
			long total = calc(boxes, toys);
			System.out.print(total);
			
		} catch(Exception e) {
			e.printStackTrace();
		}
	}

	long calc(ArrayList<Type> boxes, ArrayList<Type> toys) {
		
		long total = 0;
		
		if(boxes.size()==0 || toys.size()==0)
			return total;
		
		Type b = boxes.get(0);
		Type t = toys.get(0);

		if(b.type == t.type) {
			long min = Math.min(b.quantity, t.quantity);
			total += min;				
			
			b.quantity -= min;
			t.quantity -= min;
			
//			if(b.quantity == 0) 
//				boxes.remove(0);
//			
//			if(t.quantity==0)
//				toys.remove(0);
		}
		
		
		total += Math.max(calc(subArray(boxes,1), subArray(toys,0)), calc(subArray(boxes,0),subArray(toys,1)));
		
		return total;
	}

	private ArrayList<Type> subArray(ArrayList<Type> types, int index) {
		if(types.size()-index < 0) {
			return new ArrayList<Type>();
		}
		
		ArrayList<Type> newArray = new ArrayList<Type>(types.size()-index);
		
		for(int i=index; i<types.size(); ++i) {
			newArray.add(types.get(i).clone());
		}
		
		return newArray;
	}
}
