/**
 * 
 */
package gcj;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map.Entry;
import java.util.AbstractMap.SimpleImmutableEntry;

/**
 * @author dan
 *
 */
public class TrainCase {

	private int _turnaround;
	private List<MyEntry<Integer,Integer>> _timesAB;
	private List<MyEntry<Integer,Integer>> _timesBA;

	/**
	 * 
	 */
	public TrainCase ( int turnaround, List<MyEntry<Integer,Integer>> timesAB, List<MyEntry<Integer,Integer>> timesBA ) {
		_turnaround = turnaround;
		_timesAB = timesAB;
		_timesBA = timesBA;
		
		Collections.sort( _timesAB );
		Collections.sort( _timesBA );
		
		//System.out.println( "Created: " + turnaround + " " + _timesAB + " " + timesBA );
	}
	
	public Entry<Integer, Integer> MinimizeNumTrains( ) {
		List<Train> StationA = new ArrayList<Train>( );
		List<Train> StationB = new ArrayList<Train>( );
		
		int trainsA = 0, trainsB = 0;
		
		MyEntry<Integer,Integer> nextTimeA = null;
		if( _timesAB.size( ) > 0 )
			nextTimeA = _timesAB.remove( 0 );
		MyEntry<Integer,Integer> nextTimeB = null;
		if( _timesBA.size( ) > 0 )
			nextTimeB = _timesBA.remove( 0 );
		
		while( nextTimeA != null || nextTimeB != null )
		{
			if( nextTimeA == null ||
					( nextTimeB != null &&
						nextTimeB.getKey( ) < nextTimeA.getKey( ) ) )
			{
				// train moves from B to A.
				//System.out.println( "Moving train from B to A." );
				Train toMove = null;
				for( Train t : StationB )
					if( t.GetNextAvailTime( ) <= nextTimeB.getKey( ) )
						toMove = t;
				if( toMove == null )
				{
					trainsB++;
					toMove = new Train( );
				}
				else
					StationB.remove( toMove );
				StationA.add( toMove );
				toMove.SetNextAvailTime( nextTimeB.getValue( ) + _turnaround );
				nextTimeB = 
					_timesBA.size( ) > 0 ?
							_timesBA.remove( 0 ) : null;
			}
			else
			{
				//System.out.println( "Moving train from A to B." );
				// train moves from A to B.
				Train toMove = null;
				for( Train t : StationA )
					if( t.GetNextAvailTime( ) <= nextTimeA.getKey( ) )
						toMove = t;
				if( toMove == null )
				{
					toMove = new Train( );
					trainsA++;
				}
				else
					StationA.remove( toMove );
				StationB.add( toMove );
				toMove.SetNextAvailTime( nextTimeA.getValue( ) + _turnaround );
				nextTimeA = 
					_timesAB.size( ) > 0 ?
							_timesAB.remove( 0 ) : null;
			}
		}
		
		return new SimpleImmutableEntry<Integer,Integer>( trainsA, trainsB );
	}

	/**
	 * @param args
	 * @throws Exception 
	 */
	public static void main ( String[] args ) throws Exception {
		String fileName = "B-large.in";
		File f = new File(fileName);
		BufferedReader br = new BufferedReader( new FileReader( f ) );
		String readLine;
		readLine = br.readLine( );
		int numCases = Integer.parseInt( readLine );
		
		List<TrainCase> cases = new ArrayList<TrainCase>( );
		
		for( int i = 0; i < numCases; i++ )
		{
			int waitTime;
			List<MyEntry<Integer,Integer>> timesAB = new ArrayList<MyEntry<Integer,Integer>>( );
			List<MyEntry<Integer,Integer>> timesBA = new ArrayList<MyEntry<Integer,Integer>>( );
			
			waitTime = Integer.parseInt( br.readLine( ) );
			
			String[] readArray = br.readLine( ).split( " " );
			int numAB = Integer.parseInt( readArray[0] );
			int numBA = Integer.parseInt( readArray[1] );
			for( int j = 0; j < numAB; j++ )
			{
				String[] lineArr = br.readLine( ).split( " " );
				timesAB.add( new MyEntry<Integer,Integer>( ParseTime( lineArr[0] ), ParseTime( lineArr[1] ) ) );
			}
			
			for( int j = 0; j < numBA; j++ )
			{
				String[] lineArr = br.readLine( ).split( " " );
				timesBA.add( new MyEntry<Integer,Integer>( ParseTime( lineArr[0] ), ParseTime( lineArr[1] ) ) );
			}
			
			cases.add( new TrainCase( waitTime, timesAB, timesBA ) );
		}
		br.close( );
		
		String newLine = "";
		BufferedWriter bw = new BufferedWriter( new FileWriter( new File( "out.txt" ) ) );
		for( int i = 0; i < cases.size( ); i++ )
		{
			bw.write( newLine );
			TrainCase tc = cases.get( i );
			Entry<Integer,Integer> result = tc.MinimizeNumTrains( );
			bw.write( "Case #" + (i+1) + ": " + result.getKey( ) + " " + result.getValue( ) );
			newLine = "\r\n";
		}
		bw.close( );
	}

	/**
	 * @param string
	 * @return
	 */
	private static Integer ParseTime ( String string ) {
		String[] arr = string.split( ":" );
		return Integer.parseInt( arr[0] ) * 60 + Integer.parseInt( arr[1] );
	}

}
