import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StreamTokenizer;
import java.util.ArrayDeque;
import java.util.Arrays;

public class ProblemC {

	public static void main(String[] args) throws IOException {
		PonyExpress pe = new PonyExpress();
		pe.solve();
	}

}


class PonyExpress {
	
	static class Triple {
		
		Triple(int c, int h, double tm, int r){
			city = c;
			horse = h;
			time = tm;
			rest = r;
		}
		
		public String toString(){
			return "[" + city + " (c), " + horse + " (h), " + time + "]";
		}
		
		int city;
		int horse;
		double time;
		int rest;
	}
	
	PonyExpress() throws IOException {
		in = new FScanner("input.txt");
		out = new FPrinter("output.txt");
		t = in.nextInt();
	}
	
	void read() throws IOException {
		n = in.nextInt();
		q = in.nextInt();
		
		for (int i = 1; i <= n; i++){
			e[i] = in.nextInt();
			s[i] = in.nextInt();			
		}
		
		for (int i = 1; i <= n; i++){
			for (int j = 1; j <= n; j++){
				d[i][j] = in.nextInt();
			}
		}
		
		for (int i = 0; i < q; i++){
			start[i] = in.nextInt();
			fin[i] = in.nextInt();
		}
		
		Arrays.fill(y, 0);
		
	}
	
	double query(int num){
		double res = MAXT;
		for (int i = 1; i < MAXN+1; i++){
			Arrays.fill(dpt[i], MAXT);
		}
		
		for (int i = 1; i < MAXN+1; i++){
			Arrays.fill(dpr[i], 0);
		}
				
		now.clear();
		
		now.add(new Triple(start[num], 0, 0, 0));
		
		while (!now.isEmpty()) {
			Triple tr = now.pollFirst();
			for (int j = 1; j <= n; j++){
				if (d[tr.city][j] != -1){
										
					if (tr.rest >= d[tr.city][j]){
						double curt = tr.time + (1.0*d[tr.city][j])/s[tr.horse];
						int curr = tr.rest - d[tr.city][j];
						if ((dpt[j][tr.horse] > curt)
							|| ((Math.abs(dpt[j][tr.horse] - curt) <= EPS) && (dpr[j][tr.horse] < curr))) {
							
								dpt[j][tr.horse] = curt;
								dpr[j][tr.horse] = curr;
							
								now.add(new Triple(j, tr.horse, curt, curr));
						}
					}
					
					if (e[tr.city] >= d[tr.city][j]){
						double curt = tr.time + (1.0*d[tr.city][j])/s[tr.city];
						int curr = e[tr.city] - d[tr.city][j];

						if ((dpt[j][tr.city] > curt)
							|| ((Math.abs(dpt[j][tr.city] - curt) <= EPS) && (dpr[j][tr.city] < curr))) {
								
								dpt[j][tr.city] = curt;
								dpr[j][tr.city] = curr;
						
								now.add(new Triple(j, tr.city, curt, curr));
						}
					}
				} // if
		
			} //for
			
		} // while
		
		int f = fin[num];
		for (int i = 1; i <= n; i++){
			if (dpt[f][i] < res){
				res = dpt[f][i];
			}
		}
		
		return res;
	}
	
	void test(int tc) throws IOException {
		read();
		for (int i = 0; i < q; i++){
			y[i] = query(i);
		}
		out.printCase(tc);
		for (int i = 0; i < q; i++){
			out.print(" ");
			out.print(y[i]);
		}
		out.println();
	}
	
	void solve() throws IOException {
		e = new int[MAXN+1];
		s = new int[MAXN+1];
		d = new int[MAXN+1][MAXN+1];
		start = new int[MAXQ];
		fin = new int[MAXQ];
		y = new double[MAXQ];
		
		now = new ArrayDeque<>();
		uses = new boolean[MAXN+1];
		
		dpt = new double[MAXN+1][MAXN+1];
		dpr = new int[MAXN+1][MAXN+1];
		
		for (int tc = 1; tc <= t; tc++){
			test(tc);
		}
		
		out.fclose();
	}
	
	ArrayDeque<Triple> now;
	boolean [] uses;
	
	int n;
	int q;
	
	int [] e;
	int [] s;
	int [][] d;
	
	int [] start;
	int [] fin;
	double[] y;
	
	double [][] dpt;
	int [][] dpr;
	
	int t;
	FScanner in;
	FPrinter out;
	
	static int MAXN = 100;
	static int MAXQ = 100;
	static double MAXT = 1000.0*1000*1000*1000;
	static double EPS = 1E-9;
}


class FScanner {
	
	FScanner(String inputfile) throws IOException {
		in = new StreamTokenizer(new BufferedReader(new FileReader(inputfile)));
	}
	
	int nextInt() throws IOException {
		in.nextToken();
		return (int)in.nval;
	}
	
	double nextDouble() throws IOException {
		in.nextToken();
		return in.nval;
	}
	
	String next() throws IOException {
		in.nextToken();
		return in.sval;
	}

	StreamTokenizer in;
}

class FPrinter {
	
	FPrinter(String outputfile) throws IOException {
		out = new PrintWriter(outputfile);
	}
	
	void printCase(int tc) throws IOException {
		out.print("Case #");
		out.print(tc);
		out.print(":");
	}
	
	void printlnCase(int tc, String ans) throws IOException {
		printCase(tc);
		out.println(ans);
	}
	
	void printlnCase(int tc, long ans) throws IOException {
		printCase(tc);
		out.println(ans);
	}	
	
	void print(String s){
		out.print(s);
	}
	
	void print(double d){
		out.print(d);
	}
	
	void println() {
		out.println();
	}
	
	void fclose() {
		out.flush();
		out.close();
	}
	
	PrintWriter out;
}
