import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StreamTokenizer;
import java.util.ArrayList;
import java.util.Collections;

public class ProblemB {

	public static void main(String[] args) throws IOException {
		JC jc = new JC();
		jc.solve();
	}

}


class JC {
	
	static class Pair implements Comparable<Pair>{
		Pair(int s, int f){
			start = s;
			finish = f;
		}
		
		public String toString() {
			return "[" + start + ", " + finish + "]";
		}
		
		public int compareTo(Pair p){
			if (finish < p.finish) return -1;
			if (finish > p.finish) return 1;
			return 0;
		}
		
		int start;
		int finish;
	}
	
	static class Triple implements Comparable<Triple>{
		Triple (int s, int f, int len){
			st = s;
			fn = f;
			this.len = len;
		}
		
		public String toString() {
			return "[" + st + ", " + fn + " (" + len +  ")]";
		}
		
		public int compareTo(Triple p){
			if (len < p.len) return -1;
			if (len > p.len) return 1;
			return 0;
		}
		
		
		int st;
		int fn;
		int len;
	}

	JC() throws IOException {
		in = new FScanner("input.txt");
		out = new FPrinter("output.txt");
		t = in.nextInt();
	}
	
	void prepare() {
		Collections.sort(cm);
		Collections.sort(jm);	
		ci.clear();
		ji.clear();
		
		for (int i = 0; i < cm.size()-1; i++) {
			int d = cm.get(i+1).start - cm.get(i).finish;
			if (d != 0) {
				ci.add(new Triple(cm.get(i).finish, cm.get(i+1).start, d));
			}
		}
			
		if (cm.size() != 0) {
			int d = cm.get(0).start - cm.get(cm.size()-1).finish + DAY;
			if (d != 0) {
				ci.add(new Triple(cm.get(cm.size()-1).finish, cm.get(0).start, d));
			}
		}
		
		Collections.sort(ci);
		
		for (int i = 0; i < jm.size()-1; i++) {
			int d = jm.get(i+1).start - jm.get(i).finish;
			if (d != 0) {
				ji.add(new Triple(jm.get(i).finish, jm.get(i+1).start, d));
			}
		}
			
		if (jm.size() != 0) {
			int d = jm.get(0).start - jm.get(jm.size()-1).finish + DAY;
			if (d != 0) {
				ji.add(new Triple(jm.get(jm.size()-1).finish, jm.get(0).start, d));
			}
		}

		Collections.sort(ji);
		
	}
	
	
	void analyzeTest(int tc) throws IOException {
		cm.clear();
		jm.clear();
		ac = in.nextInt();
		aj = in.nextInt();
		
		int ftc = HDAY;
		int ftj = HDAY;
		
		for (int i = 0; i < ac; i++){
			int c = in.nextInt();
			int d = in.nextInt();
			cm.add(new Pair(c, d));
			ftc = ftc - (d-c);
		}
		
		for (int i = 0; i < aj; i++){
			int c = in.nextInt();
			int d = in.nextInt();
			jm.add(new Pair(c, d));
			ftj = ftj - (d-c);
		}
		
		prepare();
		
		int sci = ci.size();
		int sji = ji.size();
		
		if (sci < sji){
			ArrayList<Triple> ai = ji;
			ji = ci;
			ci = ai;
			
			ArrayList<Pair> a = cm;
			cm = jm;
			jm = a;
			
			sci = ci.size();
			sji = ji.size();
			
			int ft = ftc;
			ftc = ftj;
			ftj = ft;
		}
		
		answer = 2*sci;
		
		for (int i = 0; i < sci; i++){
			if (ci.get(i).len <= ftc) {
				boolean flag = false;
				for (Pair p: jm){
					if (((p.start <= ci.get(i).st) && (ci.get(i).st < p.finish)) ||
							((p.start <= ci.get(i).fn) && (ci.get(i).fn < p.finish))){
						flag = true;
					}
				}
				if (!flag){
					answer = answer - 2;
					ftc = ftc - ci.get(i).len;
				}
			}
		}
		
		out.printlnCase(tc, answer);
		
	}
	
	void solve() throws IOException {
		cm = new ArrayList<>();
		jm = new ArrayList<>();
		ci = new ArrayList<>();
		ji = new ArrayList<>();
		for (int tc = 1; tc <= t; tc++){
			analyzeTest(tc);
		}
		out.fclose();
	}
	
	int answer;
	
	int ac;
	int aj;
	
	ArrayList<Pair> cm;
	ArrayList<Pair> jm;
	
	ArrayList<Triple> ci;
	ArrayList<Triple> ji;
	
	int t;
	
	FScanner in;
	FPrinter out;
	
	static int DAY = 1440;
	static int HDAY = 720;
}

class FScanner {
	
	FScanner(String inputfile) throws IOException {
		in = new StreamTokenizer(new BufferedReader(new FileReader(inputfile)));
	}
	
	int nextInt() throws IOException {
		in.nextToken();
		return (int)in.nval;
	}
	
	double nextDouble() throws IOException {
		in.nextToken();
		return in.nval;
	}
	
	String next() throws IOException {
		in.nextToken();
		return in.sval;
	}

	StreamTokenizer in;
}

class FPrinter {
	
	FPrinter(String outputfile) throws IOException {
		out = new PrintWriter(outputfile);
	}
	
	void printCase(int tc) throws IOException {
		out.print("Case #");
		out.print(tc);
		out.print(": ");
	}
	
	void printlnCase(int tc, String ans) throws IOException {
		printCase(tc);
		out.println(ans);
	}
	
	void printlnCase(int tc, long ans) throws IOException {
		printCase(tc);
		out.println(ans);
	}	
	
	void printlnCase(int tc, double ans) throws IOException {
		printCase(tc);
		out.println(ans);
	}	
	
	void fclose() {
		out.flush();
		out.close();
	}
	
	PrintWriter out;
}
