import java.io.InputStream;
import java.util.Collections;
import java.util.LinkedList;
import java.util.Scanner;

class BotTrust {
	public static void main(String args[]) {
		TestCase[] testCases = TestCase.loadTestCases(System.in);
		for (int i=0; i<testCases.length; i++) {
//			testCases[i].dump();
			testCases[i].solve();
		}
	}
}

class TestCase {
	int mCaseNum;
	LinkedList<Item> mItemB = new LinkedList<Item>();
	LinkedList<Item> mItemO = new LinkedList<Item>();
	
	private static class Item {
		public int order;
		public int pos;
		
		public Item(int order, int pos) {
			this.order = order;
			this.pos = pos;
		}
		
		public String toString() {
			return "("+order+","+pos+")";
		}
	}
	
	public TestCase(int caseNum, int[] robots, int[] buttons) {
		mCaseNum = caseNum;
		for (int i=0; i<robots.length; i++) {
			if (robots[i] == 0) // blue
				mItemB.add(new Item(i, buttons[i]));
			else // orange
				mItemO.add(new Item(i, buttons[i]));
		}
	}
	
	public static TestCase[] loadTestCases(InputStream is) {
		Scanner sc = new Scanner(is);
		int caseNum = Integer.parseInt(sc.nextLine());
		TestCase[] testCases = new TestCase[caseNum];
		for (int i=0; i<testCases.length; i++) {
			int len = sc.nextInt();
			int[] robots = new int[len];
			int[] buttons = new int[len];
			for (int j=0; j<len; j++) {
				if (sc.next().equals("B"))
					robots[j] = 0;
				else
					robots[j] = 1;
				buttons[j] = sc.nextInt();
			}
			testCases[i] = new TestCase(i+1, robots, buttons);
			sc.nextLine();
		}
		sc.close();
		return testCases;
	}
	
	public void dump() {
		System.out.println("case "+mCaseNum);
		System.out.println("B="+mItemB);
		System.out.println("O="+mItemO);
	}
	
	public void solve() {
		int len = mItemB.size() + mItemO.size();
		int totalTime = 0;
		int time = 0;
		int posB = 1;
		int posO = 1;
		while(!(mItemB.isEmpty() && mItemO.isEmpty())) {
			if (mItemB.isEmpty() || (!mItemO.isEmpty() && mItemB.get(0).order > mItemO.get(0).order)) { // orange
				time = Math.abs(mItemO.get(0).pos - posO) + 1;
				posO = mItemO.get(0).pos;
				mItemO.remove(0);
				if (!mItemB.isEmpty())
					posB = moveTo(posB, mItemB.get(0).pos, time);
			} else if (mItemO.isEmpty() || (!mItemB.isEmpty() && mItemB.get(0).order < mItemO.get(0).order)) { // blue
				time = Math.abs(mItemB.get(0).pos - posB) + 1;
				posB = mItemB.get(0).pos;
				mItemB.remove(0);
				if (!mItemO.isEmpty())
					posO = moveTo(posO, mItemO.get(0).pos, time);
			} else {
				posB = posB;
			}
			totalTime += time;
		}
		System.out.println("Case #" + mCaseNum + ": " + totalTime);
	}
	
	private int moveTo(int cur, int dst, int time) {
		if (cur < dst) {
			return cur + Math.min(dst - cur, time);
		} else
			return cur - Math.min(cur - dst, time);
	}
}