import java.io.InputStream;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Random;
import java.util.Scanner;

class FairWarning {	
	public static void main(String args[]) {
		TestCase[] testCases = TestCase.loadTestCases(System.in);
		//TestCase[] testCases = TestCase.generateTestCases();
		long startTime = System.currentTimeMillis();
		for (int i=0; i<testCases.length; i++) {
			//testCases[i].dump();
			testCases[i].solve();
		}
		long endTime = System.currentTimeMillis();
		//System.out.println("Time="+((endTime - startTime) / 1000));
	}
}

class TestCase {
	int mCaseNum;
	ArrayList<BigInteger> mEvents;
	
	public TestCase(int caseNum, ArrayList<BigInteger> events) {
		mCaseNum = caseNum;
		mEvents = events;
	}
	
	public static TestCase[] loadTestCases(InputStream is) {
		Scanner sc = new Scanner(is);
		int caseNum = Integer.parseInt(sc.nextLine());
		TestCase[] testCases = new TestCase[caseNum];
		for (int i=0; i<testCases.length; i++) {
			int eventsNum = sc.nextInt();
			ArrayList<BigInteger> events = new ArrayList<BigInteger>();
			for (int j=0; j<eventsNum; j++)
				events.add(new BigInteger(sc.next()));
			sc.nextLine();
			testCases[i] = new TestCase(i+1, events);
		}
		sc.close();
		return testCases;
	}
	
	public static TestCase[] generateTestCases() {
		int caseNum = 1;
		TestCase[] testCases = new TestCase[caseNum];
		for (int i=0; i<testCases.length; i++) {
			int eventsNum = nextInt(2, 3);
			ArrayList<BigInteger> events = new ArrayList<BigInteger>();
			for (int j=0; j<eventsNum; j++)
				events.add(new BigInteger(26, new Random()));
			testCases[i] = new TestCase(i+1, events);
		}
		return testCases;
	}
	
	private static int nextInt(int min, int max) {
		Random rnd = new Random();
		int i = rnd.nextInt();
		if (i < 0) i = -i;
		return (i % (max-min) + min);
	}
	
	public void dump() {
		System.out.println("------------- case "+mCaseNum);
		System.out.println("events " + mEvents);		
	}
	
	public void solve() {
		Collections.sort(mEvents);
		ArrayList<BigInteger> diffList = new ArrayList<BigInteger>();
		for (int i=1; i<mEvents.size(); i++)
			diffList.add(mEvents.get(i).subtract(mEvents.get(i-1)));
		BigInteger divisor = diffList.get(0);
		for (int i=1; i<diffList.size(); i++)
			divisor = divisor.gcd(diffList.get(i));
		BigInteger remainder = mEvents.get(0).remainder(divisor); // assume all remainders are same			
		BigInteger answer = remainder == BigInteger.ZERO ? remainder : (divisor.subtract(remainder));		
		System.out.println("Case #" + mCaseNum + ": " + answer);
	}
	/*
	private static class BigInteger implements Comparable<BigInteger> {
		private static final int UNIT_SIZE = 2;
		private ArrayList<Integer> mNumber = new ArrayList<Integer>();
		
		public BigInteger(BigInteger from) {
			mNumber.addAll(from.mNumber);
		}

		public BigInteger(String data) {
			int numLen = data.length();
			int unit = 0;
			for (int i=0; i<numLen; i++) {
				unit = 10 * unit + (data.charAt(i) - '0');
				if (numLen - i % UNIT_SIZE == 0) {
					mNumber.add(unit);
					unit = 0;
				}
			}
		}
		
		public BigInteger sub(BigInteger arg0) {
			BigInteger res = new BigInteger(this);
			return res;
		}
		
		@Override
		public int compareTo(BigInteger o) {
			if (mNumber.size() > o.mNumber.size())
				return 1;
			else if (mNumber.size() < o.mNumber.size())
				return -1;
			else {
				for (int i=0; i<mNumber.size(); i++) {
					if (mNumber.get(i) > o.mNumber.get(i))
						return 1;
					else if (mNumber.get(i) < o.mNumber.get(i))
						return -1;
				}
				return 0;
			}
		}
	}
	*/
}