import java.io.InputStream;
import java.util.Random;
import java.util.Scanner;

class ThemePark {	
	public static void main(String args[]) {
		TestCase[] testCases = TestCase.loadTestCases(System.in);
		//TestCase[] testCases = TestCase.generateTestCases();
		long startTime = System.currentTimeMillis();
		for (int i=0; i<testCases.length; i++) {
			//testCases[i].dump();
			testCases[i].solve();
		}
		long endTime = System.currentTimeMillis();
		System.out.println("Time="+((endTime - startTime) / 1000));
	}
}

class TestCase {
	int mCaseNum;
	int mRide;
	int mCapacity;
	Data[] mGroups;
	
	public TestCase(int caseNum, int ride, int capacity, Data[] groups) {
		mCaseNum = caseNum;
		mRide = ride;
		mCapacity = capacity;
		mGroups = groups;
	}
	
	public static TestCase[] loadTestCases(InputStream is) {
		Scanner sc = new Scanner(is);
		int caseNum = Integer.parseInt(sc.nextLine());
		TestCase[] testCases = new TestCase[caseNum];
		for (int i=0; i<testCases.length; i++) {
			int ride = sc.nextInt();
			int capacity = sc.nextInt();
			int groupsSize = sc.nextInt();
			sc.nextLine();
			Data[] groups = new Data[groupsSize];
			for (int j=0; j<groupsSize; j++)
				groups[j] = new Data(j, sc.nextInt());
			sc.nextLine();
			testCases[i] = new TestCase(i+1, ride, capacity, groups);
		}
		sc.close();
		return testCases;
	}
	
	public static TestCase[] generateTestCases() {
		int caseNum = 50;
		TestCase[] testCases = new TestCase[caseNum];
		for (int i=0; i<testCases.length; i++) {
			int ride = nextInt(1, 100000000);
			int capacity = nextInt(1, 1000000000);
			int groupsSize = nextInt(1, 1000);
			Data[] groups = new Data[groupsSize];
			for (int j=0; j<groupsSize; j++)
				groups[j] = new Data(j, nextInt(1, 1000000));
			testCases[i] = new TestCase(i+1, ride, capacity, groups);
		}
		return testCases;
	}
	
	private static int nextInt(int min, int max) {
		Random rnd = new Random();
		int i = rnd.nextInt();
		if (i < 0) i = -i;
		return (i % max + min);
	}
	
	public void dump() {
		System.out.println("------------- case "+mCaseNum);		
		System.out.println("ride " + mRide + ", capacity " + mCapacity);
		System.out.println("groups " + mGroups);		
	}
	
	public void solve() {
		for (int i=0; i<mGroups.length; i++) {
			Data cur = mGroups[i];
			if (i > 0) {
				Data prev = mGroups[i - 1];
				if (prev.mStart != prev.mEnd) {
					cur.mEnd = prev.mEnd;
					cur.mMax = prev.mMax - mGroups[prev.mStart].mGroup;
				}
			}
			while(true) {
				int nextEnd = (cur.mEnd + 1) % mGroups.length;
				int nextMax = cur.mMax + mGroups[nextEnd].mGroup;
				if (nextEnd == cur.mStart || nextMax > mCapacity)
					break;
				cur.mMax = nextMax;
				cur.mEnd = nextEnd;
			}
		}

		double allRidePeople = 0;
		int start = 0;
		for (int j=0; j<mRide; j++) {
			Data cur = mGroups[start];
			if (cur.mMax <= mCapacity) {
				allRidePeople += cur.mMax;
				start = (cur.mEnd + 1) % mGroups.length;
			}
		}
		
		System.out.println("Case #" + mCaseNum + ": " + (int)allRidePeople);
	}

	private static class Data {
		// input
		public int mStart = -1; // start index
		public int mGroup; // people in this group
		// output
		public int mEnd; // end index
		public int mMax; // max people from start group to end group
		
		public Data(int start, int group) {
			mStart = start;
			mEnd = start;
			mGroup = group;
			mMax = group;
		}
	}
}