import java.io.InputStream;
import java.util.Scanner;

class A {	
	public static void main(String args[]) {
		TestCase[] testCases = TestCase.loadTestCases(System.in);
		for (int i=0; i<testCases.length; i++) {
			testCases[i].start(1);
		}
	}
}

class TestCase {
	int mCaseNum;
	int mK;
	int[][] mBoard;
	
	private static final int NONE = 0;
	private static final int RED = 1;
	private static final int BLUE = 2;
	
	public TestCase(int caseNum, int k, int[][] board) {
		mCaseNum = caseNum;
		mK = k;
		mBoard = board;
	}
	
	public static TestCase[] loadTestCases(InputStream is) {
		Scanner sc = new Scanner(is);
		int caseNum = Integer.parseInt(sc.nextLine());
		TestCase[] testCases = new TestCase[caseNum];
		for (int t=0; t<testCases.length; t++) {
			int n = sc.nextInt();
			int k = sc.nextInt();
			sc.nextLine();
			int[][] board = makeArray(n, n);
			for (int i=0; i<n; i++) {				
				String line = sc.nextLine();				
				for (int j=0; j<n; j++)
					if (line.charAt(j) == 'R')
						board[i][j] = RED;
					else if (line.charAt(j) == 'B')
						board[i][j] = BLUE;
					else
						board[i][j] = NONE;
			}
			testCases[t] = new TestCase(t+1, k, board);
		}
		sc.close();
		return testCases;
	}
	
	public void start(int mode) {
		if (mode == 0)
			dump();
		else {
			long startTime = System.currentTimeMillis();
			solve();
			long endTime = System.currentTimeMillis();
			//System.out.println("Time="+((endTime - startTime) / 1000));
		}
	}
	
	public void dump() {
		System.out.println("case "+mCaseNum);
		System.out.println("K="+mK);
		for (int i=0; i<mBoard.length; i++) {
			for (int j=0; j<mBoard.length; j++)
				System.out.print(" "+mBoard[i][j]);
			System.out.println();
		}
	}
	
	public void solve() {
		int[][] rotated = rotate(mBoard);
		gravity(rotated);
		boolean redWin = isWin(RED, mK, rotated);
		boolean blueWin = isWin(BLUE, mK, rotated);
		String result = "Neither";
		if (redWin && blueWin)
			result = "Both";
		else if (redWin)
			result = "Red";
		else if (blueWin)
			result = "Blue";
		System.out.println("Case #" + mCaseNum + ": " + result);
	}
	
	private int[][] rotate(int[][] board) { // clockwise
		int[][] prev = board;
		int[][] next = makeArray(board.length, board.length);
		for (int i=0; i<board.length; i++) {
			for (int j=0; j<board.length; j++) {
				//System.out.println("("+(board.length-j-1)+","+(i)+") -> ("+i+","+j+")");
				next[i][j] = prev[board.length-j-1][i];
			}
		}
		return next;
	}
	
	private void gravity(int[][] board) {
		int[] filledCol = new int[board.length];
		for (int i=0; i<board.length; i++) {
			for (int j=board.length-1; j>=0; j--)
				filledCol[j] = NONE;
			int fillIdx = board.length - 1;
			for (int j=board.length-1; j>=0; j--) {
				if (board[j][i] != NONE)
					filledCol[fillIdx--] = board[j][i];
			}
			for (int j=board.length-1; j>=0; j--) {
				board[j][i] = filledCol[j];
			}
		}
	}
	
	private boolean isWin(int p, int k, int[][] board) {
		int len;
		// horizontal
		for (int i=0; i<board.length; i++) {
			len = 0;
			for (int j=0; j<board.length; j++) {
				if (board[i][j] == p)
					len++;
				else
					len = 0;
				if (len >= k)
					return true; // win
			}
		}
		// vertical
		for (int i=0; i<board.length; i++) {
			len = 0;
			for (int j=0; j<board.length; j++) {
				if (board[j][i] == p)
					len++;
				else
					len = 0;
				if (len >= k)
					return true; // win
			}
		}
		// diagonal /
		for (int i=k-1; i<board.length; i++) {
			len = 0;
			for (int j=0; j<=i; j++) {
				//System.out.print("("+(i-j)+","+j+") ");
				if (board[i-j][j] == p)
					len++;
				else
					len = 0;
				if (len >= k)
					return true; // win
			}
			//System.out.println();
			if (i == board.length-1)
				continue;
			len = 0;
			for (int j=0; j<=i; j++) {
				//System.out.print("("+(board.length-j-1)+","+(j+(board.length-i-1))+") ");
				if (board[board.length-j-1][j+(board.length-i-1)] == p)
					len++;
				else
					len = 0;
				if (len >= k)
					return true; // win
			}
			//System.out.println();
		}
		// diagonal \
		for (int i=0; i<=board.length-k; i++) {
			len = 0;
			for (int j=0; j<board.length-i; j++) {
				//System.out.print("("+(j)+","+(j+i)+") ");
				if (board[j][j+i] == p)
					len++;
				else
					len = 0;
				if (len >= k)
					return true; // win
			}
			//System.out.println();
			if (i == 0)
				continue;
			len = 0;
			for (int j=0; j<board.length-i; j++) {
				//System.out.print("("+(j+i)+","+(j)+") ");
				if (board[j+i][j] == p)
					len++;
				else
					len = 0;
				if (len >= k)
					return true; // win
			}
			//System.out.println();
		}
		return false;
	}
	
	private static int[][] makeArray(int h, int w) {
		int[][] array = new int[h][];
		for (int i=0; i<h; i++)
			array[i] = new int[w];
		return array;
	}
}