import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.Map;
import java.util.Scanner;
import java.util.TreeMap;

public class Program {

    static class Horse implements Comparable<Horse> {
        double destinationPos;
        double speed;
        double startingPos;

        Horse(double destinationPos, Map.Entry<Double, Double> d) {
            startingPos = d.getKey();
            speed = d.getValue();
            this.destinationPos = destinationPos;
        }

        double getFinishTime() {
            return (destinationPos - startingPos) / speed;
        }

        @Override
        public int compareTo(Horse o) {
            return Double.compare(this.getFinishTime(), o.getFinishTime());
        }

        @Override
        public String toString() {
            return String.format("<Horse startingPos=%s, speed=%s>", startingPos, speed);
        }

    }

    public static void main(String[] args) {
        BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
        Scanner scanner = new Scanner(br);
        int t = scanner.nextInt();
        for (int ti = 1; ti <= t; ti++) {
            // one case
            double distance = scanner.nextDouble();
            int horseCount = scanner.nextInt();
            TreeMap<Double, Double> horses = new TreeMap<>();
            for (int hi = 0; hi < horseCount; hi++) {
                double k = scanner.nextDouble();
                double s = scanner.nextDouble();
                horses.put(k, s);
            }
            System.out.println(String.format(
                    "Case #%s: %s",
                    ti,
                    solve(distance, horses)));
        }
    }

    private static double solve(double distance, TreeMap<Double, Double> horses) {
        while (horses.size() > 1) {
            Horse leader = new Horse(distance, horses.pollLastEntry());
            Horse follower = new Horse(distance, horses.pollLastEntry());
            Horse laterArriver = leader.compareTo(follower) <= 0 ? follower : leader;
            horses.put(laterArriver.startingPos, laterArriver.speed);
        }
        Horse otherHorse = new Horse(distance, horses.firstEntry());
        return distance / otherHorse.getFinishTime();
    }

}
