import static java.lang.Integer.parseInt;
import static java.lang.Long.parseLong;
import static java.lang.Math.max;
import static java.lang.Math.min;

import java.io.*;
import java.math.BigInteger;
import java.util.ArrayDeque;
import java.util.Queue;
import java.util.Random;
import java.util.StringTokenizer;

public class B {
	
	static BufferedReader in;
	static PrintWriter out;
	static StringTokenizer tok;
	
	static long get(long arr[][], int i, int j) {
		if (i < 0 || i >= arr.length || j < 0 || j >= arr[0].length) {
			return 0;
		}
		return arr[i][j];
	}
	
	static class Cell {
		final int i, j;

		Cell(int i, int j) {
			this.i = i;
			this.j = j;
		}
	}
	
	static final int dx[] = {1, 0, -1, 0};
	static final int dy[] = {0, 1, 0, -1};
	
	static void calculateLevel(long map[][], long level[][]) {
		Queue<Cell> queue = new ArrayDeque<Cell>();
		for (int i = 0; i < map.length; i++) {
			for (int j = 0; j < map[0].length; j++) {
				level[i][j] = Long.MAX_VALUE;
				queue.add(new Cell(i, j));
			}
		}
		while (!queue.isEmpty()) {
			Cell cur = queue.remove();
			int i = cur.i;
			int j = cur.j;
			long nlevel = Long.MAX_VALUE;
			for (int d = 0; d < 4; d++) {
				nlevel = min(nlevel, get(level, i + dx[d], j + dy[d]));
			}
			nlevel = max(nlevel, map[i][j]);
			if (level[i][j] > nlevel) {
				level[i][j] = nlevel;
				for (int d = 0; d < 4; d++) {
					int ni = i + dx[d];
					int nj = j + dy[d];
					if (ni >= 0 && ni < map.length && nj >= 0 && nj < map[0].length) {
						queue.add(new Cell(ni, nj));
					}
				}
			}
		}
	}
	
	static void erode(long map[][], long level[][], long limit) {
		for (int i = 0; i < map.length; i++) {
			for (int j = 0; j < map[0].length; j++) {
				long min = level[i][j];
				for (int d = 0; d < 4; d++) {
					min = min(min, get(level, i + dx[d], j + dy[d]));
				}
				min = level[i][j] - min;
				if (min > 0) {
					min = min(min, limit);
					map[i][j] -= min;
				}
			}
		}
	}
	
	static void print(long arr[][]) {
		for (long ar[]: arr) {
			for (long a: ar) {
				System.err.printf("%2d ", a);
			}
			System.err.println();
		}
		System.err.println();
	}
	
	static final Random rng = new Random();
	
	static void solveTest() throws Exception {
		int n = nextInt();
		int m = nextInt();
		long d = nextLong();
//		int n = 10;
//		int m = 10;
//		long d = 1;
		long map[][] = new long[n][m];
		for (int i = 0; i < n; i++) {
			for (int j = 0; j < m; j++) {
				map[i][j] = nextLong();
//				map[i][j] = rng.nextInt(101);
			}
		}
		long level[][] = new long[n][m];
		calculateLevel(map, level);
		for (int day = 0; ; day++) {
			check: for (int i = 0; ; i++) {
				if (i >= n) {
					out.println(day);
					return;
				}
				for (int j = 0; j < m; j++) {
					if (map[i][j] != 0) {
						break check;
					}
				}
			}
//			System.err.println("Day " + day);
//			print(map);
//			print(level);
			erode(map, level, d);
			calculateLevel(map, level);
		}
	}
	
	static void solve() throws Exception {
		int tests = nextInt();
		for (int test = 1; test <= tests; test++) {
			out.print("Case #" + test + ": ");
			solveTest();
		}
	}

	public static void main(String[] args) throws Exception {
		in = new BufferedReader(new InputStreamReader(System.in));
		out = new PrintWriter(new BufferedWriter(new OutputStreamWriter(System.out)));
		solve();
		in.close();
		out.close();
	}
	
	static String next() throws IOException {
		while (tok == null || !tok.hasMoreTokens()) {
			tok = new StringTokenizer(in.readLine());
		}
		return tok.nextToken();
	}
	
	static char nextChar() throws IOException {
		String token = next();
		if (token.length() != 1) {
			throw new IllegalArgumentException("String \"" + token + "\" is not a single character");
		}
		return token.charAt(0);
	}
	
	static int nextInt() throws IOException {
		return parseInt(next());
	}
	
	static long nextLong() throws IOException {
		return parseLong(next());
	}
	
	static BigInteger nextBigInt() throws IOException {
		return new BigInteger(next());
	}
}