import static java.lang.Double.parseDouble;
import static java.lang.Integer.parseInt;
import static java.lang.Long.parseLong;
import static java.lang.Math.min;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Map.Entry;
import java.util.StringTokenizer;

public class A {
	
	static BufferedReader in;
	static PrintWriter out;
	static StringTokenizer tok;
	
	static class Stack {
		
		final char letter;
		Stack next;
		Stack nextA, nextB, nextC;
		final int hash;
		
		private Stack() {
			letter = 0;
			hash = 1;
		}
		
		static final Stack BOTTOM = new Stack();
		
		public Stack(char letter, Stack next) {
			super();
			this.letter = letter;
			this.next = next;
			hash = (next == null ? 0 : 31 * next.hash) + letter;
			if (letter == 'A') {
				nextA = this;
			} else if (next == null) {
				nextA = null;
			} else {
				nextA = next.nextA;
			}
			if (letter == 'B') {
				nextB = this;
			} else if (next == null) {
				nextB = null;
			} else {
				nextB = next.nextB;
			}
			if (letter == 'C') {
				nextC = this;
			} else if (next == null) {
				nextC = null;
			} else {
				nextC = next.nextC;
			}
		}
		
		Stack next(char c) {
			switch (c) {
			case 'A':
				return nextA;
			case 'B':
				return nextB;
			case 'C':
				return nextC;
			}
			throw new AssertionError();
		}
		
		public boolean equals(Object o) {
			if (this == o) {
				return true;
			}
			if (!(o instanceof Stack)) {
				return false;
			}
			Stack s = (Stack) o;
			if (letter != s.letter || hash != s.hash) {
				return false;
			}
			if (next == s.next) {
				return true;
			}
			if (next == null || s.next == null) {
				return false;
			}
			if (next.equals(s.next)) {
				s.next = next;
				return true;
			}
			return false;
		}
		
		public int hashCode() {
			return hash;
		}
	}
	
	static void solveTest() throws Exception {
		String s = in.readLine();
		Map<Stack, Integer> stacks = new HashMap<Stack, Integer>();
		stacks.put(Stack.BOTTOM, 0);
		for (int i = 0; i < s.length(); i++) {
			char c = s.charAt(i);
			Map<Stack, Integer> newStacks = new HashMap<A.Stack, Integer>();
			for (Entry<Stack, Integer> e: stacks.entrySet()) {
				Stack stack = e.getKey();
				int val = e.getValue();
				Stack newStack = new Stack(c, stack);
				int newVal = val + 1;
				if (stack.next(c) != stack && (stack.next == null || stack.next(c) != stack.next) && (!newStacks.containsKey(newStack) || newStacks.get(newStack) > newVal)) {
					newStacks.put(newStack, newVal);
				}
				newStack = stack.next(c);
				newVal = val;
				if (newStack != null && (!newStacks.containsKey(newStack) || newStacks.get(newStack) > newVal)) {
					newStacks.put(newStack, newVal);
				}
			}
			stacks = newStacks;
		}
		int ans = Integer.MAX_VALUE;
		for (int val: stacks.values()) {
			ans = min(ans, val);
		}
		out.println(s.length() + 2 * ans);
	}
	
	static void solve() throws Exception {
		int tests = nextInt();
		for (int test = 1; test <= tests; test++) {
			out.print("Case #" + test + ": ");
			solveTest();
			System.out.print('.');
		}
	}

	public static void main(String[] args) throws Exception {
		Locale.setDefault(Locale.US);
		System.out.print("Enter filename: ");
		System.out.flush();
		String filename = new BufferedReader(new InputStreamReader(System.in)).readLine();
		in = new BufferedReader(new InputStreamReader(
			new FileInputStream(new File(filename + ".in"))));
		out = new PrintWriter(new BufferedWriter(new OutputStreamWriter(
			new FileOutputStream(new File(filename + ".out")))));
		solve();
		in.close();
		out.close();
	}
	
	static String next() throws IOException {
		while (tok == null || !tok.hasMoreTokens()) {
			tok = new StringTokenizer(in.readLine());
		}
		return tok.nextToken();
	}
	
	static int nextInt() throws IOException {
		return parseInt(next());
	}
	
	static long nextLong() throws IOException {
		return parseLong(next());
	}
	
	static double nextDouble() throws IOException {
		return parseDouble(next());
	}
	
	static BigInteger nextBigInt() throws IOException {
		return new BigInteger(next());
	}
}