package q3;

import java.util.HashSet;
import java.util.LinkedList;
import java.util.Set;

public class BoardState {
	
	public static class Position {
		@Override
		public int hashCode() {
			final int prime = 31;
			int result = 1;
			result = prime * result + col;
			result = prime * result + row;
			return result;
		}

		@Override
		public boolean equals(Object obj) {
			if (this == obj)
				return true;
			if (obj == null)
				return false;
			if (getClass() != obj.getClass())
				return false;
			Position other = (Position) obj;
			if (col != other.col)
				return false;
			if (row != other.row)
				return false;
			return true;
		}

		public Position(int row, int col) {
			super();
			this.row = row;
			this.col = col;
		}

		public final int row, col;
		
	}
	
	private final int R, C;
	private Set<Position> mines = new HashSet<>();
	
	public BoardState(int r, int c) {
		super();
		R = r;
		C = c;
	}
	
	public BoardState(BoardState bs) {
		this(bs.R, bs.C);
		mines.addAll(bs.mines);
	}
	
	public int mineCount() {
		return mines.size();
	}
	
	public void addMine(int r, int c) {
		mines.add(new Position(r,c));
	}
	
	public boolean hasMine(int r, int c) {
		return mines.contains(new Position(r,c));
	}
	
	public boolean click(int r, int c) {
		int[][] board = new int[R][C];
		for(int i=0;i<R;i++) {
			for(int j=0;j<C;j++) {
				board[i][j]=0;
			}
		}
		
		//Build board
		for(Position p : mines) {
			board[p.row][p.col] = 10;
			for(int i=-1;i<=1;i++) {
				for(int j=-1;j<=1;j++) {
					if(i!=0||j!=0) {
						int nr=p.row+i;
						int nc=p.col+j;
						if (nr>=0 && nr<R && nc>=0 && nc<C) {
							board[nr][nc]++;
						}
					}
				}
			}
		}
		
		//Check
		if(board[r][c]==0) {
			boolean mask[][] = new boolean[R][C];
			for(int i=0;i<R;i++) {
				for(int j=0;j<C;j++){
					mask[i][j]=true;
				}
			}
			LinkedList<Position> queue = new LinkedList<>();
			queue.add(new Position(r,c));
			while(!queue.isEmpty()) {
				Position p = queue.removeFirst();
				if(board[p.row][p.col]<10)
					mask[p.row][p.col]=false;
				if (board[p.row][p.col] == 0) {
					for(int i=-1;i<=1;i++) {
						for(int j=-1;j<=1;j++) {
							if(i!=0||j!=0) {
								int nr=p.row+i;
								int nc=p.col+j;
								if (nr>=0 && nr<R && nc>=0 && nc<C && mask[nr][nc]) {
									queue.add(new Position(nr,nc));
								}
							}
						}
					}
				}
			}
			
			for(int i=0;i<R;i++) {
				for(int j=0;j<C;j++){
					if(mask[i][j] && board[i][j]<10)
						return false;
				}
			}
			
			return true;
		}
		
		return false;
	}
}
