
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.BitSet;
import java.util.Formatter;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.Locale;
import java.util.Objects;
import java.util.Queue;

/**
 *
 * @author edemairy
 */
public class Main {

	private static class Pair {

		public BitSet bs;
		public int depth;

		private Pair(BitSet bs, int d) {
			this.bs = bs;
			this.depth = d;
		}

		public static Pair of(BitSet bs, int d) {
			Pair result = new Pair(bs, d);
			return result;
		}

		@Override
		public int hashCode() {
			return Objects.hash(bs, depth);
		}

		@Override
		public boolean equals(Object obj) {
			if (this == obj) {
				return true;
			}
			if (obj == null) {
				return false;
			}
			if (getClass() != obj.getClass()) {
				return false;
			}
			final Pair other = (Pair) obj;
			if (this.depth != other.depth) {
				return false;
			}
			if (!Objects.equals(this.bs, other.bs)) {
				return false;
			}
			return true;
		}
		@Override
		public String toString() {
			return "("+bs+":"+depth+")";
		}
	}
	private HashSet<BitSet> alreadySeen;

	private int nbTC;
	private StringBuilder result = new StringBuilder();

	private static class EndException extends RuntimeException {
	}

	public void run() throws IOException {
		//        Scanner scanner = new Scanner(System.in);
		BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
		nbTC = readInt(reader);
//         nbTC = Integer.MAX_VALUE;
//        scanner.nextLine();
		try {
			for (int tc = 1; tc <= nbTC; ++tc) {
				result.append(String.format("Case #%d: ", tc));
				result.append(oneTestCase(reader));
				result.append('\n');
			}
		} catch (EndException e) {
		}
		System.out.print(result);
	}

	/**
	 * @param args the command line arguments
	 */
	public static void main(String[] args) throws IOException {
		Main main = new Main();
		main.run();
	}

	private StringBuilder oneTestCase(BufferedReader reader) throws IOException {
		alreadySeen = new HashSet<BitSet>();
		Formatter formatter = new Formatter(Locale.ENGLISH);
		StringBuilder output = new StringBuilder();
		String currentLine = reader.readLine();
		String[] parts = currentLine.split(" ");
		int K = Integer.parseInt(parts[1]);
		int width = parts[0].length();
		BitSet bs = new BitSet(width);
		for (int cbs = 0; cbs < width; cbs++) {
			bs.set(cbs, parts[0].charAt(cbs) == '+');
		}
		Queue<Pair> queue = new LinkedList<Pair>();
		queue.add(Pair.of(bs, 0));
		boolean resultFound = false;
		while (!queue.isEmpty() && !resultFound) {
			Pair element = queue.poll();
			alreadySeen.add(element.bs);
//			System.err.println(alreadySeen);
//			System.err.println(queue);
			if (element.bs.cardinality() == width) {
				output.append(element.depth);
				resultFound = true;
			} else {
				for (int k = 0; k + K <= width; k++) {
					BitSet newbs = (BitSet) element.bs.clone();
					newbs.flip(k, k + K);
					if (!alreadySeen.contains(newbs)) {
						queue.add(Pair.of(newbs, element.depth + 1));
					}
				}
			}
		}
		if (!resultFound) {
			output.append("IMPOSSIBLE");
		}
//        for (int i = 0; i < 5; ++i) {
//            formatter.format("%3d", n[i]);
//        }

		output.append(formatter.out());
		return output;
	}

	private int readInt(BufferedReader reader) throws IOException {
		int r = 0;
		boolean positive = true;
		char currentChar = (char) reader.read();

		while ((currentChar == ' ') || (currentChar == '\n')) {
			currentChar = (char) reader.read();
		}
		if (currentChar == (char) -1) {
			throw new IOException("end of stream");
		}
		if (currentChar == '-') {
			positive = false;
			currentChar = (char) reader.read();
		}
		while ((currentChar >= '0') && (currentChar <= '9')) {
			r = r * 10 + currentChar - '0';
			currentChar = (char) reader.read();
		}
		if (positive) {
			return r;
		} else {
			return -r;
		}
	}

	private char readChar(BufferedReader reader) throws IOException {
		return (char) reader.read();
	}
}
