import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Deque;
import java.util.Iterator;
import java.util.List;
import java.util.SortedSet;
import java.util.TreeSet;

import com.google.common.base.Joiner;
import com.google.common.base.Objects;
import com.google.common.collect.HashMultiset;
import com.google.common.collect.Multiset;

public class Treasure {

    private BufferedReader reader;

    public static void main(final String[] args) throws Exception {
        new Treasure().run();
    }

    public void run() throws Exception {
        reader = new BufferedReader(new InputStreamReader(System.in));
        final int cases = Integer.valueOf(reader.readLine());
        for (int i = 1; i <= cases; i++) {
            doRun(i);
        }
    }

    private void doRun(final int i) throws Exception {
        final Multiset<Integer> heldKeys = HashMultiset.create();
        final SortedSet<Chest> remainingChests = new TreeSet<Chest>();
        final Deque<Chest> stack = new ArrayDeque<Chest>();

        final String[] line2 = reader.readLine().split(" ");
        final int numHeldKeys = Integer.valueOf(line2[0]);
        final int numChests = Integer.valueOf(line2[1]);
        final String[] keysStrings = reader.readLine().split(" ");

        for (final String keyString : keysStrings) {
            heldKeys.add(Integer.valueOf(keyString));
        }

        if (keysStrings.length != numHeldKeys) {
            throw new AssertionError("keyStrings="
                    + Arrays.toString(keysStrings));
        }

        for (int n = 1; n <= numChests; n++) {
            final String[] chestString = reader.readLine().split(" ");
            final Integer lockKeyType = Integer.valueOf(chestString[0]);
            final int numKeys = Integer.parseInt(chestString[1]);
            final Multiset<Integer> keys = HashMultiset.create();
            for (int k = 0; k < numKeys; k++) {
                keys.add(Integer.valueOf(chestString[k + 2]));
            }
            final Chest chest = new Chest(n, lockKeyType, keys);
            remainingChests.add(chest);
        }

        final Multiset<Integer> totalKeysAvailable = HashMultiset.create();
        final Multiset<Integer> totalLocksUnopenedByType = HashMultiset
                .create();
        for (final Chest chest : remainingChests) {
            totalKeysAvailable.addAll(chest.keys);
            totalLocksUnopenedByType.add(chest.lockKeyType);
        }

        System.err.println("Starting");
        System.err.println(remainingChests);
        System.err.println(heldKeys);

        for (final Chest chest : remainingChests) {
            if (totalKeysAvailable.count(chest.lockKeyType)
                    + heldKeys.count(chest.lockKeyType) < totalLocksUnopenedByType
                        .count(chest.lockKeyType)) {
                System.err.println("Supply did not meet demand! "
                        + chest.lockKeyType + ", "
                        + totalKeysAvailable.count(chest.lockKeyType) + ", "
                        + heldKeys.count(chest.lockKeyType) + ", "
                        + totalLocksUnopenedByType.count(chest.lockKeyType));
                System.out.println(String.format("Case #%d: IMPOSSIBLE", i));
                return;
            }
        }

        final boolean result = solveRecursively(remainingChests,
                HashMultiset.create(heldKeys), stack, totalLocksUnopenedByType);
        if (result) {
            final List<String> chestIds = new ArrayList<String>();
            final Iterator<Chest> it = stack.descendingIterator();

            final Multiset<Integer> verify = HashMultiset.create(heldKeys);
            int c = 0;
            while (it.hasNext()) {
                final Chest chest = it.next();
                chestIds.add(String.valueOf(chest.chestId));
                if (!verify.remove(chest.lockKeyType)) {
                    throw new AssertionError();
                }
                verify.addAll(chest.keys);
                c++;
            }
            if (c != numChests) {
                throw new AssertionError();
            }
            final String chestIdsString = Joiner.on(" ").join(chestIds);
            System.out
                    .println(String.format("Case #%d: %s", i, chestIdsString));
        } else {
            System.out.println(String.format("Case #%d: IMPOSSIBLE", i));
        }

    }

    long i = 0;

    private boolean solveRecursively(final SortedSet<Chest> remainingChests,
            final Multiset<Integer> heldKeys, final Deque<Chest> stack,
            final Multiset<Integer> totalLocksUnopenedByType) {

        i++;
        if (i % 10000 == 0) {
            System.err.println(i);
        }
        System.err.println(stack);
        System.err.println(remainingChests);
        System.err.println(heldKeys);

        if (remainingChests.isEmpty()) {
            // Success!!
            return true;
        }

        for (final Multiset.Entry<Integer> e : totalLocksUnopenedByType
                .entrySet()) {
            boolean hasSelfLoop = false;
            int numLockOnly = 0;
            for (final Chest chest : remainingChests) {
                int numKeys = chest.keys.count(e.getElement());
                if (numKeys == 1) {
                    if (chest.lockKeyType == e.getElement()) {
                        System.err.println("Lock key type: "
                                + chest.lockKeyType + ", chest = " + chest);
                        hasSelfLoop = true;
                        continue;
                    } else {
                        hasSelfLoop = false;
                        break;
                    }
                } else if (numKeys > 1) {
                    hasSelfLoop = false;
                    break;
                } else {
                    if (chest.lockKeyType == e.getElement()) {
                        numLockOnly++;
                    }
                }
            }

            if (hasSelfLoop
                    && (numLockOnly > heldKeys.count(e.getElement()) || heldKeys
                            .count(e.getElement()) == 0)) {
                System.err.println("Had self loops");
                return false;
            }
        }

        final SortedSet<Chest> child = new TreeSet<Chest>(remainingChests);

        for (final Chest chest : remainingChests) {

            // System.err.println(chest);
            if (heldKeys.count(chest.lockKeyType) < 1) {
                // Missing the key
                continue;
            }

            // if (heldKeys.count(chest.lockKeyType)) {
            //
            // }

            // TODO: Sanity checks

            child.remove(chest);
            heldKeys.remove(chest.lockKeyType);
            stack.push(chest);
            heldKeys.addAll(chest.keys);
            totalLocksUnopenedByType.remove(chest.lockKeyType);

            // Try it
            final boolean result = solveRecursively(child, heldKeys, stack,
                    totalLocksUnopenedByType);
            if (result) {
                return true;
            }

            totalLocksUnopenedByType.add(chest.lockKeyType);
            heldKeys.removeAll(chest.keys);
            stack.pop();
            heldKeys.add(chest.lockKeyType);
            child.add(chest);
        }

        // No luck
        return false;
    }

    private class Chest implements Comparable<Chest> {
        private final int chestId;
        private final Integer lockKeyType;
        private final Multiset<Integer> keys;

        public Chest(final int chestId, final Integer lockKeyType,
                Multiset<Integer> keys) {
            this.chestId = chestId;
            this.lockKeyType = lockKeyType;
            this.keys = keys;
        }

        /**
         * {@inheritDoc}
         */
        @Override
        public int compareTo(final Chest that) {

            if (this.chestId < that.chestId) {
                return -1;
            }

            if (this.chestId == that.chestId) {
                return 0;
            }

            return 1;
        }

        public boolean equals(final Object that) {
            return (that instanceof Chest)
                    && (this.chestId == ((Chest) that).chestId);
        }

        public String toString() {
            return Objects.toStringHelper(this).add("chestId", chestId)
                    .add("lockKeyType", lockKeyType).add("keys", keys)
                    .toString();
        }
    }
}