import java.util.*;
import java.io.*;
public class CSmall
{
	public static ArrayList<Edge>[] adj;
	public static int source;
	public static int sink;
	public static int[] dist;
	public static boolean[] blocked;
	
	public static void main(String[] args) throws Exception
	{
//		Scanner in = new Scanner(System.in);
		Scanner in = new Scanner(new File("c-small-attempt0.in"));
		PrintWriter out = new PrintWriter(new FileWriter(new File("csmallattempt0.out")));
		
		int t = in.nextInt();
		for(int x = 0; x < t; x++)
		{
			int w = in.nextInt();
			int h = in.nextInt();
			int b = in.nextInt();
			
			int[][] river = new int[w][h];
			for(int y = 0; y < b; y++)
			{
				int x0 = in.nextInt();
				int y0 = in.nextInt();
				int x1 = in.nextInt();
				int y1 = in.nextInt();
				
				for(int z = x0; z <= x1; z++)
				{
					for(int a = y0; a <= y1; a++)
					{
						river[z][a] = 1;
					}
				}
			}
			
			adj = new ArrayList[2 * w * h + 2];
			for(int c = 0; c < adj.length; c++)
			{
				adj[c] = new ArrayList<Edge>();
			}
			
			source = 2 * w * h;
			sink = 2 * w * h + 1;
			
			int[] dr = {1, 0, -1, 0};
			int[] dc = {0, 1, 0, -1};
			
			for(int d = 0; d < river.length; d++)
			{
				for(int e = 0; e < river[0].length; e++)
				{
					if(river[d][e] == 0)
					{
						add(convert(d, e, h), convert(d, e, h) + w * h, 1);
						
						if(e == 0)
						{
							add(source, convert(d, e, h), 1);
						}
						if(e == h - 1)
						{
							add(convert(d, e, h) + w * h, sink, 1);
						}
						
						for(int f = 0; f < dr.length; f++)
						{
							int nr = d + dr[f];
							int nc = e + dc[f];
							
							if(nr >= 0 && nr < river.length && nc >= 0 && nc < river[0].length && river[nr][nc] == 0)
							{
								add(convert(d, e, h) + w * h, convert(nr, nc, h), 1);
							}
						}
					}
				}
			}
			
			System.out.println(x);
			out.println("Case #" + (x + 1) + ": " + dinic());
		}
		
		out.close();
	}
	
	public static int convert(int r, int c, int h)
	{
		return r * h + c;
	}
	
	public static void add(int a, int b, int cap)
	{
		Edge e1 = new Edge(b, cap);
		Edge e2 = new Edge(a, 0);
		e1.rev = e2;
		e2.rev = e1;
		adj[a].add(e1);
		adj[b].add(e2);
	}
	
	public static int dinic()
	{
		int result = 0;
		
		dist = new int[adj.length];
		
		while(getLevels())
		{
			blocked = new boolean[adj.length];
			result += blockingFlow(source, Integer.MAX_VALUE);
		}
		
		return result;
	}
	
	public static boolean getLevels()
	{
		Arrays.fill(dist, -1);
		ArrayDeque<Integer> queue = new ArrayDeque<Integer>();
		
		dist[source] = 0;
		queue.add(source);
		
		while(queue.size() > 0)
		{
			int node = queue.remove();
			
			for(Edge e : adj[node])
			{
				if(dist[e.end] == -1 && e.capacity > 0)
				{
					dist[e.end] = dist[node] + 1;
					queue.add(e.end);
				}
			}
		}
		
		return dist[sink] != -1;
	}
	
	public static int blockingFlow(int node, int flow)
	{
		if(flow == 0)
		{
			return 0;
		}
		else if(node == sink)
		{
			return flow;
		}
		else
		{
			int ret = 0;
			for(Edge e : adj[node])
			{
				if(!blocked[e.end] && dist[e.end] == dist[node] + 1 && e.capacity > 0)
				{
					int current = blockingFlow(e.end, Math.min(flow, e.capacity));
					e.capacity -= current;
					e.rev.capacity += current;
					flow -= current;
					ret += current;
				}
			}
			
			blocked[node] |= (flow > 0);
			
			return ret;
		}
	}
	
	static class Edge
	{
		int end;
		int capacity;
		Edge rev;
		
		public Edge(int e, int c)
		{
			end = e;
			capacity = c;
		}
	}
}
