package google.qualification;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;

public class TicTacToeTomek {

    static int T;
    static char[][][] INPUT;

    public enum Status {
        X_WON("X won"), O_WON("O won"), DRAW("Draw"), NOT_COMPLETED("Game has not completed");

        String msg;

        private Status(String msg) {
            this.msg = msg;
        }
    }

    public Status guessStatus(char[][] dashboard) {
        Status status = Status.DRAW;

        // check horizontal and vertical
        for (int i = 0; i < dashboard.length; i++) {
            status = check(dashboard[i]);
            if (status != null) {
                return status;
            }

            char[] col = new char[dashboard.length];
            for (int j = 0; j < dashboard.length; j++) {
                col[j] = dashboard[j][i];
            }
            status = check(col);
            if (status != null) {
                return status;
            }
        }

        // check diagonals
        char[] diag1 = new char[dashboard.length];
        char[] diag2 = new char[dashboard.length];
        for (int i = 0; i < dashboard.length; i++) {
            diag1[i] = dashboard[i][i];
            diag2[i] = dashboard[i][dashboard.length - i - 1];
        }
        status = check(diag1);
        if (status != null) {
            return status;
        }
        status = check(diag2);
        if (status != null) {
            return status;
        }

        // No one wins... check for empty spaces...
        for (int i = 0; i < dashboard.length; i++) {
            for (int j = 0; j < dashboard.length; j++) {
                if (dashboard[i][j] == '.') {
                    return Status.NOT_COMPLETED;
                }
            }
        }

        return Status.DRAW;
    }

    public Status check(char[] line) {
        int x_count = 0, o_count = 0, t_count = 0;
        for (int i = 0; i < line.length; i++) {
            switch (line[i]) {
                case 'X':
                    x_count++;
                    break;
                case 'O':
                    o_count++;
                    break;
                case 'T':
                    t_count++;
                    break;
            }
        }

        if (x_count + t_count == 4) {
            return Status.X_WON;
        }
        if (o_count + t_count == 4) {
            return Status.O_WON;
        }

        return null;
    }

    public static void main(String[] args) throws Exception {
        String file = "A-large.in";
        BufferedReader reader = null;
        try {
            InputStream stream = TicTacToeTomek.class.getClassLoader().getResourceAsStream(file);
            reader = new BufferedReader(new InputStreamReader(stream));

            T = Integer.parseInt(reader.readLine().trim());

            for (int i = 0; i < T; i++) {
                char[][] INPUT = new char[4][4];

                for (int j = 0; j < 4; j++) {
                    String line = reader.readLine().trim();
                    for (int k = 0; k < 4; k++) {
                        INPUT[j][k] = line.charAt(k);
                    }
                }
                Status result = new TicTacToeTomek().guessStatus(INPUT);
                System.out.println(String.format("Case #%s: %s", (i + 1), result.msg));

                reader.readLine(); // discard line
            }
        } finally {
            if (reader != null) {
                reader.close();
            }
        }
    }
}
