package round1a;

import com.google.common.base.Preconditions;
import org.w3c.dom.css.Rect;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.*;

/**
 * @author jhedwardyang
 */
public class P1 {

    static void printGrid(char[][] grid) {
        for (int row = 0; row < grid.length; ++row) {
            for (int col = 0; col < grid[0].length; ++col) {
                System.out.print(grid[row][col]);
            }
            System.out.println();
        }
    }

    static List<Map.Entry<Integer, Integer>> letters(char[][] grid) {
        List<Map.Entry<Integer, Integer>> lst = new ArrayList<>();
        for (int row = 0; row < grid.length; ++row) {
            for (int col = 0; col < grid[row].length; ++col) {
                if ('?' != grid[row][col]) {
                    lst.add(new AbstractMap.SimpleEntry<>(row, col));
                }
            }
        }
        return lst;
    }

    static int fillLeft(char[][] grid, int row, int col) {
        int counter = 0;
        if (col == 0) {
            return counter;
        }
        for (int cCol = col - 1; cCol >= 0; --cCol) {
            if ('?' == grid[row][cCol]) {
                grid[row][cCol] = grid[row][col];
                ++counter;
            } else {
                break;
            }
        }
        return counter;
    }

    static int fillRight(char[][] grid, int row, int col) {
        int counter = 0;
        if (col == grid[0].length - 1) {
            return counter;
        }
        for (int cCol = col + 1; cCol < grid[0].length; ++cCol) {
            if ('?' == grid[row][cCol]) {
                grid[row][cCol] = grid[row][col];
                ++counter;
            } else {
                break;
            }
        }
        return counter;
    }

    static void fillDown(char[][] grid, int row, int col, int left, int right) {
        if (row == grid.length) {
            return;
        }
        for (int cRow = row + 1; cRow < grid.length; ++cRow) {
            for (int cCol = left; cCol <= right; ++cCol) {
                if ('?' != grid[cRow][cCol]) {
                    return;
                }
            }
            for (int cCol = left; cCol <= right; ++cCol) {
                grid[cRow][cCol] = grid[row][col];
            }
        }
    }

    static void fillUp(char[][] grid, int row, int col, int left, int right) {
        if (row == 0) {
            return;
        }
        for (int cRow = row - 1; cRow >= 0; --cRow) {
            for (int cCol = left; cCol <= right; ++cCol) {
                if ('?' != grid[cRow][cCol]) {
                    return;
                }
            }
            for (int cCol = left; cCol <= right; ++cCol) {
                grid[cRow][cCol] = grid[row][col];
            }
        }
    }



    static void solve(final char[][] grid, List<Map.Entry<Integer, Integer>> lst) {
        lst.stream().forEach(entry -> {
            int row = entry.getKey();
            int col = entry.getValue();
            int left = col - fillLeft(grid, row, col);
            int right = col + fillRight(grid, row, col);
            fillDown(grid, row, col, left, right);
            fillUp(grid, row, col, left, right);
        });
    }

    public static void main(String[] args) throws FileNotFoundException {
        Preconditions.checkArgument(1 == args.length);

        Scanner in = new Scanner(new File(args[0]));
        int cases = in.nextInt();


        for (int i = 1; i <= cases; ++i) {
            int numRows = in.nextInt();
            int numCols = in.nextInt();
            char[][] grid = new char[numRows][numCols];
            for (int j = 0; j < numRows; ++j) {
                String row = in.next();
                for (int k = 0; k < numCols; ++k) {
                    grid[j][k] = row.charAt(k);
                }
            }

            List<Map.Entry<Integer, Integer>> letters = letters(grid);
            solve(grid, letters);


            // read it.
            // run it.
            System.out.println("Case #" + i + ":");
            printGrid(grid);
        }
    }
}
