import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Scanner;


public class Y2015_RQ_C {

    private static final String Q_NUM = "C";
    private static final InputType IN_TYPE = InputType.SMALL;
    private static final boolean DEBUG = false;

    private enum InputType {SAMPLE, SMALL, LARGE}

    private class Quaternion {
        char c; // 1, i, j, k
        boolean neg;

        public Quaternion(char c, boolean neg) {
            this.c = c;
            this.neg = neg;
        }

        public boolean isOne() {
            return c == '1';
        }
        public boolean isLetter() {
            return c != '1';
        }
        public boolean isPositive() {
            return !neg;
        }
        public boolean isNegative() {
            return neg;
        }

        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            Quaternion that = (Quaternion) o;
            if (c != that.c) return false;
            return neg == that.neg;
        }
        public int hashCode() {
            int result = (int) c;
            result = 31 * result + (neg ? 1 : 0);
            return result;
        }

        public Quaternion multiply(char c0) {
            char newC = 'z';
            boolean newNeg = false;
            if (c == c0) {
                newC = '1';
                if (c == '1')
                    newNeg = false;
                else
                    newNeg = true;
            }
            else if (c == '1' && c0 != '1') {
                newC = c0;
                newNeg = false;
            }
            else if (c != '1' && c0 == '1') {
                newC = c;
                newNeg = false;
            }
            else if (c == 'i' && c0 == 'j') {
                newC = 'k';
                newNeg = false;
            }
            else if (c == 'i' && c0 == 'k') {
                newC = 'j';
                newNeg = true;
            }
            else if (c == 'j' && c0 == 'i') {
                newC = 'k';
                newNeg = true;
            }
            else if (c == 'j' && c0 == 'k') {
                newC = 'i';
                newNeg = false;
            }
            else if (c == 'k' && c0 == 'i') {
                newC = 'j';
                newNeg = false;
            }
            else if (c == 'k' && c0 == 'j') {
                newC = 'i';
                newNeg = true;
            } // should have included all cases
            else
                System.err.println("ERROR in multiply()");

            return new Quaternion(newC, newNeg ^ neg);
        }

        public boolean isI() {
            return c == 'i' && neg == false;
        }
        public boolean isJ() {
            return c == 'j' && neg == false;
        }
        public boolean isK() {
            return c == 'k' && neg == false;
        }
    }

    private Quaternion calculate(String s) {
        Quaternion q = new Quaternion('1', false);
        for (char c : s.toCharArray())
            q = q.multiply(c);
        return q;
    }

    private String solve(Scanner sc, int nCase) {
        String answerNO  = "Case #" + (nCase + 1) + ": NO";
        String answerYES = "Case #" + (nCase + 1) + ": YES";
        int L = sc.nextInt();
        int X = sc.nextInt();
        sc.nextLine();
        String s = sc.nextLine().trim(); // s.length == L
        Quaternion ql = calculate(s);
        if (ql.isLetter() && X % 4 != 2)
            return answerNO;
        else if (ql.isOne() && ql.isPositive())
            return answerNO;
        else if (ql.isOne() && ql.isNegative() && X % 2 == 0)
            return answerNO;
        else {
            StringBuilder sb = new StringBuilder();
            for (int i = 0; i < X; i++)
                sb.append(s);
            String sx = sb.toString(); // the whole string - length X * L
            char[] c = sx.toCharArray();
            Quaternion q1 = new Quaternion('1', false); // look for i
            for (int p1 = 0; p1 < c.length - 2; p1++) {
                q1 = q1.multiply(c[p1]);
                if (q1.isI()) {
                    Quaternion q2 = new Quaternion('1', false); // look for j
                    for (int p2 = p1 + 1; p2 < c.length - 1; p2++) {
                        q2 = q2.multiply(c[p2]);
                        if (q2.isJ()) {
                            Quaternion q3 = new Quaternion('1', false); // look for k
                            for (int p3 = p2 + 1; p3 < c.length; p3++) {
                                q3 = q3.multiply(c[p3]);
                                if (q3.isK()) {
                                    return answerYES;
                                }
                            }
                        }
                    }
                }
            }
        }
        return answerNO;
    }

    public Y2015_RQ_C() throws IOException {
        String prefix = Q_NUM + '/' + Q_NUM;
        String file_in, file_out;
        if (IN_TYPE == InputType.SMALL) {
            file_in = prefix + "-small.in";
            file_out = prefix + "-small.out";
        } else if (IN_TYPE == InputType.LARGE) {
            file_in = prefix + "-large.in";
            file_out = prefix + "-large.out";
        } else {
            file_in = prefix + "ii";
            file_out = prefix + "oo0";
        }

        Scanner sc = new Scanner(new File(file_in));
        int T = sc.nextInt();
        sc.nextLine();

        StringBuilder solAll = new StringBuilder();

        for (int nCase = 0; nCase < T; nCase++) {
            solAll.append(solve(sc, nCase));
            solAll.append("\n");
        }

        String output = solAll.toString();
        System.out.println(output);
        BufferedWriter writer = new BufferedWriter(new FileWriter(file_out));
        writer.write(output);

        sc.close();
        writer.close();
    }

    public static void main(String[] args) throws IOException {
        new Y2015_RQ_C();
    }

}
