import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.*;


public class Y2016_RQ_B {

    private static final String Q_NUM = "B";
    private static final int INPUT_TYPE = 2;

    private String solve(Scanner sc, int caseNum) {
        char[] chars = sc.nextLine().trim().toCharArray();
        boolean[] arr = new boolean[chars.length];
        for (int i = 0; i < chars.length; i++) {
            arr[i] = chars[i] == '+';
        }

        PancakeStack initial = new PancakeStack(arr, 0);
        if (initial.allHappy()) {
            return "0";
        }

        Set<PancakeStack> seen = new HashSet<>();
        seen.add(initial);

        Queue<PancakeStack> queue = new LinkedList<PancakeStack>();
        queue.add(initial);

        while (!queue.isEmpty()) {
            PancakeStack parent = queue.poll();
            for (PancakeStack child : parent.children()) {
                if (child.allHappy()) {
                    return String.valueOf(child.getFlips());
                }
                if (seen.contains(child)) {
                    continue;
                }
                seen.add(child);
                queue.add(child);
            }
        }
        return "not found";
    }

    private class PancakeStack {
        private boolean[] happy;
        private int flips;
        private int hashCode;

        public PancakeStack(boolean[] happy, int flips) {
            this.happy = happy;
            this.flips = flips;
            this.hashCode = Arrays.hashCode(happy);
        }

        public boolean allHappy() {
            for (int i = 0; i < happy.length; i++) {
                if (!happy[i]) return false;
            }
            return true;
        }

        public List<PancakeStack> children() {
            int len = happy.length;
            List<PancakeStack> children = new ArrayList<>(len);
            for (int lift = 0; lift < len; lift++) {
                // "lift" is the index of the last one lifted, inclusive
                boolean[] arr = new boolean[len];
                for (int i = 0; i < len; i++) {
                    if (i > lift) {
                        arr[i] = happy[i];
                    } else {
                        arr[i] = !happy[lift - i];
                    }
                }
                PancakeStack child = new PancakeStack(arr, flips + 1);
                children.add(child);
            }
            return children;
        }

        public int getFlips() {
            return flips;
        }

        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            PancakeStack that = (PancakeStack) o;
            return hashCode == that.hashCode;
        }

        public int hashCode() {
            return hashCode;
        }

        public String toString() {
            return Arrays.toString(happy);
        }
    }

    public Y2016_RQ_B() throws IOException {
        String prefix = Q_NUM + '/' + Q_NUM;
        String file_in, file_out;
        if (INPUT_TYPE == 2) {
            file_in = prefix + "-small.in";
            file_out = prefix + "-small.out";
        } else if (INPUT_TYPE == 3) {
            file_in = prefix + "-large.in";
            file_out = prefix + "-large.out";
        } else {
            file_in = prefix + "ii";
            file_out = prefix + "oo0";
        }

        Scanner sc = new Scanner(new File(file_in));
        int T = sc.nextInt();
        sc.nextLine();

        StringBuilder solAll = new StringBuilder();

        for (int i = 0; i < T; i++) {
            int caseNum = i + 1;
            solAll.append("Case #" + caseNum + ": " + solve(sc, caseNum));
            solAll.append("\n");
        }

        String output = solAll.toString();
        System.out.println(output);
        BufferedWriter writer = new BufferedWriter(new FileWriter(file_out));
        writer.write(output);

        sc.close();
        writer.close();
    }

    public static void main(String[] args) throws IOException {
        new Y2016_RQ_B();
    }

}
