import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.*;


public class Y2015_RQ_B_search {

    private static final String Q_NUM = "B";
    private static final InputType IN_TYPE = InputType.SMALL;
    private static final boolean DEBUG = false;

    private enum InputType {SAMPLE, SMALL, LARGE}

    private class State {
        List<Integer> p;
        int cost;

        public State(List<Integer> p, int cost) {
            this.p = p;
            this.cost = cost;
        }

        public List<State> children() {
            List<State> children = new ArrayList<>();
            int cost = this.cost + 1;

            int last = p.size() - 1;
            int max = p.get(last);
            int part1 = max / 2;
            int part2 = max - part1;
            while (part1 > 1) {
                List<Integer> p = new ArrayList<>();
                p.addAll(this.p);
                p.remove(last);
                p.add(part1--);
                p.add(part2++);
                Collections.sort(p);
                children.add(new State(p, cost));
            }

            // add eat status
            List<Integer> p = new ArrayList<>();
            for (int pi : this.p) {
                if (pi - 1 > 0)
                    p.add(pi - 1);
            }
            children.add(new State(p, cost));

            return children;
        }

        public boolean isFinished() {
            for (int pi : p) {
                if (pi > 0)
                    return false;
            }
            return true;
        }
    }

    private String solve(Scanner sc, int nCase) {
        int D = sc.nextInt();
        List<Integer> P = new ArrayList<>(D);
        for (int i = 0; i < D; i++)
            P.add(sc.nextInt());
        Collections.sort(P);

        State initial = new State(P, 0);
        Queue<State> queue = new LinkedList<>();
        queue.add(initial);
        while (!queue.isEmpty()) {
            State state = queue.poll();
            if (state.isFinished())
                return "Case #" + (nCase + 1) + ": "+state.cost;
            queue.addAll(state.children());
        }

        return "EEEEEEEEEEEEEEE";
    }

    public Y2015_RQ_B_search() throws IOException {
        String prefix = Q_NUM + '/' + Q_NUM;
        String file_in, file_out;
        if (IN_TYPE == InputType.SMALL) {
            file_in = prefix + "-small.in";
            file_out = prefix + "-small.out";
        } else if (IN_TYPE == InputType.LARGE) {
            file_in = prefix + "-large.in";
            file_out = prefix + "-large.out";
        } else {
            file_in = prefix + "ii";
            file_out = prefix + "oo0";
        }

        Scanner sc = new Scanner(new File(file_in));
        int T = sc.nextInt();
        sc.nextLine();

        StringBuilder solAll = new StringBuilder();

        for (int nCase = 0; nCase < T; nCase++) {
            solAll.append(solve(sc, nCase));
            solAll.append("\n");
        }

        String output = solAll.toString();
        System.out.println(output);
        BufferedWriter writer = new BufferedWriter(new FileWriter(file_out));
        writer.write(output);

        sc.close();
        writer.close();
    }

    public static void main(String[] args) throws IOException {
        new Y2015_RQ_B_search();
    }

}
