package com.eevoskos.codejam;

import java.io.BufferedReader;
import java.io.InputStreamReader;

public class TicTacToeTomek {

	private static final int STATUS_X_WON = 1;
	private static final int STATUS_O_WON = 2;
	private static final int STATUS_DRAW = 3;
	private static final int STATUS_NOT_COMPLETE = 4;

	class Board {
		char[][] board;

		Board() {
			board = new char[4][4];
		}

		void setRow(int i, char[] row) {
			board[i] = row;
		}

		char[] getRow(int i) {
			//System.out.println("Row " + i + ": [" + String.copyValueOf(board[i]) + "]");
			return board[i];
		}

		char[] getColumn(int i) {
			char[] column = new char[4];
			column[0] = board[0][i];
			column[1] = board[1][i];
			column[2] = board[2][i];
			column[3] = board[3][i];
			return column;
		}

		char[] getDiagonalLeft() {
			char[] diag = new char[4];
			for (int i = 0; i < 4; i++) {
				diag[i] = board[i][i];
			}
			return diag;
		}

		char[] getDiagonalRight() {
			char[] diag = new char[4];
			for (int i = 0; i < 4; i++) {
				diag[i] = board[i][3 - i];
			}
			return diag;
		}
	}

	class Four {
		char[] four;
		int numX;
		int numO;
		int numT;
		int numE;

		Four(char[] four) {
			this.four = four;
			this.numX = 0;
			this.numO = 0;
			this.numT = 0;
			this.numE = 0;
			calc();
		}

		void calc() {
			for (int i = 0; i < four.length; i++) {
				char c = four[i];
				switch (c) {
				case 'X':
					numX++;
					break;
				case 'O':
					numO++;
					break;
				case 'T':
					numT++;
					break;
				case '.':
					numE++;
					break;
				default:
					break;
				}
			}
		}

		int status() {
			if (numX == 4 || (numX == 3 && numT == 1)) {
				return STATUS_X_WON;
			} else if (numO == 4 || (numO == 3 && numT == 1)) {
				return STATUS_O_WON;
			} else if (numE > 0) {
				return STATUS_NOT_COMPLETE;
			} else {
				return STATUS_DRAW;
			}
		}
	}

	Board board;

	public TicTacToeTomek() {
		board = new Board();
	}

	public void printBoard() {
		for (int i = 0; i < 4; i++) {
			System.out.println(board.getRow(i));
		}
	}

	int getStatus() {
		int countIncomplete = 0;

		// Calculate rows
		for (int i = 0; i < 4; i++) {
			Four four = new Four(board.getRow(i));
			int stat = four.status();
			if (stat == STATUS_X_WON) {
				return STATUS_X_WON;
			} else if (stat == STATUS_O_WON) {
				return STATUS_O_WON;
			} else if (stat == STATUS_NOT_COMPLETE) {
				countIncomplete++;
			}
		}

		// Calculate columns
		for (int i = 0; i < 4; i++) {
			Four four = new Four(board.getColumn(i));
			int stat = four.status();
			if (stat == STATUS_X_WON) {
				return STATUS_X_WON;
			} else if (stat == STATUS_O_WON) {
				return STATUS_O_WON;
			} else if (stat == STATUS_NOT_COMPLETE) {
				countIncomplete++;
			}
		}

		// Calculate diagonals
		Four diagL = new Four(board.getDiagonalLeft());
		int stat = diagL.status();
		if (stat == STATUS_X_WON) {
			return STATUS_X_WON;
		} else if (stat == STATUS_O_WON) {
			return STATUS_O_WON;
		} else if (stat == STATUS_NOT_COMPLETE) {
			countIncomplete++;
		}

		// Calculate diagonals
		Four diagR = new Four(board.getDiagonalRight());
		stat = diagR.status();
		if (stat == STATUS_X_WON) {
			return STATUS_X_WON;
		} else if (stat == STATUS_O_WON) {
			return STATUS_O_WON;
		} else if (stat == STATUS_NOT_COMPLETE) {
			countIncomplete++;
		}

		if (countIncomplete > 0) {
			return STATUS_NOT_COMPLETE;
		} else {
			return STATUS_DRAW;
		}
	}

	String getMessageForStatus(int status) {
		switch (status) {
		case STATUS_X_WON:
			return "X won";
		case STATUS_O_WON:
			return "O won";
		case STATUS_DRAW:
			return "Draw";
		case STATUS_NOT_COMPLETE:
			return "Game has not completed";
		default:
			return "Error!";
		}
	}

	public static void main(String... args) {
		try {
			// Console reader
			BufferedReader c = new BufferedReader(new InputStreamReader(
					System.in));

			// Number of test cases
			int T = Integer.valueOf(c.readLine());

			// Do, for each test case
			for (int i = 0; i < T; i++) {
				// Create game
				TicTacToeTomek game = new TicTacToeTomek();

				// Read the board (4 next rows)
				for (int r = 0; r < 4; r++) {
					String row = c.readLine();
					game.board.setRow(r, row.toCharArray());
				}
				
				// Read empty line
				c.readLine();

				// Get status
				int status = game.getStatus();

				// Print the game status message
				System.out.println("Case #" + (i + 1) + ": "
						+ game.getMessageForStatus(status));

			}

		} catch (Exception e) {
			e.printStackTrace();
		}
	}

}
