package TicTacToeTomek;

import java.io.IOException;

/**
 * @author Efe Karakus
 * @date: 4/13/13
 * @time: 11:27 AM
 */
public class TTTT {

    private class Meta {
        int leftCount = 0;
        int topCount = 0;
        int leftDiagonalCount = 0;
        int rightDiagonalCount = 0;
    }

    private class Square {
        char symbol;
        Meta xMeta;
        Meta oMeta;

        public Square(char s) {
            symbol = s;
            xMeta = new Meta();
            oMeta = new Meta();

            if (s == 'T') {
                initXMeta();
                initOMeta();
            } else if (s == 'X') {
                initXMeta();
            } else if (s == 'O') {
                initOMeta();
            }
        }

        private void initXMeta() {
            xMeta.leftCount = 1;
            xMeta.topCount = 1;
            xMeta.leftDiagonalCount = 1;
            xMeta.rightDiagonalCount = 1;
        }

        private void initOMeta() {
            oMeta.leftCount = 1;
            oMeta.topCount = 1;
            oMeta.leftDiagonalCount = 1;
            oMeta.rightDiagonalCount = 1;
        }
    }

    private Square[][] board;
    private boolean isOver;
    private String message;
    private final int ROW_COUNT = 4;
    private final int COL_COUNT = 4;

    public TTTT() {
        board = new Square[ROW_COUNT][COL_COUNT];
        isOver = false;
        message = "Draw";
    }

    public void addSquare(int x, int y, char s) {
        board[x][y] = new Square(s);
        if (!isOver && s == '.') message = "Game has not completed";

        if (isValid(x, y-1)) { //left
            if (shouldUpdateMeta(board[x][y], board[x][y-1]) ) {
                updateMeta(board[x][y], board[x][y-1], 0);
            }
        }
        if (isValid(x-1, y)) { // top
            if ( shouldUpdateMeta(board[x][y], board[x-1][y]) ) {
                updateMeta(board[x][y], board[x-1][y], 1);
            }
        }
        if (isValid(x-1, y-1)) { // left diagonal
            if (shouldUpdateMeta(board[x][y], board[x - 1][y - 1]) ) {
                updateMeta(board[x][y], board[x-1][y-1], 2);
            }
        }
        if (isValid(x-1, y+1)) { // right diagonal
            if (shouldUpdateMeta(board[x][y], board[x - 1][y + 1]) ) {
                updateMeta(board[x][y], board[x-1][y+1], 3);
            }
        }
    }

    public String getMessage() {
        return message;
    }

    private boolean shouldUpdateMeta(Square mySquare, Square otherSquare) {
        if (mySquare.symbol == '.') return false;
        if (otherSquare.symbol == '.') return false;
        if (mySquare.symbol != 'T' && otherSquare.symbol != 'T') {
            if (mySquare.symbol != otherSquare.symbol) return false;
        }
        return true;
    }

    private void updateMeta (Square mySquare, Square otherSquare, int pos) {
        if (otherSquare.symbol == 'X') {
            if (pos == 0) {
                mySquare.xMeta.leftCount = otherSquare.xMeta.leftCount + 1;
                if (mySquare.xMeta.leftCount == 4) {
                    isOver = true;
                    message = "X won";
                }
            } else if (pos == 1) {
                mySquare.xMeta.topCount = otherSquare.xMeta.topCount + 1;
                if (mySquare.xMeta.topCount == 4) {
                    isOver = true;
                    message = "X won";
                }
            } else if (pos == 2) {
                mySquare.xMeta.leftDiagonalCount = otherSquare.xMeta.leftDiagonalCount + 1;
                if (mySquare.xMeta.leftDiagonalCount == 4) {
                    isOver = true;
                    message = "X won";
                }
            } else {
                mySquare.xMeta.rightDiagonalCount = otherSquare.xMeta.rightDiagonalCount + 1;
                if (mySquare.xMeta.rightDiagonalCount == 4) {
                    isOver = true;
                    message = "X won";
                }
            }

        } else if (otherSquare.symbol == 'O') {

            if (pos == 0) {
                mySquare.oMeta.leftCount = otherSquare.oMeta.leftCount + 1;
                if (mySquare.oMeta.leftCount == 4) {
                    isOver = true;
                    message = "O won";
                }
            } else if (pos == 1) {
                mySquare.oMeta.topCount = otherSquare.oMeta.topCount + 1;
                if (mySquare.oMeta.topCount == 4) {
                    isOver = true;
                    message = "O won";
                }
            } else if (pos == 2) {
                mySquare.oMeta.leftDiagonalCount = otherSquare.oMeta.leftDiagonalCount + 1;
                if (mySquare.oMeta.leftDiagonalCount == 4) {
                    isOver = true;
                    message = "O won";
                }
            } else {
                mySquare.oMeta.rightDiagonalCount = otherSquare.oMeta.rightDiagonalCount + 1;
                if (mySquare.oMeta.rightDiagonalCount == 4) {
                    isOver = true;
                    message = "O won";
                }
            }

        } else if (otherSquare.symbol == 'T') {
            if (mySquare.symbol == 'X') {
                if (pos == 0) {
                    mySquare.xMeta.leftCount = otherSquare.xMeta.leftCount + 1;
                    if (mySquare.xMeta.leftCount == 4) {
                        isOver = true;
                        message = "X won";
                    }
                } else if (pos == 1) {
                    mySquare.xMeta.topCount = otherSquare.xMeta.topCount + 1;
                    if (mySquare.xMeta.topCount == 4) {
                        isOver = true;
                        message = "X won";
                    }
                } else if (pos == 2) {
                    mySquare.xMeta.leftDiagonalCount = otherSquare.xMeta.leftDiagonalCount + 1;
                    if (mySquare.xMeta.leftDiagonalCount == 4) {
                        isOver = true;
                        message = "X won";
                    }
                } else {
                    mySquare.xMeta.rightDiagonalCount = otherSquare.xMeta.rightDiagonalCount + 1;
                    if (mySquare.xMeta.rightDiagonalCount == 4) {
                        isOver = true;
                        message = "X won";
                    }
                }
            } else {

                if (pos == 0) {
                    mySquare.oMeta.leftCount = otherSquare.oMeta.leftCount + 1;
                    if (mySquare.oMeta.leftCount == 4) {
                        isOver = true;
                        message = "O won";
                    }
                } else if (pos == 1) {
                    mySquare.oMeta.topCount = otherSquare.oMeta.topCount + 1;
                    if (mySquare.oMeta.topCount == 4) {
                        isOver = true;
                        message = "O won";
                    }
                } else if (pos == 2) {
                    mySquare.oMeta.leftDiagonalCount = otherSquare.oMeta.leftDiagonalCount + 1;
                    if (mySquare.oMeta.leftDiagonalCount == 4) {
                        isOver = true;
                        message = "O won";
                    }
                } else {
                    mySquare.oMeta.rightDiagonalCount = otherSquare.oMeta.rightDiagonalCount + 1;
                    if (mySquare.oMeta.rightDiagonalCount == 4) {
                        isOver = true;
                        message = "O won";
                    }
                }

            }
        }
    }

    private boolean isValid(int x, int y) {
        if (x < 0 || x >= ROW_COUNT) return false;
        if (y < 0 || y >= COL_COUNT) return false;
        if (board[x][y] == null)     return false;
        return true;
    }

    public static void main(String[] args) throws IOException {
        String path = "/Users/efekarakus/Code-Jam/src/TicTacToeTomek/";
        String inputName = "A-large.in";
        FileReader reader = new FileReader(path + inputName);
        FileOutput output = new FileOutput(path + "output.txt");

        int casesCount = Integer.parseInt(reader.readLine());

        for (int i = 0; i < casesCount; i++) {
            TTTT tttt = new TTTT();

            String firstRow = reader.readLine();
            String secondRow = reader.readLine();
            String thirdRow = reader.readLine();
            String fourthRow = reader.readLine();
            if (i != casesCount-1) reader.readLine();

            for (int j = 0; j < firstRow.length(); j++) {
                char s = firstRow.charAt(j);
                tttt.addSquare(0,j,s);
            }

            for (int j = 0; j < secondRow.length(); j++) {
                char s = secondRow.charAt(j);
                tttt.addSquare(1,j,s);
            }

            for (int j = 0; j < thirdRow.length(); j++) {
                char s = thirdRow.charAt(j);
                tttt.addSquare(2,j,s);
            }

            for (int j = 0; j < fourthRow.length(); j++) {
                char s = fourthRow.charAt(j);
                tttt.addSquare(3,j,s);
            }

            String msg = tttt.getMessage();
            output.write("Case #" + (i + 1) + ": " + msg + "\n");
        }
        output.close();
        reader.close();
    }
}
