package gcj2015.qualification;

import gcj2014.qualification.D_DeceitfulWar;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.Scanner;

public class C_Dijkstra {
	
	static class ConcurrentSolver {
		C_Dijkstra tests[];
		int index = 0;

		public ConcurrentSolver(C_Dijkstra[] tests) {
			this.tests = tests;
		}

		public void solve() {
			Thread thread[] = new Thread[2];
			for(int i=0; i<2; i++) {
				thread[i] = new Thread() {
					public void run() {
						C_Dijkstra test;
						while((test = getNextTest()) != null) {
							test.solve();
						}
					}
				};
				thread[i].start();
			}
			
			// Wait for thread to finish executing
			for(int i=0; i<2; i++) {
				try {
					thread[i].join();
				} catch (InterruptedException e) {
					e.printStackTrace();
				}
			}
		}
		
		public synchronized C_Dijkstra getNextTest() {
			if(index >= tests.length) {
				return null;
			}
			return tests[index++];
		}
	}
	
	public static void main(String args[]) throws FileNotFoundException {
		Scanner scanner = new Scanner(new File(args[0]));
		
		int T = scanner.nextInt();
		C_Dijkstra tests[] = new C_Dijkstra[T];
		for(int t=0; t<T; t++) {
			int L = scanner.nextInt();
			int X = scanner.nextInt();
			
			tests[t] = new C_Dijkstra(X, scanner.next());
		}
		
		new ConcurrentSolver(tests).solve();
		
		scanner.close();
		
		for(int t=0; t<T; t++) {
			System.out.println("Case #" + (t+1) + ": " + (tests[t].result ?"YES":"NO"));
		}
	}
	

	int letters[];
	Boolean result;
	
	public C_Dijkstra(int X, String str) {
		letters = buildLetters(X, str);
	}
	
	int[] buildLetters(int X, String str) {
		int letters[] = new int[X * str.length()];
		
		for(int i=0; i<str.length(); i++) {
			letters[i] = convert(str.charAt(i));
		}
		
		for(int x=1; x<X; x++) {
			int start = x*str.length();
			for(int i=0; i<str.length(); i++) {
				letters[start+i] = letters[i];
			}
		}
		
		return letters;
	}
	
	int convert(char c) {
		switch(c) {
		case'1': return 1;
		case'i': return I;
		case'j': return J;
		case'k': return K;
		}
		System.err.println("Incorrect quaternion: " + c);
		return -1;
	}
	
	void solve() {
		result = solveI(0);
	}
	
	boolean solveI(int i) {
		int a = 1;
		for(; i<letters.length-2; i++) {
			a = qmult(a, letters[i]);			
			if(a == I) {
				if(solveJ(i+1)) {
					return true;
				}
			}
		}
		return false;
	}
	
	boolean solveJ(int i) {
		int a = 1;
		for(; i<letters.length-1; i++) {
			a = qmult(a, letters[i]);			
			if(a == J) {
				if(solveK(i+1)) {
					return true;
				}
			}
		}
		return false;
	}
	
	boolean solveK(int i) {
		int a = letters[i++];
		for(; i<letters.length; i++) {
			a = qmult(a, letters[i]);			
		}
		return a == K;
	}
	
	
	static final int I = 2;
	static final int J = 3;
	static final int K = 4;
	static final int Q_MULT_TABLE[][] = {
		{0, 0, 0, 0, 0},
		{0, 1, I, J, K},
		{0, I,-1, K,-J},
		{0, J,-K,-1, I},
		{0, K, J,-I,-1}
	};
	
	int qmult(int a, int b) {
		if(a < 0) {
			return -qmult(-a, b);	
		}
		if(b < 0) {
			return -qmult(a, -b);
		}
		return Q_MULT_TABLE[a][b];
	}
	
	void testQmult() {
		testQmult(I, J, K);
		testQmult(J, I, -K);
		testQmult(I, I, -1);
		testQmult(I, K, -J);
	}

	void testQmult(int a, int b, int r) {
		int actualR = qmult(a, b);
		if(actualR != r) {
			throw new Error("qmult test failed: " + convert(a) + " * " + convert(b) + " = " + convert(actualR) + " (expected: " + convert(r) + ")");
		}
	}
	
	String convert(int q) {
		if(q < 0) {
			return "-" + convert(-q);
		}
		switch(q) {
		case 1: return "1";
		case I: return "i";
		case J: return "j";
		case K: return "k";
		}
		return "?";
	}
}
