import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.*;

/**
 * @author Egor Kulikov (kulikov@devexperts.com)
 */
public class Task implements Runnable {
    private static final String TASK_ID = "watersheds";
    private static final String IN_FILE = TASK_ID + ".in";
    private static final String OUT_FILE = TASK_ID + ".out";
	private static final int[] dx = {-1, 0, 0, 1};
	private static final int[] dy = {0, -1, 1, 0};

    private Scanner in;
    private PrintWriter out;
    private int t, h, w;
    private int[][] a;
    private char[][] ans;
	private int[][] c;

	private int getColor(int x1, int y1) {
		if (c[x1][y1] == x1 * w + y1)
			return x1 * w + y1;
		return c[x1][y1] = getColor(c[x1][y1] / w, c[x1][y1] % w);
	}

    private void init() {
        try {
            in = new Scanner(new File(IN_FILE));
        } catch (FileNotFoundException ignored) {}
        try {
            out = new PrintWriter(OUT_FILE);
        } catch (FileNotFoundException ignored) {}
    }

    private void read() {
        h = in.nextInt();
        w = in.nextInt();
        a = new int[h][w];
        for (int i = 0; i < h; i++) {
            for (int j = 0; j < w; j++)
                a[i][j] = in.nextInt();
        }
    }

    private void solve() {
		c = new int[h][w];
		for (int i = 0; i < h; i++) {
			for (int j = 0; j < w; j++) {
				c[i][j] = w * i + j;
			}
		}
		for (int i = 0; i < h; i++) {
			for (int j = 0; j < w; j++) {
				int bx = i;
				int by = j;
				for (int k = 0; k < 4; k++) {
					int nx = i + dx[k];
					int ny = j + dy[k];
					if (nx >= 0 && nx < h && ny >= 0 && ny < w && a[nx][ny] < a[bx][by]) {
						bx = nx;
						by = ny;
					}
				}
				c[i][j] = bx * w + by;
			}
		}
		char[] s = new char[w * h];
		ans = new char[h][w];
		char cur = 'a';
		for (int i = 0; i < h; i++) {
			for (int j = 0; j < w; j++) {
				if (s[getColor(i, j)] == 0) {
					s[getColor(i, j)] = cur;
					ans[i][j] = cur++;
				} else
					ans[i][j] = s[getColor(i, j)];
			}
		}
    }

    private void write() {
        out.println("Case #" + t + ":");
        for (char[] r : ans) {
            out.print(r[0]);
            for (int i = 1; i < r.length; i++)
                out.print(" " + r[i]);
			out.println();
        }
    }

    public void run() {
        init();
        int n;
        n = in.nextInt();
        for (t = 1; t <= n; t++) {
            System.out.println("Test " + t);
            read();
            solve();
            write();
        }
        out.close();
    }
    public static void main(String[] args) {
        new Thread(new Task()).start();
    }
}
