import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Scanner;
import java.util.Set;

public class C_2 {
	public static void main(String[] args) throws FileNotFoundException {
		Scanner scan = new Scanner(new File("C-small-attempt0.in"));
		PrintWriter out = new PrintWriter("out.txt");
		int cases = scan.nextInt();
		for (int i = 0; i < cases; i++) {
			int rectangles = scan.nextInt();
			HashSet<Location> livePoints = new HashSet<Location>();
			for (int rect = 0; rect < rectangles; rect++) {
				int x1 = scan.nextInt();
				int y1 = scan.nextInt();
				int x2 = scan.nextInt();
				int y2 = scan.nextInt();

				for (int x = x1; x <= x2; x++)
					for (int y = y1; y <= y2; y++)
						livePoints.add(new Location(x, y));
			}

			GameOfLife gol = new GameOfLife(livePoints);
			int seconds = 0;
			while (gol.getNumberOfLiveCells() != 0) {
				gol.step();
				seconds++;
			}

			out.printf("Case #%d: %d%n", i + 1, seconds);
		}
		out.close();
	}

	public static class GameOfLife {
		private ActivesTracker activeCells;
		private HashSet<Location> liveCells;

		public GameOfLife(Set<Location> liveCells) {
			this.liveCells = new HashSet<Location>(liveCells);
			activeCells = new ActivesTracker();
			for (Location loc : liveCells)
				activeCells.activate(loc);
		}

		public int getNumberOfLiveCells() {
			return liveCells.size();
		}

		public boolean isAlive(int x, int y) {
			return isAlive(new Location(x, y));
		}

		public boolean isAlive(Location loc) {
			return liveCells.contains(loc);
		}

		public void reverseState(Location loc) {
			if (liveCells.contains(loc)) {
				liveCells.remove(loc);
			} else {
				liveCells.add(loc);
			}
			activeCells.activate(loc);
		}

		public void step() {
			List<Location> changes = new ArrayList<Location>();

			for (Location loc : activeCells) {
				boolean west = isAlive(new Location(loc.getX() - 1, loc.getY()));
				boolean north = isAlive(new Location(loc.getX(), loc.getY() - 1));
				if (isAlive(loc)) {
					if (!west && !north) {
						changes.add(loc);
					}
				} else {
					if (west && north) {
						changes.add(loc);
					}
				}
			}

			activeCells.clear();

			for (Location loc : changes)
				reverseState(loc);
		}

		@Override
		public String toString() {
			return toString('O', '.');
		}

		public String toString(char live, char dead) {
			Iterator<Location> all = liveCells.iterator();
			if (!all.hasNext()) {
				return "";
			}
			Location current = all.next();
			int minX = current.getX(), maxX = minX;
			int minY = current.getY(), maxY = minY;
			while (all.hasNext()) {
				current = all.next();
				int x = current.getX(), y = current.getY();
				if (x < minX) {
					minX = x;
				} else if (x > maxX) {
					maxX = x;
				}
				if (y < minY) {
					minY = y;
				} else if (y > maxY) {
					maxY = y;
				}
			}

			StringBuilder result = new StringBuilder((maxX - minX + 2) * (maxY - minY + 1) - 1);
			for (int y = minY; y <= maxY; y++) {
				for (int x = minX; x <= maxX; x++) {
					if (isAlive(x, y)) {
						result.append(live);
					} else {
						result.append(dead);
					}
				}
				if (y != maxY) {
					result.append('\n');
				}
			}

			return result.toString();
		}
	}

	public static class Location {
		private static final long serialVersionUID = 1L;

		private int x, y;

		public Location(int x, int y) {
			this.x = x;
			this.y = y;
		}

		public int getX() {
			return x;
		}

		public int getY() {
			return y;
		}

		@Override
		public int hashCode() {
			final int PRIME = 31;
			int result = 3;
			result = PRIME * result + x;
			result = PRIME * result + y;
			return result;
		}

		@Override
		public String toString() {
			return "(" + x + ", " + y + ")";
		}

		@Override
		public boolean equals(Object obj) {
			if (this == obj) {
				return true;
			}
			if (obj == null || getClass() != obj.getClass()) {
				return false;
			}
			final Location other = (Location) obj;
			return x == other.x && y == other.y;
		}
	}

	public static class ActivesTracker implements Cloneable, Iterable<Location> {
		private Set<Location> activeCells;

		public ActivesTracker() {
			activeCells = new HashSet<Location>();
		}

		public ActivesTracker(Set<Location> activeCells) {
			this.activeCells = new HashSet<Location>(activeCells);
		}

		public void activate(Location loc) {
			for (int x = loc.getX() - 1; x <= loc.getX() + 1; x++) {
				for (int y = loc.getY() - 1; y <= loc.getY() + 1; y++) {
					addToActives(x, y);
				}
			}
		}

		public void clear() {
			activeCells.clear();
		}

		public Iterator<Location> iterator() {
			return activeCells.iterator();
		}

		private void addToActives(int x, int y) {
			addToActives(new Location(x, y));
		}

		private void addToActives(Location loc) {
			activeCells.add(loc);
		}
	}
}