import java.io.*;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.Locale;
import java.util.PriorityQueue;
import java.util.StringTokenizer;

public class Lawnmower {

	public static final String in = "B-large.in";
	public static final String ou = "B-large.out";

	public static final DecimalFormat DF = new DecimalFormat("0.000",new DecimalFormatSymbols(Locale.ENGLISH));
	public static final double EPSILON = 1E-9;

	public Lawnmower(BufferedReader input) {
		this.input = input;
		this.outputBuilder = new StringBuilder();
	}
	
	public String go() throws Exception {
		// Solve problem here!
		int cases = INT();
		for(int cc = 1; cc <= cases; cc++) {

            int n = INT(), m = INT();

            PriorityQueue<Spot> queue = new PriorityQueue<Spot>();
            int[][] board = new int[n][m];
            for(int i = 0; i < n; i++) {
                for(int j = 0; j < m; j++) {
                    board[i][j] = INT();
                    queue.add(new Spot(i,j,board[i][j]));
                }
            }

            boolean ok = true;
            while(!queue.isEmpty()) {
                Spot next = queue.poll();
                if(board[next.x][next.y] < 0) {
                    continue;
                }

                if(checkRow(board, next.x, next.height)) {
                    chooseRow(board, next.x);
                } else if(checkCol(board, next.y, next.height)) {
                    chooseCol(board, next.y);
                } else {
                    ok = false;
                    break;
                }

            }


			write("Case #" + cc + ": ");
			writeln(ok?"YES":"NO");
			
		}
		return outputBuilder.toString();
	}

    private void chooseRow(int[][] board, int row) {

        for(int j = 0; j < board[row].length; j++) {
            board[row][j] = -1;
        }

    }

    private boolean checkRow(int[][] board, int row, int max) {

        for(int j = 0; j < board[row].length; j++) {
            if(board[row][j] > max)return false;
        }
        return true;
    }

    private void chooseCol(int[][] board, int col) {

        for(int i = 0; i < board.length; i++) {
            board[i][col] = -1;
        }

    }

    private boolean checkCol(int[][] board, int col, int max) {

        for(int i = 0; i < board.length; i++) {
            if(board[i][col] > max)return false;
        }
        return true;
    }

    private static class Spot implements Comparable<Spot> {
        int x, y, height;

        Spot(int x, int y, int height) {
            this.x = x;
            this.y = y;
            this.height = height;
        }

        @Override
        public int compareTo(Spot spot) {
            return this.height - spot.height;
        }
    }
	
	// Scaffolding
	public static void main(String[] args) throws Exception {
		BufferedWriter output = new BufferedWriter(new FileWriter(new File(ou)));
		output.write(new Lawnmower(new BufferedReader(new FileReader(new File(in)))).go());


//        BufferedWriter output = new BufferedWriter(new OutputStreamWriter(System.out));
//        output.write(new Lawnmower(new BufferedReader(new InputStreamReader(System.in))).go());

		output.flush();
		output.close();
	}
	
	// Output methods
	StringBuilder outputBuilder = new StringBuilder();
	void write(String str) { outputBuilder.append(str); }
	void write(int num) {    outputBuilder.append(num); }
	void write(long num) {   outputBuilder.append(num); }
	void write(char ch) {    outputBuilder.append(ch); }
	void writeln(String str) { outputBuilder.append(str); outputBuilder.append("\n");}
	void writeln(int num) {    outputBuilder.append(num); outputBuilder.append("\n"); }
	void writeln(long num) {   outputBuilder.append(num); outputBuilder.append("\n"); }
	void writeln(char ch) {    outputBuilder.append(ch); outputBuilder.append("\n"); }
	
	// Input methods
	BufferedReader input;
	StringTokenizer st;
	String LINE() throws Exception { return input.readLine(); }
	String TOKEN() throws Exception {
		while (st == null || !st.hasMoreTokens())st = new StringTokenizer(LINE());
		return st.nextToken();
	}
	int INT() throws Exception {return Integer.parseInt(TOKEN());}
	long LONG() throws Exception {return Long.parseLong(TOKEN());}
	double DOUBLE() throws Exception {return Double.parseDouble(TOKEN());}
	

}
