package round2;
import java.io.*;
import java.util.*;
import java.math.*;
import java.text.*;

public class Bacteria {

	static DecimalFormat DF = new DecimalFormat("0.000",new DecimalFormatSymbols(Locale.ENGLISH));
	
	public static void run() throws Exception {
		
		init("C-large");
		
		int cases = INT();
		for(int cc = 1;cc<=cases;cc++) {
			int R = INT();
			
			int[][] rects = new int[R][4];
			for(int i = 0;i<R;i++) {
				int x1 = INT(), y1 = INT();
				int x2 = INT(), y2 = INT();
				rects[i] = new int[] {x1,y1,x2,y2};
			}
			
			DisjointSet set = new DisjointSet(R);
			for(int i = 0;i<R;i++)set.createSet(i);
			
			for(int i = 0;i<R;i++) {
				for(int j = i+1;j<R;j++) {
					if(adjacent(rects[i],rects[j]))
						set.mergeSets(i, j);
				}
			}
			int[][] bottom = new int[R][2];
			for(int i = 0;i<R;i++) {
				int ss = set.findSet(i);
				bottom[ss][0] = Math.max(bottom[ss][0], rects[i][2]);
				bottom[ss][1] = Math.max(bottom[ss][1], rects[i][3]);
			}
			int iterations = 1;
			for(int i = 0;i<R;i++) {
				int ss = set.findSet(i);
				int x = bottom[ss][0], y = bottom[ss][1];
				iterations = Math.max(iterations, 1+x-rects[i][0]+y-rects[i][1]);
			}
			
			println("Case #"+cc+": "+iterations);
		}
		
	}
	
	public static boolean adjacent(int[] a, int[] b) {
		if(a[0]==b[2]-1 && a[3]==b[1]-1)return true;
		if(b[0]==a[2]-1 && b[3]==a[1]-1)return true;
		int minx = Math.max(a[0],b[0]);
		int maxx = Math.min(a[2],b[2]);
		int miny = Math.max(a[1],b[1]);
		int maxy = Math.min(a[3],b[3]);
		
		return minx<=maxx && miny<=maxy;
	}
	
	public static class DisjointSet {
		
		private int[] rank;
		private int[] parent;
		
		DisjointSet(int size) {
			rank = new int[size];
			Arrays.fill(rank,-1);
			parent = new int[size];
		}
		
		public void createSet(int x) {
			if(rank[x]>=0)throw new IllegalArgumentException("Item "+x+" already exists!");
			rank[x] = 0;
			parent[x] = x;
		}
		
		public int findSet(int x) {
			if(rank[x]<0)throw new IllegalArgumentException("Item "+x+" doesn't exist");
			if(parent[x]!=x)parent[x] = this.findSet(parent[x]);
			return parent[x];
		}
		
		public void mergeSets(int x, int y) {
			int rootX = this.findSet(x);
			int rootY = this.findSet(y);
			if(rank[rootX]>rank[rootY])parent[rootY] = rootX;
			else parent[rootX] = rootY;
			if(rank[rootX]==rank[rootY])rank[rootX] = rank[rootY]+1;
		}
		
		
	}
	
	// *************************************************************************************
	// *********************************** FRAMEWORK ***************************************
	// *************************************************************************************
	
	public static BufferedReader stdin = new BufferedReader(new InputStreamReader(System.in));
	public static boolean isStandardInput = false;
	
	public static File input;
	public static FileReader inputreader;
	public static BufferedReader in;
	
	public static File output;
	public static FileWriter outputwriter;
	public static BufferedWriter out;
	
	public static StringTokenizer st;
	
	public static void main(String[] args) throws Exception {
		doSTDIN(true);
		setOutput("test.out");
		run();
		close();
	}
	
	public static void init(String problemName) throws Exception {
		doSTDIN(false);
		setInput(problemName+".in");
		setOutput(problemName+".out");
	}
	
	// **************** PRINT METHODS **********************
	
	public static void println() throws IOException {
		out.write("\n");
		System.out.println();
	}
	
	public static void println(Object obj) throws IOException {
		out.write(obj.toString());
		out.write("\n");
		System.out.println(obj.toString());
	}
	
	public static void print(Object obj) throws IOException {
		out.write(obj.toString());
		System.out.print(obj.toString());
	}
	
	public static void println(long number) throws IOException {
		out.write(Long.toString(number));
		out.write("\n");
		System.out.println(number);
	}
	
	public static void print(long number) throws IOException {
		out.write(Long.toString(number));
		System.out.print(number);
	}
	
	public static void println(char c) throws IOException {
		out.write(Character.toString(c));
		out.write("\n");
		System.out.println(c);
	}
	
	public static void print(char c) throws IOException {
		out.write(Character.toString(c));
		System.out.print(c);
	}
	
	public static void println(String line) throws IOException {
		out.write(line);
		out.write("\n");
		System.out.println(line);
	}
	
	public static void print(String line) throws IOException {
		out.write(line);
		System.out.print(line);
	}
	
	// ******************** INPUT DECLARATION ******************
	
	public static void doSTDIN(boolean standard) {
		isStandardInput = standard;
	}
	
	public static void setInput(String filename) throws IOException {
		input = new File(filename);
		inputreader = new FileReader(input);
		in = new BufferedReader(inputreader);
	}
	
	public static void setOutput(String filename) throws IOException {
		output = new File(filename);
		outputwriter = new FileWriter(output);
		out = new BufferedWriter(outputwriter);
	}
	
	public static void close() throws IOException {
		if(in!=null)in.close();
		if(inputreader!=null)inputreader.close();
		
		if(out!=null)out.flush();
		if(out!=null)out.close();
		if(outputwriter!=null)outputwriter.close();
	}
	
	// ************************** INPUT READING *****************
	
	static String LINE() throws IOException { return isStandardInput?stdin.readLine():in.readLine(); }
	static String TOKEN() throws IOException {
		while (st == null || !st.hasMoreTokens())st = new StringTokenizer(LINE());
		return st.nextToken();
	}
	static int INT() throws IOException {return Integer.parseInt(TOKEN());}
	static long LONG() throws IOException {return Long.parseLong(TOKEN());}
	static double DOUBLE() throws IOException {return Double.parseDouble(TOKEN());}
	static BigInteger BIGINT() throws IOException {return new BigInteger(TOKEN());}
	
}
