import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.Scanner;

public final class tidyNumbers {

    public static void main(final String[] args) {
        final Scanner in = new Scanner(new BufferedReader(new InputStreamReader(System.in)));
        final int t = in.nextInt();
        assert t >= 1 && t <= 100;
        for (int i = 0; i < t; i++) {
            final String s = in.next();
            assert s.length() >= 2 && s.length() <= 1000;
            final int k = in.nextInt();
            assert k >= 2 && k <= s.length();

            final PancakeArray pancakeArray = new PancakeArray(s, k);
            CaseResult result;
            try {
                int timesFlipped = 0;
                for (int j = 0; j < pancakeArray.length(); j++) {
                    if (pancakeArray.getSide(j) == Side.BLANK) {
                        pancakeArray.flip(j);
                        timesFlipped++;
                    }
                }
                result = new SuccessCaseResult(i, timesFlipped);
            } catch (Exception e) {
                result = new ImpossibleCaseResult(i);
            }

            System.out.println(result);
        }
    }

    public static final class PancakeArray {

        private final Side[] array;
        private final int flipperSize;

        public PancakeArray(final String s, final int flipperSize) {
            this(Side.parse(s), flipperSize);
        }
        
        public PancakeArray(final Side[] array, final int flipperSize) {
            assert flipperSize > 0;
            this.array = array;
            this.flipperSize = flipperSize;
        }

        public Side getSide(final int index) {
            if (index >= 0 && index < length()) {
                return array[index];
            } else {
                throw new IndexOutOfBoundsException();
            }
        }

        public int length() {
            return array.length;
        }

        public int getFlipperSize() {
            return flipperSize;
        }

        public void flip(final int index) {
            if (index >= 0 && index + getFlipperSize() <= length()) {
                for (int i = index; i < index + getFlipperSize(); i++) {
                    array[i] = array[i].reverse();
                }
            } else {
                throw new IndexOutOfBoundsException();
            }
        }

    }

    public enum Side {

        HAPPY,
        BLANK;

        public final Side reverse() {
            switch (this) {
                case HAPPY:
                    return BLANK;
                case BLANK:
                    return HAPPY;
                default:
                    throw new UnsupportedOperationException();
            }
        }

        public static Side[] parse(final String s) {
            final Side[] result = new Side[s.length()];
            for (int i = 0; i < s.length(); i++) {
                result[i] = parse(s.charAt(i));
            }
            return result;
        }

        public static Side parse(final char c) {
            switch (c) {
                case '+':
                    return HAPPY;
                case '-':
                    return BLANK;
                default:
                    throw new UnsupportedOperationException();
            }
        }

    }

    public static abstract class CaseResult {

        private final int caseNumber;

        protected CaseResult(int caseNumber) {
            assert caseNumber > 0;
            this.caseNumber = caseNumber;
        }

        public int getCaseNumber() {
            return caseNumber;
        }

        public abstract String getResultString();

        public String toString() {
            return "Case #" + getCaseNumber() + ": " + getResultString();
        }

    }

    public static class SuccessCaseResult extends CaseResult {

        private final int timesFlipped;

        public SuccessCaseResult(final int caseNumber, final int timesFlipped) {
            super(caseNumber);
            assert timesFlipped > 0;
            this.timesFlipped = timesFlipped;
        }

        @Override
        public String getResultString() {
            return Integer.toString(timesFlipped);
        }

    }

    public static class ImpossibleCaseResult extends CaseResult {

        protected ImpossibleCaseResult(int caseNumber) {
            super(caseNumber);
        }

        @Override
        public String getResultString() {
            return "IMPOSSIBLE";
        }

    }

}