package gorosort;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Locale;
import java.util.Scanner;
import java.util.Stack;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class GoroSort {

	private static final int THREAD_COUNT = Runtime.getRuntime().availableProcessors();
	private static final String OUT_FILE_NAME = "gs_small.txt";

	public static void main(String[] args) throws Exception {

		List<Case> cases = new GoroSortCaseReader().readCase();

		ExecutorService exec = Executors.newFixedThreadPool(THREAD_COUNT);
		List<Future<String>> results = new ArrayList<Future<String>>();

		for (Case caze : cases) {
			results.add(exec.submit(new Task(caze)));
		}
		exec.shutdown();

		try {
			FileWriter fileWriter = new FileWriter(new File(OUT_FILE_NAME));
			for (Future<String> result : results) {
				fileWriter.append(result.get()).append('\n');
			}
			fileWriter.close();
		} catch (Exception e) {
		}
	}
}

abstract class Case {
	String id;

	abstract public String solve();
}

interface CaseReader {
	public List<? extends Case> readCase();
}

class Task implements Callable<String> {

	private Case caze;

	public Task(Case caze) {
		this.caze = caze;
	}

	@Override
	public String call() throws Exception {
		return caze.solve();
	}
}

class GoroSortCase extends Case {

	int[] elements;

	private int count = 0;

	public String solve() {

		int copy[] = Arrays.copyOf(elements, elements.length);
		Arrays.sort(copy);
		for (int i = 0; i < copy.length - 1; i++) {
			if (elements[i] == copy[i]) {
				continue;
			}
			for (int j = i + 1; j < copy.length; j++) {
				if(copy[i] == elements[j]) {
					swap(elements, i, j);
				}
			}
		}
		double d = count * 2.0;

		return "Case #" + id + ": " + String.format(Locale.ENGLISH,"%.6f", d);
	}

	private void swap(int x[], int a, int b) {
		count++;
		int t = x[a];
		x[a] = x[b];
		x[b] = t;
	}
}

class GoroSortCaseReader implements CaseReader {

	@Override
	public List<Case> readCase() {
		List<Case> cases = new ArrayList<Case>();
		try {
			Scanner scanner = new Scanner(new FileInputStream(new File("in.txt")), "utf8");
			int caseCount = scanner.nextInt();
			for (int i = 1; i <= caseCount; i++) {
				GoroSortCase caze = new GoroSortCase();
				caze.id = "" + i;

				int length = scanner.nextInt();
				caze.elements = new int[length];
				for (int j = 0; j < length; j++) {
					caze.elements[j] = scanner.nextInt();
				}

				cases.add(caze);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return cases;
	}
}