package magicka;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Scanner;
import java.util.Stack;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class Magicka {

	private static final int THREAD_COUNT = Runtime.getRuntime().availableProcessors();
	private static final String OUT_FILE_NAME = "m_large.txt";

	public static void main(String[] args) throws Exception {

		List<Case> cases = new MagickaCaseReader().readCase();

		ExecutorService exec = Executors.newFixedThreadPool(THREAD_COUNT);
		List<Future<String>> results = new ArrayList<Future<String>>();

		for (Case caze : cases) {
			results.add(exec.submit(new Task(caze)));
		}
		exec.shutdown();

		try {
			FileWriter fileWriter = new FileWriter(new File(OUT_FILE_NAME));
			for (Future<String> result : results) {
				fileWriter.append(result.get()).append('\n');
			}
			fileWriter.close();
		} catch (Exception e) {
		}
	}
}

abstract class Case {
	String id;

	abstract public String solve();
}

interface CaseReader {
	public List<? extends Case> readCase();
}

class Task implements Callable<String> {

	private Case caze;

	public Task(Case caze) {
		this.caze = caze;
	}

	@Override
	public String call() throws Exception {
		return caze.solve();
	}
}

class MagickaCase extends Case {
	char[][] combine = new char[26][26];
	boolean[][] oppose = new boolean[26][26];
	int elementCount;
	char[] elements;

	public MagickaCase() {
		for (int i = 0; i < 26; i++) {
			for (int j = 0; j < 26; j++) {
				combine[i][j] = '-';
				oppose[i][j] = false;
			}
		}
	}

	public String solve() {

		Stack<Character> stack = new Stack<Character>();
		LOOP: for (int i = 0; i < elements.length; i++) {
			char currChar = elements[i];
			int currInt = currChar - 'A';
			if (stack.isEmpty()) {
				stack.add(currChar);
				continue;
			}
			char lastChar = stack.pop();
			int lastInt = lastChar - 'A';

			if (combine[lastInt][currInt] != '-') {
				stack.add(combine[lastInt][currInt]);
				continue;
			}

			stack.add(lastChar);

			for (int j = 0; j < 26; j++) {
				if (oppose[currInt][j] && stack.contains((char)('A' + j))) {
					stack.clear();
					continue LOOP;
				}
			}

			stack.add(currChar);

		}
		Character[] rrr = new Character[stack.size()];
		rrr = stack.toArray(rrr);
		return "Case #" + id + ": " + Arrays.toString(rrr);
	}
}

class MagickaCaseReader implements CaseReader {

	@Override
	public List<Case> readCase() {
		List<Case> cases = new ArrayList<Case>();
		try {
			Scanner scanner = new Scanner(new FileInputStream(new File("in.txt")), "utf8");
			int caseCount = scanner.nextInt();
			for (int i = 1; i <= caseCount; i++) {
				MagickaCase caze = new MagickaCase();
				caze.id = "" + i;

				int combineCount = scanner.nextInt();
				for (int j = 0; j < combineCount; j++) {
					String ccc = scanner.next();
					char a = ccc.charAt(0);
					char b = ccc.charAt(1);
					char r = ccc.charAt(2);
					int i1 = a - 'A';
					int i2 = b - 'A';
					caze.combine[i1][i2] = r;
					caze.combine[i2][i1] = r;

				}

				int opposeCount = scanner.nextInt();
				for (int j = 0; j < opposeCount; j++) {
					String ooo = scanner.next();
					char a = ooo.charAt(0);
					char b = ooo.charAt(1);
					int i1 = a - 'A';
					int i2 = b - 'A';
					caze.oppose[i1][i2] = true;
					caze.oppose[i2][i1] = true;
				}
				caze.elementCount = scanner.nextInt();
				caze.elements = scanner.next().toCharArray();

				cases.add(caze);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return cases;
	}
}