package bottrust;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class BotTrust {

	private static final int THREAD_COUNT = Runtime.getRuntime().availableProcessors();
	private static final String OUT_FILE_NAME = "bt_small.txt";

	public static void main(String[] args) throws Exception {

		List<Case> cases = new BotTrustCaseReader().readCase();

		ExecutorService exec = Executors.newFixedThreadPool(THREAD_COUNT);
		List<Future<String>> results = new ArrayList<Future<String>>();

		for (Case caze : cases) {
			results.add(exec.submit(new Task(caze)));
		}
		exec.shutdown();

		try {
			FileWriter fileWriter = new FileWriter(new File(OUT_FILE_NAME));
			for (Future<String> result : results) {
				fileWriter.append(result.get()).append('\n');
			}
			fileWriter.close();
		} catch (Exception e) {
		}
	}
}

abstract class Case {
	String id;

	abstract public String solve();
}

interface CaseReader {
	public List<? extends Case> readCase();
}

class Task implements Callable<String> {

	private Case caze;

	public Task(Case caze) {
		this.caze = caze;
	}

	@Override
	public String call() throws Exception {
		return caze.solve();
	}
}

class BotTrustCase extends Case {

	char[] movers;
	int[] buttons;

	private int oLocation = 1;
	private int bLocation = 1;
	private int oLastActionTime = 0;
	private int bLastActionTime = 0;
	private int totalTime = 0;

	public String solve() {
		
		for (int i = 0; i < movers.length; i++) {
			char mover = movers[i];
			int target = buttons[i];
			
			int location = mover == 'O' ? oLocation : bLocation;
			int lastActionTime = mover == 'O' ? oLastActionTime : bLastActionTime;
			
			int distance = Math.abs(location - target);
			
			if (lastActionTime + distance <= totalTime) {
				totalTime++;
			} else {
				totalTime = lastActionTime + distance + 1;
			}
			if(mover == 'O') {
				oLocation = target;
				oLastActionTime = totalTime;
			} else {
				bLocation = target;
				bLastActionTime = totalTime;
			}
			
		}

		return "Case #" + id + ": " + totalTime;
	}
}

class BotTrustCaseReader implements CaseReader {

	@Override
	public List<Case> readCase() {
		List<Case> cases = new ArrayList<Case>();
		try {
			Scanner scanner = new Scanner(new FileInputStream(new File("in.txt")), "utf8");
			int caseCount = scanner.nextInt();
			for (int i = 1; i <= caseCount; i++) {
				BotTrustCase caze = new BotTrustCase();
				caze.id = "" + i;

				int moveCount = scanner.nextInt();
				caze.buttons = new int[moveCount];
				caze.movers = new char[moveCount];
				for (int j = 0; j < moveCount; j++) {
					caze.movers[j] = scanner.next().charAt(0);
					caze.buttons[j] = scanner.nextInt();
				}
				cases.add(caze);
			}
		} catch (Exception e) {
		}
		return cases;
	}
}