import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.BitSet;
import java.util.LinkedList;
import java.util.Queue;
import java.util.Scanner;

import com.google.common.base.Stopwatch;

public class MinesweeperMaster {

    private static final String inputName = "e:/downloads/C-small-attempt0.in";
    private static final String outputName = "C:/workspaces/algo/GCJ/src/prolemC.out";
    private static String[][][] cache;

    public static void main(String[] args) throws IOException {
        Scanner sc = new Scanner(new FileReader(inputName));
        // Scanner sc = new Scanner(System.in);
        BufferedWriter bw = new BufferedWriter(new FileWriter(outputName));
        cache = AnswerGenerator.createCache();
        int T = sc.nextInt();
        for (int t = 0; t < T; t++) {
            int R = sc.nextInt();
            int C = sc.nextInt();
            int M = sc.nextInt();
            String answer = solve(R, C, M);
            String res = String.format("Case #%s:\n%s", t + 1, answer);
            bw.write(res);
            System.out.print(res);
        }
        bw.close();
    }

    private static String solve(int R, int C, int M) {
        String res = cache[R - 1][C - 1][M];
        if (res == null) {
            res = "Impossible\n";
        }
        return res;
    }

    public static class AnswerGenerator {

        public static String[][][] createCache() {
            Stopwatch sw = Stopwatch.createStarted();
            String[][][] cache = new String[5][5][26];
            for (int R = 1; R < 6; R++) {
                for (int C = 1; C < 6; C++) {
                    int N = C * R;
                    for (int i = 0; i < 1 << N; i++) {
                        BitSet bs = BitSet.valueOf(new long[] { i });
                        if (bs.get(0)) {
                            continue;
                        }
                        int M = bs.cardinality();
                        if (cache[R - 1][C - 1][M] != null) {
                            continue;
                        }
                        boolean[][] field = new boolean[R][C];
                        for (int j = 0; j < N; j++) {
                            field[j / C][j % C] = bs.get(j);
                        }
                        int opened = openInOneMove(field);
                        if (opened == N - M) {
                            String answer = toAnswer(field);
                            cache[R - 1][C - 1][M] = answer;
                        }
                    }
                }
            }
            System.out.println("It took : " + sw);
            return cache;
        }

        private static String toAnswer(boolean[][] field) {
            StringBuilder sb = new StringBuilder(field.length * (field[0].length + 1));
            for (int i = 0; i < field.length; i++) {
                for (int j = 0; j < field[0].length; j++) {
                    if (i == 0 && j == 0) {
                        sb.append('c');
                    } else {
                        if (field[i][j]) {
                            sb.append('*');
                        } else {
                            sb.append('.');
                        }
                    }
                }
                sb.append('\n');
            }
            return sb.toString();
        }

        private static int openInOneMove(boolean[][] field) {
            Queue<int[]> q = new LinkedList<>();
            q.offer(new int[] { 0, 0 });
            boolean[][] checked = new boolean[field.length][field[0].length];
            int[] dr = { -1, -1, -1, 0, 0, 1, 1, 1 };
            int[] dc = { -1, 0, 1, -1, 1, -1, 0, 1 };
            while (q.peek() != null) {
                int[] pos = q.poll();
                checked[pos[0]][pos[1]] = true;
                int mines = countNeighbourMines(field, pos[0], pos[1]);
                if (mines != 0) {
                    continue;
                }
                for (int i = 0; i < dr.length; i++) {
                    int r = pos[0] + dr[i];
                    int c = pos[1] + dc[i];
                    if (r >= 0 && r < field.length && c >= 0 && c < field[0].length) {
                        if (!field[r][c]) {
                            if (!checked[r][c] && mines == 0) {
                                q.offer(new int[] { r, c });
                            }
                            checked[r][c] = true;
                        }
                    }
                }
            }
            int res = 0;
            for (int i = 0; i < field.length; i++) {
                for (int j = 0; j < field[0].length; j++) {
                    if (!field[i][j] && checked[i][j]) {
                        res++;
                    }
                }
            }
            return res;
        }

        private static int countNeighbourMines(boolean[][] field, int r0, int c0) {
            int res = 0;
            int[] dr = { -1, -1, -1, 0, 0, 1, 1, 1 };
            int[] dc = { -1, 0, 1, -1, 1, -1, 0, 1 };
            for (int i = 0; i < dr.length; i++) {
                int r = r0 + dr[i];
                int c = c0 + dc[i];
                if (r >= 0 && r < field.length && c >= 0 && c < field[0].length && field[r][c]) {
                    res++;
                }
            }
            return res;
        }
    }

}
