import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Scanner;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

import org.jgrapht.Graphs;
import org.jgrapht.alg.EdmondsKarpMaximumFlow;
import org.jgrapht.ext.DOTExporter;
import org.jgrapht.ext.EdgeNameProvider;
import org.jgrapht.ext.VertexNameProvider;
import org.jgrapht.graph.DefaultDirectedWeightedGraph;
import org.jgrapht.graph.DefaultWeightedEdge;

import com.google.common.collect.Lists;

public class BreakTheNile {
    private static final String inputName = "e:/downloads/C-small-attempt0.in";
    private static final String outputName = "C:/workspaces/algo/GCJ/src/prolemC.out";

    private static class Building {
        int w0, h0, w1, h1;

        public Building(int w0, int h0, int w1, int h1) {
            this.w0 = w0;
            this.h0 = h0;
            this.w1 = w1;
            this.h1 = h1;
        }

        private boolean contains(int h, int w) {
            return h >= h0 && h <= h1 && w <= w1 && w >= w0;
        }

        @Override
        public String toString() {
            return "Building [w0=" + w0 + ", h0=" + h0 + ", w1=" + w1 + ", h1=" + h1 + "]";
        }

    }

    public static void main(String[] args) throws IOException, InterruptedException, ExecutionException {
        Scanner sc = new Scanner(new FileReader(inputName));
        // Scanner sc = new Scanner(System.in);
        int T = sc.nextInt();
        ExecutorService executor = Executors.newFixedThreadPool(4);
        List<Future<Long>> results = new ArrayList<>();
        for (int t = 0; t < T; t++) {
            int W = sc.nextInt();
            int H = sc.nextInt();
            int B = sc.nextInt();
            List<Building> buildings = new ArrayList<>();
            for (int i = 0; i < B; i++) {
                buildings.add(new Building(sc.nextInt(), sc.nextInt(), sc.nextInt(), sc.nextInt()));
            }
            Future<Long> res = executor.submit(new Solver(W, H, buildings));
            results.add(res);
        }
        executor.shutdown();
        BufferedWriter bw = new BufferedWriter(new FileWriter(outputName));
        for (int t = 0; t < T; t++) {
            Long res = results.get(t).get();
            String str = String.format("Case #%s: %s\n", t + 1, res);
            bw.write(str);
            System.out.print(str);
        }
        bw.close();
    }

    private static class Solver implements Callable<Long> {
        private int W, H;
        private List<Building> buildings;

        public Solver(int w, int h, List<Building> buildings) {
            W = w;
            H = h;
            this.buildings = buildings;
        }

        @Override
        public Long call() throws Exception {
            DefaultDirectedWeightedGraph<String, DefaultWeightedEdge> graph = createInputGraph(W, H, buildings);
            EdmondsKarpMaximumFlow<String, DefaultWeightedEdge> solver = new EdmondsKarpMaximumFlow<String, DefaultWeightedEdge>(graph);
            solver.calculateMaximumFlow("source", "sink");
            long res = solver.getMaximumFlowValue().longValue();
            return res;
        }

        private static final int[] dw = { 0, 1, 0, -1 };
        private static final int[] dh = { 1, 0, -1, 0 };

        private void writeFlowToFile(final DefaultDirectedWeightedGraph<String, DefaultWeightedEdge> graph,
                final Map<DefaultWeightedEdge, Double> flow) throws IOException {
            VertexNameProvider<String> vertexIDProvider = new VertexNameProvider<String>() {
                @Override
                public String getVertexName(String vertex) {
                    return vertex;
                }
            };
            VertexNameProvider<String> vertexLabelProvider = new VertexNameProvider<String>() {
                @Override
                public String getVertexName(String vertex) {
                    return vertex;
                }
            };
            EdgeNameProvider<DefaultWeightedEdge> nameProdvider = new EdgeNameProvider<DefaultWeightedEdge>() {
                @Override
                public String getEdgeName(DefaultWeightedEdge edge) {
                    return "" + graph.getEdgeWeight(edge) + "(" + flow.get(edge) + ")";
                }
            };
            DOTExporter<String, DefaultWeightedEdge> exporter = new DOTExporter<String, DefaultWeightedEdge>(vertexIDProvider,
                    vertexLabelProvider, nameProdvider);
            PrintWriter writer = new PrintWriter(System.out);
            exporter.export(writer, graph);
        }

        private DefaultDirectedWeightedGraph<String, DefaultWeightedEdge> createInputGraph(int W, int H, List<Building> buildings) {
            DefaultDirectedWeightedGraph<String, DefaultWeightedEdge> graph = new DefaultDirectedWeightedGraph<String, DefaultWeightedEdge>(
                    DefaultWeightedEdge.class);
            List<String> vertices = Lists.newArrayList("source", "sink");
            for (int w = 0; w < W; w++) {
                for (int h = 0; h < H; h++) {
                    if (!isBuildingCell(buildings, w, h)) {
                        vertices.add("v" + w + "_" + h + "_source");
                        vertices.add("v" + w + "_" + h + "_sink");
                        Graphs.addEdgeWithVertices(graph, "v" + w + "_" + h + "_source", "v" + w + "_" + h + "_sink", 1);
                    }
                }
            }
            Graphs.addAllVertices(graph, vertices);
            for (int w = 0; w < W; w++) {
                if (!isBuildingCell(buildings, w, 0)) {
                    Graphs.addEdgeWithVertices(graph, "source", "v" + w + "_0_source", 1);
                }
                if (!isBuildingCell(buildings, w, H - 1)) {
                    Graphs.addEdgeWithVertices(graph, "v" + w + "_" + (H - 1) + "_sink", "sink", 1);
                }
            }
            for (int w = 0; w < W; w++) {
                for (int h = 0; h < H; h++) {
                    boolean isBuilding = isBuildingCell(buildings, w, h);
                    if (isBuilding) {
                        continue;
                    }
                    for (int d = 0; d < dw.length; d++) {
                        int tw = dw[d] + w;
                        int th = dh[d] + h;
                        if (tw >= 0 && tw < W && th < H && th >= 0) {
                            if (isBuildingCell(buildings, tw, th)) {
                                continue;
                            }
                            Graphs.addEdgeWithVertices(graph, "v" + w + "_" + h + "_sink", "v" + tw + "_" + th + "_source", 1);
                        }
                    }
                }
            }
            return graph;
        }

        private boolean isBuildingCell(List<Building> buildings, int w, int h) {
            boolean isBuilding = false;
            for (Building building : buildings) {
                if (building.contains(h, w)) {
                    isBuilding = true;
                    break;
                }
            }
            return isBuilding;
        }
    }

}
