import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.StringTokenizer;
import java.util.concurrent.Callable;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.tuple.Pair;

import com.google.common.math.BigIntegerMath;

public class CoinJam {

    private static final String INPUT_FILE = "e:/downloads/A-small-attempt0.in";
    private static final String OUTPUT_FOLDER = "C:/workspaces/algo/GCJ/src/";
    private static final String OUTPUT_FILE = "C-large.out";

    private static final BigInteger TWO = new BigInteger("2");

    public static void main(String[] args) throws Exception {
        InputReader in = new InputReader(new FileInputStream(INPUT_FILE));
        PrintWriter pw = new PrintWriter(new File(OUTPUT_FOLDER, OUTPUT_FILE));
        int T = in.nextInt();
        ExecutorService executor = Executors.newFixedThreadPool(4);
        for (int t = 1; t <= T; t++) {
            int N = in.nextInt();
            int J = in.nextInt();
            long minNum = Long.parseLong(1 + StringUtils.repeat('0', N - 2) + "1", 2);
            Map<String, List<BigInteger>> nums = new ConcurrentHashMap<>();
            long num = minNum;

            while (nums.size() < J) {
                List<Future<Pair<String, List<BigInteger>>>> results = new ArrayList<>(1000);
                for (int i = 0; i <= 1000; i++) {
                    String binaryStr = Long.toBinaryString(num);
                    Calculator calc = new Calculator(binaryStr);
                    Future<Pair<String, List<BigInteger>>> checkRes = executor.submit(calc);
                    results.add(checkRes);
                    num++;
                }
                for (Future<Pair<String, List<BigInteger>>> result : results) {
                    Pair<String, List<BigInteger>> pair = result.get();
                    List<BigInteger> divs = pair.getRight();
                    String binaryStr = pair.getKey();
                    if (divs != null) {
                        nums.put(binaryStr, divs);
                        System.out.println(binaryStr + " is coin. Current size : " + nums.size());
                    }
                }
            }
            String res = String.format("Case #%d:\n", t);
            for (Entry<String, List<BigInteger>> entry : nums.entrySet()) {
                res += entry.getKey();
                for (BigInteger divisor : entry.getValue()) {
                    res += " " + divisor;
                }
                res += "\n";
            }
            pw.println(res);
            System.out.println(res);
        }
        pw.close();
    }

    private static class Calculator implements Callable<Pair<String, List<BigInteger>>> {
        private String binaryStr;

        public Calculator(String binaryStr) {
            this.binaryStr = binaryStr;
        }

        @Override
        public Pair<String, List<BigInteger>> call() throws Exception {
            List<BigInteger> divs = null;
            if (binaryStr.endsWith("1")) {
                divs = isCoin(binaryStr);
                System.out.println("Checking " + binaryStr + " : " + divs != null);
            }
            return Pair.of(binaryStr, divs);
        }

    }

    private static List<BigInteger> isCoin(String num) {
        List<BigInteger> res = new ArrayList<>(9);
        for (int radix = 2; radix <= 10; radix++) {
            BigInteger convertedNum = new BigInteger(num, radix);
            if (isPrime(convertedNum)) {
                res = null;
                break;
            }
            BigInteger divisor = getDivisor(convertedNum);
            if (divisor == null) {
                res = null;
                break;
            }
            res.add(divisor);
        }
        return res;
    }

    private static boolean isPrime(BigInteger num) {
        return num.isProbablePrime(40);
    }

    private static BigInteger getDivisor(BigInteger num) {
        if (num.remainder(TWO).equals(BigInteger.ZERO)) {
            return TWO;
        }
        BigInteger ind = BigInteger.valueOf(3);
        BigInteger sqrt = BigIntegerMath.sqrt(num, RoundingMode.HALF_DOWN);
        BigInteger limit = sqrt.min(BigInteger.valueOf(10_000));
        while (ind.compareTo(limit) <= 0) {
            if (num.remainder(ind).equals(BigInteger.ZERO)) {
                return ind;
            }
            ind = ind.add(TWO);
        }
        // throw new IllegalArgumentException(num + " does not have divisors");
        return null;
    }

    public static class InputReader {
        public BufferedReader reader;
        public StringTokenizer tokenizer;

        public InputReader(InputStream stream) {
            reader = new BufferedReader(new InputStreamReader(stream), 32768);
            tokenizer = null;
        }

        public String next() {
            while (tokenizer == null || !tokenizer.hasMoreTokens()) {
                try {
                    tokenizer = new StringTokenizer(reader.readLine());
                } catch (IOException e) {
                    throw new RuntimeException(e);
                }
            }
            return tokenizer.nextToken();
        }

        public int nextInt() {
            return Integer.parseInt(next());
        }

    }

}
