import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;

public class TrainTable {

    public static class Route implements Comparable<Route> {
        int start, end;


        public Route(int start, int end) {
            super();
            this.start = start;
            this.end = end;
        }


        public String toString() {
            return start + ":" + end;
        }


        public int compareTo(Route o) {
            if (start != o.start) {
                return start - o.start;
            }
            if (end != o.end)
                return end - o.end;
            return 0;
        }
    }
    
    static private int[] solveTask(List<Route> fromA, List<Route>fromB, int T) {
        int atA =0;
        int atB = 0;
        while (!fromA.isEmpty() || !fromB.isEmpty()) {
            if (fromA.isEmpty()) {
                atB += fromB.size();
                break;
            }
            if (fromB.isEmpty()) {
                atA += fromA.size();
                break;
            }
            Route minA = fromA.get(0);
            Route minB = fromB.get(0);
            int curCity = 0;
            atA++;
            if (minA.compareTo(minB) > 0) {
                curCity = 1;
                atA--;
                atB++;
            }
            int curTime = Math.min(fromA.get(0).start, fromB.get(0).start);
            while (true) {
                Iterator<Route> it; 
                if (curCity == 0) {
                    it = fromA.iterator();
                } else {
                    it = fromB.iterator();
                }
                boolean found = false;
                Route next = null;
                while (!found && it.hasNext()) {
                    next = it.next();
                    if (next.start >= curTime) {
                        it.remove();
                        found = true;
                        break;
                    }
                }
                if (found) {
                    curTime = next.end;
                } else {
                    break;
                }
                curTime += T;
                curCity = 1 - curCity;
            }
        }
        int[] res = {atA, atB};
        return res;
    }

    public static void main(String[] args) throws IOException {
        BufferedReader br = new BufferedReader(new FileReader("D:/downloads/B-large.in"));
        BufferedWriter bw = new BufferedWriter(new FileWriter("D:/downloads/B-large.out"));
        int N = Integer.parseInt(br.readLine());
        for (int j = 0; j < N; j++) {
            int T = Integer.parseInt(br.readLine());
            String[] str = br.readLine().split(" ");
            int m = Integer.parseInt(str[0]);
            int n = Integer.parseInt(str[1]);
            List<Route> fromA = new LinkedList<Route>();
            for (int i = 0; i < m; i++) {
                String st = br.readLine();
                String[] times = st.split(" ");
                StringTokenizer s = new StringTokenizer(times[0], ":");
                int hour = Integer.parseInt(s.nextToken());
                int min = Integer.parseInt(s.nextToken());
                int start = 60 * hour + min;
                s = new StringTokenizer(times[1], ":");
                hour = Integer.parseInt(s.nextToken());
                min = Integer.parseInt(s.nextToken());
                int end = 60 * hour + min;
                Route route = new Route(start, end);
                fromA.add(route);
            }
            List<Route> fromB = new LinkedList<Route>();
            for (int i = 0; i < n; i++) {
                String st = br.readLine();
                String[] times = st.split(" ");
                StringTokenizer s = new StringTokenizer(times[0], ":");
                int hour = Integer.parseInt(s.nextToken());
                int min = Integer.parseInt(s.nextToken());
                int start = 60 * hour + min;
                s = new StringTokenizer(times[1], ":");
                hour = Integer.parseInt(s.nextToken());
                min = Integer.parseInt(s.nextToken());
                int end = 60 * hour + min;
                Route route = new Route(start, end);
                fromB.add(route);
            }
            Collections.sort(fromA);
            Collections.sort(fromB);
            int[] res = solveTask(fromA, fromB, T);
            bw.write("Case #" + (j + 1) + ": " + res[0] + " " + res[1] + "\n");
        }
        bw.close();
        br.close();
    }

}