import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Scanner;

import org.apache.commons.math3.fraction.BigFraction;

public class CookieClicker {

    private static final String inputName = "e:/downloads/B-large.in";
    private static final String outputName = "C:/workspaces/algo/GCJ/src/prolemB.out";

    private BigFraction C;
    private BigFraction X;
    private BigFraction F;

    public CookieClicker(BigFraction c, BigFraction f, BigFraction x) {
        C = c;
        X = x;
        F = f;
    }

    private BigDecimal solve() {
        int factories = calculateNumberOfFactories();
        BigDecimal res = BigDecimal.ZERO;
        res.setScale(10, BigDecimal.ROUND_UP);
        for (int i = 0; i < factories; i++) {
            BigFraction factoryTime = C.divide(BigFraction.TWO.add(F.multiply(i)));
            res = res.add(factoryTime.bigDecimalValue(10, BigDecimal.ROUND_UP));
        }
        BigFraction mainTime = X.divide(BigFraction.TWO.add(F.multiply(factories)));
        res = res.add(mainTime.bigDecimalValue(10, BigDecimal.ROUND_UP));
        return res;
    }

    private int calculateNumberOfFactories() {
        BigFraction factoryThreshold = X.multiply(F).subtract(C.multiply(F)).subtract(C.multiply(BigFraction.TWO));
        factoryThreshold = factoryThreshold.divide(F.multiply(C));
        if (factoryThreshold.compareTo(BigFraction.ZERO) < 0) {
            factoryThreshold = BigFraction.ZERO;
        }
        BigInteger num = factoryThreshold.getNumerator();
        BigInteger den = factoryThreshold.getDenominator();
        BigInteger[] divisionResult = num.divideAndRemainder(den);
        int factories = divisionResult[0].intValue();
        if (divisionResult[1].compareTo(BigInteger.ZERO) != 0) {
            factories++;
        }
        return factories;
    }

    public static void main(String[] args) throws IOException {
        Scanner sc = new Scanner(new FileReader(inputName));
        // Scanner sc = new Scanner(System.in);
        BufferedWriter bw = new BufferedWriter(new FileWriter(outputName));
        int T = sc.nextInt();
        for (int t = 0; t < T; t++) {
            String C = sc.next();
            String F = sc.next();
            String X = sc.next();
            CookieClicker cc = new CookieClicker(getFraction(C), getFraction(F), getFraction(X));
            BigDecimal answer = cc.solve();
            String res = String.format("Case #%s: %s\n", t + 1, answer);
            bw.write(res);
        }
        bw.close();
    }

    private static BigFraction getFraction(String str) {
        BigDecimal fr = new BigDecimal(str).multiply(BigDecimal.valueOf(100000L));
        BigFraction c = new BigFraction(fr.longValue(), 100000L);
        return c;
    }

}
