package codejam;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class Permutation {
    public static <T> T[] getPermutation(long permutationNumber, T[] array, long[] factorials, T[] permutationResult, int[] sequenceResult) {
        int[] sequence = generateSequence(permutationNumber, array.length - 1, factorials, sequenceResult);
        T[] permutation = generatePermutation(array, sequence, permutationResult);

        return permutation;
    }

    public static <T> T[] generatePermutation(T[] array, int[] sequence, T[] permutationResult) {
    	if (permutationResult == null) {
    		permutationResult = array.clone();
    	}

        for (int i = 0; i < permutationResult.length - 1; i++) {
            swap(permutationResult, i, i + sequence[i]);
        }

        return permutationResult;
    }

    private static int[] generateSequence(long permutationNumber, int size, long[] factorials, int[] sequenceResult) {
    	if (sequenceResult == null) {
    		sequenceResult = new int[size];
    	}

        for (int j = 0; j < sequenceResult.length; j++) {
            long factorial = factorials[sequenceResult.length - j];
            sequenceResult[j] = (int) (permutationNumber / factorial);
            permutationNumber = (int) (permutationNumber % factorial);
        }

        return sequenceResult;
    }

    private static <T> void swap(T[] array, int i, int j) {
        T t = array[i];
        array[i] = array[j];
        array[j] = t;
    }

    public static long[] getFactorials(int length) {
        long[] factorials = new long[length];
        long factor = 1;

        for (int i = 0; i < length; i++) {
            factor *= i <= 1 ? 1 : i;
            factorials[i] = factor;
        }

        return factorials;
    }
    
    public static <T> List<T[]> getPermutations(T[] array) {
    	long[] factorials = Permutation.getFactorials(array.length + 1);
    	
		ArrayList<T[]> permutations = new ArrayList<T[]>((int)factorials[array.length]);
		
    	for (long i = 0; i < factorials[array.length]; i++) {
    		T[] generatePermutation = getPermutation(i, array, factorials, null, null);
    		permutations.add(generatePermutation);
    	}
    	
    	return permutations;
    }
    
    @SuppressWarnings("unchecked")
    public static <T> List<List<T>> getPermutations(List<T> list, boolean findFirst, PermutationValidator<T> validator) {
    	T[] array = (T[]) list.toArray();
    	long[] factorials = Permutation.getFactorials(array.length + 1);
    	
    	long maxPermutations = factorials[array.length];
    	
    	int seq[] = new int[array.length - 1];
    	
		ArrayList<List<T>> permutations;
		
		T[] permutationContainer = null;
		
		if (findFirst) {
			permutations = new ArrayList<>(1);
			permutationContainer = (T[]) array.clone();
		} else if (maxPermutations < Integer.MAX_VALUE) {
			permutations = new ArrayList<>((int)maxPermutations);
		} else {
			permutations = new ArrayList<>();
		}
		
    	for (long i = 0; i < factorials[array.length]; i++) {
			T[] generatePermutation = getPermutation(i, array, factorials, permutationContainer, seq);
			
			List<T> asList = Arrays.asList(generatePermutation);
			if (validator == null || validator.isValidPermutation(asList)) {
				permutations.add(asList);
				if (findFirst) return permutations;
			}
    	}
    	
    	return permutations;
    }
    
    @SuppressWarnings("unchecked")
    public static <T> Object processPermutations(List<T> list, PermutationProcessor<T> validator) {
    	T[] array = (T[]) list.toArray();
    	long[] factorials = Permutation.getFactorials(array.length + 1);
    	
    	int seq[] = new int[array.length - 1];
		
		T[] permutationContainer = (T[]) array.clone();
		
    	for (long i = 0; i < factorials[array.length]; i++) {
			T[] generatePermutation = getPermutation(i, array, factorials, permutationContainer, seq);
			
			List<T> asList = Arrays.asList(generatePermutation);
			Object processPermutation = validator.processPermutation(asList);
			if (processPermutation != null) {
				return processPermutation;
			}
    	}
    	
    	return null;
    }
    
    public static void main(String[] args) {
    	String[] array = {"a","b","c","d"};
    	
    	List<String[]> permutations = getPermutations(array);
    	
    	for (String[] strings : permutations) {
			System.out.println(Arrays.toString(strings));
		}
    	
	}
}