import java.io.IOException;
import java.math.BigInteger;
import java.util.HashMap;


public class FairWarning extends CodeJam {

	public FairWarning(String file) throws Exception {
		super(file, -1);
	}

	@Override
	public Object processCase(int caseNumber) throws Exception {
		String number[] = readLine().split(" ");
		
		
		BigInteger[] diffs = new BigInteger[number.length-2];
		
		BigInteger last = null;
		BigInteger smallest = null;
		BigInteger biggestNumber = null;
		
		for (int i = 1; i < number.length; i++) {
			if (last == null) {
				last = new BigInteger('-'+number[i]);
				continue;
			}
			BigInteger current = new BigInteger('-'+number[i]);
			BigInteger diff = current.subtract(last);
			last = current;
			
			diffs[i-2] = diff;
			if (smallest == null) {
				smallest = diff;
			} else if (diff.compareTo(smallest) == -1){
				smallest = diff;
			}
			
			if (biggestNumber == null) {
				biggestNumber = current;
			} else if (biggestNumber.compareTo(current) == -1) {
				biggestNumber = current;
			}
		}
		long prime = 2;
		
		smallest = smallest.abs();
		
		while(!isMultiple(diffs, smallest)) {
			//prime = nextPrime(prime);
			smallest = smallest.divide(new BigInteger(""+prime));
			prime++;
			//System.out.println(smallest+"prime"+prime);
			if (new BigInteger(""+prime).compareTo(smallest) != -1) {
				return 0;
			}
		}
		
		BigInteger abs = smallest.abs();
		last = biggestNumber.add(abs);
		
		while(last.signum() == -1) {
			last = last.add(abs);
		}
		
		return last;
					
	}
	
	static HashMap<Long, Long> cache = new HashMap<Long, Long>();
	
	private static long nextPrime(long current) {
		Long long1 = cache.get(current);
		if (long1 != null) return long1;
		long o = current;
		while(current > 0 && !isPrime(current)) {
			current++;
		}
		cache.put(o, current);
		return current;
	}
	
	public static boolean isPrime(long num) {
		boolean prime = true;
		long limit = (long)Math.sqrt(num);

		for (long i = 2; i <= limit; i++) {
			if (num % i == 0) {
				prime = false;
				break;
			}
		}

		return prime;
	}


	private boolean isMultiple(BigInteger[] diffs, BigInteger smallest) {
		try {
		for (int i = 0; i < diffs.length; i++) {
			if (!diffs[i].mod(smallest.abs()).equals(BigInteger.ZERO)) {
				return false;
			}
		}
		} catch (Exception e) {
			return false;
		}
		return true;
	}
	
	public static void main(String[] args) throws IOException, InterruptedException, Exception {
		new FairWarning(args[0]).start();
	}

}
