package com.elsa.dijkstra;


import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.nio.CharBuffer;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by elisabet on 2015-04-11.
 */
public class Dijkstra {
    public static void main(String[] args) {
        try {
            String path = args[0];
            Dijkstra d = new Dijkstra();
            List<String> result = d.readFile(path);
            String outPath = "/home/elisabet/temp.out";

            PrintWriter pw = new PrintWriter(outPath);
            for (String s : result) {
                pw.println(s);
            }
            pw.close();
        } catch (IOException e) {
            System.out.println("IOException: "+e.getMessage());
        }
    }
    private List<String> readFile(String path) throws IOException {
        FileReader fr = new FileReader(path);
        BufferedReader br = new BufferedReader(fr);
        List<String> result = new ArrayList<String>();

        int m = Integer.parseInt(br.readLine());

        for (int i = 1; i<=m; i++){
            StringBuilder stringBuilder = new StringBuilder();
            stringBuilder.append("Case #"+i+": ");
            boolean b = findIJK(nextLine(br));
            stringBuilder.append( b ? "YES" : "NO");
            System.out.println( b ? "YES" : "NO");
            result.add(stringBuilder.toString());
        }
        return result;
    }

    private String nextLine(BufferedReader br) throws IOException {
        String[] LX = br.readLine().split(" ");
        int X = Integer.parseInt(LX[1]);
        String line = br.readLine();
        return new String(new char[X]).replace("\0", line);
    }

    private boolean findIJK(String s){
        System.out.println(s);
        if(s.length()<3)
            return false;

        Letter empty = new Letter('1');
        Letter firstI = new Letter('1');

        int index1 = 0;
        while (index1 < s.length()) {
            //find next i
            int a = findLetter('i', firstI, s.substring(index1).toCharArray(), 0);
            firstI.letter = 'i';

            if (a < 0) {
                return false;
            }
            index1 += a;

            Letter firstJ = new Letter('1');
            int index = index1;
            while (index < s.length()) {
                //find next j
                int b = findLetter('j', firstJ, s.substring(index).toCharArray(), 0);
                firstJ.letter = 'j';
                if (b < 0) {
                    return false;
                }
                index += b;

                Letter letter = multiplyRest(empty, s.substring(index).toCharArray());
                if (letter.positive && letter.letter == 'k') {
                    return true;
                }
            }
        }
        return false;
    }

    private int findLetter(char lookFor, Letter l, char[] s, int index){
        if (index >= s.length)
            return -1;
        index++;

        Letter next = new Letter(s[0]);

        char[] newArray = new char[s.length-1];
        for (int i =0; i< newArray.length; i++) {
            newArray[i] = s[i+1];
        }
        Letter nextL = multiply(l, next);
        if (nextL.letter == lookFor && nextL.positive)
            return index;
        return findLetter(lookFor, nextL, newArray, index);
    }

    private Letter multiplyRest(Letter l, char[] s){
        if (s.length == 0) {
            return l;
        }
        Letter next = new Letter(s[0]);
        char[] newArray = new char[s.length-1];
        for (int i =0; i< newArray.length; i++) {
            newArray[i] = s[i+1];
        }
        return multiplyRest(multiply(l,next),newArray);
    }

    private Letter multiply(Letter a, Letter b){
        Letter res = new Letter(b.letter);

        if (b.letter == '1') {
            res.letter = a.letter;
        } else if (a.letter == b.letter) {
            res.letter = '1';
            res.positive = false;
        } else {
            if (a.letter == 'i') {
                if (b.letter == 'j'){
                    res.letter = 'k';
                } else if (b.letter == 'k'){
                    res.letter = 'j';
                }
            } else if (a.letter == 'j') {
                if (b.letter == 'i'){
                    res.letter = 'k';
                    res.positive = false;
                } else if (b.letter == 'k'){
                    res.letter = 'i';
                }
            } else if (a.letter == 'k') {
                if (b.letter == 'i'){
                    res.letter = 'j';
                } else if (b.letter == 'j'){
                    res.letter = 'i';
                    res.positive = false;
                }
            }
        }

        boolean posIn = pos(a.positive, b.positive);
        res.positive = pos(res.positive, posIn);
        return res;
    }

    private boolean pos(boolean a, boolean b) {
        return (a && b) || (!a && !b);
    }
    private class Letter {
        public boolean positive;
        public char letter;
        public Letter(char l){
            letter = l;
            positive = true;
        }
    }
}
