import java.io.*;
import java.util.*;
import java.text.*;

/**
 * @author Roman Elizarov
 */
public class A extends Thread {
	public static void main(String[] args) throws FileNotFoundException, InterruptedException {
		Locale.setDefault(Locale.US);
		if (args.length == 0)
			args = new String[] { "A.in" };
		for (String infile : args)
			new A().go(infile);
	}

	private Scanner in;
	private PrintWriter out;

	private void go(String infile) throws FileNotFoundException, InterruptedException {
		open(infile);
		start();
		join();
		close();
	}

	private void open(String infile) throws FileNotFoundException {
		String outfile = infile.replaceFirst("(\\.in)?$", ".out");
		System.out.printf("Processing %s, writing %s...%n", infile, outfile);
		in = new Scanner(new File(infile));
		out = new PrintWriter(new File(outfile));
	}

	private void close() {
		if (in != null)
			in.close();
		if (out != null)
			out.close();
	}

	public void run() {
		int n = in.nextInt();
		int lastp = 0;
		boolean nl = true;
		long start = System.currentTimeMillis();
		for (int i = 1; i <= n; i++) {
			if (nl) {
				System.out.print(new SimpleDateFormat("HH:mm:ss.SSS").format(new Date()) + " : ");
				nl = false;
			}
			doCase(i);
			System.out.print(".");
			int p = i * 20 / n;
			if (lastp != p) {
				System.out.printf("%d%%, ~%d sec more to go%n", (i * 100 / n), (System.currentTimeMillis() - start) * (n - i) / i / 1000);
				lastp = p;
				nl = true;
			}
		}
	}

	int m;
	int ic;

	int[] nv;
	boolean[] g;
	boolean[] c;
	int[][] dp;

	private static final int INF = Integer.MAX_VALUE / 2 - 1;

	private void doCase(int caseNumber) {
		// read case
		m = in.nextInt();
		int v = in.nextInt();
		ic = (m - 1) / 2;
		nv = new int[m];
		g = new boolean[ic];
		c = new boolean[ic];
		for (int i = 0; i < ic; i++) {
			g[i] = in.nextInt() != 0;
			c[i] = in.nextInt() != 0;
		}
		for (int i = ic; i < m; i++) {
			nv[i] = in.nextInt();
		}

		// solve case
		for (int i = ic; --i >= 0;) {
			nv[i] = fun(g[i], nv[left(i)], nv[right(i)]);
		}
		dp = new int[m][2];
		for (int i = 0; i < m; i++) {
			Arrays.fill(dp[i], -1);
		}

		// write case result
		int result = calc(0, v);
		if (result < INF)
			out.printf("Case #%d: %d%n", caseNumber, result);
		else
			out.printf("Case #%d: IMPOSSIBLE%n", caseNumber);
	}

	private int calc(int i, int goal) {
		if (dp[i][goal] >= 0)
			return dp[i][goal];
		if (nv[i] == goal)
			return dp[i][goal] = 0;
		if (i >= ic)
			return dp[i][goal] = INF;
		int result = INF;
		for (int a = 0; a < 2; a++) {
			for (int b = 0; b < 2; b++) {
				if (fun(g[i], a, b) == goal)
					result = Math.min(result, calc(left(i), a) + calc(right(i), b));
			}
		}
		if (c[i]) {
			for (int a = 0; a < 2; a++) {
				for (int b = 0; b < 2; b++) {
					if (fun(!g[i], a, b) == goal)
						result = Math.min(result, 1 + calc(left(i), a) + calc(right(i), b));
				}
			}
		}
		return dp[i][goal] = result;
	}

	private int fun(boolean g, int a, int b) {
		if (g) {
			return (a != 0 && b != 0) ? 1 : 0;
		} else
			return (a != 0 || b != 0) ? 1 : 0;
	}

	private int right(int i) {
		return 2 * i + 2;
	}

	private int left(int i) {
		return 2 * i + 1;
	}
}