package round3;

import java.io.*;
import java.util.Arrays;
import java.util.Scanner;

/**
 * @author Roman Elizarov
 */
public class B {
	private static final short EMPTY = 10001;

	private static final int OUT = -1;
	private static final int EDGE_MASK = 0x00ff;
	private static final int CORNER_MASK = 0xff00;

	private static final int CS = 8;

	public static void main(String[] args) throws IOException {
		new B().go();
	}

	Scanner in;
	PrintWriter out;

	private void go() throws IOException  {
		in = new Scanner(new File("src\\round3\\b.in"));
		out = new PrintWriter(new File("src\\round3\\b.out"));
		int t = in.nextInt();
		for (int tn = 1; tn <= t; tn++) {
			out.println("Case #" + tn + ": " + solveCase());
		}
		in.close();
		out.close();
	}

	int s;
	int m;
	int n;
	int n2;
	short[] type;
	short[] f;
	boolean[] g;
	int k;
	boolean bridge;
	boolean fork;
	boolean ring;

	private String solveCase() {
		readSizes();
		allocateField();
		assignTypes();
		readField();
		allocateStack();
		return solve();
	}

	String solve() {
		int lo = 1;
		int hi = m + 1;
		int minAns = m + 1;
		String ans = "none";
		g = new boolean[n2];
		while (lo < hi) {
			k = (lo + hi) / 2;
			bridge = false;
			fork = false;
			ring = false;
			Arrays.fill(g, false);
			for (int i = 0; i < s - 1; i++) {
				visitCornerOrEdge(i, 0);
				visitCornerOrEdge(s - 1 + i, i);
				visitCornerOrEdge(n - 1, s - 1 + i);
				visitCornerOrEdge(n - 1 - i, n - 1);
				visitCornerOrEdge(s - 1 - i, n - 1 - i);
				visitCornerOrEdge(0, s - 1 - i);
			}
			for (int pos = 0; pos < n2; pos++)
				if (type[pos] == 0 && free(pos) && !g[pos]) {
					ring = true;
					break;
				}
			boolean win = bridge || fork || ring;
			if (win) {
				hi = k;
				if (k < minAns) {
					StringBuilder sb = new StringBuilder();
					if (bridge)
						sb.append("bridge");
					if (fork) {
						if (sb.length() > 0)
							sb.append("-");
						sb.append("fork");
					}
					if (ring) {
						if (sb.length() > 0)
							sb.append("-");
						sb.append("ring");
					}
					sb.append(" in move ").append(k);
					ans = sb.toString();
					minAns = k;
				}
			} else
				lo = k + 1;
		}
		return ans;
	}

	void assignTypes() {
		type = new short[n2];
		for (int i = 0; i < s - 1; i++) {
			setType(i, 0, i == 0 ? (1 << CS) : 1);
			setType(s - 1 + i, i, i == 0 ? (2 << CS) : 2);
			setType(n - 1, s - 1 + i, i == 0 ? (4 << CS) : 4);
			setType(n - 1 - i, n - 1, i == 0 ? (8 << CS) : 8);
			setType(s - 1 - i, n - 1 - i, i == 0 ? (16 << CS) : 16);
			setType(0, s - 1 - i, i == 0 ? (32 << CS) : 32);
			for (int j = 0; j <= i; j++) {
				setType(j, s + i, OUT);
				setType(s + i, j, OUT);
			}
		}
//		System.out.println("-------------");
//		for (int i = 0; i < n; i++) {
//			for (int j = 0; j < n; j++) {
//				int pos = i * n + j;
//				if (type[pos] == OUT)
//					System.out.print(" xx");
//				else
//					System.out.printf(" %2d", 32 - Integer.numberOfLeadingZeros(type[pos]));
//			}
//			System.out.println();
//		}
	}

	private void readField() {
		for (short i = 1; i <= m; i++) {
			int x = in.nextInt() - 1;
			int y = in.nextInt() - 1;
			int pos = n * y + x;
			assert type[pos] != OUT;
			assert f[pos] == EMPTY;
			f[pos] = i;
		}
	}

	void allocateField() {
		n = 2 * s - 1;
		n2 = n * n;
		f = new short[n2];
		Arrays.fill(f, EMPTY);
	}

	private void readSizes() {
		s = in.nextInt();
		m = in.nextInt();
	}

	private void setType(int x, int y, int t) {
		int pos = n * y + x;
		assert type[pos] == 0;
		type[pos] = (short)t;
	}

	void visitCornerOrEdge(int x0, int y0) {
		int pos = n * y0 + x0;
		assert type[pos] != 0;
		assert type[pos] != OUT;
		if (g[pos])
			return;
		boolean free = free(pos);
		int mask = visit(x0, y0, pos, free);
		if (!free) {
			if (Integer.bitCount(mask & CORNER_MASK) >= 2)
				bridge = true;
			if (Integer.bitCount(mask & EDGE_MASK) >= 3)
				fork = true;
		}
	}

	int sp;
	short[] sx;
	short[] sy;
	int[] spos;
	int mask;

	void allocateStack() {
		sx = new short[n2];
		sy = new short[n2];
		spos = new int[n2];
	}

	void push(int x, int y, int pos, boolean free) {
		if (x < 0 || y < 0 || x >= n || y >= n || type[pos] == OUT || g[pos] || free != free(pos))
			return;
		sx[sp] = (short)x;
		sy[sp] = (short)y;
		spos[sp] = pos;
		g[pos] = true;
		mask |= type[pos];
		sp++;
	}

	private boolean free(int pos) {
		return f[pos] > k;
	}

	int visit(int x, int y, int pos, boolean free) {
		sp = 0;
		mask = 0;
		push(x, y, pos, free);
		while (sp > 0) {
			sp--;
			x = sx[sp];
			y = sy[sp];
			pos = spos[sp];
			push(x + 1, y, pos + 1, free);
			push(x - 1, y, pos - 1, free);
			push(x, y + 1, pos + n, free);
			push(x, y - 1, pos - n, free);
			push(x + 1, y + 1, pos + n + 1, free);
			push(x - 1, y - 1, pos - n - 1, free);
		}
		return mask;
	}
}
