import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;

public class WarGame {
	private ArrayList <Double> blocksFirst;
	private ArrayList <Double> blocksSecond;
	private int size;
	
	public WarGame (int sizeGame, ArrayList <Double> first, ArrayList <Double> second) {
		blocksFirst = first;
		blocksSecond = second;
		size = sizeGame;
		
		Collections.sort(blocksFirst, Collections.reverseOrder());
		Collections.sort(blocksSecond);
	}
	
	public int obtainPointsWar () {
		// The best strategy for the first player in War is to start using the biggest blocks
		boolean [] used;
		int worse, points;
		boolean found;
		
		used = new boolean [size];
		Arrays.fill(used, false);
		points = 0;
		
		for (int i=0; i<size; i++) { // Larger to smaller
			worse = -1;
			found = false;
			
			for (int j=0; j<size && !found; j++) { // Smaller to larger
				if (!used[j]) {
					if (worse == -1) {
						worse = j;
					}
					
					if (blocksSecond.get(j) > blocksFirst.get(i)) {
						found = true;
						used[j] = true;
					}
				}
			}
			
			if (!found) {
				points++;
				used[worse] = true;
			}
		}
		
		return points;
	}
	
	public int obtainPointsDeceitfulWar () {
		// With Deceitful War, you can only win with the pairs of values that obtain a better weight with respect to the other player
		boolean [] used;
		int better, points;
		boolean found;
		
		used = new boolean [size];
		Arrays.fill(used, false);
		points = 0;
		
		for (int i=0; i<size; i++) { // Larger to smaller
			better = -1;
			found = false;
			
			for (int j=size-1; j>-1 && !found; j--) { // Larger to smaller
				if (!used[j]) {
					if (better == -1) {
						better = j;
					}
					
					if (blocksSecond.get(j) < blocksFirst.get(i)) {
						found = true;
						used[j] = true;
					}
				}
			}
			
			if (found) {
				points++;
			}
			else {
				used[better] = true;
			}
		}
		
		return points;
	}

	public String toString() {
		String current = "";
		
		current += ("Number of blocks is " + size + "\n");
		current += ("First player blocks are " + blocksFirst.toString() + "\n");
		current += ("First player blocks are " + blocksSecond.toString() + "\n");
		
		current += "\n";
		
		return current;
	}
}
