import java.io.*;
import java.util.Arrays;
import java.util.Locale;
import java.util.Scanner;

public class SpinningBlade {

    int R, C, D;
    String[] a;



    private long[][] precompute(long[][] m) {
        long[][] s = new long[R][C];
        s[0][0] = m[0][0];
        for (int i = 1; i < C; i++) {
            s[0][i] = m[0][i] + s[0][i-1];
        }
        for (int i = 1; i < R; i++) {
            s[i][0] = m[i][0] + s[i-1][0];
        }

        for (int i = 1; i < R; i++) {
            long sum = m[i][0];
            for (int j = 1; j < C; j++) {
                sum += m[i][j];
                s[i][j] = s[i-1][j] + sum;
            }
        }
        return s;
    }

    private long sum(long[][] m, int i0, int j0, int i1, int j1) {
        return m[i1][j1] - (i0 == 0? 0 :m[i0-1][j1]) - (j0 == 0? 0: m[i1][j0-1]) + (i0 == 0 || j0 == 0? 0: m[i0-1][j0-1]);
    }

    private Object bruteSolve() throws Exception {
        int[][] m = new int[R][C];
        for (int i = 0; i < R; i++) {
            for (int j = 0; j < C; j++) {
                char ch = a[i].charAt(j);
                m[i][j] = (ch - '0') + D;
            }
        }

        int bestK = -1;
        for (int i0 = 0; i0 < R; i0++) {
            for (int j0 = 0; j0 < C; j0++) {
                for (int K = 3; i0 + K <= R && j0 + K <= C; K++) {

                    int si = 0, sj = 0, sm = 0;
                    for (int i = 0; i < K ; i++) {
                        for (int j = 0; j < K; j++) {
                            if ((i == 0 || i == K-1) && (j == 0 || j == K-1)) continue;
                            si += i * m[i+i0][j+j0];
                            sj += j * m[i+i0][j+j0];
                            sm += m[i+i0][j+j0];
                        }
                    }
                    si *= 2; sj *= 2;
                    if (si % sm != 0 || sj % sm != 0) continue;
                    si /= sm;
                    sj /= sm;
                    if (si == sj && si+1 == K) {
                        bestK = Math.max(K, bestK);
                    }


                }
            }
        }
        return bestK < 3? "IMPOSSIBLE": bestK;
    }

    private Object solve() throws Exception {
        if (true) return bruteSolve();

        long[][] m = new long[R][C];
        long[][] mi = new long[R][C];
        long[][] mj = new long[R][C];
        for (int i = 0; i < R; i++) {
            for (int j = 0; j < C; j++) {
                char ch = a[i].charAt(j);
                m[i][j] = (ch - '0') + D;
                mi[i][j] = m[i][j] * i;
                mj[i][j] = m[i][j] * j;
            }
        }

        long [][] si = precompute(mi);
        long [][] sj = precompute(mj);
        long [][] sm = precompute(m);

        int bestK = -1;
        for (int i = 0; i < R; i++) {
            for (int j = 0; j < C; j++) {
                for (int K = 3; i + K <= R && j + K <= C; K++) {
                    long sumi = sum(si, i, j, i + K - 1, j + K - 1) - mi[i][j] - mi[i+K-1][j] - mi[i][j+K-1] - mi[i+K-1][j+K-1];
                    long sumj = sum(sj, i, j, i + K - 1, j + K - 1) - mj[i][j] - mj[i+K-1][j] - mj[i][j+K-1] - mj[i+K-1][j+K-1];
                    long summ = sum(sm, i, j, i + K - 1, j + K - 1) - m[i][j] - m[i+K-1][j] - m[i][j+K-1] - m[i+K-1][j+K-1];
                    if (sumi % summ != 0 || sumj % summ != 0) continue;
                    sumi /= summ;
                    sumj /= summ;
                    if (sumi - i == sumj - j && 2*(sumi-i) + 1 == K) {
                        bestK = Math.max(K, bestK);
                    }
                }
            }
        }

        return bestK < 3? "IMPOSSIBLE": bestK;
    }

    private void load() throws Exception {
        R = nextInt();
        C = nextInt();
        D = nextInt();
        a = nextTokenArray(R);


        log.print("R: " + R + ", C: " + C + ", D:" + D + ", a: " + Arrays.toString(a));
    }


    private static final String PREFIX = "B-small-attempt2";
    private static final String PATH = "d:/gcjam11/r2/";
    private static final String POSTFIX_IN = ".in";
    private static final String POSTFIX_OUT = ".out";
    private static final PrintStream log = System.out;

    public static void main(String args[]) throws Exception {
        Locale.setDefault(Locale.US);
        InputStreamReader reader = new InputStreamReader(new BufferedInputStream(new FileInputStream(PATH + PREFIX + POSTFIX_IN)));
        PrintStream out = new PrintStream(new FileOutputStream(PATH + PREFIX + POSTFIX_OUT));
        Scanner in = new Scanner(reader);

        long t0 = System.nanoTime();
        int testCount = in.nextInt(); in.nextLine();
        for (int testIndex = 1; testIndex <= testCount; testIndex++) {
            log.printf("Data #%d: ", testIndex);

            SpinningBlade s = new SpinningBlade();
            s.in = in;
            s.load();
            s.in = null;
            log.println();

            long t1 = System.nanoTime();
            String result = "Case #" + testIndex + ": " + s.solve();

            out.println(result);
            log.println(result);
            log.printf("Time #%d: %.6f sec\n\n", testIndex, (System.nanoTime() - t1) / 1e9);
        }
        log.printf("Total time: %.6f sec", (System.nanoTime() - t0)/1e9);

        reader.close();
        out.close();
    }

    private Scanner in;
    private int nextInt() { return in.nextInt(); }
    private long nextLong() { return in.nextLong(); }
    private double nextDouble() { return Double.parseDouble(in.next()); }
    private String nextLine() { return in.nextLine().trim(); }
    private void skipLine() { in.nextLine(); }
    private String next() { return in.next().trim(); }
    private int[] nextIntArray(int size) { int[] a = new int[size]; for (int i = 0; i < size; i++) a[i] = in.nextInt(); return a; }
    private long[] nextLongArray(int size) { long[] a = new long[size]; for (int i = 0; i < size; i++) a[i] = in.nextLong(); return a; }
    private double[] nextDoubleArray(int size) { double[] a = new double[size]; for (int i = 0; i < size; i++) a[i] = Double.parseDouble(in.next());  return a; }
    private String[] nextLineArray(int size) { String[] a = new String[size]; for (int i = 0; i < size; i++) a[i] = in.nextLine().trim(); return a; }
    private String[] nextTokenArray(int size) { String[] a = new String[size]; for (int i = 0; i < size; i++) a[i] = in.next().trim(); return a; }
}
