package com.google.codejam;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.List;

public class Repeater {
	
	private BufferedReader in;
	private BufferedWriter out;
	private Node [] words;
	
	private class Node {
		char c;
		int count = 1;
		Node next = null;
		public Node(char c){
			this.c = c;
		}
	}
	
	public static void main(String [] args){
		new Repeater(new File(args[0]), new File(args[1])).doIt();
	}
	
	private Repeater(File inFile, File outFile){
		try {
			in = new BufferedReader(new FileReader(inFile));
			out = new BufferedWriter(new FileWriter(outFile));
		} catch (Exception e){
			e.printStackTrace();
		}
	}
	
	private void doIt(){
		try {
			int n = Integer.parseInt(in.readLine());
			StringBuilder sb = new StringBuilder();
			for (int i = 0; i < n; i++){
				sb.append("Case #")
				.append(i + 1)
				.append(": ")
				.append(compute())
				.append((i + 1 == n)?"":"\n");
			}
			String ret = sb.toString();
			System.out.println(ret);
			out.write(ret);
			in.close();
			out.close();
		}catch(Exception e){
			e.printStackTrace();
		}
	}
	
	private void read(){
		try {
			int num = Integer.parseInt(in.readLine());
			if (num > 0){
				words = new Node[num];
				char[]  swp;
				Node swpNode;
				for (int i = 0; i < num; i++){
					swp = in.readLine().toCharArray();
					swpNode = new Node(swp[0]);
					words[i] = swpNode;
					if (swp.length > 1){
						for (int j = 1; j < swp.length; j++){
							if (swpNode.c == swp[j]){
								swpNode.count++;
							} else {
								swpNode.next = new Node(swp[j]);
								swpNode = swpNode.next;
							}
						}
					}
				}
			}
		}catch(Exception e){
			e.printStackTrace();
		}
	}
	
	private boolean areTheSame(){
		String reference = getText(words[0], "");
		if (words.length > 1){
			for (int i = 1; i < words.length; i++){
				if (!reference.equals(getText(words[i], ""))){
					return false;
				}
			}
		}
		return true;
	}
	
	private String getText(Node n, String soFar){
		if (n == null){
			return soFar;
		} else {
			return getText(n.next, soFar + n.c);
		}
	}
	
	private String getStepCount(){
		Integer[] averages = getAverages();
		Node[] swp = words;
		int counter = 0;
		int iter = 0;
		while (swp[0] != null){
			for (int i = 0; i < swp.length; i++){
				counter += Math.abs(averages[iter] - swp[i].count);
				swp[i] = swp[i].next;
			}
			iter++;
		}
		
		return counter + "";
	}
	
	private Integer [] getAverages(){
		Node[] swp = new Node[words.length];
		for (int i = 0; i < swp.length; i++){
			swp[i] = new Node(words[i].c);
			swp[i].count = words[i].count;
			swp[i].next = words[i].next;
		}
		List<Integer> ret = new ArrayList<Integer>();
		while (swp[0] != null){
			float sum = 0f;
			for (int i = 0; i < swp.length; i++){
				sum += (float)swp[i].count;
				swp[i] = swp[i].next;
			}
			sum /= (float)swp.length;
			ret.add(new Integer(Math.round(sum)));
		}
		Integer [] retArray = new Integer[ret.size()];
		retArray = ret.toArray(retArray);
		return retArray;
	}
	
	private String compute(){
		read();
		if (!areTheSame()){
			return "Fegla Won";
		}
		
		return "" + getStepCount();
	}
	
}
