package com.google.codejam;

import java.awt.Point;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.List;

public class MineSweeper {
	
	private static final char MINE = '*';
	private static final char CLICK = 'c';
	private static final char FREE = '.';
	private static final char [] MAP = {'0', '1', '2', '3', '4', '5', '6', '7', '8'};
	
	private int height;
	private int width;
	private int numberOfMines;
	
	private char[][] field;
	private char[][] clickedField;
	
	public static void main(String [] args){
		MineSweeper ms = new MineSweeper();
		ms.doIt(new File(args[0]), new File(args[1]));
//		ms.test();
	}
	
	private void test(){
		height = 5;
		width = 2;
		numberOfMines = 3;
		generateField();
		doClick();
		printBothFields();
		System.out.println(isFieldDoneWithOneClick());
	}
	
	public void doIt(File inFile, File outFile){
		BufferedReader in = null;
		BufferedWriter out = null;
		int log = 0;
		try {
			StringBuilder sb = new StringBuilder();
			String [] buffer;
			in = new BufferedReader(new FileReader(inFile));
			out = new BufferedWriter(new FileWriter(outFile));
			
			int n = Integer.parseInt(in.readLine());
			
			for (int i = 0; i < n; i++){
				log = i;
				buffer = in.readLine().split(" ");
				width = Integer.parseInt(buffer[1]);
				height = Integer.parseInt(buffer[0]);
				numberOfMines = Integer.parseInt(buffer[2]);
				
				sb.append("Case #")
					.append(i + 1)
					.append(":\n")
					.append(doIt());
				if (i + 1 < n){
					sb.append("\n");
				}
			}
			
			String swp = sb.toString();
			System.out.println(swp);
			out.write(swp);
		} catch (Exception e){
			System.out.println(log);
			e.printStackTrace();
		} finally {
			if (in != null) try { in.close(); } catch (Exception e) {}
			if (out != null) try { out.close(); } catch (Exception e) {}
		}
	}
	
	private String doIt(){
		generateField();
		doClick();
		if (isFieldDoneWithOneClick()){
			return printField();
		} else {
			return "Impossible";
		}
	}
	
	private void doClick(){
		Point swp;
		List<Point> toExplore = new ArrayList<Point>();
		toExplore.add(new Point(height - 1, width - 1));
		field[height - 1][width - 1] = CLICK;
		
		while (toExplore.size() > 0){
			swp = toExplore.remove(0);
			clickedField[swp.x][swp.y] = countMines(swp);
			
			if (clickedField[swp.x][swp.y] == '0'){
				if (swp.x != 0 && clickedField[swp.x - 1][swp.y] != MINE){
					toExplore.add(new Point(swp.x - 1, swp.y));
				}
				if (swp.x != 0 && swp.y != 0 && clickedField[swp.x - 1][swp.y - 1] != MINE){
					toExplore.add(new Point(swp.x - 1, swp.y - 1));
				}
			}
			
			if (swp.x + 1 == height && swp.y != 0 && clickedField[swp.x][swp.y - 1] != MINE){
				toExplore.add(new Point(swp.x, swp.y - 1));
			}
		}
	}
	
	private boolean isFieldDoneWithOneClick(){
		if (height * width == numberOfMines + 1){
			return true;
		}
		if (clickedField[height - 1][width - 1] == '0' && !containsDot()){
			return true;
		}
		return false;
	}
	
	private boolean containsDot(){
		for (int i = 0; i < clickedField.length; i++)
			for (int j = 0; j < clickedField[0].length; j++)
				if (clickedField[i][j] == '.')
					return true;
		return false;
	}
	
	private char countMines(Point p){
		int ret = 0;
		if (p.x > 0 && field[p.x - 1][p.y] == MINE)	ret++;
		if (p.y > 0 && field[p.x][p.y - 1] == MINE) ret++;
		if (p.x > 0 && p.y > 0 && field[p.x - 1][p.y - 1] == MINE)ret++;
		
		return MAP[ret];
	}
	
	private void generateField(){
		clearField();
		int set = 0;
		int wi = 0;
		int hi = 0;
		
		while (set < numberOfMines) {
			if (field.length - hi < field[0].length - wi){
				for (int i = wi; i < field.length; i++){
					field[i][hi] = MINE;
					clickedField[i][hi] = MINE;
					if (++set == numberOfMines) return;
				}
				hi++;
			} else {
				for (int i = hi; i < field[0].length; i++){
					field[wi][i] = MINE;
					clickedField[wi][i] = MINE;
					if (++set == numberOfMines) return;
				}
				wi++;
			}
		}
	}
	
	private void clearField(){
		field = new char[height][width];
		clickedField = new char[height][width];
		for (int i = 0; i < field.length; i++){
			for (int j = 0; j < field[i].length; j++){
				field[i][j] = FREE;
				clickedField[i][j] = FREE;
			}
		}
	}

	private void printBothFields(){
		System.out.println("Normal\n" + printField());
		System.out.println("Clicked");
		for (int i = 0; i < clickedField.length; i++){
			for (int j = 0; j < clickedField[i].length; j++){
				System.out.print(clickedField[i][j]);
			}
			System.out.println();
		}
	}
	
	private String printField(){
		StringBuilder sb = new StringBuilder();
		
		for (int i = 0; i < field.length; i++){
			for (int j = 0; j < field[i].length; j++){
				sb.append(field[i][j]);
			}
			if (i + 1 != field.length){
				sb.append("\n");
			}
		}
		
		return sb.toString();
	}
}
