package com.goose.qualification;

import java.io.*;
import java.util.Arrays;
import java.util.StringTokenizer;

import static java.lang.Double.parseDouble;
import static java.lang.Integer.parseInt;
import static java.lang.Long.parseLong;
import static java.lang.System.exit;

/**
 * Created by michal on 08.04.2017.
 */
public class BathroomStalls {


    static BufferedReader in;
    static PrintWriter out;
    static StringTokenizer tok;

    static int numOfTests;
    static int caseNum;

    static char[] stall;
    static int[] Ls;
    static int[] Rs;

    public static boolean isOccupied(int index) {
        return stall[index] == 'O';
    }

    public static boolean isEmpty(int index) {
        return stall[index] != 'O';
    }

    public static void occupyStall(int index) {
        stall[index] = 'O';
    }

    public static void updateLsRs(int occupiedStallIndex) {
        for(int rsIndex = occupiedStallIndex - 1; rsIndex > 0; rsIndex--) {
            if(isEmpty(rsIndex)) { Rs[rsIndex] = occupiedStallIndex - rsIndex - 1; }
            else { break; }
        }

        for(int lsIndex = occupiedStallIndex + 1; lsIndex < stall.length - 1; lsIndex++) {
            if(isEmpty(lsIndex)) { Ls[lsIndex] = lsIndex - occupiedStallIndex - 1; }
            else { break; }
        }
    }

    public static void createStalls(int N) {
        stall = new char[N+2];
        stall[0] = 'O';
        stall[N+1] = 'O';
        Ls = new int[N+2];
        Rs = new int[N+2];
    }

    public static void calculateLs(int index) {
        Ls[index] = 0;
        int i = index - 1;
        while (isEmpty(i)) { Ls[index]++; i--; }
    }

    public static void calculateRs(int index) {
        Rs[index] = 0;
        int i = index + 1;
        while (isEmpty(i)) { Rs[index]++; i++; }
    }

    public static int chooseStall() {
        int bestIndexSofar = 0;
        int bestMinLsRs = Integer.MIN_VALUE, currentMinLsRs;
        int bestMaxLsRs = Integer.MIN_VALUE, currentMaxLsRs;


        for(int index= 1;index < stall.length - 1; index++) {
            if(isOccupied(index)) { continue; }
            currentMinLsRs = Math.min(Ls[index], Rs[index]);
            currentMaxLsRs = Math.max(Ls[index], Rs[index]);
            //System.out.println("index:" + index + " currentMinLsRs:" + currentMinLsRs + ", currentMaxLsRs:" + currentMaxLsRs);
            if(currentMinLsRs > bestMinLsRs ||
                    (currentMinLsRs == bestMinLsRs && currentMaxLsRs > bestMaxLsRs)  ){
                bestIndexSofar = index;
                bestMinLsRs = currentMinLsRs;
                bestMaxLsRs = currentMaxLsRs;
            }
        }
        return bestIndexSofar;
    }

    public static void solve() throws IOException {
        printCase();

        long N = nextLong();
        long K = nextLong();

        if(N == K) {
            out.print("0 0");
            return;
        }

        int N_int = (int) N;
        int K_int = (int) K;

        int stallToOccupy = 0;

        createStalls(N_int);
        updateLsRs(N_int + 1);
        updateLsRs(0);

        //printStallsState();

        while(K_int > 0) {
            stallToOccupy = chooseStall();
            //System.out.println("stallToOccupy:" + stallToOccupy);
            occupyStall(stallToOccupy);
            updateLsRs(stallToOccupy);
            //printStallsState();
            K_int--;
        }

        out.print(String.format("%d %d", Math.max(Ls[stallToOccupy], Rs[stallToOccupy]), Math.min(Ls[stallToOccupy], Rs[stallToOccupy])));

    }

    private static void printStallsState() {
        System.out.println("stalls:" + Arrays.toString(stall));
        System.out.println("Rs:" + Arrays.toString(Rs));
        System.out.println("Ls:" + Arrays.toString(Ls));
    }

    static void printCase() {
        out.print("Case #" + caseNum + ": ");
    }

    static void printlnCase() {
        out.println("Case #" + caseNum + ": ");
    }

    static int nextInt() throws IOException {
        return parseInt(next());
    }

    static long nextLong() throws IOException {
        return parseLong(next());
    }

    static double nextDouble() throws IOException {
        return parseDouble(next());
    }

    static String next() throws IOException {
        while(tok == null || !tok.hasMoreTokens() ) {
            tok = new StringTokenizer(in.readLine());
        }
        return tok.nextToken();
    }

    public static void main(String[] args)  {

        try {
            in = new BufferedReader(new InputStreamReader(System.in));
            out = new PrintWriter(new OutputStreamWriter(System.out));
            numOfTests = nextInt();

            for(caseNum = 1; caseNum <= numOfTests; caseNum++) {
                if(caseNum != 1) { out.print("\n"); }
                solve();
            }
            in.close();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
            exit(1);
        }


    }

}
