package com.goose;

import java.io.*;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

public class HouseOfPancakes {

    private static class PancakesConfiguration {

        public static HashMap<PancakesConfiguration, Integer> pancakesRoundCountMemoizer = new HashMap<>();

        Integer[] pancakes; //sorted
        final Integer pancakesNum;
        final Integer maxPancake;
        Integer maxPancakesCount;
        public boolean isPancakesConfigEmpty() {
            return pancakes == null || pancakes.length ==0;
        }

        public Integer getMaximalRounds() {
            if(isPancakesConfigEmpty()) return 0;
            return pancakes[0];
        }

        public PancakesConfiguration(Integer[] pancakes) {
            this.pancakes = pancakes;
            Arrays.sort(this.pancakes, Comparator.<Integer>reverseOrder());
            pancakesNum = pancakes.length;
            maxPancake = this.pancakes[0];
            maxPancakesCount = 1;
            for (int i = 1; i < pancakesNum; i++) {
                if(pancakes[i].equals(maxPancake)) {
                    maxPancakesCount++;
                } else {
                    break;
                }

            }
            //System.out.println(this.toString());
        }

        public boolean isDeclaringSpecialMinutesWorthIt() {
            if(isPancakesConfigEmpty()) return false;

            Integer pancakesSaving = (int) (maxPancake / 2) - maxPancakesCount;
            return pancakesSaving > 0;
        }

        public PancakesConfiguration declareSpecialMinutes(int howMuchToTake) {

            List<Integer> newPancakes = new ArrayList<>(Arrays.asList(Arrays.copyOfRange(pancakes, maxPancakesCount, pancakesNum)));

            for (int i = 0; i < maxPancakesCount; i++) {
                newPancakes.add(howMuchToTake);
                newPancakes.add(maxPancake - howMuchToTake);
            }

            PancakesConfiguration afterSplitting = new PancakesConfiguration(newPancakes.toArray(new Integer[newPancakes.size()]));
            return afterSplitting;
        }


        @Override
        public String toString() {

            return  "PancakesConfiguration{" +
                    "pancakes=" + Arrays.toString(pancakes) +
                    ", pancakesNum=" + pancakesNum +
                    ", maxPancake=" + maxPancake +
                    ", maxPancakesCount=" + maxPancakesCount +
                    '}';
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PancakesConfiguration that = (PancakesConfiguration) o;

            // Probably incorrect - comparing Object[] arrays with Arrays.equals
            if (!Arrays.equals(pancakes, that.pancakes)) return false;
            if (!pancakesNum.equals(that.pancakesNum)) return false;
            if (!maxPancake.equals(that.maxPancake)) return false;
            return maxPancakesCount.equals(that.maxPancakesCount);

        }

        @Override
        public int hashCode() {
            int result = Arrays.hashCode(pancakes);
            result = 31 * result + pancakesNum.hashCode();
            result = 31 * result + maxPancake.hashCode();
            result = 31 * result + maxPancakesCount.hashCode();
            return result;
        }

        public Integer getMinRoundsCount() {
            //if(pancakesRoundCountMemoizer.containsKey(this)) return pancakesRoundCountMemoizer.get(this);
            Integer result;
            if(isPancakesConfigEmpty()) { return 0; }
            //if(!isDeclaringSpecialMinutesWorthIt()) {
                //pancakesRoundCountMemoizer.put(this, getMaximalRounds());
                //return pancakesRoundCountMemoizer.get(this);
            //    return getMaximalRounds();
            //}
            result = getMaximalRounds();
            for(int i = 2;i<maxPancake-1;i++) {
                result = Math.min(result, maxPancakesCount + declareSpecialMinutes(i).getMinRoundsCount());
            }

            //result = Math.min(getMaximalRounds(), maxPancakesCount + declareSpecialMinutes().getMinRoundsCount());
            pancakesRoundCountMemoizer.put(this, result);
            return result;
        }
    }

    private Integer testCaseNum;
    private List<Integer> solutions;
    private List<Integer[]> testCasesList;


    public void writeSolutionToFile(String fileName) throws IOException {
        BufferedWriter bf = null;

        try {
            FileWriter fw = new FileWriter(fileName, false);
            bf = new BufferedWriter(fw);
            for(int i=1;i<solutions.size();i++) {
                bf.write("Case #" + i + ": " + solutions.get(i - 1).toString());
                bf.newLine();
            }
            bf.write("Case #" + solutions.size() + ": " + solutions.get(solutions.size() - 1).toString());
        }finally {
            if(bf != null) {
                bf.close();
            }
        }
    }

    public HouseOfPancakes(String fileName) throws IOException {
        BufferedReader br = new BufferedReader(new FileReader(fileName));

        try {
            String line = br.readLine();
            this.testCaseNum = Integer.parseInt(line);
            testCasesList = new ArrayList<>(testCaseNum);
            solutions = new ArrayList<>(testCaseNum);
            Integer n;
            String[] numList;
            Integer numDiners;
            for(int caseNum=0;caseNum<testCaseNum;caseNum++) {
                line = br.readLine();
                numDiners = Integer.parseInt(line);
                testCasesList.add(new Integer[numDiners]);
                line = br.readLine();
                numList = line.split(" ");
                for (int i = 0; i < numDiners ; i++) {
                    testCasesList.get(caseNum)[i] = Integer.parseInt(numList[i]);
                }

            }

        }finally {

        }

    }

    public void solve() {
        PancakesConfiguration pc = null;

        for (int i = 0; i < testCaseNum ; i++) {
            PancakesConfiguration.pancakesRoundCountMemoizer.clear();
            pc = new PancakesConfiguration(testCasesList.get(i));
            solutions.add(pc.getMinRoundsCount());
            System.out.println("Case #" + (i + 1) + ": " + pc + " " + " minRoundsCount:" + pc.getMinRoundsCount());
        }
        //System.out.println(PancakesConfiguration.pancakesRoundCountMemoizer.size());
    }

    public static void main(String[] args) throws IOException {
	    HouseOfPancakes houseOfPancakes = new HouseOfPancakes("resources/B-small-attempt2.in");
        houseOfPancakes.solve();
        houseOfPancakes.writeSolutionToFile("resources/B-small-attempt2.out");

        //HouseOfPancakes houseOfPancakes = new HouseOfPancakes("resources/other.txt");
        //houseOfPancakes.solve();
        //houseOfPancakes.writeSolutionToFile("resources/other.out");

    }
}
