package com.goose;

import com.sun.org.apache.xpath.internal.operations.Bool;

import java.io.*;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Omino {

    private Integer testCaseNum;
    private List<String> solutions;
    private List<OminoConfig> testCasesList;

    public Omino(String fileName) throws IOException {
        BufferedReader br = new BufferedReader(new FileReader(fileName));

        try {
            String line = br.readLine();
            this.testCaseNum = Integer.parseInt(line);
            testCasesList = new ArrayList<>(testCaseNum);
            solutions = new ArrayList<>(testCaseNum);
            String[] numList;
            for(int caseNum=0;caseNum<testCaseNum;caseNum++) {
                line = br.readLine();
                numList = line.split(" ");
                testCasesList.add(new OminoConfig(Integer.parseInt(numList[0]), Integer.parseInt(numList[1]), Integer.parseInt(numList[2])));
            }
        }finally {

        }
    }

    public static class OminoConfig {
        RCGrid rcGrid;
        public Integer X;
        public static Map<OminoConfig, Boolean> gabrielWins;

        static {
            gabrielWins = new HashMap<>();
            for(int i=1;i<=4;i++) {
                for(int j=1;j<=4;j++) {
                    gabrielWins.put(new OminoConfig(1, i, j), true);
                }
            }
            for(int i=1;i<=4;i++) {
                for(int j=1;j<=4;j++) {
                    gabrielWins.put(new OminoConfig(2, i, j), (i*j % 2) ==0);
                }
            }

            gabrielWins.put(new OminoConfig(3, 1, 1), false);
            gabrielWins.put(new OminoConfig(3, 1, 2), false);
            gabrielWins.put(new OminoConfig(3, 1, 3), false);
            gabrielWins.put(new OminoConfig(3, 1, 4), false);

            gabrielWins.put(new OminoConfig(3, 2, 2), false);
            gabrielWins.put(new OminoConfig(3, 2, 3), true);
            gabrielWins.put(new OminoConfig(3, 2, 4), false);

            gabrielWins.put(new OminoConfig(3, 3, 3), true);
            gabrielWins.put(new OminoConfig(3, 3, 4), true);

            gabrielWins.put(new OminoConfig(3, 4, 4), false);

            gabrielWins.put(new OminoConfig(4, 1, 1), false);
            gabrielWins.put(new OminoConfig(4, 1, 2), false);
            gabrielWins.put(new OminoConfig(4, 1, 3), false);
            gabrielWins.put(new OminoConfig(4, 1, 4), false);

            gabrielWins.put(new OminoConfig(4, 2, 2), false);
            gabrielWins.put(new OminoConfig(4, 2, 3), false);
            gabrielWins.put(new OminoConfig(4, 2, 4), false);

            gabrielWins.put(new OminoConfig(4, 3, 3), false);
            gabrielWins.put(new OminoConfig(4, 3, 4), true);

            gabrielWins.put(new OminoConfig(4, 4, 4), true);

        }

        public OminoConfig(Integer x, Integer r, Integer c) {
            rcGrid = new RCGrid(r, c);
            X = x;
        }

        public boolean canBeSolved() {
            //return gabrielWins.get(this);
            if(X.equals(1)) { return true; } //Gabriel wins
            if(X.equals(2)) {
                return (rcGrid.C * rcGrid.R) % 2 == 0;
            }
            if(X.equals(3)) {
                if( (rcGrid.C * rcGrid.R) % 3 == 0) {
                    if(rcGrid.C.equals(1) || rcGrid.R.equals(1)) { return false; }
                    else { return true; }
                } else { return false; }
            }
            if(X.equals(4)) {
                if( (rcGrid.C * rcGrid.R) % 4 == 0) {
                    if(rcGrid.C.equals(1) || rcGrid.R.equals(1)) { return false; }
                    if(rcGrid.C.equals(2) || rcGrid.R.equals(2)) { return false; }
                    if(rcGrid.C.equals(3) || rcGrid.R.equals(3)) { return true; }
                    else { return true; }
                } else { return false; }
            }
            return true;
        }

        public static class RCGrid {
            public Integer R;
            public Integer C;

            public Integer getField() {
                return R * C;
            }
            public boolean isFieldEven() {
                return getField() % 2 == 0;
            }

            public RCGrid(Integer r, Integer c) {
                if(r < c) {
                    R = r;
                    C = c;
                } else {
                    R = c;
                    C = r;
                }
            }

            @Override
            public boolean equals(Object o) {
                if (this == o) return true;
                if (o == null || getClass() != o.getClass()) return false;

                RCGrid rcGrid = (RCGrid) o;

                if (R != null ? !R.equals(rcGrid.R) : rcGrid.R != null) return false;
                return !(C != null ? !C.equals(rcGrid.C) : rcGrid.C != null);

            }

            @Override
            public int hashCode() {
                int result = R != null ? R.hashCode() : 0;
                result = 31 * result + (C != null ? C.hashCode() : 0);
                return result;
            }

            @Override
            public String toString() {
                return "RCGrid{" +
                        "R=" + R +
                        ", C=" + C +
                        '}';
            }
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            OminoConfig that = (OminoConfig) o;

            if (rcGrid != null ? !rcGrid.equals(that.rcGrid) : that.rcGrid != null) return false;
            return !(X != null ? !X.equals(that.X) : that.X != null);

        }

        @Override
        public int hashCode() {
            int result = rcGrid != null ? rcGrid.hashCode() : 0;
            result = 31 * result + (X != null ? X.hashCode() : 0);
            return result;
        }

        @Override
        public String toString() {
            return "OminoConfig{" +
                    "rcGrid=" + rcGrid +
                    ", X=" + X +
                    '}';
        }
    }

    public void solve() {
        for(OminoConfig ominoConfig: testCasesList) {
            if(ominoConfig.canBeSolved()) {
                solutions.add("GABRIEL");
            } else {
                solutions.add("RICHARD");
            }
        }
    }

    public void writeSolutionToFile(String fileName) throws IOException {
        BufferedWriter bf = null;

        try {
            FileWriter fw = new FileWriter(fileName, false);
            bf = new BufferedWriter(fw);
            for(int i=1;i<solutions.size();i++) {
                bf.write("Case #" + i + ": " + solutions.get(i - 1).toString());
                bf.newLine();
            }
            bf.write("Case #" + solutions.size() + ": " + solutions.get(solutions.size() - 1).toString());
        }finally {
            if(bf != null) {
                bf.close();
            }
        }
    }

    public static void main(String[] args) throws IOException {
        Omino omino = new Omino("resources/D-small-attempt1.in");
        omino.solve();
        omino.writeSolutionToFile("resources/D-small-attempt1.out");

    }
}
