package qualify;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.StringTokenizer;

public class TrainTimetable {
	
	public static void main(String[] args) {
		String path = args[0];
		int cont = 1;
		// Se procesa el archivo
		List<TrainTimetableInput> testCases = fileToList(path);
		// Se ejecuta el algortimo por cada caso de prueba
		for (Iterator<TrainTimetableInput> iterator = testCases.iterator(); iterator.hasNext(); ) {
			TrainTimetableOutput output = new TrainTimetableOutput();
			process(iterator.next(), output);
			System.out.println("Case #" + cont++ + ": " + output.getTrainsStartAtA() + " " + output.getTrainsStartAtB());
		}
	}
	
	private static List<TrainTimetableInput> fileToList(String path) {
		List<TrainTimetableInput> testCases = new ArrayList<TrainTimetableInput>();
		try {
			BufferedReader in = new BufferedReader(new FileReader(path));
			// Se lee el numero de casos
			String line = in.readLine();
			Integer cases = new Integer(line);
			// Por cada caso se procesa el archivo
			for (int i = 0; i < cases.intValue(); i++) {
				TrainTimetableInput input = new TrainTimetableInput();
				// Se lee el tiempo de espera
				input.setTurnAroundTime(Integer.parseInt(in.readLine()));
				// Se leen los viajes de cada origen
				StringTokenizer tokenizer = new StringTokenizer(in.readLine(), " ");
				input.setTripsFromAToB(Integer.parseInt(tokenizer.nextToken()));
				input.setTripsFromBToA(Integer.parseInt(tokenizer.nextToken()));
				// Se leen los detalles de los viajes
				for (int j = 0; j < input.getTripsFromAToB(); j++) {
					TripDetail tripDetail = transformLine(in.readLine());
					tripDetail.setFromA(true);
					input.getTripDetailsFromAToB().add(tripDetail);
					input.getTripDetails().add(tripDetail);
				}
				// Se ordena el listado de viajes de A a B
				if (input.getTripDetailsFromAToB().size() != 0) {
					input.setTripDetailsFromAToB(sortByDepartureTime(input.getTripDetailsFromAToB()));
				}
				for (int j = 0; j < input.getTripsFromBToA(); j++) {
					TripDetail tripDetail = transformLine(in.readLine());
					tripDetail.setFromA(false);
					input.getTripDetailsFromBToA().add(tripDetail);
					input.getTripDetails().add(tripDetail);
				}
				// Se ordena el listado de viajes de B a A
				if (input.getTripDetailsFromBToA().size() != 0) {
					input.setTripDetailsFromBToA(sortByDepartureTime(input.getTripDetailsFromBToA()));
				}
				// Se ordena el listado global
				if (input.getTripDetails().size() != 0) {
					input.setTripDetails(sortByArrivalTime(input.getTripDetails()));
				}
				// Se adiciona el caso de prueba
				testCases.add(input);
			}
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return testCases;
	}
	
	private static TripDetail transformLine(String line) {
		StringTokenizer tokenizer = new StringTokenizer(line, " ");
		String departureTime = tokenizer.nextToken();
		String arrivalTime = tokenizer.nextToken();
		
		TripDetail tripDetail = new TripDetail();
		departureTime = departureTime.replaceAll(":", "");
		arrivalTime = arrivalTime.replaceAll(":", "");
		tripDetail.setDepartureTime(Integer.parseInt(departureTime));
		tripDetail.setArrivalTime(Integer.parseInt(arrivalTime));
		
		return tripDetail;
	}
	
	private static List<TripDetail> sortByDepartureTime(List<TripDetail> list) {
		List<TripDetail> sortedList = new ArrayList<TripDetail>();
		while (list.size() != 0) {
			int index = 0;
			int minIndex = 0;
			int minTime = 2400;
			for (Iterator<TripDetail> iterator = list.iterator(); iterator.hasNext(); index++) {
				TripDetail tripDetail = iterator.next();
				if (tripDetail.getDepartureTime() < minTime) {
					minIndex = index;
					minTime = tripDetail.getDepartureTime();
				}
			}
			sortedList.add(list.remove(minIndex));
		}
		return sortedList;
	}
	
	private static List<TripDetail> sortByArrivalTime(List<TripDetail> list) {
		List<TripDetail> sortedList = new ArrayList<TripDetail>();
		while (list.size() != 0) {
			int index = 0;
			int minIndex = 0;
			int minTime = 2400;
			for (Iterator<TripDetail> iterator = list.iterator(); iterator.hasNext(); index++) {
				TripDetail tripDetail = iterator.next();
				if (tripDetail.getArrivalTime() < minTime) {
					minIndex = index;
					minTime = tripDetail.getArrivalTime();
				}
			}
			sortedList.add(list.remove(minIndex));
		}
		return sortedList;
	}
	
	private static void process(TrainTimetableInput input, TrainTimetableOutput output) {
		while (input.getTripDetails().size() != 0) {
			TripDetail tripDetail = input.getTripDetails().remove(0);
			if (tripDetail.isFromA()) {
				output.setTrainsStartAtA(output.getTrainsStartAtA() + 1);
				input.getTripDetailsFromAToB().remove(tripDetail);
				cascade(input, fixTime(tripDetail.getArrivalTime(), input.getTurnAroundTime()), false);
			} else {
				output.setTrainsStartAtB(output.getTrainsStartAtB() + 1);
				input.getTripDetailsFromBToA().remove(tripDetail);
				cascade(input, fixTime(tripDetail.getArrivalTime(), input.getTurnAroundTime()), true);
			}
		}
	}
	
	private static void cascade(TrainTimetableInput input, int currentTime, boolean fromA) {
		if (fromA) {
			int index = nextTrip(currentTime, input.getTripDetailsFromAToB());
			if (input.getTripDetailsFromAToB().size() != index) {
				TripDetail tripDetail = input.getTripDetailsFromAToB().remove(index);
				input.getTripDetails().remove(tripDetail);
				cascade(input, fixTime(tripDetail.getArrivalTime(), input.getTurnAroundTime()), false);
			} else {
				return;
			}
		} else {
			int index = nextTrip(currentTime, input.getTripDetailsFromBToA());
			if (input.getTripDetailsFromBToA().size() != index) {
				TripDetail tripDetail = input.getTripDetailsFromBToA().remove(index);
				input.getTripDetails().remove(tripDetail);
				cascade(input, fixTime(tripDetail.getArrivalTime(), input.getTurnAroundTime()), true);
			} else {
				return;
			}
		}
	}
	
	private static int nextTrip(int currentTime, List<TripDetail> list) {
		int index = 0;
		for (Iterator<TripDetail> iterator = list.iterator(); iterator.hasNext(); index++) {
			if (currentTime <= iterator.next().getDepartureTime()) {
				break;
			}
		}
		return index;
	}
	
	private static int fixTime(int currentTime, int offset) {
		int hours = 0;
		int minutes = 0;
		String time = Integer.toString(currentTime);
		if (Integer.toString(currentTime).length() > 2) {
			hours = Integer.parseInt(time.substring(0, time.length() - 2));
			minutes = Integer.parseInt(time.substring(time.length() - 2));
		} else {
			minutes = currentTime;
		}
		minutes += offset;
		if (minutes >= 60) {
			minutes -= 60;
			hours++;
		}
		return hours * 100 + minutes;
	}

}
