import java.lang.Integer;
import java.lang.Double;

import java.util.*;
import java.io.File;
import java.text.DecimalFormat;

public class MineSweeperMaster implements Solvable {

    private static final int CASE_LENGTH = 1;

    public static void main(String[] args) {
        File f;
        if(args.length > 0 && (f = new File(args[0])).canRead()){
            List<InputCase> cases = IOUtils.fromFile(f, CASE_LENGTH);
            IOUtils.toFile(new MineSweeperMaster(), cases, f);
        }
    }

    public String solveCase(InputCase i) {
        String[] inputElements = i.getTextAtLine(0).split("\\s+");
        final int rows =
            Integer.valueOf(inputElements[0]); //R: Change every problem
        final int columns =
            Integer.valueOf(inputElements[1]); //C: Change every problem
        final int mines =
            Integer.valueOf(inputElements[2]); //M: Change every problem

        if(rows * columns <= mines) {
            return "Case #" + i.getCaseNumber() + ":\nImpossible";
        }
        // Conjecture: when these hypothesis occur then a solution exists
        if(mines == 0 ||
            rows == 1 ||  columns == 1 ||
            rows * columns - mines == 1 ||
            (((rows * columns - mines) & 1) == 0
                && rows * columns - mines > 2)) {
            return "Case #" + i.getCaseNumber() + ":\n"
            + print(buildFieldCompact(rows, columns, mines));
        }
        try {
            return "Case #" + i.getCaseNumber() + ":\n"
            + print(buildFieldSmart(rows, columns, mines));
        } catch(SolutionNotFoundException e) {
            return "Case #" + i.getCaseNumber() + ":\nImpossible";
        }
    }

    private char[][] buildFieldCompact(int rows, int columns, int mines) {
        char[][] field = new char[rows][columns];
        int placedMines = 0;
        initField(field);
        //fill with mines all the field except last two rows
        outer1:
        for(int i=0; i < rows-2; i++) {
            for(int j=0; j < columns; j++) {
                if(mines - placedMines++ == 0) {
                    break outer1;
                }
                field[i][j] = '*';
            }
        }
        //fill with mines all the field except last two rows
        outer2:
        if(mines - placedMines > 0) {
            for(int j=0; j < columns; j++) {
                for(int i=(rows-2 < 0) ? 0 :rows-2; i < rows; i++){
                    if(mines - placedMines++ == 0) {
                        break outer2;
                    }
                    field[i][j] = '*';
                }
            }
        }
        field[rows-1][columns-1] = 'c';
        return field;
    }

    // placing mines along the longest dimension
    // when free blocks are odd, checks if the field can be solved
    // if i can place all the mines then the problem can be solved
    private char[][] buildFieldSmart(int rows, int columns, int mines) throws SolutionNotFoundException {
        char[][] field = new char[rows][columns];
        initField(field);
        int placedMines = 0;
        if (rows > columns) {
          placingloop:
          for(int j=0; j < columns; j++) {
            for (int i = 0; i < rows; i++) {
              if (mines - placedMines == 0) {
                break placingloop;
              }
              field[i][j] = '*';
              placedMines++;
              /*if (!hasSolution(field)) {
                throw new SolutionNotFoundException();
              }*/
            }
          }
        } else {
            placingloop:
            for(int i=0; i < rows; i++) {
              for (int j = 0; j < columns; j++) {
                if (mines - placedMines == 0) {
                  break placingloop;
                }
                field[i][j] = '*';
                placedMines++;
                /*if (!hasSolution(field)) {
                  throw new SolutionNotFoundException();
                }*/
              }
            }
        }
        if (!hasSolution(field)) {
          throw new SolutionNotFoundException();
        }
        //find a position without near mines
        for(int i=0; i < field.length; i++) {
            for(int j=0; j < field[i].length; j++) {
                if (nearMines(field, i, j) == 0) {
                    field[i][j] = 'c';
                    return field;
                }
            }
        }
    throw new SolutionNotFoundException();
    }

    private int nearMines(char[][] field, int x, int y) {
        int maxX = field.length-1;
        int maxY = field[0].length-1;
        int minesCounter = 0;
        // check neighbors +1 0 -1
        for(int i = -1; i<=1; i++) {
            for (int j = -1; j <=1; j++) {
                // skip border cases
                if ( (j == -1 && y == 0) || (j == 1 && y == maxY) ||
                     (i == -1 && x == 0) || (i == 1 && x == maxX) ||
                    (i == 0 && j == 0) ) {
                    continue;
                }
                if (field[x+i][y+j] == '*') {
                    minesCounter++;
                }
            }
        }
        return minesCounter;
    }

    private boolean hasSolution(char[][] field) {
        char[][] testField = new char[field.length][field[0].length];
        int startX, startY;

        // deep copy array
        for(int i=0; i < field.length; i++) {
            for(int j=0; j < field[i].length; j++) {
                testField[i][j] = field[i][j];
            }
        }
        //find a position without near mines
        for(int i=0; i < field.length; i++) {
            for(int j=0; j < field[i].length; j++) {
                if (testField[i][j] != '*' && nearMines(testField, i, j) == 0) {
                    startX = i;
                    startY = j;
                    visitNeighbors(testField, startX, startY);
                    return verifySolution(testField);
                }
            }
        }
        return false;
    }

    private void visitNeighbors(char[][] field, int x, int y) {
       int maxY = field[0].length-1;
       int maxX = field.length-1;
       field[x][y] = 'v';
       if (field[x][y] != '*' && nearMines(field, x, y) == 0) {
            for(int i = -1; i<=1; i++) {
                for (int j = -1; j <=1; j++) {
                    // skip borders
                    if ((j == -1 && y == 0) || (j == 1 && y == maxY) ||
                        (i == -1 && x == 0) || (i == 1 && x == maxX) ||
                        (i == 0 && j == 0) ) {
                        continue;
                    }
                    if (field[x+i][y+j] != 'v') {
                        visitNeighbors(field, x+i, y+j);
                    }
                }
            }
        }
    }

    private boolean verifySolution(char[][] field) {
        for(int i=0; i < field.length; i++) {
            for(int j=0; j < field[i].length; j++) {
                if (field[i][j] == '.') {
                    return false;
                }
            }
        }
        return true;
    }

    private void initField(char[][] field) {
        for(int i=0; i < field.length; i++) {
            for(int j=0; j < field[i].length; j++) {
                field[i][j] = '.';
            }
        }
    }

    private String print(char[][] field) {
        StringBuilder sb = new StringBuilder();
        for(int i=0; i < field.length; i++) {
            for(int j=0; j < field[i].length; j++) {
                sb.append(field[i][j]);
            }
            sb.append('\n');
        }
        return sb.toString();
    }

}

class SolutionNotFoundException extends Exception {
    public SolutionNotFoundException() {
        super();
    }
}

