import java.lang.System;
import java.lang.Integer;
import java.util.*;
import java.io.*;

public class MagicTrickExposed {

    private static final int CASE_LENGTH = 10;

    public static void main(String[] args) {
        File f;
        if(args.length > 0 && (f = new File(args[0])).canRead()){
            List<InputCase> cases = InputCase.fromFile(f, CASE_LENGTH);
            for(InputCase i : cases) {
                testMagicTrick(i);
            }
        }
    }

    private static void testMagicTrick(InputCase i) {
        String fChoice =
            i.getTextAtLine(Integer.parseInt(i.getTextAtLine(0)));
        Set<String> fChoiceSet =
            new HashSet<String>(Arrays.asList(fChoice.split("\\s+")));
        String sChoice =
            i.getTextAtLine(5 + Integer.parseInt(i.getTextAtLine(5)));
        Set<String> sChoiceSet =
            new HashSet<String>(Arrays.asList(sChoice.split("\\s+")));
        fChoiceSet.retainAll(sChoiceSet);
        switch(fChoiceSet.size()) {
            case 0: System.out.printf("Case #%d: Volunteer cheated!\n",
                i.getCaseNumber());
                break;
            case 1: System.out.printf("Case #%d: %s\n",
                i.getCaseNumber(),
                fChoiceSet.iterator().next());
                break;
            default: System.out.printf("Case #%d: Bad magician!\n",
                i.getCaseNumber());
                break;
        }
    }
}


class InputCase {
    private final int caseNumber;
    private final String[] text;

    public InputCase(List<String> input, int caseNumber){
        this.caseNumber = caseNumber;
        text = input.toArray(new String[0]);
    }

    public static List<InputCase> fromFile(File f, int caseLength) {
        BufferedReader in = null;
        List<InputCase> cases = new ArrayList<InputCase>();
        try {
            in = new BufferedReader(new FileReader(f));
            int counter = 0;
            int caseN = 1;
            String line = in.readLine(); // first line is the number of test cases
            List<String> tmpList = new ArrayList<String>();
            while((line = in.readLine()) != null) {
                tmpList.add(line);
                if(counter++ % caseLength == caseLength - 1) {
                    cases.add(new InputCase(tmpList, caseN++));
                    tmpList = new ArrayList<String>();
                }
            }
        } catch (IOException e) {
            System.out.println("Some error occured while reading!");
            e.printStackTrace(System.out);
        } finally {
            if(in != null) {
                try{
                    in.close();
                } catch (IOException e) {
                    System.out.println("Some error occured while reading!");
                    e.printStackTrace(System.out);
                }
            }
        }
        return cases;
    }

    public int getCaseNumber() {
        return caseNumber;
    }

    public String[] getText() {
        return text;
    }

    public String getTextAtLine(int l) {
        return text[l];
    }
}
