import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.Scanner;

public class FairSquare {

	private Scanner readTheFile(String fileName) {
		Scanner scanner = null;
		try {
			scanner = new Scanner(new File(fileName));
		} catch (FileNotFoundException e) {
			System.exit(-1);
		}
		return scanner;
	}

	private String getNextInput(Scanner scanner) {
		return scanner.nextLine();
	}

	private int getTestCaseCount(Scanner scanner) {
		return scanner.nextInt();
	}

	private void writeOutput(String[] str, String outFile) {
		int i = 1;
		File file = new File(outFile);
		PrintWriter out = null;
		try {
			out = new PrintWriter(new FileWriter(file));
			for (String status : str) {
				out.println("Case #" + i++ + ": " + status);
			}
		} catch (IOException e) {

		} finally {
			if (out != null) {
				out.close();
			}
		}
	}

	public static void main(String args[]) {
		final FairSquare fairSquare = new FairSquare();
		final Scanner scanner = fairSquare.readTheFile(args[0]);
		String[] str = fairSquare.resolveFairSquareProblem(scanner, fairSquare);
		fairSquare.writeOutput(str, args[1]);
	}

	public final boolean isPerfectSquare(BigInteger value) {
		BigInteger hexRemained = value.mod(new BigInteger("10"));
		if (hexRemained.intValue() == 0 || hexRemained.intValue() == 1 || hexRemained.intValue() == 4
				|| hexRemained.intValue() == 9) {
			long sqrt = (long) Math.sqrt(value.doubleValue());
			if (sqrt * sqrt == value.longValue()) {
				return isPalindrome(sqrt + "");
			} else {
				return false;
			}
		}

		if (value.mod(new BigInteger("2")).intValue() == 2 || value.mod(new BigInteger("7")).intValue() == 5) {
			return false;
		}
		if (value.mod(new BigInteger("11")).intValue() == 8 || value.mod(new BigInteger("31")).intValue() == 20) {
			return false;
		}

		if (value.mod(new BigInteger("47")).intValue() == 32 || value.mod(new BigInteger("127")).intValue() == 80) {
			return false;
		}

		if (value.mod(new BigInteger("191")).intValue() == 128 || value.mod(new BigInteger("511")).intValue() == 320) {
			return false;
		}

		long sqrt = (long) Math.sqrt(value.doubleValue());
		if (sqrt * sqrt == value.longValue()) {
			return isPalindrome(sqrt + "");
		} else {
			return false;
		}
	}

	public boolean isPalindrome(String input) {
		for (int start = 0, end = input.length() - 1; start < end;) {
			if (input.charAt(start++) != input.charAt(end--)) {
				return false;
			}
		}
		return true;
	}

	private BigInteger getStartRange(String[] input) {
		return new BigInteger(input[0]);
	}

	private BigInteger getEndRange(String[] input) {
		return new BigInteger(input[1]);
	}

	private String getFairSquareCount(BigInteger startRange, BigInteger endRange) {
		String numberToCheck;
		int countFairSquare = 0;
		endRange = endRange.add(new BigInteger("1"));
		while (startRange.compareTo(endRange) != 0) {
			numberToCheck = startRange + "";
			if (isPalindrome(numberToCheck)) {
				if (isPerfectSquare(new BigInteger(numberToCheck))) {
					System.out.println("number is " + numberToCheck);
					countFairSquare++;
				}
			}
			startRange = startRange.add(new BigInteger("1"));
		}
		return countFairSquare + "";
	}

	private String[] resolveFairSquareProblem(Scanner scanner, FairSquare fairSquare) {
		final int testCaseCount = fairSquare.getTestCaseCount(scanner);
		scanner.nextLine();
		String nextInput;
		BigInteger startRange;
		BigInteger endRange;
		String[] splittedInput;
		String[] output = new String[testCaseCount];
		for (int testCase = 0; testCase < testCaseCount; testCase++) {
			nextInput = getNextInput(scanner);
			splittedInput = nextInput.split(" ");
			startRange = getStartRange(splittedInput);
			endRange = getEndRange(splittedInput);
			output[testCase] = getFairSquareCount(startRange, endRange);
		}
		return output;
	}
}
