import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Scanner;

public class TicTacToeGame {

	private final char X = 'X';
	private final char O = 'O';
	private final char T = 'T';
	private final char DOT = '.';

	private static final String XWON = "X won";
	private static final String OWON = "O won";
	private static final String DRAWN = "Draw";
	private static final String DEFAULT = "Game has not completed";
	private static final String DOT_STRING = ".";
	private static final String EMPTY_STRING = "";

	private Scanner readTheFile(String fileName) {
		Scanner scanner = null;
		try {
			scanner = new Scanner(new File(fileName));
		} catch (FileNotFoundException e) {
			System.exit(-1);
		}
		return scanner;
	}

	private String getNextInput(Scanner scanner) {
		return scanner.nextLine();
	}

	private void ignoreEmptyLine(Scanner scanner, boolean dontGotoNextLine) {
		if (!dontGotoNextLine) {
			scanner.nextLine();
		}
	}

	private int getTestCaseCount(Scanner scanner) {
		return scanner.nextInt();
	}

	private String playGame(int boardCount, String board, Player xPlayer, Player oPlayer, int currentBoard) {
		String status = EMPTY_STRING;
		for (int i = 0; i < boardCount; i++) {
			switch (board.charAt(i)) {
			case T:
				if (xPlayer.updateScore(currentBoard, i)) {
					xPlayer.setStatus(XWON);
					return XWON;
				}
				if (oPlayer.updateScore(currentBoard, i)) {
					xPlayer.setStatus(OWON);
					return OWON;
				}
				break;
			case X:
				if (xPlayer.updateScore(currentBoard, i)) {
					xPlayer.setStatus(XWON);
					return XWON;
				}
				break;
			case O:
				if (oPlayer.updateScore(currentBoard, i)) {
					xPlayer.setStatus(OWON);
					return OWON;
				}
				break;
			case DOT:
				if (!xPlayer.equals(XWON)) {
					xPlayer.setStatus(DOT_STRING);
				}
				if (!oPlayer.equals(OWON)) {
					oPlayer.setStatus(DOT_STRING);
				}
				break;
			}

		}
		return status;
	}

	public static void main(String args[]) {
		final TicTacToeGame ticTacToeGame = new TicTacToeGame();
		final Scanner scanner = ticTacToeGame.readTheFile(args[0]);
		String[] str = ticTacToeGame.resolveTicTacToe(scanner, ticTacToeGame);

		int i = 1;
		File file = new File(args[1]);
		PrintWriter out = null;
		try {
			out = new PrintWriter(new FileWriter(file));
			for (String status : str) {
				out.println("Case #" + i++ + ": " + status);
			}
		} catch (IOException e) {

		} finally {
			if (out != null) {
				out.close();
			}
		}
	}

	private String[] resolveTicTacToe(Scanner scanner, TicTacToeGame ticTacToeGame) {
		final int testCaseCount = ticTacToeGame.getTestCaseCount(scanner);
		scanner.nextLine();
		int boardSize = 4;
		Player xPlayer;
		Player yPlayer;
		String status;
		boolean hasSomebodyWon;
		final String[] finalStatus = new String[testCaseCount];
		for (int testCase = 0; testCase < testCaseCount; testCase++) {
			hasSomebodyWon = false;
			xPlayer = ticTacToeGame.new Player(boardSize);
			yPlayer = ticTacToeGame.new Player(boardSize);
			for (int row = 0; row < boardSize; row++) {
				status = ticTacToeGame.playGame(boardSize, ticTacToeGame.getNextInput(scanner), xPlayer, yPlayer, row);
				if (status.equals(XWON) || status.equals(OWON)) {
					finalStatus[testCase] = status;
					hasSomebodyWon = true;
					for (int count = row + 1; count < boardSize; count++) {
						ignoreEmptyLine(scanner, false);
					}
					break;
				}
			}

			if (!hasSomebodyWon) {
				if (xPlayer.getStatus() == null) {
					finalStatus[testCase] = DRAWN;
				} else {
					finalStatus[testCase] = DEFAULT;
				}
			}
			ignoreEmptyLine(scanner, testCase == testCaseCount - 1);
		}
		return finalStatus;
	}

	private class Player {
		int[] rowScore;
		int[] colScore;
		int[] diagsScore = new int[2];
		int boardSize;
		String status;

		public Player(int boardSize) {
			rowScore = new int[boardSize];
			colScore = new int[boardSize];
			this.boardSize = boardSize;
		}

		public boolean updateScore(int row, int col) {
			if (++rowScore[row] == boardSize)
				return true;
			if (++colScore[col] == boardSize)
				return true;
			if (row == col) {
				if (++diagsScore[0] == boardSize)
					return true;
			}
			for (int i = 0; i < boardSize; i++) {
				if (row == i && col == (boardSize - 1 - i))
					if (++diagsScore[1] == boardSize)
						return true;
			}
			return false;
		}

		public String getStatus() {
			return status;
		}

		public void setStatus(String status) {
			this.status = status;
		}

	}
}
