import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

/**
 * Skeleton for solving the problems along with helper methods.
 */
public class PractiseExample {

	private final static String CASE_STRING = "Case #" ;
	private final static String COLON = ": ";
	private final static char NEW_LINE_CHAR = '\n';
	private final static String SPACE_STRING = " ";
	private static Scanner scanner = null;
	private static PrintWriter writer = null;

	/*
	 * Returns next int value within a line.
	 * @param scanner
	 * @return
	 */
	private int getNextIntWithNewLine() {
		final int nextInt = getNextInt();
		getNextLine();
		return nextInt;
	}

	/*
	 * Returns next int value.
	 * @param scanner
	 * @return
	 */
	private int getNextInt() {
		return scanner.nextInt();
	}

	/*
	 * Returns whole line. By line i mean where it finds '\n'
	 * @param scanner
	 * @return
	 */
	private String getNextLine() {
		try {
			return scanner.nextLine();
		} catch (Exception e) {
		}
		return null;
	}
	
	/*
	 * Being on same line, will return the next token from the same line.
	 * Say for e.g. if we have 1,2,3 and we call this method, we will get 1.
	 * Calling again will retrun 2 and so on.
	 * @param scanner
	 * @return
	 */
	private String getNextToken() {
		final String nextToken = scanner.next();
		getNextLine();
		return scanner.next();
	}
	
	/*
	 * Returns next boolean value.
	 * @param scanner
	 * @return
	 */
	private boolean getNextBool() {
		final boolean nextBoolean = scanner.nextBoolean(); 
		getNextLine();
		return nextBoolean;
	}

	/*
	 * Returns string array tokenized by separator
	 * @param string
	 * @param separator
	 * @return
	 */
	private String[] getTokenisedStringArray(final String string, final String separator) {
		return string.split(separator);
	}

	/*
	 * Returns string array tokenized by separator
	 * @param string
	 * @param separator
	 * @return
	 */
	private List<String> getTokenisedStringCollection(final String string, final String separator) {
		return Arrays.asList(string.split(separator));
	}

	/*
	 * Actual algorithm/logic resides here.
	 * @param scanner
	 * @return
	 */
	private String solveProblem(final PractiseExample exampleSolver) {
		final StringBuilder stringBuilder = new StringBuilder();
		final int sampleCount = exampleSolver.getNextIntWithNewLine();
		int beforeCount;
		int afterCount;
		int[][] matrixBefore = new int[4][4];
		int[][] matrixAfter = new int[4][4];
		String solution;
		for (int sample = 1; sample <= sampleCount; sample ++) {
			beforeCount = exampleSolver.getNextIntWithNewLine();
			for (int row = 0; row < 4; row ++) {
				for (int col=0; col<4; col++) {
					matrixBefore[row][col] = exampleSolver.getNextInt();
				}
				exampleSolver.getNextLine();
			}
			afterCount = exampleSolver.getNextInt();
			for (int row = 0; row < 4; row ++) {
				for (int col=0; col<4; col++) {
					matrixAfter[row][col] = exampleSolver.getNextInt();
				}
				exampleSolver.getNextLine();
			}
			solution = exampleSolver.solve(beforeCount - 1, afterCount - 1, matrixBefore, matrixAfter);
			stringBuilder.append(CASE_STRING);
			stringBuilder.append(sample);
			stringBuilder.append(COLON);
			stringBuilder.append(solution);
			stringBuilder.append(NEW_LINE_CHAR);
		}
		return stringBuilder.toString();
	}
	
	private String solve(int beforeCount, int afterCount, int[][] matrixB, int[][] matrixA) {
		int count = 0;
		int solution = 0;
		for (int i = 0; i< 4; i++) {
			for (int j=0; j< 4; j++) {
				if (matrixB[beforeCount][i] == matrixA[afterCount][j]) {
					count ++;
					solution = matrixA[afterCount][j];
				}
			}
		}
		
		if (count == 1) {
			return solution + "";
		} else if (count == 0) {
			return "Volunteer cheated!";
		}  else {
			return "Bad magician!";
		}
	}
	
	/**
	 * All the main logic resides over here.
	 * @param args
	 * @throws IOException
	 */
	public static void main(String args[]) throws IOException {
		final PractiseExample exampleSolver = new PractiseExample();
		try {
			exampleSolver.initResources(args);
			final String valueToWrite = exampleSolver.solveProblem(exampleSolver);
			exampleSolver.writeOutput(writer, valueToWrite);
		} finally {
			exampleSolver.closeResources();
		}
	}
	
	/*
	 * Write the final output to a file. 
	 * @param writer
	 * @param valueToWrite
	 * @throws IOException
	 */
	private void writeOutput(final Writer writer, final String valueToWrite) throws IOException {
		writer.write(valueToWrite);		
	}
	
	/*
	 * Initialize the IO resources.
	 * @param scanner
	 * @param writer
	 * @param args
	 * @throws FileNotFoundException
	 */
	private void initResources(String args[]) throws FileNotFoundException {
		scanner = new Scanner(new File(args[0]));
		writer = new PrintWriter(args[1]);
	}
	
	/*
	 * Close the IO resources
	 * @param writer
	 * @param scanner
	 * @throws IOException
	 */
	private void closeResources() throws IOException {
		if (writer != null) {
			writer.close(); 
		}
		if (scanner != null) {
			scanner.close();
		}
	}
}
