import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

/**
 * Skeleton for solving the problems along with helper methods.
 */
public class PractiseExample {

	private final static String CASE_STRING = "Case #" ;
	private final static String COLON = ": ";
	private final static char NEW_LINE_CHAR = '\n';
	private final static String SPACE_STRING = " ";
	private static Scanner scanner = null;
	private static PrintWriter writer = null;

	/*
	 * Returns next int value within a line.
	 * @param scanner
	 * @return
	 */
	private int getNextIntWithNewLine() {
		final int nextInt = getNextInt();
		getNextLine();
		return nextInt;
	}
	
	private double getNextDoubleWithNewLine() {
		final double nextDouble = getNextDouble();
		getNextLine();
		return nextDouble;
	}

	/*
	 * Returns next int value.
	 * @param scanner
	 * @return
	 */
	private int getNextInt() {
		return scanner.nextInt();
	}
	
	/*
	 * Returns next int value.
	 * @param scanner
	 * @return
	 */
	private double getNextDouble() {
		return scanner.nextDouble();
	}

	/*
	 * Returns whole line. By line i mean where it finds '\n'
	 * @param scanner
	 * @return
	 */
	private String getNextLine() {
		try {
			return scanner.nextLine();
		} catch (Exception e) {
		}
		return null;
	}
	
	/*
	 * Being on same line, will return the next token from the same line.
	 * Say for e.g. if we have 1,2,3 and we call this method, we will get 1.
	 * Calling again will retrun 2 and so on.
	 * @param scanner
	 * @return
	 */
	private String getNextToken() {
		final String nextToken = scanner.next();
		getNextLine();
		return scanner.next();
	}
	
	/*
	 * Returns next boolean value.
	 * @param scanner
	 * @return
	 */
	private boolean getNextBool() {
		final boolean nextBoolean = scanner.nextBoolean(); 
		getNextLine();
		return nextBoolean;
	}

	/*
	 * Returns string array tokenized by separator
	 * @param string
	 * @param separator
	 * @return
	 */
	private String[] getTokenisedStringArray(final String string, final String separator) {
		return string.split(separator);
	}

	/*
	 * Returns string array tokenized by separator
	 * @param string
	 * @param separator
	 * @return
	 */
	private List<String> getTokenisedStringCollection(final String string, final String separator) {
		return Arrays.asList(string.split(separator));
	}

	/*
	 * Actual algorithm/logic resides here.
	 * @param scanner
	 * @return
	 */
	private String solveProblem(final PractiseExample exampleSolver) {
		final StringBuilder stringBuilder = new StringBuilder();
		final int sampleCount = exampleSolver.getNextIntWithNewLine();
		double c;
		double f;
		double x;
		String solution;
		for (int sample = 1; sample <= sampleCount; sample ++) {
			c = getNextDouble();
			f = getNextDouble();
			x = getNextDoubleWithNewLine();
			solution = solve(c, f, x);
			stringBuilder.append(CASE_STRING);
			stringBuilder.append(sample);
			stringBuilder.append(COLON);
			stringBuilder.append(solution);
			stringBuilder.append(NEW_LINE_CHAR);
		}
		return stringBuilder.toString();
	}
	
	private String solve(final double c, final double f, final double x) {
		double currentRate = 2d;
		double best = 0d;
		double lastSummation = Double.MAX_VALUE;
		double summation = 0d;
		double result = 0d;
		while (true) {
			best = x / currentRate;
			result = summation + best;
			if (result < lastSummation) {
				lastSummation = result; 
			} else {
				return lastSummation + "";
			}
			summation = summation + (c / currentRate);
			currentRate = currentRate + f;
		}
	}
	
	/**
	 * All the main logic resides over here.
	 * @param args
	 * @throws IOException
	 */
	public static void main(String args[]) throws IOException {
		final PractiseExample exampleSolver = new PractiseExample();
		try {
			exampleSolver.initResources(args);
			final String valueToWrite = exampleSolver.solveProblem(exampleSolver);
			exampleSolver.writeOutput(writer, valueToWrite);
		} finally {
			exampleSolver.closeResources();
		}
	}
	
	/*
	 * Write the final output to a file. 
	 * @param writer
	 * @param valueToWrite
	 * @throws IOException
	 */
	private void writeOutput(final Writer writer, final String valueToWrite) throws IOException {
		writer.write(valueToWrite);		
	}
	
	/*
	 * Initialize the IO resources.
	 * @param scanner
	 * @param writer
	 * @param args
	 * @throws FileNotFoundException
	 */
	private void initResources(String args[]) throws FileNotFoundException {
		scanner = new Scanner(new File(args[0]));
		writer = new PrintWriter(args[1]);
	}
	
	/*
	 * Close the IO resources
	 * @param writer
	 * @param scanner
	 * @throws IOException
	 */
	private void closeResources() throws IOException {
		if (writer != null) {
			writer.close(); 
		}
		if (scanner != null) {
			scanner.close();
		}
	}
}
