import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

/**
 * Skeleton for solving the problems along with helper methods.
 */
public class PractiseExample {

	private final static String CASE_STRING = "Case #" ;
	private final static String COLON = ":\n";
	private final static char NEW_LINE_CHAR = '\n';
	private final static String SPACE_STRING = " ";
	private final static String MISSION_IMPOSSIBLE = "Impossible";
	private final static char CLICKED = 'c';
	private final static char MINES = '*';
	private final static char OPEN = '.';
	private static Scanner scanner = null;
	private static PrintWriter writer = null;

	/*
	 * Returns next int value within a line.
	 * @param scanner
	 * @return
	 */
	private int getNextIntWithNewLine() {
		final int nextInt = getNextInt();
		getNextLine();
		return nextInt;
	}
	
	private double getNextDoubleWithNewLine() {
		final double nextDouble = getNextDouble();
		getNextLine();
		return nextDouble;
	}

	/*
	 * Returns next int value.
	 * @param scanner
	 * @return
	 */
	private int getNextInt() {
		return scanner.nextInt();
	}
	
	/*
	 * Returns next int value.
	 * @param scanner
	 * @return
	 */
	private double getNextDouble() {
		return scanner.nextDouble();
	}

	/*
	 * Returns whole line. By line i mean where it finds '\n'
	 * @param scanner
	 * @return
	 */
	private String getNextLine() {
		try {
			return scanner.nextLine();
		} catch (Exception e) {
		}
		return null;
	}
	
	/*
	 * Being on same line, will return the next token from the same line.
	 * Say for e.g. if we have 1,2,3 and we call this method, we will get 1.
	 * Calling again will retrun 2 and so on.
	 * @param scanner
	 * @return
	 */
	private String getNextToken() {
		final String nextToken = scanner.next();
		getNextLine();
		return scanner.next();
	}
	
	/*
	 * Returns next boolean value.
	 * @param scanner
	 * @return
	 */
	private boolean getNextBool() {
		final boolean nextBoolean = scanner.nextBoolean(); 
		getNextLine();
		return nextBoolean;
	}

	/*
	 * Returns string array tokenized by separator
	 * @param string
	 * @param separator
	 * @return
	 */
	private String[] getTokenisedStringArray(final String string, final String separator) {
		return string.split(separator);
	}

	/*
	 * Returns string array tokenized by separator
	 * @param string
	 * @param separator
	 * @return
	 */
	private List<String> getTokenisedStringCollection(final String string, final String separator) {
		return Arrays.asList(string.split(separator));
	}

	/*
	 * Actual algorithm/logic resides here.
	 * @param scanner
	 * @return
	 */
	private String solveProblem(final PractiseExample exampleSolver) {
		final StringBuilder stringBuilder = new StringBuilder();
		final int sampleCount = exampleSolver.getNextIntWithNewLine();
		int r;
		int c;
		int m;
		String solution;
		for (int sample = 1; sample <= sampleCount; sample ++) {
			r = getNextInt();
			c = getNextInt();
			m = getNextIntWithNewLine();
			solution = solve(r, c, m);
			stringBuilder.append(CASE_STRING);
			stringBuilder.append(sample);
			stringBuilder.append(COLON);
			stringBuilder.append(solution);
			stringBuilder.append(NEW_LINE_CHAR);
		}
		return stringBuilder.toString();
	}
	
	private String solve(final int row, final int column, final int mineCount) {
		
		if (row >=2 && column >=2) {
			if (row * column - mineCount <= 3) {
				return MISSION_IMPOSSIBLE;
			}
		}
		
		if ((row*column <= mineCount || ((row == 1 || column == 1) && Math.ceil((row * column / 2d)) < mineCount)) && mineCount != 0) {
			return MISSION_IMPOSSIBLE;
		}
		int mine = 0;
		char[][] board = new char[row][column];
		for (int i = 0; i< row; i++) {
			Arrays.fill(board[i], OPEN);
		}
		board[row - 1][column - 1] = CLICKED;
		loop: for (int i = 0; i< row; i++) {
			for (int j = 0; j< column; j++) {
				if ((i == row - 2 && j >= column - 2) || (i == row - 1 && j >= column - 2)) {
					continue;
				}
				if (mine >= mineCount)
					break loop;
				board[i][j] = MINES;
				mine ++;
			}
		}
		
		if (mine != mineCount) {
			return MISSION_IMPOSSIBLE;
		}
		
		if (row != 1 && column != 1) {
			if (row - 2 < 0) {
				if (board[row - 1][column - 2] != OPEN) {
					return MISSION_IMPOSSIBLE;
				}
			} else if (column - 2 < 0) {
				if (board[row - 2][column - 1] != OPEN) {
					return MISSION_IMPOSSIBLE;
				}
			} else if (board[row - 2][column - 2] != OPEN || board[row - 1][column - 2] != OPEN || board[row - 2][column - 1] != OPEN) {
				return MISSION_IMPOSSIBLE;
			}
		}	
		StringBuilder str = new StringBuilder();
		for (int i=0; i< row; i ++) {
			str.append(board[i]);
			if (i != row -1)
			str.append(NEW_LINE_CHAR);
		}
		return str.toString();
	}
	
	/**
	 * All the main logic resides over here.
	 * @param args
	 * @throws IOException
	 */
	public static void main(String args[]) throws IOException {
		final PractiseExample exampleSolver = new PractiseExample();
		try {
			exampleSolver.initResources(args);
			final String valueToWrite = exampleSolver.solveProblem(exampleSolver);
			exampleSolver.writeOutput(writer, valueToWrite);
		} finally {
			exampleSolver.closeResources();
		}
	}
	
	/*
	 * Write the final output to a file. 
	 * @param writer
	 * @param valueToWrite
	 * @throws IOException
	 */
	private void writeOutput(final Writer writer, final String valueToWrite) throws IOException {
		writer.write(valueToWrite);		
	}
	
	/*
	 * Initialize the IO resources.
	 * @param scanner
	 * @param writer
	 * @param args
	 * @throws FileNotFoundException
	 */
	private void initResources(String args[]) throws FileNotFoundException {
		scanner = new Scanner(new File(args[0]));
		writer = new PrintWriter(args[1]);
	}
	
	/*
	 * Close the IO resources
	 * @param writer
	 * @param scanner
	 * @throws IOException
	 */
	private void closeResources() throws IOException {
		if (writer != null) {
			writer.close(); 
		}
		if (scanner != null) {
			scanner.close();
		}
	}
}
