import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintWriter;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.sql.Struct;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@SuppressWarnings("all")
public class Pipeta {

	private static final String LINE_SEPARATOR_INPUT = "\n";
	private static final String LINE_SEPARATOR_OUTPUT = "\n";
	
	public static class TestCase{
		public int nLines;
		public List<String> lines = new ArrayList<String>();
		
		public int moves = 0;
		public boolean possible = false;
		public Map<Character, List<Integer>> characters = new HashMap<Character, List<Integer>>();
	}
	
	public static void main(String[] args) throws IOException {
		long start = System.currentTimeMillis();
		StringBuilder sb = new StringBuilder();
		String input = readFile("C:\\Google\\A-small-attempt1.in", StandardCharsets.UTF_8);
		
		String [] fileLines = input.split(LINE_SEPARATOR_INPUT);
		
		int test_cases = Integer.parseInt(fileLines[0]);
		List<TestCase> cases = new ArrayList<TestCase>();
		int currentLine = 1;
		for(int i = 0; i < test_cases; i++){
			TestCase aux = new TestCase();
			aux.nLines = Integer.parseInt(fileLines[currentLine]);
			currentLine++;
			for(int j = 0; j < aux.nLines; j++){
				aux.lines.add(fileLines[currentLine + j]);
			}
			currentLine += aux.nLines;
			cases.add(aux);
		}
		for(int i = 0; i < cases.size(); i++){
			System.out.println(i);
			PrepareCases(cases.get(i));
			System.out.println(i + "Count");
			if(cases.get(i).possible)
				CountMoves(cases.get(i));
		}
		
		for(int i = 0; i < cases.size(); i++){
			String line = "";
			if(cases.get(i).possible)
				line = "Case #" + (i + 1) + ": " + cases.get(i).moves;
			else
				line = "Case #" + (i + 1) + ": " + "Fegla Won";
			writeLine(sb, line);
		}
		
		writeToFile(sb.toString());
	}
	
	
	private static void CountMoves(TestCase item){
		Character[] keys = item.characters.keySet().toArray(new Character[item.characters.keySet().size()]);
		
		int totalMoves = 0;
		for(int i = 0; i < keys.length; i++){
			List<Integer> values = item.characters.get(keys[i]);
			int maxValue = Collections.max(values);
			int minValue = Collections.min(values);
			int bestMove = Integer.MAX_VALUE;
			for(int j = minValue; j <= maxValue; j++){
				int sum = 0;
				for(int k = 0; k < values.size(); k++){
					sum += Math.abs(values.get(k) - j);
				}
				if(bestMove > sum)
					bestMove = sum;
			}
			totalMoves += bestMove;
		}
		item.moves = totalMoves;
	}
	
	
	private static void PrepareCases(TestCase item){
		char[] charArray = item.lines.get(0).toCharArray();
		for(int i = 0; i < charArray.length; i++){
			item.characters.put(charArray[i], new ArrayList<Integer>());
			int count = 0;
			for(int j = i; j < charArray.length && charArray[i] == charArray[j]; j++){
				count++;
			}
			i += count - 1;
			item.characters.get(charArray[i]).add(count);
		}
		
		boolean possible = true;
		Character[] keys = item.characters.keySet().toArray(new Character[item.characters.keySet().size()]);
		Map<Character, Boolean> keyMap = new HashMap<Character, Boolean>();
		for(int i = 0; i < keys.length; i++){
			keyMap.put(keys[i], false);
		}
		for(int i = 1; i < item.nLines && possible; i++){
			char[] lineChars = item.lines.get(i).toCharArray();
			char previous = lineChars[0];
			int count = 1;
			for(int j = 1; j < lineChars.length; j++){
				if(!item.characters.containsKey(lineChars[j])){
					possible = false;
					break;
				}
				if(previous == lineChars[j]){
					count++;
				}
				else{
					if(item.characters.containsKey(previous))
						item.characters.get(previous).add(count);
					else{
						possible = false;
						break;
					}
					keyMap.put(previous, true);
					count = 1;
				}
				previous = lineChars[j];
			}
			if(item.characters.containsKey(previous))
				item.characters.get(previous).add(count);
			else{
				possible = false;
				break;
			}
			keyMap.put(previous, true);
		}
		item.possible = possible;
		Boolean[] aux = keyMap.values().toArray(new Boolean[keyMap.values().size()]);
		for(int i = 0; i < aux.length; i++){
			item.possible &= aux[i];
		}
	}

	
	private static String readFile(String path, Charset encoding) throws IOException {
		byte[] encoded = Files.readAllBytes(Paths.get(path));
		return new String(encoded, encoding);
	}
	
	private static int getSingle(int lineIndex, String input) {
		String [] lines = input.split(LINE_SEPARATOR_INPUT);
		return Integer.parseInt(lines[lineIndex]);
	}
	
	private static void writeToFile(String result) throws FileNotFoundException {
		PrintWriter out = new PrintWriter("C:/Google/output" + System.currentTimeMillis() + ".txt");
		out.append(result);
		out.close();
	}
	
	private static void writeLine(StringBuilder sb, String line) {
		sb.append(line).append(LINE_SEPARATOR_OUTPUT);
	}
	
	private static List<String> splitLines(int from, int linesAmount, String input, String separatorRegex) {
		String [] lines = input.split(LINE_SEPARATOR_INPUT);
		List<String> tokens = new ArrayList<String>();
		for(int i = from; i < from + linesAmount ; i++) {
			tokens.addAll(Arrays.asList(lines[i].split(separatorRegex)));
		}
		return tokens;
	}
	
	private static List<Integer> parseListToInteger(List<String> strings) {
		List<Integer> tokens = new ArrayList<Integer>();
		for (String s : strings) {
			tokens.add(Integer.parseInt(s));
		}
		return tokens;
	}
	
	private static List<Integer> splitList(List<Integer> list, int from, int to) {
		List<Integer> result = new ArrayList<Integer>();
		for(int i = from; i <= to; i++) {
			result.add(list.get(i));
		}
		
		return result;
	}
	
	private static <T> List<T> intersection(List<T> list1, List<T> list2) {
		List<T> list = new ArrayList<T>();
		for (T t : list1) {
			if(list2.contains(t)) {
				list.add(t);
			}
		}
		return list;
	}
}
