import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Scanner;
import java.util.Set;


public class Main {

	private static BufferedWriter outputFile;

	public static class Point{
		private static final int MINE = -1;
		private int content = 0;

		List<Point> neighbors = new ArrayList<>(8);
		private int numberMineAround;
		private Point[][] mineField;
		private int x;
		private int y;
		private int lineNb;
		private int columnNb;

		public Point(Point[][] mineField, int x, int y, int lineNb, int columnNb) {
			this.mineField = mineField;
			this.x = x;
			this.y = y;
			this.lineNb = lineNb;
			this.columnNb = columnNb;
		}

		public void setMine() {
			content = MINE;
			for (Point n : neighbors) {
				n.increaseNumberMineAround();
			}
		}

		private void increaseNumberMineAround() {
			numberMineAround++;
		}

		public boolean isOkToPlaceMine() {
			boolean ok = true;
			if (content == MINE) {
				return false;
			}
			for (Point n : neighbors) {
				ok &= n.supposeImAMine(this);
			}
			return ok;
		}

		private boolean supposeImAMine(Point testedMinedPoint) {
			if (content == MINE){
				return true;
			} else {
				// do I have a zero mines around neighbors
				for (Point p : neighbors) {
					if (p != testedMinedPoint){
						if ( p.getNumberMineAround() == 0 ){
							return true;
						}
					}
				}
				return false;
			}
		}

		private int getNumberMineAround() {
			return numberMineAround;
		}

		public void lookupNeibors() {
			if (x - 1 >= 0) {
				if (y - 1 >= 0){
					neighbors.add(mineField[x-1][y-1]);
				} 
				neighbors.add(mineField[x-1][y]);
				if (y + 1 < lineNb){
					neighbors.add(mineField[x-1][y+1]);
				} 
			}

			if (y - 1 >= 0){
				neighbors.add(mineField[x][y-1]);
			} 
			if (y + 1 < lineNb){
				neighbors.add(mineField[x][y+1]);
			} 

			if (x + 1 < columnNb) {
				if (y - 1 >= 0){
					neighbors.add(mineField[x+1][y-1]);
				} 
				neighbors.add(mineField[x+1][y]);
				if (y + 1 < lineNb){
					neighbors.add(mineField[x+1][y+1]);
				} 
			}


		}

		public String getContent() {
			if (content == 0 ){
				return ".";
			} else if (content == MINE) {
				return "*";
			} else {
				return "c";
			}
		}

		public void setClick() {
			content = 1;
		}

	}

	public static void main(String[] args) throws IOException {
		//Scanner scanner = new Scanner(Main.class.getResourceAsStream("sample.in"));
		Scanner scanner = new Scanner(Main.class.getResourceAsStream("C-small-attempt0.in"));
		//Scanner scanner = new Scanner(Main.class.getResourceAsStream("C-large.in"));

		outputFile = new BufferedWriter(new FileWriter("src/result.txt"));
		int caseNbTotal = scanner.nextInt();
		for (int caseNb = 0 ; caseNb < caseNbTotal ; caseNb++){
			// read case data
			int lineNb  = scanner.nextInt();
			int columnNb = scanner.nextInt();
			int mineNb = scanner.nextInt();
			Point [][] mineField = new Point[columnNb][lineNb];
			// first try
			for(int x = 0 ; x < columnNb ; x++){
				for(int y = 0 ; y < lineNb ; y++){
					mineField[x][y]=  new Point(mineField, x,y, lineNb, columnNb); //nothing
				}
			}
			for(int x = 0 ; x < columnNb ; x++){
				for(int y = 0 ; y < lineNb ; y++){
					mineField[x][y].lookupNeibors(); //nothing
				}
			}
			boolean lastMinePlaced = false;
			for (int mine = 0 ; mine < mineNb ; mine++){
				int xTry = 0, yTry = 0;
				lastMinePlaced = false;
				Point pointTried = mineField[xTry][yTry];
				while (pointTried != null) {
					if (pointTried.isOkToPlaceMine()) {
						pointTried.setMine();
						lastMinePlaced = true;
						pointTried = null;
					} else {
						xTry++;
						if (xTry == columnNb) {
							xTry = 0;
							yTry ++;
							if (yTry == lineNb) {
								break;
							}
						}
						pointTried = mineField[xTry][yTry];
					}
				}
				if (lastMinePlaced == false) {
					break;
				}
			}

			StringBuilder result = new StringBuilder();
			if ( lastMinePlaced == false) {
				result.append("\nImpossible");
			} else {
				boolean clickSet = false;
				for(int y = 0 ; y < lineNb && !clickSet; y++){
					for(int x = 0 ; x < columnNb && !clickSet ; x++){
						if (mineField[x][y].getNumberMineAround() == 0 && !mineField[x][y].getContent().equals("*") ){
							mineField[x][y].setClick();
							clickSet = true;
						}
					}
				}
				if (clickSet == false){
					result.append("\nImpossible");
				} else {
					for(int y = 0 ; y < lineNb ; y++){
						result.append("\n");
						for(int x = 0 ; x < columnNb ; x++){
							result.append(mineField[x][y].getContent()); //nothing
						}
					}
				}
			}

			// write case solution
			writeCase(caseNb, result.toString());
		}
		scanner.close();
		outputFile.close();
	}

	private static void writeCase(int caseNb, String result) {
		StringBuilder sb = new StringBuilder("Case #");
		sb.append(caseNb+1);
		sb.append(": ");
		sb.append(result);
		String line = sb.toString();
		System.out.println(line);
		try {
			outputFile.write(line);
			outputFile.write("\n");
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
