package round1b.a;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream.GetField;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Iterator;
import java.util.Scanner;

public class RPI {
	public static enum CellType {
		WIN, LOSE, NONE;
		static CellType fromString(char c) {
			return c == '1' ? WIN : c == '0' ? LOSE : NONE;
		}
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) throws IOException,
			InterruptedException {
		final String fileName = "round1b/a/small";

		FileInputStream inFile = new FileInputStream(fileName + ".in");
		Scanner in = new Scanner(inFile);

		FileOutputStream outFile = new FileOutputStream(fileName + ".out");
		PrintWriter out = new PrintWriter(outFile);

		int testCases = in.nextInt();

		for (int t = 1; t <= testCases; t++) {
			int n = in.nextInt();
			CellType[][] grid = new CellType[n][n];
			for (int i = 0; i < n; i++) {
				String line = in.next();
				for (int j = 0; j < n; j++) {
					grid[i][j] = CellType.fromString(line.charAt(j));
				}
			}
			double[] wp = solveTestCase(grid);
			out.println("Case #" + t + ":");
			for (double d : wp) {
				out.printf("%.12f\n", d);
			}
		}
		System.out.println("Done");
		out.flush();
		out.close();
	}

	private static double[] solveTestCase(CellType[][] grid) {
		int[] wins = new int[grid.length];
		int[] gamesPlayed = new int[grid.length];
		double[] wps = new double[grid.length];
		for (int i = 0; i < grid.length; i++) {
			for (int j = 0; j < grid[i].length; j++) {
				if (grid[i][j] == CellType.WIN)
					wins[i]++;
				if (grid[i][j] != CellType.NONE)
					gamesPlayed[i]++;
			}
			wps[i] = (double) wins[i] / gamesPlayed[i];
		}
		double[] owps = new double[grid.length];
		for (int i = 0; i < grid.length; i++) {
			double owp = 0;
			for (int j = 0; j < grid[i].length; j++) {
				if (grid[i][j] == CellType.WIN)
					owp += (double) wins[j] / (gamesPlayed[j] - 1);
				else if (grid[i][j] == CellType.LOSE)
					owp += (double) (wins[j] - 1) / (gamesPlayed[j] - 1);
			}
			owps[i] = owp / gamesPlayed[i];
		}
		
		double[] oowps = new double[grid.length];
		for (int i = 0; i < grid.length; i++) {
			double oowp = 0;
			
			for (int j = 0; j < grid[i].length; j++)
				if (grid[i][j] != CellType.NONE)
					oowp += owps[j];
			
			oowps[i] = oowp / gamesPlayed[i];
		}
		
		double[] rpi = new double[grid.length];
		for (int i = 0; i < rpi.length; i++) {
			rpi[i] = 0.25 * wps[i] + 0.5 * owps[i] + 0.25 * oowps[i];
		}
		
		return rpi;
	}
}
