/**
 * 
 */
package myUtil;

import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.Deque;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.Map;
import java.util.Stack;

/**
 * @author Wang
 *
 */
public class StringUtil {

	/**
	 * Generate the array indicating the ith suffix is at A[i] position.
	 */
	private static int[] creatSuffixArray(String str) {

		int N = str.length();
		int max_Iteration = 1 + (int) Math.ceil((Math.log(N) / Math.log(2)));

		// Dp array [i][j] stores rank of suffix[j] at each iteration i.
		int[][] suffixRank = new int[max_Iteration][N];

		// Initial 0 iteration based on single character.
		for (int i = 0; i < suffixRank[0].length; i++) {
			suffixRank[0][i] = str.charAt(i) - 'a';
		}

		// Suffix[i] represent each suffix
		// suffix[i][0] stores the original pos.
		// suffix[i][1] stores the rank of first half substring.
		// suffix[i][2] stores the rank of second half substring.
		int[][] suffix = new int[N][3];

		// cnt represents the length of range to be considered while ranking.
		int stp = 1, cnt = 1;

		while (cnt < N) {

			for (int i = 0; i < N; i++) {
				suffix[i][0] = i;
				suffix[i][1] = suffixRank[stp - 1][i];
				suffix[i][2] = (i + cnt < N) ? suffixRank[stp - 1][i + cnt]
						: -1;
			}

			Arrays.sort(suffix, new Comparator<int[]>() {
				@Override
				public int compare(int[] o1, int[] o2) {
					if (o1[1] == o2[1]) {
						return o1[2] - o2[2];
					}
					return o1[1] - o2[1];
				}
			});

			suffixRank[stp][suffix[0][0]] = 0;

			for (int i = 1, curRank = 0; i < N; i++) {
				if (suffix[i - 1][1] != suffix[i][1]
						|| suffix[i - 1][2] != suffix[i][2])
					curRank++;
				suffixRank[stp][suffix[i][0]] = curRank;
			}

			stp++;
			cnt <<= 1;
		}

		int suffixArray[] = new int[N];
		for (int i = 0; i < suffixArray.length; i++) {
			suffixArray[i] = suffix[i][0];
		}

		return suffixArray;
	}

	public static int[] createLCPArray(String str) {
		int[] sa = creatSuffixArray(str);
		int[] rank = new int[str.length()];
		int[] lcp = new int[str.length()];

		int i = 0, k = 0, n = rank.length;

		for (i = 0; i < n; i++)
			rank[sa[i]] = i;

		i = 0;
		while (i < n) {
			if (rank[i] == n - 1) {
				k = 0;
			} else {

				int j = sa[rank[i] + 1];
				while (i + k < n && j + k < n
						&& str.charAt(i + k) == str.charAt(j + k)) {

					k++;
				}

				lcp[rank[i] + 1] = k;
			}

			if (k > 0)
				k--;
			i++;
		}

		return lcp;
	}

	/**
	 * 12. Integer to Roman
	 *
	 * Given an integer, convert it to a roman numeral.
	 * 
	 * Input is guaranteed to be within the range from 1 to 3999.
	 * 
	 * 
	 * @param num
	 * @return
	 */
	public static String intToRoman(int num) {
		String M[] = { "", "M", "MM", "MMM" };
		String C[] = { "", "C", "CC", "CCC", "CD", "D", "DC", "DCC", "DCCC",
				"CM" };
		String X[] = { "", "X", "XX", "XXX", "XL", "L", "LX", "LXX", "LXXX",
				"XC" };
		String I[] = { "", "I", "II", "III", "IV", "V", "VI", "VII", "VIII",
				"IX" };
		return M[num / 1000] + C[(num % 1000) / 100] + X[(num % 100) / 10]
				+ I[num % 10];
	}

	/**
	 * 38. Count and Say
	 * 
	 * The count-and-say sequence is the sequence of integers beginning as
	 * follows: 1, 11, 21, 1211, 111221, ...
	 * 
	 * 1 is read off as "one 1" or 11. 11 is read off as "two 1s" or 21. 21 is
	 * read off as "one 2, then one 1" or 1211. Given an integer n, generate the
	 * nth sequence.
	 * 
	 * @param n
	 * @return
	 */
	public static String countAndSay(int n) {
		String str = "1";

		while (n-- > 1) {

			String ans = "";
			int pos = 0, count = 1;

			while (pos < str.length()) {
				if (pos < str.length() - 1
						&& str.charAt(pos) == str.charAt(pos + 1)) {
					count++;
				} else {
					ans += Integer.toString(count) + str.charAt(pos);
					count = 1;
				}
				pos++;
			}
			str = ans;
		}
		return str;

	}

	/**
	 * 205. Isomorphic Strings
	 * 
	 * Given two strings s and t, determine if they are isomorphic.
	 * 
	 * Two strings are isomorphic if the characters in s can be replaced to get
	 * t.
	 * 
	 * All occurrences of a character must be replaced with another character
	 * while preserving the order of characters. No two characters may map to
	 * the same character but a character may map to itself.
	 * 
	 * For example, Given "egg", "add", return true.
	 * 
	 * Given "foo", "bar", return false.
	 * 
	 * Given "paper", "title", return true.
	 * 
	 * @param s
	 * @param t
	 * @return
	 */
	public static boolean isIsomorphic(String s, String t) {

		Map<Character, Character> map = new HashMap<>();
		for (int i = 0; i < s.length(); i++) {
			if (map.containsKey(s.charAt(i))) {
				if (t.charAt(i) != map.get(s.charAt(i))) {
					return false;
				}
			} else {
				if (!map.containsValue(t.charAt(i))) {
					map.put(s.charAt(i), t.charAt(i));
				} else
					return false;
			}

		}
		return true;
	}

	/**
	 * 3. Longest Substring Without Repeating Characters
	 * 
	 * Medium Given a string, find the length of the longest substring without
	 * repeating characters. For example, the longest substring without
	 * repeating letters for "abcabcbb" is "abc", which the length is 3. For
	 * "bbbbb" the longest substring is "b", with the length of 1.
	 * 
	 * 
	 * @param s
	 * @return
	 */
	public static int lengthOfLongestSubstring(String s) {

		int max = 0, left = 0, right = 0;

		Map<Character, Integer> map = new HashMap<>();

		while (left < s.length() && right < s.length()) {
			if (!map.containsKey(s.charAt(right))) {
				map.put(s.charAt(right), right);
				right++;
				max = Math.max(max, right - left);
			} else {
				int target = map.get(s.charAt(right));
				for (int i = left; i <= target; i++) {
					map.remove(s.charAt(i));
				}
				left = target + 1;
			}
		}

		return max;
	}

	/**
	 * 43. Multiply Strings
	 * 
	 * Given two numbers represented as strings, return multiplication of the
	 * numbers as a string.
	 * 
	 * Note: The numbers can be arbitrarily large and are non-negative.
	 * 
	 * @param num1
	 * @param num2
	 * @return
	 */
	public static String multiply(String num1, String num2) {

		int len1 = num1.length(), len2 = num2.length();
		int[] ans = new int[len1 + len2];

		for (int i = len1 - 1; i >= 0; i--) {
			for (int j = len2 - 1; j >= 0; j--) {
				int low = i + j + 1, hi = i + j;
				int res = (num1.charAt(i) - '0') * (num2.charAt(j) - '0')
						+ ans[low];

				ans[low] = res % 10;
				ans[hi] += res / 10;
			}
		}

		int pos = 0;

		while (pos < ans.length && ans[pos] == 0) {
			pos++;
		}

		if (pos == ans.length) {
			return "0";
		} else {
			StringBuilder sb = new StringBuilder();
			while (pos < ans.length) {
				sb.append(ans[pos]);
				pos++;
			}

			return sb.toString();
		}

	}

	public static String add(String num1, String num2) {

		int i = num1.length() - 1, j = num2.length() - 1, endi = 0, endj = 0;
		StringBuilder sb = new StringBuilder();
		int carry = 0;

		while (endi < num1.length() && num1.charAt(endi) == '0') {
			endi++;
		}
		while (endj < num2.length() && num2.charAt(endj) == '0') {
			endj++;
		}

		while (i >= endi || j >= endj || carry > 0) {
			int a = i >= 0 ? num1.charAt(i) - '0' : 0;
			int b = j >= 0 ? num2.charAt(j) - '0' : 0;
			int sum = a + b + carry;
			if (sum > 9) {
				carry = 1;
			} else {
				carry = 0;
			}
			sb.append(sum % 10);
			i--;
			j--;
		}
		return sb.length() == 0 ? "0" : sb.reverse().toString();
	}

	/**
	 * 224. Basic Calculator
	 * 
	 * 
	 * Implement a basic calculator to evaluate a simple expression string.
	 * 
	 * The expression string may contain open ( and closing parentheses ), the
	 * plus + or minus sign -, non-negative integers and empty spaces .
	 * 
	 * You may assume that the given expression is always valid.
	 * 
	 * Some examples: "1 + 1" = 2 " 2-1 + 2 " = 3 "(1+(4+5+2)-3)+(6+8)" = 23
	 * 
	 * @param num1
	 * @param num2
	 * @return
	 */
	public static int calculate(String s) {

		Stack<Integer> stack = new Stack<>();

		int num = 0, sign = 1, res = 0;

		for (int i = 0; i < s.length(); i++) {

			char c = s.charAt(i);

			switch (c) {
			case ' ': {
				break;
			}
			case '+': {
				res += sign * num;
				num = 0;
				sign = 1;
				break;
			}
			case '-': {
				res += sign * num;
				num = 0;
				sign = -1;
				break;
			}
			case '(': {
				stack.push(res);
				stack.push(sign);
				res = 0;
				sign = 1;
				break;
			}
			case ')': {
				res += sign * num;
				res = res * stack.pop() + stack.pop();
				sign = 1;
				num = 0;
				break;
			}
			default: {
				num = c - '0' + num * 10;
			}
			}
		}
		res += sign * num;
		return res;

	}

	/**
	 * 150. Evaluate Reverse Polish Notation
	 * 
	 * Evaluate the value of an arithmetic expression in Reverse Polish
	 * Notation.
	 * 
	 * Valid operators are +, -, *, /. Each operand may be an integer or another
	 * expression.
	 * 
	 * Some examples: ["2", "1", "+", "3", "*"] -> ((2 + 1) * 3) -> 9 ["4",
	 * "13", "5", "/", "+"] -> (4 + (13 / 5)) -> 6
	 * 
	 * @param tokens
	 * @return
	 */
	public static int evalRPN(String[] tokens) {

		Stack<Integer> s = new Stack<Integer>();

		for (String str : tokens) {
			switch (str) {
			case "+": {
				s.push(s.pop() + s.pop());
				break;
			}
			case "-": {
				int tmp = s.pop();
				s.push(s.pop() - tmp);
				break;
			}
			case "*": {
				s.push(s.pop() * s.pop());
				break;
			}
			case "/": {
				int tmp = s.pop();
				s.push(s.pop() / tmp);
				break;
			}
			default:
				s.push(Integer.valueOf(str));
			}
		}

		return s.pop();
	}

	/**
	 * 76. Minimum Window Substring
	 * 
	 * Given a string S and a string T, find the minimum window in S which will
	 * contain all the characters in T in complexity O(n).
	 * 
	 * For example, S = "ADOBECODEBANC" T = "ABC"
	 * 
	 * Minimum window is "BANC".
	 * 
	 * @param s
	 * @param t
	 * @return
	 */
	public static String minWindow(String s, String t) {

		Map<Character, Integer> need = new HashMap<>();
		int count = 0;
		for (char c : t.toCharArray()) {
			need.put(c, need.getOrDefault(c, 0) + 1);
			count++;
		}

		int lo = 0, hi = 0;
		String ans = "";

		while (hi < s.length()) {
			if (need.containsKey(s.charAt(hi))) {
				need.put(s.charAt(hi), need.get(s.charAt(hi)) - 1);
				if (need.get(s.charAt(hi)) >= 0) {
					count--;
				}
			}
			hi++;

			while (count == 0) {

				if (ans.equals("") || ans.length() > hi - lo) {
					ans = s.substring(lo, hi);
				}
				if (need.containsKey(s.charAt(lo))) {
					need.put(s.charAt(lo), 1 + need.get(s.charAt(lo)));
					if (need.get(s.charAt(lo)) > 0)
						count++;
				}
				lo++;
			}
		}

		return ans;

	}

	/**
	 * 242. Valid Anagram
	 * 
	 * Given two strings s and t, write a function to determine if t is an
	 * anagram of s.
	 * 
	 * For example, s = "anagram", t = "nagaram", return true. s = "rat", t =
	 * "car", return false.
	 * 
	 * 
	 * @param s
	 * @param t
	 * @return
	 */
	public static boolean isAnagram(String s, String t) {

		if (s.length() != t.length())
			return false;

		int[] alphabet = new int[256];
		for (int i = 0; i < s.length(); i++) {
			alphabet[s.charAt(i) - 'a']++;
			alphabet[t.charAt(i) - 'a']--;
		}
		for (int i : alphabet)
			if (i != 0)
				return false;
		return true;
	}

	/**
	 * 
	 * 87. Scramble String
	 * 
	 * Given a string s1, we may represent it as a binary tree by partitioning
	 * it to two non-empty substrings recursively.
	 * 
	 * Below is one possible representation of s1 = "great":
	 * 
	 * great / \ gr eat / \ / \ g r e at / \ a t
	 * 
	 * To scramble the string, we may choose any non-leaf node and swap its two
	 * children.
	 * 
	 * For example, if we choose the node "gr" and swap its two children, it
	 * produces a scrambled string "rgeat".
	 * 
	 * rgeat / \ rg eat / \ / \ r g e at / \ a t
	 * 
	 * We say that "rgeat" is a scrambled string of "great".
	 * 
	 * Similarly, if we continue to swap the children of nodes "eat" and "at",
	 * it produces a scrambled string "rgtae".
	 * 
	 * rgtae / \ rg tae / \ / \ r g ta e / \ t a
	 * 
	 * We say that "rgtae" is a scrambled string of "great".
	 * 
	 * Given two strings s1 and s2 of the same length, determine if s2 is a
	 * scrambled string of s1.
	 * 
	 * Subscribe to see which companies asked this question
	 * 
	 * @param s1
	 * @param s2
	 * @return
	 */
	public static boolean isScramble(String s1, String s2) {

		if (!isIsomorphic(s1, s2)) {
			return false;
		}

		if (s1.length() == 1) {
			return s1.equals(s2);
		}

		for (int i = 1; i < s1.length(); i++) {
			if (isScramble(s1.substring(0, i), s2.substring(s2.length() - i))
					&& isScramble(s1.substring(i),
							s2.substring(0, s2.length() - i))
					|| isScramble(s1.substring(0, i), s2.substring(0, i))
					&& isScramble(s1.substring(i), s2.substring(i)))
				return true;
		}

		return false;

	}

	/**
	 * 316. Remove Duplicate Letters
	 * 
	 * Given a string which contains only lowercase letters, remove duplicate
	 * letters so that every letter appear once and only once. You must make
	 * sure your result is the smallest in lexicographical order among all
	 * possible results.
	 * 
	 * Example: Given "bcabc" Return "abc"
	 * 
	 * Given "cbacdcbc" Return "acdb"
	 * 
	 * @param s
	 * @return
	 */
	public static String removeDuplicateLetters(String s) {

		int[] have = new int[256];
		boolean[] added = new boolean[256];

		for (char c : s.toCharArray()) {
			have[c]++;
		}

		Deque<Character> stack = new LinkedList<>();

		for (int i = 0; i < s.length(); i++) {
			char c = s.charAt(i);
			have[c]--;
			if (!added[c]) {
				while (!stack.isEmpty() && stack.peek() > c
						&& have[stack.peek()] > 0) {
					added[stack.pop()] = false;
				}

				stack.push(c);
				added[c] = true;
			}
		}

		String ans = "";

		while (!stack.isEmpty()) {
			ans = stack.pop() + ans;
		}

		return ans;
	}

	/**
	 * 273. Integer to English Words
	 * 
	 * Convert a non-negative integer to its english words representation. Given
	 * input is guaranteed to be less than 231 - 1.
	 * 
	 * For example, 123 -> "One Hundred Twenty Three" 12345 ->
	 * "Twelve Thousand Three Hundred Forty Five" 1234567 ->
	 * "One Million Two Hundred Thirty Four Thousand Five Hundred Sixty Seven"
	 * 
	 * @param num
	 * @return
	 */
	public static String numberToWords(int num) {
		final String[] thousands = { "", "Thousand", "Million", "Billion" };
		if (num == 0)
			return "Zero";
		int i = 0;
		String words = "";

		while (num > 0) {
			if (num % 1000 != 0)
				words = numberToWordshelper(num % 1000) + thousands[i] + " "
						+ words;
			num /= 1000;
			i++;
		}

		return words.trim();
	}

	private static String numberToWordshelper(int num) {
		final String[] lessThan20 = { "", "One", "Two", "Three", "Four",
				"Five", "Six", "Seven", "Eight", "Nine", "Ten", "Eleven",
				"Twelve", "Thirteen", "Fourteen", "Fifteen", "Sixteen",
				"Seventeen", "Eighteen", "Nineteen" };
		final String[] tens = { "", "Ten", "Twenty", "Thirty", "Forty",
				"Fifty", "Sixty", "Seventy", "Eighty", "Ninety" };
		if (num == 0)
			return "";
		else if (num < 20)
			return lessThan20[num] + " ";
		else if (num < 100)
			return tens[num / 10] + " " + numberToWordshelper(num % 10);
		else
			return lessThan20[num / 100] + " Hundred "
					+ numberToWordshelper(num % 100);
	}

}
