package c;

import java.io.*;
import java.math.BigInteger;

public class SolutionLarge {
//    private static final String FILENAME = "test";
//    private static final String FILENAME = "C-small-attempt0";
    private static final String FILENAME = "C-large";

    public static void main(String[] args) throws IOException {
        final long start = System.nanoTime();

        // READ INPUT FILE
        final FileReader fileReader = new FileReader("input/c/" + FILENAME + ".in");
        final BufferedReader bufferedReader = new BufferedReader(fileReader);

        String line = bufferedReader.readLine();
        final Integer numberOfCases = Integer.parseInt(line);
        final int[][] cases = new int[numberOfCases][2];

        for (int i = 0; i < numberOfCases; i++) {
            line = bufferedReader.readLine();
            final String[] parts = line.split(" ");
            cases[i][0] = Integer.parseInt(parts[0]);
            cases[i][1] = Integer.parseInt(parts[1]);
        }

        bufferedReader.close();


        // WRITE OUTPUT FILE
        final FileWriter fileWriter = new FileWriter("output/c/" + FILENAME + ".out");
        final BufferedWriter bufferedWriter = new BufferedWriter(fileWriter);

        for (int i = 0; i < cases.length; i++) {
            final int length = cases[i][0];
            final int quantity = cases[i][1];
            bufferedWriter.write("Case #" + (i + 1) + ":" + System.lineSeparator());

            final String[] solution = solveCase(length, quantity);

            for (int j = 0; j < solution.length; j++) {
                bufferedWriter.write(solution[j] + System.lineSeparator());
            }
        }

        bufferedWriter.close();

        final long end = System.nanoTime();

        System.out.println("Total time: " + (end - start) / 1000000.0);
    }

    private static String[] solveCase(final int length, final int quantity) {
        final String[] result = new String[quantity];
        long binaryNumber = (long) Math.pow(2.0, (double) length - 1) + 1;
        int count = 0;

        while (count < quantity) {
            boolean isValid = true;
            final String[] divisors = new String[9];

//            System.out.println();
//            System.out.println("Number: " + asBinaryString(binaryNumber));

            for (int i = 2; i <= 10; i++) {
                BigInteger number = decode(binaryNumber, i);
//                System.out.println("Number (" + i + "): " + number);
                BigInteger divisor = getDivisor(number);

                if (divisor.equals(number)) {
                    isValid = false;
                    break;
                } else {
                    divisors[i - 2] = divisor.toString();
                }
            }

            if (isValid) {
                result[count++] = asBinaryString(binaryNumber) + " " + String.join(" ", divisors);
//                System.out.println("Result #" + (count - 1) + ": " + result[count - 1]);
            }

            binaryNumber += 2;
        }

        return result;
    }

    private static BigInteger decode(final long binaryNumber, final int base) {
        long currentBinaryNumber = binaryNumber;
        BigInteger currentNumber = BigInteger.ZERO;
        long currentExponent = 0;

        while (currentBinaryNumber > 0) {
            if (currentBinaryNumber % 2 == 1) {
                BigInteger number = BigInteger.valueOf(base).pow((int) currentExponent);
                currentNumber = currentNumber.add(number);
            }

            currentExponent++;
            currentBinaryNumber /= 2;
        }

        return currentNumber;
    }

    private static BigInteger getDivisor(final BigInteger number) {
        final BigInteger lastNumber = BigInteger.valueOf(1000000L);
        final BigInteger TWO = BigInteger.valueOf(2);

        if (number.mod(TWO).equals(BigInteger.ZERO)) {
            return TWO;
        }

        BigInteger currentNumber = BigInteger.valueOf(3);

        while (currentNumber.compareTo(lastNumber) <= 0) {
            if (number.mod(currentNumber).equals(BigInteger.ZERO)) {
                return currentNumber;
            }
            currentNumber = currentNumber.add(TWO);
        }

        return number;
    }

    private static String asBinaryString(final long binaryNumber) {
        long currentBinaryNumber = binaryNumber;
        String result = "";

        for (; currentBinaryNumber > 0; currentBinaryNumber /= 2) {
            result = (currentBinaryNumber % 2) + result;
        }

        return result;
    }
}
