package round1c.a;

import java.io.*;
import java.util.*;

public class Solution {
    private static final String EXERCISE = "a";
    private static final String INPUT_FOLDER = "input/round1c/" + EXERCISE;
    private static final String OUTPUT_FOLDER = "output/round1c/" + EXERCISE;

//    private static final String FILENAME = "test";
//    private static final String FILENAME = EXERCISE.toUpperCase() + "-small-attempt0";
    private static final String FILENAME = EXERCISE.toUpperCase() + "-large";

    private static final String ALPHABET = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
    private static final char[] PARTY_NAMES = ALPHABET.toCharArray();

    public static void main(String[] args) throws IOException {
        final long start = System.nanoTime();

        // READ INPUT FILE
        final FileReader fileReader = new FileReader(INPUT_FOLDER + "/" + FILENAME + ".in");
        final BufferedReader bufferedReader = new BufferedReader(fileReader);

        String line = bufferedReader.readLine();
        final Integer numberOfCases = Integer.parseInt(line);
        final String[] cases = new String[numberOfCases];

        for (int i = 0; i < numberOfCases; i++) {
            bufferedReader.readLine(); // Ignoring this line
            line = bufferedReader.readLine();
            cases[i] = line;
        }

        bufferedReader.close();


        // WRITE OUTPUT FILE
        final FileWriter fileWriter = new FileWriter(OUTPUT_FOLDER + "/" + FILENAME + ".out");
        final BufferedWriter bufferedWriter = new BufferedWriter(fileWriter);

        for (int i = 0; i < cases.length; i++) {
            final String[] temp = cases[i].split(" ");
            final int[] politicians = new int[temp.length];

            for (int j = 0; j < politicians.length; j ++) {
                politicians[j] = Integer.parseInt(temp[j]);
            }

            bufferedWriter.write("Case #" + (i + 1) + ": " + solveCase(politicians) + System.lineSeparator());
        }

        bufferedWriter.close();

        final long end = System.nanoTime();

        System.out.println("Total time: " + (end - start) / 1000000.0);
    }

    private static String solveCase(final int[] politicians) {
        final List<String> result = new ArrayList<>();
        final List<Integer> ignore = new ArrayList<>();

        while (!isEmpty(politicians)) {
            final int party1 = getMajorParty(politicians, ignore);
            politicians[party1] --;

            int party2 = getMajorParty(politicians, ignore);

            while (party2 != -1) {
                if (isSafe(politicians, party2)) {
                    politicians[party2] --;
                    result.add(PARTY_NAMES[party1] + "" + PARTY_NAMES[party2]);
                    break;
                } else {
                    ignore.add(party2);
                    party2 = getMajorParty(politicians, ignore);
                }
            }

            if (party2 == -1) {
                result.add(PARTY_NAMES[party1] + "");
            }

            ignore.clear();
        }

        return getString(result);
    }

    private static boolean isEmpty(final int[] politicians) {
        for (int i = 0; i < politicians.length; i ++) {
            if (politicians[i] != 0) {
                return false;
            }
        }

        return true;
    }

    private static int getMajorParty(final int[] politicians, final List<Integer> ignore) {
        int result = -1;
        int partyMembers = 0;

        for (int i = 0; i < politicians.length; i ++) {
            if (!ignore.contains(i) && politicians[i] > partyMembers) {
                partyMembers = politicians[i];
                result = i;
            }
        }

        return result;
    }

    private static boolean isSafe(final int[] politicians, final int party2) {
        politicians[party2] --;
        boolean isSafe = isSafe(politicians);
        politicians[party2] ++;

        return isSafe;
    }

    private static boolean isSafe(final int[] politicians) {
        int total = 0;
        int max = 0;

        for (int i = 0; i < politicians.length; i ++) {
            total += politicians[i];

            if (politicians[i] > max) {
                max = politicians[i];
            }
        }

        return (max <= (total / 2));
    }

    private static String getString(final List<String> solution) {
        final StringBuilder stringBuilder = new StringBuilder("");

        for (int i = 0; i < solution.size(); i ++) {
            if (i != 0) {
                stringBuilder.append(" ");
            }
            stringBuilder.append(solution.get(i));
        }

        return stringBuilder.toString();
    }
}
