import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.InputMismatchException;

public class RedTapeCommittee {
	public static void main(String[] args) {
		FileScanner sc = new FileScanner("io/input.txt");
		StringBuilder sb = new StringBuilder();
		
		int T = sc.nextInt();
		for (int t = 1; t <= T; t++) {
			int N = sc.nextInt();
			int K = sc.nextInt();
			double[] P = new double[N];
			for (int i = 0; i < N; i++) {
				P[i] = sc.nextDouble();
			}
			double best = 0;
			int[][] combos = getCombinations(N, K);
			for (int[] c : combos) {
				double[] probs = new double[K];
				for (int i = 0; i < K; i++) {
					probs[i] = P[c[i]];
				}
				best = Math.max(best, calcProb(probs));
			}
			sb.append(String.format("Case #%d: %.12f\n", t, best));
		}
		
		try (PrintWriter pw = new PrintWriter("io/output.txt")) {
			pw.append(sb.toString());
		} catch (FileNotFoundException e) {
			System.out.println("Error with output file!");
		}
	}
	
	private static double calcProb(double[] p) {
		final int N = p.length;
		double[][] dp = new double[N][N + 1];
		dp[0][0] = 1 - p[0];
		dp[0][1] = p[0];
		for (int i = 1; i < N; i++) {
			dp[i][0] = dp[i - 1][0] * (1 - p[i]);
			for (int j = 1; j <= N; j++) {
				dp[i][j] = (dp[i - 1][j] * (1 - p[i])) + (dp[i - 1][j - 1] * p[i]);
			}
		}
		return dp[N - 1][N / 2];
	}

	/**
	 * Method for computing combinations.  Returns an array of int[], which contains k elements from { 0, 1, ..., n - 1 }.
	 * Each int[] will be sorted in ascending order, and they array of int[] will be sorted ascending as well.
	 */
	public static int[][] getCombinations(int n, int k)
	{
		ArrayList<int[]> lst = new ArrayList<int[]>();
		int[] arr = new int[k];
		combinationHelper(n, k, 0, 0, arr, lst);
		return lst.toArray(new int[0][]);
	}

	/**
	 * Helper method for computing combinations.  Used by GetCombinations(...).
	 */
	private static void combinationHelper(int n, int k, int i, int t, int[] curr, ArrayList<int[]> lst)
	{
		if (t == k)
		{
			lst.add(curr);
			return;
		}

		curr[t] = i;

		if (k - t > n - i)
			return;

		int[] next = new int[k];
		System.arraycopy(curr, 0, next, 0, k);

		combinationHelper(n, k, i + 1, t + 1, next, lst);
		combinationHelper(n, k, i + 1, t, curr, lst);
	}
	
	public static class FileScanner {
		private byte[] buf = new byte[1024];
		private int curChar;
		private int numChars;
		private InputStream stream;
		
		public FileScanner(String file) {
			try {
				stream = new FileInputStream(file);
			} catch (FileNotFoundException e) {
				System.out.println("Error with input file!");
			}
		}
		
		public int read() {
			if (numChars == -1)
				throw new InputMismatchException();
			if (curChar >= numChars) {
				curChar = 0;
				try {
					numChars = stream.read(buf);
				} catch (IOException e) {
					throw new InputMismatchException();
				}
				if (numChars <= 0)
					return -1;
			}
			return buf[curChar++];
		}

		public String nextLine() {
			int c = read();
			while (isSpaceChar(c))
				c = read();
			StringBuilder res = new StringBuilder();
			do {
				res.appendCodePoint(c);
				c = read();
			} while (!isEndOfLine(c));
			return res.toString();
		}

		public String nextString() {
			int c = read();
			while (isSpaceChar(c))
				c = read();
			StringBuilder res = new StringBuilder();
			do {
				res.appendCodePoint(c);
				c = read();
			} while (!isSpaceChar(c));
			return res.toString();
		}

		public long nextLong() {
			int c = read();
			while (isSpaceChar(c))
				c = read();
			int sgn = 1;
			if (c == '-') {
				sgn = -1;
				c = read();
			}
			long res = 0;
			do {
				if (c < '0' || c > '9')
					throw new InputMismatchException();
				res *= 10;
				res += c - '0';
				c = read();
			} while (!isSpaceChar(c));
			return res * sgn;
		}

		public int nextInt() {
			int c = read();
			while (isSpaceChar(c))
				c = read();
			int sgn = 1;
			if (c == '-') {
				sgn = -1;
				c = read();
			}
			int res = 0;
			do {
				if (c < '0' || c > '9')
					throw new InputMismatchException();
				res *= 10;
				res += c - '0';
				c = read();
			} while (!isSpaceChar(c));
			return res * sgn;
		}
		
		public double nextDouble() {
			return Double.parseDouble(nextString());
		}

		public int[] nextIntArray(int n) {
			return nextIntArray(n, 0);
		}

		public int[] nextIntArray(int n, int off) {
			int[] arr = new int[n + off];
			for (int i = 0; i < n; i++) {
				arr[i + off] = nextInt();
			}
			return arr;
		}

		public long[] nextLongArray(int n) {
			return nextLongArray(n, 0);
		}

		public long[] nextLongArray(int n, int off) {
			long[] arr = new long[n + off];
			for (int i = 0; i < n; i++) {
				arr[i + off] = nextLong();
			}
			return arr;
		}

		private boolean isSpaceChar(int c) {
			return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
		}

		private boolean isEndOfLine(int c) {
			return c == '\n' || c == '\r' || c == -1;
		}
	}
}