import java.io.File;
import java.io.FileNotFoundException;
import java.math.BigInteger;
import java.util.Scanner;

/**
 * Created by Ran on 09/04/2016.
 */
public class CoinJam {

    private static BigInteger[][] baseMult = new BigInteger[11][];
    private static long[] lastDivisors = new long[11];

    private static final BigInteger two = new BigInteger("2");
    private static final BigInteger three = new BigInteger("3");

    private static void initBaseMult() {

        for (int i = 2; i <= 10; i++) {
            baseMult[i] = new BigInteger[32];
            baseMult[i][0] = new BigInteger("1");
            for (int j = 1; j < 16; j++)
                baseMult[i][j] = baseMult[i][j-1].multiply(BigInteger.valueOf((long)i));
        }
    }

    private static BigInteger transToBase(BigInteger n, int base) {

        BigInteger res = new BigInteger("0");

        for (int i = 0; i < 16; i++) {
            int digit = n.mod(two).intValue();
            n = n.divide(two);
            if (digit == 1)
                res = res.add(baseMult[base][i]);
        }

        return res;
    }

    private static long isPrime(BigInteger n) {

        BigInteger a = n.mod(two);
        int b = a.compareTo(BigInteger.ZERO);
        if (n.mod(two).compareTo(BigInteger.ZERO) == 0)
            return 2;

        if (n.mod(three).compareTo(BigInteger.ZERO) == 0)
            return 3;

        long i = 5;
        long w = 2;

        while (BigInteger.valueOf(i * i).compareTo(n) <= 0) {

            if (n.mod(BigInteger.valueOf((long)i)).compareTo(BigInteger.ZERO) == 0)
                return i;

            i += w;
            w = 6 - w;
        }

        return 0;
    }

    private static boolean isJamCoin(BigInteger n) {

        boolean prime = false;

        for (int i = 2; i <= 10; i++) {
            BigInteger b = transToBase(n, i);
            lastDivisors[i] = isPrime(b);
            if (lastDivisors[i] == 0) {
                prime = true;
                break;
            }
        }

        return !prime;
    }

    public static void main (String[] args) {

        initBaseMult();

        Scanner s = null;
        try {
            s = new Scanner (new File("C-large.in"));
        } catch (FileNotFoundException e) {
            e.printStackTrace ();
        }

        int t = s.nextInt();
        if (t != 1) {
            System.out.println("Error: t must be 1.");
            return;
        }

        System.out.println ("Case #1:");

        int n = s.nextInt();
        int j = s.nextInt();

        if (n != 32) {
            System.out.println("Error: n must be 32.");
            return;
        }

        if (j != 500) {
            System.out.println("Error: j must be 500.");
            return;
        }

        int count = 0;

        BigInteger start = new BigInteger("2147483649");
        BigInteger end = new BigInteger("4294967296");

        for (BigInteger i = start; i.compareTo(end) < 0; i = i.add(two)) {
            if (isJamCoin(i)) {
                System.out.print(i.toString(2));
                for (int b = 2; b <= 10; b++)
                    System.out.print(" " + lastDivisors[b]);
                System.out.println();
                count++;
                if (count >= j)
                    break;
            }
        }
    }
}
