import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;

public abstract class TestCaseProcessor<I,O,IP extends InputProcessor<I>,TEST_TYPE extends TestCase<I,O,IP>> {

	public void solve(String inputFile, String outputFile) {
		try(BufferedReader reader = new BufferedReader(new FileReader(inputFile))) {
			try(PrintWriter writer = new PrintWriter(outputFile)) {
				int testCount = Integer.parseInt(reader.readLine());
				for(int i = 0; i < testCount; i++) {
					TEST_TYPE testCase = createTestCase();
					O solution = testCase.solve(reader);
					writer.print("Case #" + (i+1) + ": ");
					report(solution,writer);
				}
			}
		} catch (FileNotFoundException e) {
			throw new RuntimeException(e);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
	}
	
	protected abstract TEST_TYPE createTestCase();
	protected abstract void report(O output, PrintWriter writer);
}
