
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;


public class Dijkstra {
    public enum Digit { ONE, EYE, JAY, KAY }
    
    private static class DigitWithSign {
        Digit d;
        boolean isPos;
        
        public DigitWithSign(Digit d, boolean isPos) {
            this.d = d;
            this.isPos = isPos;
        }
    }
    
    private static final Digit[][] mulResult = { { Digit.ONE, Digit.EYE, Digit.JAY, Digit.KAY },
                                                 { Digit.EYE, Digit.ONE, Digit.KAY, Digit.JAY },
                                                 { Digit.JAY, Digit.KAY, Digit.ONE, Digit.EYE },
                                                 { Digit.KAY, Digit.JAY, Digit.EYE, Digit.ONE} };
    
    private static final boolean[][] switchSign = {  { false, false, false, false },
                                                     { false, true, false, true },
                                                     { false, true, true, false },
                                                     { false, false, true, true}};
    
    private static DigitWithSign mul(DigitWithSign first, DigitWithSign second) {
        boolean prelimSign = (first.isPos && second.isPos) || (!first.isPos && !second.isPos);
        Digit prelimDigit = mulResult[first.d.ordinal()][second.d.ordinal()];
        
        if(switchSign[first.d.ordinal()][second.d.ordinal()])
            prelimSign = !prelimSign;
        
        return new DigitWithSign(prelimDigit, prelimSign);
    }
    
    
    public static void main(String[] args) {
        Scanner in = new Scanner(System.in);
        
        int noTests = in.nextInt();
        
        for(int test=1; test<=noTests; test++) {
            int noDigits = in.nextInt();
            int reps = in.nextInt();
            in.nextLine();
            
            int totDigits = noDigits * reps;
            
            DigitWithSign[] digits = new DigitWithSign[totDigits];
            DigitWithSign eye = new DigitWithSign(Digit.EYE, true);
            DigitWithSign jay = new DigitWithSign(Digit.JAY, true);
            DigitWithSign kay = new DigitWithSign(Digit.KAY, true);
            
            //read first noDigits
            char[] digitArray = in.nextLine().toCharArray();
            for(int i=0; i<digitArray.length; i++) {
                char curChar = digitArray[i];
                if(curChar == 'i')      digits[i] = eye;
                else if(curChar == 'j') digits[i] = jay;
                else                    digits[i] = kay;
            }
            //fill in the rest
            for(int i=noDigits; i<totDigits; i++) {
                digits[i] = digits[i % noDigits];
            }
            
            List<Integer> iIdxs = new ArrayList<>();
            List<Integer> kIdxs = new ArrayList<>();
            
            //do a forward pass to get the i Idxs
            DigitWithSign curDigit = new DigitWithSign(Digit.ONE, true);
            for(int i=0; i<digits.length; i++) {
                curDigit = mul(curDigit, digits[i]);
                if(curDigit.d == Digit.EYE && curDigit.isPos)
                    iIdxs.add(i);
            }
            
            //do a backward pass to get the k idxs
            curDigit = new DigitWithSign(Digit.ONE, true);
            for(int i=digits.length - 1; i>=0; i--) {
                curDigit = mul(digits[i], curDigit);
                if(curDigit.d == Digit.KAY && curDigit.isPos)
                    kIdxs.add(i);
            }
            
            Collections.sort(kIdxs, null);
            
            boolean isSolvable = false;
            
            //better loop
            outerloop:
            for(int i=0; i<iIdxs.size(); i++) {
                int strIdx = iIdxs.get(i) + 1;
                int curIdx = strIdx;
                
                curDigit = new DigitWithSign(Digit.ONE, true);
                
                for(int j=0; j<kIdxs.size(); j++) {
                    int endIdx = kIdxs.get(j) - 1;
                    if(endIdx < strIdx)
                        continue;
                    
                    while(curIdx <= endIdx) {
                        curDigit = mul(curDigit, digits[curIdx]);
                        curIdx++;
                    }
                    
                    if(curDigit.d == Digit.JAY && curDigit.isPos) {
                        isSolvable = true;
                        break outerloop;
                    }
                }
            }
            
            System.out.printf("Case #%d: %s%n", test, isSolvable ? "YES" : "NO");
        }
    }
}

