import java.io.File;
import java.io.FileWriter;
import java.io.RandomAccessFile;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;

import sun.net.www.http.Hurryable;


public class TrainTimeTable
{

	/**
	 * @param args
	 */
	public static void main(String[] args) throws Exception
	{
		File f1 = new File(args[0]);
		File f2 = new File(args[1]);
		if(f2.exists())
		{
			f2.delete();
		}
		f2.createNewFile();
		RandomAccessFile fin = new RandomAccessFile(f1, "r");
		FileWriter fout = new FileWriter(f2);
		String numberTestLine = fin.readLine();
		for(int i = 0; i < Integer.valueOf(numberTestLine.trim()); i++)
		{
			int turnAroundTime = Integer.parseInt(fin.readLine());
			String trainNumbers = fin.readLine();
			String[] trains = trainNumbers.split(" ");
			
			ArrayList<Event> events = new ArrayList<Event>();
			//Read trains start in A
			for(int j = 0; j < Integer.valueOf(trains[0]); j++)
			{
				String trainSquedule = fin.readLine();
				String[] trainSqueduleParts = trainSquedule.split(" ");
				Event eventLeave = new Event();
				eventLeave.station = "A";
				eventLeave.arrive = false;
				eventLeave.setHourStr(trainSqueduleParts[0]);
				
				Event eventArrive = new Event();
				eventArrive.station = "B";
				eventArrive.arrive = true;
				eventArrive.setHourStr(trainSqueduleParts[1]);
				
				addTurnArround(eventArrive,turnAroundTime);
				
				events.add(eventLeave);
				events.add(eventArrive);
			}

			//Read trains start in B
			for(int j = 0; j < Integer.valueOf(trains[1]); j++)
			{
				String trainSquedule = fin.readLine();
				String[] trainSqueduleParts = trainSquedule.split(" ");
				Event eventLeave = new Event();
				eventLeave.station = "B";
				eventLeave.arrive = false;
				eventLeave.setHourStr(trainSqueduleParts[0]);
				
				Event eventArrive = new Event();
				eventArrive.station = "A";
				eventArrive.arrive = true;
				eventArrive.setHourStr(trainSqueduleParts[1]);
				addTurnArround(eventArrive,turnAroundTime);
				
				events.add(eventLeave);
				events.add(eventArrive);
			}

			Collections.sort(events);
			
			int trainsStartA = 0;
			int trainsStartB = 0;
			
			int trainsNumA = 0;
			int trainsNumB = 0;
			
			for(Iterator<Event> itEvents = events.iterator(); itEvents.hasNext();)
			{
				Event event = itEvents.next();
				if(event.arrive)
				{
					if(event.station.equals("A"))
					{
						trainsNumA ++;
					}
					else //if(event.station.equals("B"))
					{
						trainsNumB ++;
					}
				}
				else //if(!event.arrive)
				{
					if(event.station.equals("A"))
					{
						if(trainsNumA > 0)
						{
							trainsNumA --;
						}
						else
						{
							trainsStartA++;
						}
					}
					else //if(event.station.equals("B"))
					{
						if(trainsNumB > 0)
						{
							trainsNumB --;
						}
						else
						{
							trainsStartB++;
						}
					}
				}
			}
			
			fout.write("Case #" + (i+1) + ": " + trainsStartA + " " + trainsStartB + "\n");
		}
		fout.flush();
		fout.close();
	}

	static public void addTurnArround(Event event, int turnAroundTime)
	{
		int minutesNum = event.minutes + turnAroundTime;
		int hourNum = event.hour;
		if(minutesNum >= 60)
		{
			hourNum += minutesNum/60;
			minutesNum = minutesNum%60;
		}
		event.minutes = minutesNum;
		event.hour = hourNum;
	}
}

class Event implements Comparable<Event>
{
	int hour;
	int minutes;
	String station;
	boolean arrive;
	public void setHourStr(String hourStr)
	{
		String[] hourParts = hourStr.split(":");
		hour = Integer.parseInt(hourParts[0]);
		minutes = Integer.parseInt(hourParts[1]);
	}
	public int compareTo(Event o)
	{
		if(this.hour == o.hour)
		{
			if( this.minutes == o.minutes)
			{
				if(this.arrive) return -1;
				else return 1;
			}
			else
			{
				return  this.minutes - o.minutes;
			}
		}
		else
		{
			return this.hour - o.hour;
		}
	}
	
	public String toString()
	{
		return hour + ":" + minutes + "(" + station + ") => arrive " + arrive;
	}
}

