package infinitehouseofpancakes;

import java.util.Arrays;
import java.util.LinkedList;
import java.util.TreeSet;

public class Case implements Comparable<Case> {
	public boolean[] sides;
	public int flips;
	public int width;
	
	public Case(boolean[] sides, int width, int flips) {
		this.sides = sides;
		this.width = width;
		this.flips = flips;
	}
	
	@Override
	public int compareTo(Case arg0) {
		return Integer.compare(arg0.flips + getUpCount(), flips + getUpCount());
	}
	
	public Case flip(int index) {
		boolean[] newsides = Arrays.copyOf(sides, sides.length);
		
		// flip the pancakes!
		for(int i = index; i < index + width; i++)
			newsides[i] ^= true;
		
	//	System.out.println(flips);
		
		return new Case(newsides, width, flips + 1);
	}
	
	public boolean isSolved() {
		for(boolean b : sides)
			if(!b) return false;
		return true;
	}
	
	public void addPermutationsTo(LinkedList<Case> ts) {
		for(int i = 0; i < sides.length - width + 1; i++) {
			ts.add(flip(i));
//			System.out.println(flip(i));
		}
		ts.remove(this);
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
//		result = prime * result + flips;
		result = prime * result + Arrays.hashCode(sides);
		result = prime * result + width;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Case other = (Case) obj;
		if (flips != other.flips)
			return false;
		if (!Arrays.equals(sides, other.sides))
			return false;
		if (width != other.width)
			return false;
		return true;
	}

	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("Case [sides=");
		builder.append(Arrays.toString(sides));
		builder.append(", flips=");
		builder.append(flips);
		builder.append(", width=");
		builder.append(width);
		builder.append("]");
		return builder.toString();
	}

	public static boolean[] getBoolsFromStr(String str) {
		boolean[] ret = new boolean[str.length()];
		for(int i = 0; i < ret.length; i++) {
			char c = str.charAt(i);
			if(c == '+') {
				ret[i] = true;
			} else if(c == '-') {
				ret[i] = false;
			} else {
				throw new AssertionError();
			}
		}
		
		return ret;
	}
	
	public int getUpCount() {
		int total = 0;
		for(boolean b : this.sides)
			if(b)
				total++;
		
		
		return total;
	}
}
