package qualification;

import java.io.*;
import java.util.*;
import java.math.*;
import java.text.*;

public class Magicka
{
	static DecimalFormat DF = new DecimalFormat("0.000",
			new DecimalFormatSymbols(Locale.ENGLISH));

	static String problemName = "B-large";

	/* Valid base elements: {Q, W, E, R, A, S, D, F} */

	class ConstructRule
	{
		char base1, base2, hybrid;

		public ConstructRule(String in)
		{
			base1 = in.charAt(0);
			base2 = in.charAt(1);
			hybrid = in.charAt(2);
		}

		public String applyRule(String s)
		{
			char[] charArray1 = new char[] { base1, base2 };
			String seq1 = new String(charArray1);
			char[] charArray2 = new char[] { base2, base1 };
			String seq2 = new String(charArray2);

			String regex = "(" + seq1 + "|" + seq2 + ")";
			return s.replaceAll(regex, Character.toString(hybrid));
		}
	}

	class DestructRule
	{
		char base1, base2;

		public DestructRule(String in)
		{
			base1 = in.charAt(0);
			base2 = in.charAt(1);
		}

		public String applyRule(String s)
		{
			if (s.indexOf(base1) != -1 && s.indexOf(base2) != -1)
			{
				return "";
			}
			else
			{
				return s;
			}
		}
	}

	public static void run() throws Exception
	{
		init(problemName);

		Magicka m = new Magicka();

		// small: 1 <= T <= 100
		int cases = INT();
		for (int cc = 1; cc <= cases; cc++)
		{
			/* INPUT */
			// for each case/row
			ArrayList<ConstructRule> constructRules = new ArrayList<Magicka.ConstructRule>();
			ArrayList<DestructRule> destructRules = new ArrayList<Magicka.DestructRule>();

			// Construct
			int num_rules = INT();
			for (int i = 0; i < num_rules; i++)
			{
				String rule = TOKEN();
				ConstructRule cr = m.new ConstructRule(rule);
				constructRules.add(cr);
			}

			// Destruct
			num_rules = INT();
			for (int i = 0; i < num_rules; i++)
			{
				String rule = TOKEN();
				DestructRule dr = m.new DestructRule(rule);
				destructRules.add(dr);
			}

			String result = "";
			int num_chars = INT();
			String input = TOKEN();
			for (int i = 0; i < num_chars; i++)
			{
				String c = Character.toString(input.charAt(i));
				result += c;

				for (;;)
				{
					String start = result;

					for (ConstructRule cr : constructRules)
					{
						result = cr.applyRule(result);
					}
					for (DestructRule dr : destructRules)
					{
						result = dr.applyRule(result);
					}

					if (result == start)
						break;
				}
			}

			/* OUTPUT */
			println("Case #" + cc + ": " + resultToString(result));
		}
	}

	// *************************************************************************************
	// *********************************** FRAMEWORK
	// ***************************************
	// *************************************************************************************

	public static String resultToString(String result)
	{
		String output = "[";
		for (int i = 0; i < result.length(); i++)
		{
			output += result.charAt(i);
			if (i < result.length() - 1)
			{
				output += ", ";
			}
		}
		output += "]";
		return output;
	}

	public static BufferedReader stdin = new BufferedReader(
			new InputStreamReader(System.in));
	public static boolean isStandardInput = false;

	public static File input;
	public static FileReader inputreader;
	public static BufferedReader in;

	public static File output;
	public static FileWriter outputwriter;
	public static BufferedWriter out;

	public static StringTokenizer st;

	public static void main(String[] args) throws Exception
	{
		doSTDIN(true);
		setOutput(problemName + ".out");
		run();
		close();
	}

	public static void init(String problemName) throws Exception
	{
		doSTDIN(false);
		setInput(problemName + ".in");
		setOutput(problemName + ".out");
	}

	// **************** PRINT METHODS **********************

	public static void println() throws IOException
	{
		out.write("\n");
		System.out.println();
	}

	public static void println(Object obj) throws IOException
	{
		out.write(obj.toString());
		out.write("\n");
		System.out.println(obj.toString());
	}

	public static void print(Object obj) throws IOException
	{
		out.write(obj.toString());
		System.out.print(obj.toString());
	}

	public static void println(long number) throws IOException
	{
		out.write(Long.toString(number));
		out.write("\n");
		System.out.println(number);
	}

	public static void print(long number) throws IOException
	{
		out.write(Long.toString(number));
		System.out.print(number);
	}

	public static void println(char c) throws IOException
	{
		out.write(Character.toString(c));
		out.write("\n");
		System.out.println(c);
	}

	public static void print(char c) throws IOException
	{
		out.write(Character.toString(c));
		System.out.print(c);
	}

	public static void println(String line) throws IOException
	{
		out.write(line);
		out.write("\n");
		System.out.println(line);
	}

	public static void print(String line) throws IOException
	{
		out.write(line);
		System.out.print(line);
	}

	// ******************** INPUT DECLARATION ******************

	public static void doSTDIN(boolean standard)
	{
		isStandardInput = standard;
	}

	public static void setInput(String filename) throws IOException
	{
		input = new File(filename);
		inputreader = new FileReader(input);
		in = new BufferedReader(inputreader);
	}

	public static void setOutput(String filename) throws IOException
	{
		output = new File(filename);
		outputwriter = new FileWriter(output);
		out = new BufferedWriter(outputwriter);
	}

	public static void close() throws IOException
	{
		if (in != null)
			in.close();
		if (inputreader != null)
			inputreader.close();

		if (out != null)
			out.flush();
		if (out != null)
			out.close();
		if (outputwriter != null)
			outputwriter.close();
	}

	// ************************** INPUT READING *****************

	static String LINE() throws IOException
	{
		return isStandardInput ? stdin.readLine() : in.readLine();
	}

	static String TOKEN() throws IOException
	{
		while (st == null || !st.hasMoreTokens())
			st = new StringTokenizer(LINE());
		return st.nextToken();
	}

	static char SINGLE_FIRST_CHAR() throws IOException
	{
		String s = TOKEN();
		return s.charAt(0);
	}

	static int INT() throws IOException
	{
		return Integer.parseInt(TOKEN());
	}

	static long LONG() throws IOException
	{
		return Long.parseLong(TOKEN());
	}

	static double DOUBLE() throws IOException
	{
		return Double.parseDouble(TOKEN());
	}

	static BigInteger BIGINT() throws IOException
	{
		return new BigInteger(TOKEN());
	}

}
