package qualification;

import java.io.*;
import java.util.*;
import java.math.*;
import java.text.*;

public class BotTrust
{
	static DecimalFormat DF = new DecimalFormat("0.000",
			new DecimalFormatSymbols(Locale.ENGLISH));

	class Row
	{
		char[] R; // 'O' or 'B'
		int[] P; // 1 <= P <= 100

		public Row(int N)
		{
			R = new char[N];
			P = new int[N];
		}
	}

	public static void run() throws Exception
	{
		/* INPUT */
		init("A-small-attempt1");
		// small: 1 <= T <= 20
		int cases = INT();
		for (int cc = 1; cc <= cases; cc++)
		{
			// for each case/row
			int N = INT(); // number of moves
			Row r = (new BotTrust()).new Row(N);
			for (int i = 0; i < N; i++)
			{
				r.R[i] = SINGLE_FIRST_CHAR();
				r.P[i] = INT();
			}

			/* COMPUTE */
			int result = 0;

			// position of respective robots along hallway
			int pos_O = 1, pos_B = 1;

			// index into row array of first O, B
			int idx_O = 0, idx_B = 0;

			boolean running_O = true, running_B = true;

			while (running_O || running_B)
			{
				// find first O
				for (int i = idx_O; i <= N; i++)
				{
					if (i == N)
					{
						running_O = false;
						break;
					}

					if (r.R[i] == 'O')
					{
						idx_O = i;
						break;
					}
				}

				// find first B
				for (int i = idx_B; i <= N; i++)
				{
					if (i == N)
					{
						running_B = false;
						break;
					}

					if (r.R[i] == 'B')
					{
						idx_B = i;
						break;
					}
				}

//				System.out.println(idx_O + " " + idx_B);
//				System.out.println(running_O + " " + running_B);
				
				if (!running_O)
					idx_O = 1000;
				if (!running_B)
					idx_B = 1000;

				// O first
				if (idx_O < idx_B)
				{
					if (!running_B)
					{
						int num_steps = Math.abs(r.P[idx_O] - pos_O) + 1;
						result += num_steps;

						// update positions
						pos_O = r.P[idx_O];

						// update index
						idx_O++;
					} else
					{
						int num_steps = Math.abs(r.P[idx_O] - pos_O) + 1;
						result += num_steps;

						// update positions
						pos_O = r.P[idx_O];

						int amount = Math.min(Math.abs(r.P[idx_B] - pos_B),
								num_steps);
						amount *= (r.P[idx_B] - pos_B) < 0 ? -1 : 1;
						pos_B += amount;

						// update index
						idx_O++;
					}
				}
				// B first
				else if (idx_B < idx_O)
				{
					if (!running_O)
					{
						int num_steps = Math.abs(r.P[idx_B] - pos_B) + 1;
						result += num_steps;

						// update positions
						pos_B = r.P[idx_B];

						// update index
						idx_B++;
					} else
					{
						int num_steps = Math.abs(r.P[idx_B] - pos_B) + 1;
						result += num_steps;

						// update positions
						pos_B = r.P[idx_B];
						int amount = Math.min(Math.abs(r.P[idx_O] - pos_O),
								num_steps);
						amount *= (r.P[idx_O] - pos_O) < 0 ? -1 : 1;
						pos_O += amount;

						// update index
						idx_B++;
					}
				}

				// assert (idx_B != idx_O);
			} // end while

			/* OUTPUT */
			println("Case #" + cc + ": " + result);
		}
	}

	// *************************************************************************************
	// *********************************** FRAMEWORK
	// ***************************************
	// *************************************************************************************

	public static BufferedReader stdin = new BufferedReader(
			new InputStreamReader(System.in));
	public static boolean isStandardInput = false;

	public static File input;
	public static FileReader inputreader;
	public static BufferedReader in;

	public static File output;
	public static FileWriter outputwriter;
	public static BufferedWriter out;

	public static StringTokenizer st;

	public static void main(String[] args) throws Exception
	{
		doSTDIN(true);
		setOutput("test.out");
		run();
		close();
	}

	public static void init(String problemName) throws Exception
	{
		doSTDIN(false);
		setInput(problemName + ".in");
		setOutput(problemName + ".out");
	}

	// **************** PRINT METHODS **********************

	public static void println() throws IOException
	{
		out.write("\n");
		System.out.println();
	}

	public static void println(Object obj) throws IOException
	{
		out.write(obj.toString());
		out.write("\n");
		System.out.println(obj.toString());
	}

	public static void print(Object obj) throws IOException
	{
		out.write(obj.toString());
		System.out.print(obj.toString());
	}

	public static void println(long number) throws IOException
	{
		out.write(Long.toString(number));
		out.write("\n");
		System.out.println(number);
	}

	public static void print(long number) throws IOException
	{
		out.write(Long.toString(number));
		System.out.print(number);
	}

	public static void println(char c) throws IOException
	{
		out.write(Character.toString(c));
		out.write("\n");
		System.out.println(c);
	}

	public static void print(char c) throws IOException
	{
		out.write(Character.toString(c));
		System.out.print(c);
	}

	public static void println(String line) throws IOException
	{
		out.write(line);
		out.write("\n");
		System.out.println(line);
	}

	public static void print(String line) throws IOException
	{
		out.write(line);
		System.out.print(line);
	}

	// ******************** INPUT DECLARATION ******************

	public static void doSTDIN(boolean standard)
	{
		isStandardInput = standard;
	}

	public static void setInput(String filename) throws IOException
	{
		input = new File(filename);
		inputreader = new FileReader(input);
		in = new BufferedReader(inputreader);
	}

	public static void setOutput(String filename) throws IOException
	{
		output = new File(filename);
		outputwriter = new FileWriter(output);
		out = new BufferedWriter(outputwriter);
	}

	public static void close() throws IOException
	{
		if (in != null)
			in.close();
		if (inputreader != null)
			inputreader.close();

		if (out != null)
			out.flush();
		if (out != null)
			out.close();
		if (outputwriter != null)
			outputwriter.close();
	}

	// ************************** INPUT READING *****************

	static String LINE() throws IOException
	{
		return isStandardInput ? stdin.readLine() : in.readLine();
	}

	static String TOKEN() throws IOException
	{
		while (st == null || !st.hasMoreTokens())
			st = new StringTokenizer(LINE());
		return st.nextToken();
	}

	static char SINGLE_FIRST_CHAR() throws IOException
	{
		String s = TOKEN();
		return s.charAt(0);
	}

	static int INT() throws IOException
	{
		return Integer.parseInt(TOKEN());
	}

	static long LONG() throws IOException
	{
		return Long.parseLong(TOKEN());
	}

	static double DOUBLE() throws IOException
	{
		return Double.parseDouble(TOKEN());
	}

	static BigInteger BIGINT() throws IOException
	{
		return new BigInteger(TOKEN());
	}

}
