package codejam.google;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Iterator;
import java.util.concurrent.LinkedBlockingQueue;

/**
 *
 * @author evolplus
 */
public class QualC {

	private static final BigInteger TWO = new BigInteger("2");
	private static final BigInteger THREE = new BigInteger("3");
	private static final BigInteger MAX_SMALL = BigInteger.valueOf(1L << 32 - 1);
	private static final int THREAD_COUNT = 32;
	private static final String INPUT_FILENAME = "c-large.in";
	private static final String OUTPUT_FILENAME = "c-large.out";
	private static final LinkedBlockingQueue<BigInteger> FIRST_PRIMES = new LinkedBlockingQueue<>();
	private static final int USED_PRIME_COUNT = 1000000;

	private static byte[] SOE_MASK;
	private static volatile int found;
	private static volatile int j;

	/**
	 * @param args the command line arguments
	 * @throws java.io.IOException
	 */
	@SuppressWarnings("SleepWhileInLoop")
	public static void main(String[] args) throws IOException {
		BigInteger x = BigInteger.valueOf(3);
		BigInteger lastPrime = appxRoot(new BigInteger("11111111111111111111111111111111"));
		long primeCount = 0;
		long t1 = System.currentTimeMillis();
		while (x.compareTo(lastPrime) < 0 && primeCount <= USED_PRIME_COUNT) {
			FIRST_PRIMES.add(x);
			primeCount++;
			x = x.nextProbablePrime();
		}
		System.out.println("Search " + USED_PRIME_COUNT + " primes in " + (System.currentTimeMillis() - t1) + " ms");
		BufferedWriter bw;
		try (BufferedReader br = new BufferedReader(new FileReader(INPUT_FILENAME))) {
			bw = new BufferedWriter(new FileWriter(OUTPUT_FILENAME));
			String line;
			line = br.readLine();
			int count = Integer.parseInt(line);
			for (int caseNo = 1; caseNo <= count; caseNo++) {
				line = br.readLine();
				String[] a = line.split("\\s");
				int n = Integer.parseInt(a[0]);
				found = 0;
				j = Integer.parseInt(a[1]);
				t1 = System.currentTimeMillis();
				SOE_MASK = new byte[1 << (n - 3)];
				Arrays.fill(SOE_MASK,
					0, SOE_MASK.length, (byte) 0);
				int root = Math.round(1 << (n / 2));
				long last = (long) SOE_MASK.length * 8;
				for (int i = 3; i < root; i++) {
					if (((SOE_MASK[i / 8] >> (i % 8)) & 1) == 0) {
						for (long k = (long) i * i; k < last; k += i) {
							SOE_MASK[(int) (k / 8)] |= (byte) (1 << (k % 8));
						}
					}
				}
				System.out.println("Sieve of Eratosthenes has been built in " + (System.currentTimeMillis() - t1) + " ms");
				bw.write("Case #" + caseNo + ":");
				bw.newLine();
				long first = 1L << (n - 1);
				long pie = (last - first) / THREAD_COUNT;
				Thread[] threads = new Thread[THREAD_COUNT];
				for (int i = 0; i < THREAD_COUNT; i++) {
					long f = first + pie * i;
					if (f % 2 == 0) {
						f++;
					}
					System.out.println("Thread " + (i + 1) + ": " + f + " - " + (f + pie));
					threads[i] = new SearchThread(f, f + pie, bw);
					threads[i].start();
				}
				while (found < j) {
					try {
						Thread.sleep(100);
					} catch (InterruptedException ex) {
					}
				}
				System.out.println("Done!!!");
				for (Thread thread : threads) {
					if (thread.isAlive()) {
						thread.interrupt();
					}
				}
			}
		}
		bw.close();
	}

	public static BigInteger nextPrime(BigInteger i) {
		if (i.compareTo(MAX_SMALL) <= 0) {
			long l = i.longValue();
			if (l % 2 == 0) {
				l++;
			}
			while (((SOE_MASK[(int) (l / 8)] >> (l % 8)) & 1) == 1) {
				l++;
			}
			return BigInteger.valueOf(l);
		}
		return i.nextProbablePrime();
	}

	public static BigInteger isprime(BigInteger n) {
		if (n.compareTo(BigInteger.ONE) == 0 || n.compareTo(TWO) == 0) {
			return n;
		}
		if (n.isProbablePrime(20)) {
			return n;
		}
		BigInteger root = appxRoot(n);

		Iterator<BigInteger> it = FIRST_PRIMES.iterator();

		while (it.hasNext()) {
			BigInteger i = it.next();
			if (n.mod(i).equals(BigInteger.ZERO)) {
				return i;
			}
			if (found >= j || i.compareTo(root) > 0) {
				return n;
			}
		}
		return n;
	}

	private static BigInteger appxRoot(final BigInteger n) {
		BigInteger half = n.shiftRight(1);
		while (half.multiply(half).compareTo(n) > 0) {
			half = half.shiftRight(1);
		}
		return half.shiftLeft(1);
	}

	private static class SearchThread extends Thread {

		private final long first;
		private final long last;
		private final BufferedWriter bw;

		public SearchThread(long first, long last, BufferedWriter bw) {
			super("Search-" + first + "-" + last);
			this.bw = bw;
			this.first = first;
			this.last = last;
		}

		@Override
		public void run() {
			for (long x = first; x < last && !this.isInterrupted() && found < j; x += 2) {
				if (((SOE_MASK[(int) (x / 8)] >> (x % 8)) & 1) == 1) {
					String test = Long.toBinaryString(x);
					boolean check = true;
					BigInteger[] primes = new BigInteger[11];
					for (int i = 3; i <= 10; i++) {
						if (found >= j) {
							return;
						}
						BigInteger val = new BigInteger(test, i);
						primes[i] = isprime(val);
						if (primes[i].compareTo(val) == 0) {
							check = false;
							break;
						}
					}
					if (check) {
						try {
							synchronized (QualC.class) {
								if (found == j) {
									return;
								}
								found++;
								bw.append(test);
								int mod2 = 3;
								while ((x % mod2) != 0) {
									mod2 += 2;
								}
								bw.append(" ");
								bw.append(String.valueOf(mod2));
								for (int i = 3; i <= 10; i++) {
									bw.append(" ");
									bw.append(primes[i].toString());
								}
								bw.newLine();
							}
						} catch (IOException ex) {
							System.out.println("Error write output.");
						}
						if (found >= j) {
							return;
						}
					}
				}
			}
		}

	}
}
