/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package cgjam11;

import utils.File;

/**
 *
 * @author fabien
 */
public class BotTrust implements Runnable {
  
  private final String filename;
  private final String[] lines;
  private final int nCases;
  
  public BotTrust(String filename) {
    this.filename = filename;
    lines = File.readAllLines(filename);
    nCases = Integer.parseInt(lines[0]);
  }

  @Override
  public void run() {
    StringBuilder sb = new StringBuilder();
    String lf = System.getProperty("line.separator");
    
    for (int i = 1; i <= nCases; i++) {
      Line l = new Line(lines[i]);
      l.run();
      sb.append("Case #");
      sb.append(i);
      sb.append(": ");
      sb.append(l.getResult());
      sb.append(lf);
    }
    
    System.out.println(sb.toString());
    File.writeAllText(filename.replace(".in", ".out"), sb.toString());
  }
  
  private class Line implements Runnable {
    Bot orange = new Bot();
    Bot blue = new Bot();
    
    private String line;
    
    private int nbOperations;
    private int result;
    
    private int[] opB;
    private int[] opO;
    
    public Line(String line) {
      this.line = line;
    }

    public int getResult() {
      return result;
    }

    @Override
    public void run() {
      parse();
      move();
    }
    
    private void move() {
      result = 0;
      int nextO, nextB;
      for (int i = 0; i < nbOperations; ) {
        nextB = getNext(opB, i);
        nextO = getNext(opO, i);
        if (opB[i] != 0) {
          orange.goTo(nextO);
          if (blue.isAt(nextB)) {
            blue.pushButton();
            i++;
          } else {
            blue.goTo(nextB);
          }
        } else if (opO[i] != 0) {
          blue.goTo(nextB);
          if (orange.isAt(nextO)) {
            orange.pushButton();
            i++;
          } else {
            orange.goTo(nextO);
          }
        }
        result++;
      }
    }
    
    private int getNext(int[] t, int i) {
      int j = i;
      while (i < t.length && t[i] == 0) {
        i++;
      }
      if (i == t.length) {
        return j;
      }
      return t[i];
    }
    
    private void parse() {
      String[] all = line.split(" ");
      nbOperations = Integer.parseInt(all[0]);
      
      opB = new int[nbOperations];
      opO = new int[nbOperations];
      
      int c = 0;
      for (int i = 0; i < 2 * nbOperations; i++) {
        if (all[i + 1].equals("O")) {
          opO[c] = Integer.parseInt(all[++i + 1]);
        } else if (all[i + 1].equals("B")) {
          opB[c] = Integer.parseInt(all[++i + 1]);
        }
        c++;
      }
    }
  }
  
  private class Bot {
    private int location;
    private boolean[] buttonsPushed = new boolean[100];
    
    public void pushButton() {
      this.buttonsPushed[location] = true;
    }
    
    public boolean isPushed() {
      return buttonsPushed[location];
    }
    
    public boolean isAt(int l) {
      return (l - 1) == location;
    }
    
    public void goTo(int l) {
      l--;
      if (location < l) {
        location++;
      } else if (location > l) {
        location--;
      }
    }
  }
}