import java.util.Arrays;

import java.util.Scanner;
import java.util.Locale;

import java.util.TreeMap;
import java.util.Iterator;

/*************************************************************************
 *  Compilation:  javac StdIn.java
 *  Execution:    java StdIn
 *
 *  Reads in data of various types from standard input.
 *
 *************************************************************************/

import java.util.Scanner;
import java.util.Locale;

/**
 *  <i>Standard input</i>. This class provides methods for reading strings
 *  and numbers from standard input.
 *  <p>
 *  The Locale used is: language = English, country = US. This is consistent
 *  with the formatting conventions with Java floating-point literals,
 *  command-line arguments (via <tt>Double.parseDouble()</tt>)
 *  and standard output (via <tt>System.out.print()</tt>). It ensures that
 *  standard input works the number formatting used in the textbook.
 *  <p>
 *  For additional documentation, see <a href="http://www.cs.princeton.edu/introcs/15inout">Section 1.5</a> of
 *  <i>Introduction to Programming in Java: An Interdisciplinary Approach</i> by Robert Sedgewick and Kevin Wayne.
 */
class StdIn {

    // assume Unicode UTF-8 encoding
    private static String charsetName = "UTF-8";

    // assume language = English, country = US for consistency with System.out.
    private static Locale usLocale = new Locale("en", "US");

    // the scanner object
    private static Scanner scanner = new Scanner(System.in, charsetName);

    // can't instantiate
    private StdIn() { }

    // static initializer
    static { scanner.useLocale(usLocale); }


    /**
     * Is there only whitespace left on standard input?
     */
    public static boolean isEmpty() {
         return !scanner.hasNext();
    }

    /**
     * Return next string from standard input
     */
    public static String readString() {
        return scanner.next();
    }

    /**
     * Return next int from standard input
     */
    public static int readInt() {
        return scanner.nextInt();
    }

    /**
     * Return next double from standard input
     */
    public static double readDouble() {
        return scanner.nextDouble();
    }

    /**
     * Return next float from standard input
     */
    public static float readFloat() {
         return scanner.nextFloat();
    }

    /**
     * Return next short from standard input
     */
    public static short readShort() {
         return scanner.nextShort();
    }

    /**
     * Return next long from standard input
     */
    public static long readLong() {
        return scanner.nextLong();
    }

    /**
     * Return next byte from standard input
     */
    public static byte readByte() {
        return scanner.nextByte();
    }

    /**
     * Return next boolean from standard input, allowing "true" or "1" for true,
     * and "false" or "0" for false
     */
    public static boolean readBoolean() {
        String s = readString();
        if (s.equalsIgnoreCase("true"))  return true;
        if (s.equalsIgnoreCase("false")) return false;
        if (s.equals("1"))               return true;
        if (s.equals("0"))               return false;
        throw new java.util.InputMismatchException();
    }

    /**
     * Return rest of line from standard input
     */
    public static String readLine() {
        return scanner.nextLine();
    }

    /**
     * Return next char from standard input
     */
    // a complete hack and inefficient - email me if you have a better
    public static char readChar() {
        // (?s) for DOTALL mode so . matches a line termination character
        // 1 says look only one character ahead
        // consider precompiling the pattern
        String s = scanner.findWithinHorizon("(?s).", 1);
        return s.charAt(0);
    }

    /**
     * Return rest of input from standard input
     */
    public static String readAll() {
        if (!scanner.hasNextLine()) return null;

        // reference: http://weblogs.java.net/blog/pat/archive/2004/10/stupid_scanner_1.html
        return scanner.useDelimiter("\\A").next();
    }


}


class ST<Key extends Comparable<Key>, Val> implements Iterable<Key> {
    private TreeMap<Key, Val> st;

    public ST() {
        st = new TreeMap<Key, Val>();
    }

    public void put(Key key, Val val) {
        if (val == null) st.remove(key);
        else             st.put(key, val);
    }
    public Val get(Key key)             { return st.get(key);            }
    public Val remove(Key key)          { return st.remove(key);         }
    public boolean contains(Key key)    { return st.containsKey(key);    }
    public int size()                   { return st.size();              }
    public Iterator<Key> iterator()     { return st.keySet().iterator(); }
}

public class Magicka
{
    private  static boolean sameChars(String firstStr, String secondStr) {
        char[] first = firstStr.toCharArray();
        char[] second = secondStr.toCharArray();
        Arrays.sort(first);
        Arrays.sort(second);
        return Arrays.equals(first, second);
    }
    
    public static void main(String[] args)
    {
        int T = StdIn.readInt();
        
        
        
        for(int i = 0; i < T; i++)
        {
            
                //System.out.println("WOWOWOWOWOWO");
            ST<String, Character> combinations = new ST<String, Character>();
            ST<Character, Character> destroy = new ST<Character, Character>();
            Stack<Character> st = new Stack<Character>();
            
            int C = StdIn.readInt();
            //System.out.print("C = " + C);
            for (int j = 0; j < C; j++)
            {
                String temp = StdIn.readString();
                
                combinations.put(temp.substring(0, 2), temp.charAt(2));
            }
            
            int D = StdIn.readInt();
          //  System.out.println("D = " + D);
            for(int k = 0;k < D; k++)
            {
                
                String temp = StdIn.readString();
                destroy.put(temp.charAt(0), temp.charAt(1));
                destroy.put(temp.charAt(1), temp.charAt(0));
                
            }
            /*
            for (char iter5 : destroy)
                    System.out.print(destroy.get(iter5)+" ");*/
            
            int N = StdIn.readInt();
           // System.out.print("N = " + N);
            String input = StdIn.readString();
           // System.out.print("input = " + input);
            
            for(int l = 0;l < N; l++)
                
            { char current = input.charAt(l);
                //System.out.println("Current char : "+current+ " //");
                if(!st.isEmpty())
                {
                    char rec = st.peek();
                    st.push(current);
                    String temp1="";
                    temp1 = temp1.concat(Character.toString(rec));
                    temp1 = temp1.concat(Character.toString(current));
                    
                    if(combinations.size()!=0){
                        for (String s : combinations)
                        {
                            if (sameChars(temp1,s))
                            {
                                st.pop();
                                st.pop();
                                st.push(combinations.get(s));
                            }
                        }}
                    
                    if(destroy.size()!=0)
                    {
                        for (char iter : st)
                        {
                            char destroyer;
                            if (destroy.contains(iter))
                            {
                            destroyer = destroy.get(iter);
                            
                            for (char iter1 :st)
                            {
                                if(iter1 == destroyer)
                                {//System.out.println("IM HERE!");
                                    for(char iter2 :st)
                                    st.pop();}
                            }
                            }}
                        
                    }
                }
                else st.push(current);
             /*   System.out.println("current state: ");
                for (char iter4 : st)
                    System.out.print(iter4+" ");
                System.out.println();*/
            }
            
            System.out.printf("Case #%d: [",i+1);
        int m = st.size();
       // int n = 0;
        char[] arr = new char[st.size()];
            for (char iter4 : st)
            {
            arr[m-1] = iter4;
            m--;
            }
            
            for( m = 0; m<st.size(); m++)
            {
             if(m==st.size()-1)
                 System.out.print(arr[m]);
              else  System.out.print(arr[m]+", ");
            }
            System.out.print("]");
            System.out.println();
            
            
            
            
            
            
            
        }
        
        
    }
    
}