
import java.io.BufferedReader;
import java.io.FileReader;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Scanner;
import java.util.Set;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;

/**
 * Problem A. Counting Sheep
 *
 * Bleatrix Trotter the sheep has devised a strategy that helps her fall asleep
 * faster. First, she picks a number N. Then she starts naming N, 2 × N, 3 × N,
 * and so on. Whenever she names a number, she thinks about all of the digits in
 * that number. She keeps track of which digits (0, 1, 2, 3, 4, 5, 6, 7, 8, and
 * 9) she has seen at least once so far as part of any number she has named.
 * Once she has seen each of the ten digits at least once, she will fall asleep.
 *
 * Bleatrix must start with N and must always name (i + 1) × N directly after i
 * × N. For example, suppose that Bleatrix picks N = 1692. She would count as
 * follows:
 *
 * N = 1692. Now she has seen the digits 1, 2, 6, and 9. 2N = 3384. Now she has
 * seen the digits 1, 2, 3, 4, 6, 8, and 9. 3N = 5076. Now she has seen all ten
 * digits, and falls asleep. What is the last number that she will name before
 * falling asleep? If she will count forever, print INSOMNIA instead.
 *
 * Input
 *
 * The first line of the input gives the number of test cases, T. T test cases
 * follow. Each consists of one line with a single integer N, the number
 * Bleatrix has chosen.
 *
 * Output
 *
 * For each test case, output one line containing Case #x: y, where x is the
 * test case number (starting from 1) and y is the last number that Bleatrix
 * will name before falling asleep, according to the rules described in the
 * statement.
 *
 * Limits
 *
 * 1 ≤ T ≤ 100. Small dataset
 *
 * 0 ≤ N ≤ 200. Large dataset
 *
 * 0 ≤ N ≤ 106. Sample
 *
 *
 * Input * Output * 5 0 1 2 11 1692
 *
 * Case #1: INSOMNIA Case #2: 10 Case #3: 90 Case #4: 110 Case #5: 5076
 *
 *
 * In Case #1, since 2 × 0 = 0, 3 × 0 = 0, and so on, Bleatrix will never see
 * any digit other than 0, and so she will count forever and never fall asleep.
 * Poor sheep!
 *
 * In Case #2, Bleatrix will name 1, 2, 3, 4, 5, 6, 7, 8, 9, 10. The 0 will be
 * the last digit needed, and so she will fall asleep after 10.
 *
 * In Case #3, Bleatrix will name 2, 4, 6... and so on. She will not see the
 * digit 9 in any number until 90, at which point she will fall asleep. By that
 * point, she will have already seen the digits 0, 1, 2, 3, 4, 5, 6, 7, and 8,
 * which will have appeared for the first time in the numbers 10, 10, 2, 30, 4,
 * 50, 6, 70, and 8, respectively.
 *
 * In Case #4, Bleatrix will name 11, 22, 33, 44, 55, 66, 77, 88, 99, 110 and
 * then fall asleep.
 *
 * Case #5 is the one described in the problem statement. Note that it would
 * only show up in the Large dataset, and not in the Small dataset.
 */
public class CountingSheep {

    private static String[] results;    

    public static void main(String[] args) throws Exception {
        Scanner scanner = new Scanner(new BufferedReader(new FileReader(args[0])));
        int cases = scanner.nextInt();
        results = new String[cases];
        ExecutorService pool = Executors.newFixedThreadPool(100);
        for (int caseNum = 1; caseNum <= cases; caseNum++) {
            pool.submit(new SingleIteration(caseNum, scanner.nextLong()));
        }
        pool.shutdown();
        while(!pool.isTerminated()) {
            pool.awaitTermination(10, TimeUnit.SECONDS);
        }
        for (int i = 0; i < results.length; i++) {
            System.out.printf("Case #%d: %s\n", (i + 1), results[i]);
        }
    }
    
    private static class SingleIteration implements Runnable {
        private int caseNumber;
        private Long N;

        public SingleIteration(int caseNumber, Long n) {
            this.caseNumber = caseNumber;
            this.N = n;
        }
        
        @Override
        public void run() {
            try {
                String result = "INSOMNIA";
                if(N != 0) {
                    Set<String> sawNumbers = new HashSet<String>();
                    int x = 0;
                    String multiplication;
                    do {
                        multiplication = String.valueOf(N * (++x));
                        for (String s : multiplication.split("")) {
                            sawNumbers.add(s);
                        }
                    } while(sawNumbers.size() != 10);
                    result = multiplication;
                }
                results[caseNumber - 1] = result;
            } catch (Throwable t) {
                System.out.println("# " + caseNumber);
                System.out.println(N);
                t.printStackTrace();
                System.exit(1);
            }
        }
    }
}
