
import java.io.BufferedReader;
import java.io.FileReader;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

public class DeceitfulWar {

    public static void main(String[] args) throws Exception {
        BufferedReader reader = new BufferedReader(new FileReader(args[0]));
        int cases = Integer.valueOf(reader.readLine());
        for (int caseNum = 1; caseNum <= cases; caseNum++) {
            System.out.print("Case #" + caseNum + ":");
            int blocks = Integer.valueOf(reader.readLine());
            List<Double> naomisBlocks = readBlockWeigh(blocks, reader.readLine());
            List<Double> kensBlocks = readBlockWeigh(blocks, reader.readLine());
            System.out.print(" " + playWar(blocks, new DeceitfulWarNaomiStrategy(naomisBlocks), new KenStrategy(kensBlocks)));
            System.out.println(" " + playWar(blocks, new WarNaomiStrategy(naomisBlocks), new KenStrategy(kensBlocks)));
        }
    }

    public static int playWar(int blocks, NaomiStrategy naomis, KenStrategy kens) {
        int naomisPoints = 0;
        for (int i = 0; i < blocks; i++) {
            double[] weighs = naomis.getNextBlockWeighs(kens.blocks);
            double real = weighs[0];
            double toTell = weighs[1];
            double kensBlockWeigh = kens.getNextBlockWeigh(toTell);
            if (real > kensBlockWeigh) {
                naomisPoints++;
            }
        }
        return naomisPoints;
    }

    /**
     * Naomis strategy will return 2 weighs:
     *  - The one that will compare to ken's block
     *  - The one that will tell to ken
     */
    public static interface NaomiStrategy {
        public double[] getNextBlockWeighs(List<Double> kenRemainingBlocks);
    }

    public static class WarNaomiStrategy implements NaomiStrategy {

        List<Double> blocks;

        public WarNaomiStrategy(List<Double> blocks) {
            this.blocks = new LinkedList<Double>(blocks);
        }

        @Override
        public double[] getNextBlockWeighs(List<Double> kenRemainingBlocks) {            
            double next = blocks.remove(0);
            return new double[]{next, next};
        }
    }
    
    public static class DeceitfulWarNaomiStrategy implements NaomiStrategy {

        List<Double> blocks;

        public DeceitfulWarNaomiStrategy(List<Double> blocks) {
            this.blocks = new LinkedList<Double>(blocks);
            Collections.sort(this.blocks);
            Collections.reverse(this.blocks);
        }

        @Override
        public double[] getNextBlockWeighs(List<Double> kenRemainingBlocks) {
            if (blocks.get(blocks.size() -1) < kenRemainingBlocks.get(kenRemainingBlocks.size() - 1)) {
                double weigh = blocks.remove(blocks.size() -1);
                double kensHeavierBlock = kenRemainingBlocks.get(0);
                return new double[] {weigh, kensHeavierBlock - 0.0000001};
            } else {
                double weigh = blocks.remove(blocks.size() - 1);
                double kensHeavierBlock = kenRemainingBlocks.get(0);
                return new double[] {weigh, kensHeavierBlock + 0.0000001};                
            }
        }
    }
    
    /**
     * If he cant win, he will use the lighter block.
     * If he can win, he will use the lighter block that can win.
     */
    public static class KenStrategy {

        List<Double> blocks;

        public KenStrategy(List<Double> sortedWeighs) {
            this.blocks = new LinkedList<Double>(sortedWeighs);
            Collections.sort(blocks);
            Collections.reverse(blocks);
        }

        public double getNextBlockWeigh(double whatNaomiTells) {
            return blocks.remove(getNextBlockPosition(whatNaomiTells, blocks));
        }

        public int getNextBlockPosition(double weigh, List<Double> weighs) {
            for (int i = weighs.size() - 1; i >= 0; i--) {
                if (weighs.get(i) > weigh) {
                    return i;
                }
            }
            return weighs.size() - 1;
        }
    }

    public static List<Double> readBlockWeigh(int blocks, String line) {
        String[] split = line.split(" ");
        List<Double> weighs = new ArrayList<Double>(blocks);
        for (int i = 0; i < blocks; i++) {
            weighs.add(Double.valueOf(split[i]));
        }
        return weighs;
    }
}
