
import java.io.BufferedReader;
import java.io.FileReader;

public class MinesweeperMaster {

    public enum CellValue {

        CLICK("c"),
        EMPTY("."),
        MINE("*");
        String rep;

        private CellValue(String rep) {
            this.rep = rep;
        }
    }

    public static void main(String[] args) throws Exception {
        BufferedReader reader = new BufferedReader(new FileReader(args[0]));
        int cases = Integer.valueOf(reader.readLine());
        for (int caseNum = 1; caseNum <= cases; caseNum++) {
            System.out.println("Case #" + caseNum + ": ");
            String[] caseInfo = reader.readLine().split(" ");
            int rows = Integer.valueOf(caseInfo[0]);
            int columns = Integer.valueOf(caseInfo[1]);
            int mines = Integer.valueOf(caseInfo[2]);
            CellValue[][] matrix = createMatrix(rows, columns);
            int leftover = putMines(mines, matrix);
            if (leftover > 0) {
                System.out.println("Impossible");
            } else {
                draw(matrix);
            }
        }
    }

    public static int putMines(int mines, CellValue[][] matrix) {
        if (matrix[0].length == 1) {
            for (int r = matrix.length - 1; mines > 0; mines--, r--) {
                matrix[r][0] = CellValue.MINE;
            }
        } else if (matrix.length == 1) {
            for (int c = matrix[0].length - 1; mines > 0 && c > 1; mines--, c--) {
                matrix[0][c] = CellValue.MINE;
            }
        } else {
            int colnum = -1;
            int rownum = -1;
            if (matrix[0].length > 2 && matrix.length > 2) {
                for (; mines > 0; mines--) {
                    if (colnum == -1) {
                        colnum = matrix[0].length - 1;
                        rownum = matrix.length - 1;
                    } else {
                        colnum--;
                        if (colnum == 1) {
                            colnum = matrix[0].length - 1;
                            rownum--;
                        }
                    }
                    if (rownum == 1) {
                        break;
                    }
                    matrix[rownum][colnum] = CellValue.MINE;
                }
            }
            for (int r = matrix.length - 1; mines > 1 && r > 1; mines -= 2, r--) {
                if (r == 1) {
                    break;
                }
                matrix[r][0] = CellValue.MINE;
                matrix[r][1] = CellValue.MINE;
            }
            for (int c = matrix[0].length - 1; mines > 1 && c > 1; mines -= 2, c--) {
                if (c == 1) {
                    break;
                }
                matrix[0][c] = CellValue.MINE;
                matrix[1][c] = CellValue.MINE;
            }
        }
        return mines;
    }

    private static CellValue[][] createMatrix(int rows, int columns) {
        CellValue[][] values = new CellValue[rows][];
        for (int i = 0; i < values.length; i++) {
            CellValue[] col = new CellValue[columns];
            for (int j = 0; j < col.length; j++) {
                col[j] = CellValue.EMPTY;
            }
            values[i] = col;
        }
        values[0][0] = CellValue.CLICK;
        return values;
    }

    public static void draw(CellValue[][] matrix) {
        for (CellValue[] cellValues : matrix) {
            for (CellValue cellValue : cellValues) {
                System.out.print(cellValue.rep);
            }
            System.out.println("");
        }
    }
}
