import java.util.*;
import java.io.*;

public class C implements Runnable {
	private final String problemID = getClass().getName().toUpperCase();
	private final String problemType = "small";
	private BufferedReader in;
	private PrintWriter out;
	private StringTokenizer st;
	
	private boolean[][] field, removed;
	private int[][] left, upper, square;
	private int[] answer;
	private int n, m;
	
	private void readField() throws IOException {
		m = nextInt();
		n = nextInt();
		field = new boolean[m][n];
		for (int i = 0; i < m; i++) {
			String line = nextToken();
			for (int j = 0; j < n / 4; j++) {
				char ch = line.charAt(j);
				int num = ('0' <= ch && ch <= '9') ? ch - '0' : ch - 'A' + 10;
				field[i][4 * j] = ((num & 8) != 0);
				field[i][4 * j + 1] = ((num & 4) != 0);
				field[i][4 * j + 2] = ((num & 2) != 0);
				field[i][4 * j + 3] = ((num & 1) != 0);
			}
		}
	}
	
	private boolean scanField() throws IOException {
		int maxSize = 0;
		int minX = -1;
		int minY = -1;
		
		for (int i = 0; i < m; i++) {
			for (int j = 0; j < n; j++) {
				if (removed[i][j]) {
					continue;
				}
				left[i][j] = 1;
				if (j > 0 && field[i][j - 1] != field[i][j] && !removed[i][j - 1]) {
					left[i][j] = left[i][j - 1] + 1;
				}
				upper[i][j] = 1;
				if (i > 0 && field[i - 1][j] != field[i][j] && !removed[i - 1][j]) {
					upper[i][j] = upper[i - 1][j] + 1;
				}
				
				square[i][j] = 1;
				if (i > 0 && j > 0 && field[i - 1][j - 1] == field[i][j] && !removed[i - 1][j - 1]) {
					square[i][j] = Math.min(square[i - 1][j - 1] + 1, Math.min(left[i][j], upper[i][j]));
				}
				
				int cornerX = i - square[i][j] + 1;
				int cornerY = j - square[i][j] + 1;
				
				boolean good = (cornerX < minX) || ((cornerX == minX) && (cornerY < minY));
				if (square[i][j] > maxSize || ((square[i][j] == maxSize) && good)) {
					maxSize = square[i][j];
					minX = cornerX;
					minY = cornerY;
				}
			}
		}
		if (maxSize < 1) {
			return false;
		}
		
		removeSquare(minX, minY, maxSize);
		answer[maxSize]++;
		return true;
	}
	
	private void removeSquare(int x0, int y0, int size) {
		for (int i = x0; i < x0 + size; i++) {
			for (int j = y0; j < y0 + size; j++) {
				removed[i][j] = true;
			}
		}
	}

	private void solveSingleTest(int testNumber) throws IOException {
		readField();
		
		left = new int[m][n];
		upper = new int[m][n];
		square = new int[m][n];
		removed = new boolean[m][n];
		answer = new int[Math.max(n, m) + 1];
		
		while (scanField()) ;
		
		int k = 0;
		for (int i = 0; i < answer.length; i++) {
			if (answer[i] > 0) {
				k++;
			}
		}
		out.println("Case #" + testNumber + ": " + k);
		for (int i = answer.length - 1; i >= 0; i--) {
			if (answer[i] > 0) {
				out.println(i + " " + answer[i]);
			}
		}
	}
	
	private String nextToken() throws IOException {
		while (st == null || !st.hasMoreTokens()) {
			st = new StringTokenizer(in.readLine());
		}
		return st.nextToken();
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(nextToken());
	}
	
	public static void main(String[] args) {
		new Thread(new C()).start();
	}

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	private void solve() throws IOException {
		in = new BufferedReader(new FileReader(new File(problemID + "-" + problemType + ".in")));
		out = new PrintWriter(new File(problemID + "-" + problemType + ".out"));
		
		int testsNumber = nextInt();
		for (int i = 0; i < testsNumber; i++) {
			solveSingleTest(i + 1);
		}
		
		in.close();
		out.close();
	}
}
