import java.util.*;
import java.io.*;

public class Dsmall implements Runnable {
	private final String problemID = getClass().getName().toUpperCase();
	private final String problemType = "small";
	private BufferedReader in;
	private PrintWriter out;
	private StringTokenizer st;
	
	private double sp(double x1, double y1, double x2, double y2) {
		return x1 * x2 + y1 * y2;
	}
	
	private double vp(double x1, double y1, double x2, double y2) {
		return x1 * y2 - x2 * y1;
	}
	
	private void solveSingleTest(int testNumber) throws IOException {
		int n = nextInt();
		int m = nextInt();
		if (n != 2) {
			throw new Error();
		}
		double x1 = nextInt();
		double y1 = nextInt();
		double x2 = nextInt();
		double y2 = nextInt();
		out.print("Case #" + testNumber + ":");
		for (int i = 0; i < m; i++) {
			double px = nextInt();
			double py = nextInt();
			
			double dist = Math.hypot(x2 - x1, y2 - y1);
			
			double r1 = Math.hypot(px - x1, py - y1);
			double r2 = Math.hypot(px - x2, py - y2);
			
			double sp = sp(px - x1, py - y1, x2 - x1, y2 - y1);
			double vp = vp(px - x1, py - y1, x2 - x1, y2 - y1);
			double angle = Math.abs(Math.atan2(vp, sp));
			double area1 = r1 * r1 * (angle - Math.sin(2 * angle) / 2);
			
			sp = sp(px - x2, py - y2, x1 - x2, y1 - y2);
			vp = vp(px - x2, py - y2, x1 - x2, y1 - y2);
			angle = Math.abs(Math.atan2(vp, sp));
			double area2 = r2 * r2 * (angle - Math .sin(2 * angle) / 2);
			
			double xx = x1 + (x2 - x1) * r1 / dist; 
			double yy = y1 + (y2 - y1) * r1 / dist;
			if (Math.hypot(xx - x2, yy - y2) > r2) {
				area1 = Math.PI * r1 * r1 - area1;
			}
			
			xx = x2 + (x1 - x2) * r2 / dist; 
			yy = y2 + (y1 - y2) * r2 / dist;
			if (Math.hypot(xx - x1, yy - y1) > r1) {
				area2 = Math.PI * r2 * r2 - area2;
			}
			
			out.printf(" %.8f", area1 + area2);
		}
		out.println();
	}
	
	private String nextToken() throws IOException {
		while (st == null || !st.hasMoreTokens()) {
			st = new StringTokenizer(in.readLine());
		}
		return st.nextToken();
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(nextToken());
	}
	
	public static void main(String[] args) {
		new Thread(new Dsmall()).start();
	}

	public void run() {
		try {
			Locale.setDefault(Locale.US);
			solve();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	private void solve() throws IOException {
		in = new BufferedReader(new FileReader(new File("d-small.in")));
		out = new PrintWriter(new File("d-small.out"));
		
		int testsNumber = nextInt();
		for (int i = 0; i < testsNumber; i++) {
			solveSingleTest(i + 1);
		}
		
		in.close();
		out.close();
	}
}
