import java.util.*;
import java.io.*;

public class D implements Runnable {
	private BufferedReader in;
	private PrintWriter out;
	private String problemID = getClass().getName().toLowerCase().split("_")[0] + "-small-attempt1";
	private StringTokenizer st;
	private static final double eps = 1e-6;
	private double[] x, y, r;
	private int n;
	
	private class Point {
		public double x, y;
		
		public Point(double x, double y) {
			this.x = x;
			this.y = y;
		}
	}
	
	public Point[] intersectCircles(double x1, double y1, double r1, double x2, double y2, double r2) {
		double a = -2 * (x1 - x2);
		double b = -2 * (y1 - y2);
		double c = x1 * x1 + y1 * y1 - r1 * r1 - x2 * x2 - y2 * y2 + r2 * r2;
		
		if (Math.abs(a) < eps  && Math.abs(b) < eps) {
			return new Point[] { };
		}
		
		double d = Math.sqrt(a * a + b * b);
		a /= d;
		b /= d;
		c /= d;
		
		double x0 = -a * c;
		double y0 = -b * c;
		
		double p = -b * (x0 - x1) + a * (y0 - y1);
		double q = (x0 - x1) * (x0 - x1) + (y0 - y1) * (y0 - y1) - r1 * r1;
		d = p * p - q;
		if (d < -eps) {
			return new Point[] { };
		} else if (Math.abs(d) < eps) {
			return new Point[] { new Point(x0 + b * p, y0 - a * p) };
		} else {
			double t1 = -p + Math.sqrt(d);
			double t2 = -p - Math.sqrt(d);
			Point p1 = new Point(x0 - b * t1, y0 + a * t1);
			Point p2 = new Point(x0 - b * t2, y0 + a * t2);
			return new Point[] { p1, p2 };
		}
	}
	
	private double solve2() {
		if (n == 1) {
			return r[0];
		} else if (n == 2) {
			return Math.max(r[0], r[1]);
		}
		
		double low = 0;
		double hi = 2000;
		while (true) {
			double middle = (low + hi) / 2;
			if (low == middle || middle == hi || low == hi) {
				break;
			}
			if (check(middle)) {
				hi = middle;
			} else {
				low = middle;
			}
		}
		return hi;
	}

	
	private boolean check(double r0) {
		List<Point> points = new ArrayList<Point>();
		for (int i = 0; i < n; i++) {
			for (int j = i + 1; j < n; j++) {
				if (r0 < r[i] || r0 < r[j]) {
					continue;
				}
				Point[] tmp = intersectCircles(x[i], y[i], r0 - r[i], x[j], y[j], r0 - r[j]);
				for (int z = 0; z < tmp.length; z++) {
					points.add(tmp[z]);
				}
			}
			points.add(new Point(x[i], y[i]));
		}
		
		for (int i = 0; i < points.size(); i++) {
			LOOP:			
			for (int j = i + 1; j < points.size(); j++) {
				Point p1 = points.get(i);
				Point p2 = points.get(j);
				for (int u = 0; u < n; u++) {
					boolean inside1 = (Math.hypot(p1.x - x[u], p1.y - y[u]) + r[u] < r0 + eps);
					boolean inside2 = (Math.hypot(p2.x - x[u], p2.y - y[u]) + r[u] < r0 + eps);
					if (inside1 || inside2) {
						continue;
					}
					continue LOOP;
				}
				return true;
			}
		}
		return false;
	}

	private void solveSingleTest(int testNumber) throws IOException {
		n = nextInt();
		x = new double[n];
		y = new double[n];
		r = new double[n];
		for (int i = 0; i < n; i++) {
			x[i] = nextInt();
			y[i] = nextInt();
			r[i] = nextInt();
		}
		double answer = solve2();
		out.printf("Case #%d: %.6f\n", testNumber, answer);
	}


	private String nextToken() throws IOException {
		while (st == null || !st.hasMoreTokens()) {
			st = new StringTokenizer(in.readLine());
		}
		return st.nextToken();
	}
	
	private int nextInt() throws IOException {
		return Integer.parseInt(nextToken());
	}
	
	private void solve() throws IOException {
		int tests = nextInt();
		for (int i = 0; i < tests; i++) {
			solveSingleTest(i + 1);
		}
	}
	
	public void run() {
		try {
			Locale.setDefault(Locale.US);
			in = new BufferedReader(new FileReader(new File(problemID + ".in")));
			out = new PrintWriter(new File(problemID + ".out"));
			solve();
			in.close();
			out.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
	
	public static void main(String[] args) {
		new Thread(new D()).start();
	}
}
