import java.util.*;
import java.io.*;

public class Fly implements Runnable {
	private static final double eps = 1e-6;
	private final String problemName = getClass().getName().toLowerCase() + "_1";
	private BufferedReader in;
	private PrintWriter out;
	
	private class Point implements Comparable<Point> {
		public double x, y;
		
		public Point(double x, double y) {
			this.x = x;
			this.y = y;
		}

		public int compareTo(Point that) {
			return Double.compare(this.x, that.x);
		}
	}
	
	private List<Point> intersectSegmentAndCircle(double x1, double y1, double x2, double y2, double r) {
		double dx = x2 - x1;
		double dy = y2 - y1;
		double a = dx * dx + dy * dy;
		double b = 2 * dx * x1 + 2 * dy * y1;
		double c = x1 * x1 + y1 * y1 - r * r;
		double d = b * b - 4 * a * c;
		if (d < -eps) {
			return new ArrayList<Point>();
		}
		if (d < eps) {
			d = 0.0;
		} else {
			d = Math.sqrt(d);
		}
		double t1 = (-b + d) / 2 / a;
		double t2 = (-b - d) / 2 / a;
		List<Point> result = new ArrayList<Point>();
		if (-eps < t1 && t1 < 1 + eps) {
			result.add(new Point(x1 + t1 * dx, y1 + t1 * dy));
		}
		if (-eps < t2 && t2 < 1 + eps) {
			result.add(new Point(x1 + t2 * dx, y1 + t2 * dy));
		}
		return result;
	}
	
	private void solveSingleTest(int testNumber) throws IOException {
		Scanner sc = new Scanner(in.readLine());
		double f = sc.nextDouble();
		double R = sc.nextDouble();
		double t = sc.nextDouble();
		double r = sc.nextDouble();
		double g = sc.nextDouble();
		
		if (g < 2 * f + eps || t + f > R + eps) {
			out.println("Case #" + testNumber + ": 1.0");
			return;
		}
		f /= R;
		t /= R;
		r /= R;
		g /= R;
		R = 1.0;
		
		double totalArea = Math.PI * R * R;
		double startPos = r;
		while (startPos > -R) {
			startPos = startPos - 2 * r - g;
		}
		double goodArea = 0.0;
		for (double x1 = startPos; x1 < R; x1 += 2 * r + g) {
			for (double y1 = startPos; y1 < R; y1 += 2 * r + g) {
				double addon = intersectSquareAndCircle(x1 + f, y1 + f, g - 2 * f, R - t - f);
				goodArea = goodArea + addon;
			}
		}
		double answer = (1.0 - goodArea / totalArea);
		if (answer < 0) {
			throw new Error();
		}
		out.println("Case #" + testNumber + ": " + answer);
	}
	
	private double intersectSquareAndCircle(double x1, double y1, double side, double r) {
		List<Point> p = new ArrayList<Point>();
		p.addAll(intersectSegmentAndCircle(x1, y1, x1 + side, y1, r));
		p.addAll(intersectSegmentAndCircle(x1 + side, y1, x1 + side, y1 + side, r));
		p.addAll(intersectSegmentAndCircle(x1 + side, y1 + side, x1, y1 + side, r));
		p.addAll(intersectSegmentAndCircle(x1, y1 + side, x1, y1, r));
		p.add(new Point(-r, 0));
		p.add(new Point(r, 0));
		p.add(new Point(0, r));
		p.add(new Point(0, -r));
		p.add(new Point(x1, y1));
		p.add(new Point(x1 + side, y1 + side));
		Collections.sort(p);
		
		double answer = 0.0;
		for (int i = 0; i + 1 < p.size(); i++) {
			if (p.get(i).x + eps < p.get(i + 1).x) {
				double from = p.get(i).x;
				double to = p.get(i + 1).x;
				
				if (to < x1 + eps || from + eps > x1 + side) {
					continue;
				}
				
				if (to < -r + eps || from + eps > r) {
					continue;
				}
				
				double y1c = circleUpper(r, from);
				double y2c = -circleUpper(r, from);
				double z1c = circleUpper(r, to);
				double z2c = -circleUpper(r, to);
				double y1l = y1 + side;
				double y2l = y1;
				double z1l = y1 + side;
				double z2l = y1;
				
				if (isAbove(y2c, z2c, y1l, z1l) || isAbove(y2l, z2l, y1c, z1c)) {
					continue;
				}
				
				double addon = 0.0;
				if (isAbove(y1l, z1l, y1c, z1c)) {
					addon += areaCircle(from, to, r);
				} else {
					addon += areaLine(from, to, y1l);
				}
				if (isAbove(y2c, z2c, y2l, z2l)) {
					addon += areaCircle(from, to, r);
				} else {
					addon -= areaLine(from, to, y2l);
				}
				answer += addon;
			}
		}
//		System.out.println("[debug] Square = (" + x1 + " " + y1 + ") side = " + side + " and circle r = " + r + ": answer = " + answer);
		return answer;
	}

	private boolean isAbove(double x1, double y1, double x2, double y2) {
		if (x1 > x2 + eps) {
			return true;
		}
		if (x1 < x2 - eps) {
			return false;
		}
		return (y1 > y2 + eps);
	}

	private double areaLine(double from, double to, double y) {
		return (to - from) * y;
	}

	private double areaCircle(double from, double to, double r) {
		if (to < eps) {
			double tmp = from;
			from = to;
			to = tmp;
			from = -from;
			to = -to;
		}
		return (areaZero(to, r) - areaZero(from, r)) / 2;
	}

	private double areaZero(double to, double r) {
		double t = to * Math.sqrt(r * r - to * to);
		double alpha = Math.acos(to / r);
		double hat = alpha * r * r - t;
		return Math.PI * r * r / 2 - hat;
	}

	private double circleUpper(double r, double x) {
		return Math.sqrt(r * r - x * x);
	}

	public static void main(String[] args) {
		new Thread(new Fly()).start();
	}

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	private void solve() throws IOException {
		Locale.setDefault(Locale.US);
		in = new BufferedReader(new FileReader(new File(problemName + ".in")));
		out = new PrintWriter(new File(problemName + ".out"));
		
		int tests = Integer.parseInt(in.readLine());
		for (int test = 1; test <= tests; test++) {
			solveSingleTest(test);
		}
		
		in.close();
		out.close();
	}
}
